crs2epsg = {
"Anguilla 1957 / British West Indies Grid":"2000",
"Antigua 1943 / British West Indies Grid":"2001",
"Dominica 1945 / British West Indies Grid":"2002",
"Grenada 1953 / British West Indies Grid":"2003",
"Montserrat 1958 / British West Indies Grid":"2004",
"St. Kitts 1955 / British West Indies Grid":"2005",
"St. Lucia 1955 / British West Indies Grid":"2006",
"St. Vincent 45 / British West Indies Grid":"2007",
"NAD27(CGQ77) / SCoPQ zone 2":"2008",
"NAD27(CGQ77) / SCoPQ zone 3":"2009",
"NAD27(CGQ77) / SCoPQ zone 4":"2010",
"NAD27(CGQ77) / SCoPQ zone 5":"2011",
"NAD27(CGQ77) / SCoPQ zone 6":"2012",
"NAD27(CGQ77) / SCoPQ zone 7":"2013",
"NAD27(CGQ77) / SCoPQ zone 8":"2014",
"NAD27(CGQ77) / SCoPQ zone 9":"2015",
"NAD27(CGQ77) / SCoPQ zone 10":"2016",
"NAD27(76) / MTM zone 8":"2017",
"NAD27(76) / MTM zone 9":"2018",
"NAD27(76) / MTM zone 10":"2019",
"NAD27(76) / MTM zone 11":"2020",
"NAD27(76) / MTM zone 12":"2021",
"NAD27(76) / MTM zone 13":"2022",
"NAD27(76) / MTM zone 14":"2023",
"NAD27(76) / MTM zone 15":"2024",
"NAD27(76) / MTM zone 16":"2025",
"NAD27(76) / MTM zone 17":"2026",
"NAD27(76) / UTM zone 15N":"2027",
"NAD27(76) / UTM zone 16N":"2028",
"NAD27(76) / UTM zone 17N":"2029",
"NAD27(76) / UTM zone 18N":"2030",
"NAD27(CGQ77) / UTM zone 17N":"2031",
"NAD27(CGQ77) / UTM zone 18N":"2032",
"NAD27(CGQ77) / UTM zone 19N":"2033",
"NAD27(CGQ77) / UTM zone 20N":"2034",
"NAD27(CGQ77) / UTM zone 21N":"2035",
"NAD83(CSRS98) / New Brunswick Stereo":"2036",
"NAD83(CSRS98) / UTM zone 19N":"2037",
"NAD83(CSRS98) / UTM zone 20N":"2038",
"Israel 1993 / Israeli TM Grid":"2039",
"Locodjo 1965 / UTM zone 30N":"2040",
"Abidjan 1987 / UTM zone 30N":"2041",
"Locodjo 1965 / UTM zone 29N":"2042",
"Abidjan 1987 / UTM zone 29N":"2043",
"Hanoi 1972 / Gauss-Kruger zone 18":"2044",
"Hanoi 1972 / Gauss-Kruger zone 19":"2045",
"Hartebeesthoek94 / Lo15":"2046",
"Hartebeesthoek94 / Lo17":"2047",
"Hartebeesthoek94 / Lo19":"2048",
"Hartebeesthoek94 / Lo21":"2049",
"Hartebeesthoek94 / Lo23":"2050",
"Hartebeesthoek94 / Lo25":"2051",
"Hartebeesthoek94 / Lo27":"2052",
"Hartebeesthoek94 / Lo29":"2053",
"Hartebeesthoek94 / Lo31":"2054",
"Hartebeesthoek94 / Lo33":"2055",
"CH1903+ / LV95":"2056",
"Rassadiran / Nakhl e Taqi":"2057",
"ED50(ED77) / UTM zone 38N":"2058",
"ED50(ED77) / UTM zone 39N":"2059",
"ED50(ED77) / UTM zone 40N":"2060",
"ED50(ED77) / UTM zone 41N":"2061",
"Madrid 1870 (Madrid) / Spain":"2062",
"Dabola 1981 / UTM zone 28N":"2063",
"Dabola 1981 / UTM zone 29N":"2064",
"S-JTSK (Ferro) / Krovak":"2065",
"Mount Dillon / Tobago Grid":"2066",
"Naparima 1955 / UTM zone 20N":"2067",
"ELD79 / Libya zone 5":"2068",
"ELD79 / Libya zone 6":"2069",
"ELD79 / Libya zone 7":"2070",
"ELD79 / Libya zone 8":"2071",
"ELD79 / Libya zone 9":"2072",
"ELD79 / Libya zone 10":"2073",
"ELD79 / Libya zone 11":"2074",
"ELD79 / Libya zone 12":"2075",
"ELD79 / Libya zone 13":"2076",
"ELD79 / UTM zone 32N":"2077",
"ELD79 / UTM zone 33N":"2078",
"ELD79 / UTM zone 34N":"2079",
"ELD79 / UTM zone 35N":"2080",
"Chos Malal 1914 / Argentina 2":"2081",
"Pampa del Castillo / Argentina 2":"2082",
"Hito XVIII 1963 / Argentina 2":"2083",
"Hito XVIII 1963 / UTM zone 19S":"2084",
"NAD27 / Cuba Norte":"2085",
"NAD27 / Cuba Sur":"2086",
"ELD79 / TM 12 NE":"2087",
"Carthage / TM 11 NE":"2088",
"Yemen NGN96 / UTM zone 38N":"2089",
"Yemen NGN96 / UTM zone 39N":"2090",
"South Yemen / Gauss Kruger zone 8":"2091",
"South Yemen / Gauss Kruger zone 9":"2092",
"Hanoi 1972 / GK 106 NE":"2093",
"WGS 72BE / TM 106 NE":"2094",
"Bissau / UTM zone 28N":"2095",
"Korean 1985 / East Belt":"2096",
"Korean 1985 / Central Belt":"2097",
"Korean 1985 / West Belt":"2098",
"Qatar 1948 / Qatar Grid":"2099",
"GGRS87 / Greek Grid":"2100",
"Lake / Maracaibo Grid M1":"2101",
"Lake / Maracaibo Grid":"2102",
"Lake / Maracaibo Grid M3":"2103",
"Lake / Maracaibo La Rosa Grid":"2104",
"NZGD2000 / Mount Eden 2000":"2105",
"NZGD2000 / Bay of Plenty 2000":"2106",
"NZGD2000 / Poverty Bay 2000":"2107",
"NZGD2000 / Hawkes Bay 2000":"2108",
"NZGD2000 / Taranaki 2000":"2109",
"NZGD2000 / Tuhirangi 2000":"2110",
"NZGD2000 / Wanganui 2000":"2111",
"NZGD2000 / Wairarapa 2000":"2112",
"NZGD2000 / Wellington 2000":"2113",
"NZGD2000 / Collingwood 2000":"2114",
"NZGD2000 / Nelson 2000":"2115",
"NZGD2000 / Karamea 2000":"2116",
"NZGD2000 / Buller 2000":"2117",
"NZGD2000 / Grey 2000":"2118",
"NZGD2000 / Amuri 2000":"2119",
"NZGD2000 / Marlborough 2000":"2120",
"NZGD2000 / Hokitika 2000":"2121",
"NZGD2000 / Okarito 2000":"2122",
"NZGD2000 / Jacksons Bay 2000":"2123",
"NZGD2000 / Mount Pleasant 2000":"2124",
"NZGD2000 / Gawler 2000":"2125",
"NZGD2000 / Timaru 2000":"2126",
"NZGD2000 / Lindis Peak 2000":"2127",
"NZGD2000 / Mount Nicholas 2000":"2128",
"NZGD2000 / Mount York 2000":"2129",
"NZGD2000 / Observation Point 2000":"2130",
"NZGD2000 / North Taieri 2000":"2131",
"NZGD2000 / Bluff 2000":"2132",
"NZGD2000 / UTM zone 58S":"2133",
"NZGD2000 / UTM zone 59S":"2134",
"NZGD2000 / UTM zone 60S":"2135",
"Accra / Ghana National Grid":"2136",
"Accra / TM 1 NW":"2137",
"NAD27(CGQ77) / Quebec Lambert":"2138",
"NAD83(CSRS98) / SCoPQ zone 2":"2139",
"NAD83(CSRS98) / MTM zone 3":"2140",
"NAD83(CSRS98) / MTM zone 4":"2141",
"NAD83(CSRS98) / MTM zone 5":"2142",
"NAD83(CSRS98) / MTM zone 6":"2143",
"NAD83(CSRS98) / MTM zone 7":"2144",
"NAD83(CSRS98) / MTM zone 8":"2145",
"NAD83(CSRS98) / MTM zone 9":"2146",
"NAD83(CSRS98) / MTM zone 10":"2147",
"NAD83(CSRS98) / UTM zone 21N":"2148",
"NAD83(CSRS98) / UTM zone 18N":"2149",
"NAD83(CSRS98) / UTM zone 17N":"2150",
"NAD83(CSRS98) / UTM zone 13N":"2151",
"NAD83(CSRS98) / UTM zone 12N":"2152",
"NAD83(CSRS98) / UTM zone 11N":"2153",
"RGF93 / Lambert-93":"2154",
"American Samoa 1962 / American Samoa Lambert":"2155",
"NAD83(HARN) / UTM zone 59S":"2156",
"IRENET95 / Irish Transverse Mercator":"2157",
"IRENET95 / UTM zone 29N":"2158",
"Sierra Leone 1924 / New Colony Grid":"2159",
"Sierra Leone 1924 / New War Office Grid":"2160",
"Sierra Leone 1968 / UTM zone 28N":"2161",
"Sierra Leone 1968 / UTM zone 29N":"2162",
"US National Atlas Equal Area":"2163",
"Locodjo 1965 / TM 5 NW":"2164",
"Abidjan 1987 / TM 5 NW":"2165",
"Pulkovo 1942(83) / Gauss Kruger zone 3":"2166",
"Pulkovo 1942(83) / Gauss Kruger zone 4":"2167",
"Pulkovo 1942(83) / Gauss Kruger zone 5":"2168",
"Luxembourg 1930 / Gauss":"2169",
"MGI / Slovenia Grid":"2170",
"Pulkovo 1942(58) / Poland zone I":"2171",
"Pulkovo 1942(58) / Poland zone II":"2172",
"Pulkovo 1942(58) / Poland zone III":"2173",
"Pulkovo 1942(58) / Poland zone IV":"2174",
"Pulkovo 1942(58) / Poland zone V":"2175",
"ETRS89 / Poland CS2000 zone 5":"2176",
"ETRS89 / Poland CS2000 zone 6":"2177",
"ETRS89 / Poland CS2000 zone 7":"2178",
"ETRS89 / Poland CS2000 zone 8":"2179",
"ETRS89 / Poland CS92":"2180",
"Azores Occidental 1939 / UTM zone 25N":"2188",
"Azores Central 1948 / UTM zone 26N":"2189",
"Azores Oriental 1940 / UTM zone 26N":"2190",
"Madeira 1936 / UTM zone 28N":"2191",
"ED50 / France EuroLambert":"2192",
"NZGD2000 / New Zealand Transverse Mercator 2000":"2193",
"American Samoa 1962 / American Samoa Lambert":"2194",
"NAD83(HARN) / UTM zone 2S":"2195",
"ETRS89 / Kp2000 Jutland":"2196",
"ETRS89 / Kp2000 Zealand":"2197",
"ETRS89 / Kp2000 Bornholm":"2198",
"Albanian 1987 / Gauss Kruger zone 4":"2199",
"ATS77 / New Brunswick Stereographic (ATS77)":"2200",
"REGVEN / UTM zone 18N":"2201",
"REGVEN / UTM zone 19N":"2202",
"REGVEN / UTM zone 20N":"2203",
"NAD27 / Tennessee":"2204",
"NAD83 / Kentucky North":"2205",
"ED50 / 3-degree Gauss-Kruger zone 9":"2206",
"ED50 / 3-degree Gauss-Kruger zone 10":"2207",
"ED50 / 3-degree Gauss-Kruger zone 11":"2208",
"ED50 / 3-degree Gauss-Kruger zone 12":"2209",
"ED50 / 3-degree Gauss-Kruger zone 13":"2210",
"ED50 / 3-degree Gauss-Kruger zone 14":"2211",
"ED50 / 3-degree Gauss-Kruger zone 15":"2212",
"ETRS89 / TM 30 NE":"2213",
"Douala 1948 / AOF west":"2214",
"Manoca 1962 / UTM zone 32N":"2215",
"Qornoq 1927 / UTM zone 22N":"2216",
"Qornoq 1927 / UTM zone 23N":"2217",
"Scoresbysund 1952 / Greenland zone 5 east":"2218",
"ATS77 / UTM zone 19N":"2219",
"ATS77 / UTM zone 20N":"2220",
"Scoresbysund 1952 / Greenland zone 6 east":"2221",
"NAD83 / Arizona East (ft)":"2222",
"NAD83 / Arizona Central (ft)":"2223",
"NAD83 / Arizona West (ft)":"2224",
"NAD83 / California zone 1 (ftUS)":"2225",
"NAD83 / California zone 2 (ftUS)":"2226",
"NAD83 / California zone 3 (ftUS)":"2227",
"NAD83 / California zone 4 (ftUS)":"2228",
"NAD83 / California zone 5 (ftUS)":"2229",
"NAD83 / California zone 6 (ftUS)":"2230",
"NAD83 / Colorado North (ftUS)":"2231",
"NAD83 / Colorado Central (ftUS)":"2232",
"NAD83 / Colorado South (ftUS)":"2233",
"NAD83 / Connecticut (ftUS)":"2234",
"NAD83 / Delaware (ftUS)":"2235",
"NAD83 / Florida East (ftUS)":"2236",
"NAD83 / Florida West (ftUS)":"2237",
"NAD83 / Florida North (ftUS)":"2238",
"NAD83 / Georgia East (ftUS)":"2239",
"NAD83 / Georgia West (ftUS)":"2240",
"NAD83 / Idaho East (ftUS)":"2241",
"NAD83 / Idaho Central (ftUS)":"2242",
"NAD83 / Idaho West (ftUS)":"2243",
"NAD83 / Indiana East (ftUS)":"2244",
"NAD83 / Indiana West (ftUS)":"2245",
"NAD83 / Kentucky North (ftUS)":"2246",
"NAD83 / Kentucky South (ftUS)":"2247",
"NAD83 / Maryland (ftUS)":"2248",
"NAD83 / Massachusetts Mainland (ftUS)":"2249",
"NAD83 / Massachusetts Island (ftUS)":"2250",
"NAD83 / Michigan North (ft)":"2251",
"NAD83 / Michigan Central (ft)":"2252",
"NAD83 / Michigan South (ft)":"2253",
"NAD83 / Mississippi East (ftUS)":"2254",
"NAD83 / Mississippi West (ftUS)":"2255",
"NAD83 / Montana (ft)":"2256",
"NAD83 / New Mexico East (ftUS)":"2257",
"NAD83 / New Mexico Central (ftUS)":"2258",
"NAD83 / New Mexico West (ftUS)":"2259",
"NAD83 / New York East (ftUS)":"2260",
"NAD83 / New York Central (ftUS)":"2261",
"NAD83 / New York West (ftUS)":"2262",
"NAD83 / New York Long Island (ftUS)":"2263",
"NAD83 / North Carolina (ftUS)":"2264",
"NAD83 / North Dakota North (ft)":"2265",
"NAD83 / North Dakota South (ft)":"2266",
"NAD83 / Oklahoma North (ftUS)":"2267",
"NAD83 / Oklahoma South (ftUS)":"2268",
"NAD83 / Oregon North (ft)":"2269",
"NAD83 / Oregon South (ft)":"2270",
"NAD83 / Pennsylvania North (ftUS)":"2271",
"NAD83 / Pennsylvania South (ftUS)":"2272",
"NAD83 / South Carolina (ft)":"2273",
"NAD83 / Tennessee (ftUS)":"2274",
"NAD83 / Texas North (ftUS)":"2275",
"NAD83 / Texas North Central (ftUS)":"2276",
"NAD83 / Texas Central (ftUS)":"2277",
"NAD83 / Texas South Central (ftUS)":"2278",
"NAD83 / Texas South (ftUS)":"2279",
"NAD83 / Utah North (ft)":"2280",
"NAD83 / Utah Central (ft)":"2281",
"NAD83 / Utah South (ft)":"2282",
"NAD83 / Virginia North (ftUS)":"2283",
"NAD83 / Virginia South (ftUS)":"2284",
"NAD83 / Washington North (ftUS)":"2285",
"NAD83 / Washington South (ftUS)":"2286",
"NAD83 / Wisconsin North (ftUS)":"2287",
"NAD83 / Wisconsin Central (ftUS)":"2288",
"NAD83 / Wisconsin South (ftUS)":"2289",
"ATS77 / Prince Edward Isl. Stereographic (ATS77)":"2290",
"NAD83(CSRS98) / Prince Edward Isl. Stereographic (NAD83)":"2291",
"NAD83(CSRS98) / Prince Edward Isl. Stereographic (NAD83)":"2292",
"ATS77 / MTM Nova Scotia zone 4":"2294",
"ATS77 / MTM Nova Scotia zone 5":"2295",
"Ammassalik 1958 / Greenland zone 7 east":"2296",
"Qornoq 1927 / Greenland zone 1 east":"2297",
"Qornoq 1927 / Greenland zone 2 east":"2298",
"Qornoq 1927 / Greenland zone 2 west":"2299",
"Qornoq 1927 / Greenland zone 3 east":"2300",
"Qornoq 1927 / Greenland zone 3 west":"2301",
"Qornoq 1927 / Greenland zone 4 east":"2302",
"Qornoq 1927 / Greenland zone 4 west":"2303",
"Qornoq 1927 / Greenland zone 5 west":"2304",
"Qornoq 1927 / Greenland zone 6 west":"2305",
"Qornoq 1927 / Greenland zone 7 west":"2306",
"Qornoq 1927 / Greenland zone 8 east":"2307",
"Batavia / TM 109 SE":"2308",
"WGS 84 / TM 116 SE":"2309",
"WGS 84 / TM 132 SE":"2310",
"WGS 84 / TM 6 NE":"2311",
"Garoua / UTM zone 33N":"2312",
"Kousseri / UTM zone 33N":"2313",
"Trinidad 1903 / Trinidad Grid (ftCla)":"2314",
"Campo Inchauspe / UTM zone 19S":"2315",
"Campo Inchauspe / UTM zone 20S":"2316",
"PSAD56 / ICN Regional":"2317",
"Ain el Abd / Aramco Lambert":"2318",
"ED50 / TM27":"2319",
"ED50 / TM30":"2320",
"ED50 / TM33":"2321",
"ED50 / TM36":"2322",
"ED50 / TM39":"2323",
"ED50 / TM42":"2324",
"ED50 / TM45":"2325",
"Hong Kong 1980 Grid System":"2326",
"Xian 1980 / Gauss-Kruger zone 13":"2327",
"Xian 1980 / Gauss-Kruger zone 14":"2328",
"Xian 1980 / Gauss-Kruger zone 15":"2329",
"Xian 1980 / Gauss-Kruger zone 16":"2330",
"Xian 1980 / Gauss-Kruger zone 17":"2331",
"Xian 1980 / Gauss-Kruger zone 18":"2332",
"Xian 1980 / Gauss-Kruger zone 19":"2333",
"Xian 1980 / Gauss-Kruger zone 20":"2334",
"Xian 1980 / Gauss-Kruger zone 21":"2335",
"Xian 1980 / Gauss-Kruger zone 22":"2336",
"Xian 1980 / Gauss-Kruger zone 23":"2337",
"Xian 1980 / Gauss-Kruger CM 75E":"2338",
"Xian 1980 / Gauss-Kruger CM 81E":"2339",
"Xian 1980 / Gauss-Kruger CM 87E":"2340",
"Xian 1980 / Gauss-Kruger CM 93E":"2341",
"Xian 1980 / Gauss-Kruger CM 99E":"2342",
"Xian 1980 / Gauss-Kruger CM 105E":"2343",
"Xian 1980 / Gauss-Kruger CM 111E":"2344",
"Xian 1980 / Gauss-Kruger CM 117E":"2345",
"Xian 1980 / Gauss-Kruger CM 123E":"2346",
"Xian 1980 / Gauss-Kruger CM 129E":"2347",
"Xian 1980 / Gauss-Kruger CM 135E":"2348",
"Xian 1980 / 3-degree Gauss-Kruger zone 25":"2349",
"Xian 1980 / 3-degree Gauss-Kruger zone 26":"2350",
"Xian 1980 / 3-degree Gauss-Kruger zone 27":"2351",
"Xian 1980 / 3-degree Gauss-Kruger zone 28":"2352",
"Xian 1980 / 3-degree Gauss-Kruger zone 29":"2353",
"Xian 1980 / 3-degree Gauss-Kruger zone 30":"2354",
"Xian 1980 / 3-degree Gauss-Kruger zone 31":"2355",
"Xian 1980 / 3-degree Gauss-Kruger zone 32":"2356",
"Xian 1980 / 3-degree Gauss-Kruger zone 33":"2357",
"Xian 1980 / 3-degree Gauss-Kruger zone 34":"2358",
"Xian 1980 / 3-degree Gauss-Kruger zone 35":"2359",
"Xian 1980 / 3-degree Gauss-Kruger zone 36":"2360",
"Xian 1980 / 3-degree Gauss-Kruger zone 37":"2361",
"Xian 1980 / 3-degree Gauss-Kruger zone 38":"2362",
"Xian 1980 / 3-degree Gauss-Kruger zone 39":"2363",
"Xian 1980 / 3-degree Gauss-Kruger zone 40":"2364",
"Xian 1980 / 3-degree Gauss-Kruger zone 41":"2365",
"Xian 1980 / 3-degree Gauss-Kruger zone 42":"2366",
"Xian 1980 / 3-degree Gauss-Kruger zone 43":"2367",
"Xian 1980 / 3-degree Gauss-Kruger zone 44":"2368",
"Xian 1980 / 3-degree Gauss-Kruger zone 45":"2369",
"Xian 1980 / 3-degree Gauss-Kruger CM 75E":"2370",
"Xian 1980 / 3-degree Gauss-Kruger CM 78E":"2371",
"Xian 1980 / 3-degree Gauss-Kruger CM 81E":"2372",
"Xian 1980 / 3-degree Gauss-Kruger CM 84E":"2373",
"Xian 1980 / 3-degree Gauss-Kruger CM 87E":"2374",
"Xian 1980 / 3-degree Gauss-Kruger CM 90E":"2375",
"Xian 1980 / 3-degree Gauss-Kruger CM 93E":"2376",
"Xian 1980 / 3-degree Gauss-Kruger CM 96E":"2377",
"Xian 1980 / 3-degree Gauss-Kruger CM 99E":"2378",
"Xian 1980 / 3-degree Gauss-Kruger CM 102E":"2379",
"Xian 1980 / 3-degree Gauss-Kruger CM 105E":"2380",
"Xian 1980 / 3-degree Gauss-Kruger CM 108E":"2381",
"Xian 1980 / 3-degree Gauss-Kruger CM 111E":"2382",
"Xian 1980 / 3-degree Gauss-Kruger CM 114E":"2383",
"Xian 1980 / 3-degree Gauss-Kruger CM 117E":"2384",
"Xian 1980 / 3-degree Gauss-Kruger CM 120E":"2385",
"Xian 1980 / 3-degree Gauss-Kruger CM 123E":"2386",
"Xian 1980 / 3-degree Gauss-Kruger CM 126E":"2387",
"Xian 1980 / 3-degree Gauss-Kruger CM 129E":"2388",
"Xian 1980 / 3-degree Gauss-Kruger CM 132E":"2389",
"Xian 1980 / 3-degree Gauss-Kruger CM 135E":"2390",
"KKJ / Finland zone 1":"2391",
"KKJ / Finland zone 2":"2392",
"KKJ / Finland Uniform Coordinate System":"2393",
"KKJ / Finland zone 4":"2394",
"South Yemen / Gauss-Kruger zone 8":"2395",
"South Yemen / Gauss-Kruger zone 9":"2396",
"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 3":"2397",
"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 4":"2398",
"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 5":"2399",
"RT90 2.5 gon W":"2400",
"Beijing 1954 / 3-degree Gauss-Kruger zone 25":"2401",
"Beijing 1954 / 3-degree Gauss-Kruger zone 26":"2402",
"Beijing 1954 / 3-degree Gauss-Kruger zone 27":"2403",
"Beijing 1954 / 3-degree Gauss-Kruger zone 28":"2404",
"Beijing 1954 / 3-degree Gauss-Kruger zone 29":"2405",
"Beijing 1954 / 3-degree Gauss-Kruger zone 30":"2406",
"Beijing 1954 / 3-degree Gauss-Kruger zone 31":"2407",
"Beijing 1954 / 3-degree Gauss-Kruger zone 32":"2408",
"Beijing 1954 / 3-degree Gauss-Kruger zone 33":"2409",
"Beijing 1954 / 3-degree Gauss-Kruger zone 34":"2410",
"Beijing 1954 / 3-degree Gauss-Kruger zone 35":"2411",
"Beijing 1954 / 3-degree Gauss-Kruger zone 36":"2412",
"Beijing 1954 / 3-degree Gauss-Kruger zone 37":"2413",
"Beijing 1954 / 3-degree Gauss-Kruger zone 38":"2414",
"Beijing 1954 / 3-degree Gauss-Kruger zone 39":"2415",
"Beijing 1954 / 3-degree Gauss-Kruger zone 40":"2416",
"Beijing 1954 / 3-degree Gauss-Kruger zone 41":"2417",
"Beijing 1954 / 3-degree Gauss-Kruger zone 42":"2418",
"Beijing 1954 / 3-degree Gauss-Kruger zone 43":"2419",
"Beijing 1954 / 3-degree Gauss-Kruger zone 44":"2420",
"Beijing 1954 / 3-degree Gauss-Kruger zone 45":"2421",
"Beijing 1954 / 3-degree Gauss-Kruger CM 75E":"2422",
"Beijing 1954 / 3-degree Gauss-Kruger CM 78E":"2423",
"Beijing 1954 / 3-degree Gauss-Kruger CM 81E":"2424",
"Beijing 1954 / 3-degree Gauss-Kruger CM 84E":"2425",
"Beijing 1954 / 3-degree Gauss-Kruger CM 87E":"2426",
"Beijing 1954 / 3-degree Gauss-Kruger CM 90E":"2427",
"Beijing 1954 / 3-degree Gauss-Kruger CM 93E":"2428",
"Beijing 1954 / 3-degree Gauss-Kruger CM 96E":"2429",
"Beijing 1954 / 3-degree Gauss-Kruger CM 99E":"2430",
"Beijing 1954 / 3-degree Gauss-Kruger CM 102E":"2431",
"Beijing 1954 / 3-degree Gauss-Kruger CM 105E":"2432",
"Beijing 1954 / 3-degree Gauss-Kruger CM 108E":"2433",
"Beijing 1954 / 3-degree Gauss-Kruger CM 111E":"2434",
"Beijing 1954 / 3-degree Gauss-Kruger CM 114E":"2435",
"Beijing 1954 / 3-degree Gauss-Kruger CM 117E":"2436",
"Beijing 1954 / 3-degree Gauss-Kruger CM 120E":"2437",
"Beijing 1954 / 3-degree Gauss-Kruger CM 123E":"2438",
"Beijing 1954 / 3-degree Gauss-Kruger CM 126E":"2439",
"Beijing 1954 / 3-degree Gauss-Kruger CM 129E":"2440",
"Beijing 1954 / 3-degree Gauss-Kruger CM 132E":"2441",
"Beijing 1954 / 3-degree Gauss-Kruger CM 135E":"2442",
"JGD2000 / Japan Plane Rectangular CS I":"2443",
"JGD2000 / Japan Plane Rectangular CS II":"2444",
"JGD2000 / Japan Plane Rectangular CS III":"2445",
"JGD2000 / Japan Plane Rectangular CS IV":"2446",
"JGD2000 / Japan Plane Rectangular CS V":"2447",
"JGD2000 / Japan Plane Rectangular CS VI":"2448",
"JGD2000 / Japan Plane Rectangular CS VII":"2449",
"JGD2000 / Japan Plane Rectangular CS VIII":"2450",
"JGD2000 / Japan Plane Rectangular CS IX":"2451",
"JGD2000 / Japan Plane Rectangular CS X":"2452",
"JGD2000 / Japan Plane Rectangular CS XI":"2453",
"JGD2000 / Japan Plane Rectangular CS XII":"2454",
"JGD2000 / Japan Plane Rectangular CS XIII":"2455",
"JGD2000 / Japan Plane Rectangular CS XIV":"2456",
"JGD2000 / Japan Plane Rectangular CS XV":"2457",
"JGD2000 / Japan Plane Rectangular CS XVI":"2458",
"JGD2000 / Japan Plane Rectangular CS XVII":"2459",
"JGD2000 / Japan Plane Rectangular CS XVIII":"2460",
"JGD2000 / Japan Plane Rectangular CS XIX":"2461",
"Albanian 1987 / Gauss-Kruger zone 4":"2462",
"Pulkovo 1995 / Gauss-Kruger CM 21E":"2463",
"Pulkovo 1995 / Gauss-Kruger CM 27E":"2464",
"Pulkovo 1995 / Gauss-Kruger CM 33E":"2465",
"Pulkovo 1995 / Gauss-Kruger CM 39E":"2466",
"Pulkovo 1995 / Gauss-Kruger CM 45E":"2467",
"Pulkovo 1995 / Gauss-Kruger CM 51E":"2468",
"Pulkovo 1995 / Gauss-Kruger CM 57E":"2469",
"Pulkovo 1995 / Gauss-Kruger CM 63E":"2470",
"Pulkovo 1995 / Gauss-Kruger CM 69E":"2471",
"Pulkovo 1995 / Gauss-Kruger CM 75E":"2472",
"Pulkovo 1995 / Gauss-Kruger CM 81E":"2473",
"Pulkovo 1995 / Gauss-Kruger CM 87E":"2474",
"Pulkovo 1995 / Gauss-Kruger CM 93E":"2475",
"Pulkovo 1995 / Gauss-Kruger CM 99E":"2476",
"Pulkovo 1995 / Gauss-Kruger CM 105E":"2477",
"Pulkovo 1995 / Gauss-Kruger CM 111E":"2478",
"Pulkovo 1995 / Gauss-Kruger CM 117E":"2479",
"Pulkovo 1995 / Gauss-Kruger CM 123E":"2480",
"Pulkovo 1995 / Gauss-Kruger CM 129E":"2481",
"Pulkovo 1995 / Gauss-Kruger CM 135E":"2482",
"Pulkovo 1995 / Gauss-Kruger CM 141E":"2483",
"Pulkovo 1995 / Gauss-Kruger CM 147E":"2484",
"Pulkovo 1995 / Gauss-Kruger CM 153E":"2485",
"Pulkovo 1995 / Gauss-Kruger CM 159E":"2486",
"Pulkovo 1995 / Gauss-Kruger CM 165E":"2487",
"Pulkovo 1995 / Gauss-Kruger CM 171E":"2488",
"Pulkovo 1995 / Gauss-Kruger CM 177E":"2489",
"Pulkovo 1995 / Gauss-Kruger CM 177W":"2490",
"Pulkovo 1995 / Gauss-Kruger CM 171W":"2491",
"Pulkovo 1942 / Gauss-Kruger CM 9E":"2492",
"Pulkovo 1942 / Gauss-Kruger CM 15E":"2493",
"Pulkovo 1942 / Gauss-Kruger CM 21E":"2494",
"Pulkovo 1942 / Gauss-Kruger CM 27E":"2495",
"Pulkovo 1942 / Gauss-Kruger CM 33E":"2496",
"Pulkovo 1942 / Gauss-Kruger CM 39E":"2497",
"Pulkovo 1942 / Gauss-Kruger CM 45E":"2498",
"Pulkovo 1942 / Gauss-Kruger CM 51E":"2499",
"Pulkovo 1942 / Gauss-Kruger CM 57E":"2500",
"Pulkovo 1942 / Gauss-Kruger CM 63E":"2501",
"Pulkovo 1942 / Gauss-Kruger CM 69E":"2502",
"Pulkovo 1942 / Gauss-Kruger CM 75E":"2503",
"Pulkovo 1942 / Gauss-Kruger CM 81E":"2504",
"Pulkovo 1942 / Gauss-Kruger CM 87E":"2505",
"Pulkovo 1942 / Gauss-Kruger CM 93E":"2506",
"Pulkovo 1942 / Gauss-Kruger CM 99E":"2507",
"Pulkovo 1942 / Gauss-Kruger CM 105E":"2508",
"Pulkovo 1942 / Gauss-Kruger CM 111E":"2509",
"Pulkovo 1942 / Gauss-Kruger CM 117E":"2510",
"Pulkovo 1942 / Gauss-Kruger CM 123E":"2511",
"Pulkovo 1942 / Gauss-Kruger CM 129E":"2512",
"Pulkovo 1942 / Gauss-Kruger CM 135E":"2513",
"Pulkovo 1942 / Gauss-Kruger CM 141E":"2514",
"Pulkovo 1942 / Gauss-Kruger CM 147E":"2515",
"Pulkovo 1942 / Gauss-Kruger CM 153E":"2516",
"Pulkovo 1942 / Gauss-Kruger CM 159E":"2517",
"Pulkovo 1942 / Gauss-Kruger CM 165E":"2518",
"Pulkovo 1942 / Gauss-Kruger CM 171E":"2519",
"Pulkovo 1942 / Gauss-Kruger CM 177E":"2520",
"Pulkovo 1942 / Gauss-Kruger CM 177W":"2521",
"Pulkovo 1942 / Gauss-Kruger CM 171W":"2522",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 7":"2523",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 8":"2524",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 9":"2525",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 10":"2526",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 11":"2527",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 12":"2528",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 13":"2529",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 14":"2530",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 15":"2531",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 16":"2532",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 17":"2533",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 18":"2534",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 19":"2535",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 20":"2536",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 21":"2537",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 22":"2538",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 23":"2539",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 24":"2540",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 25":"2541",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 26":"2542",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 27":"2543",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 28":"2544",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 29":"2545",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 30":"2546",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 31":"2547",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 32":"2548",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 33":"2549",
"Samboja / UTM zone 50S":"2550",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 34":"2551",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 35":"2552",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 36":"2553",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 37":"2554",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 38":"2555",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 39":"2556",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 40":"2557",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 41":"2558",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 42":"2559",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 43":"2560",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 44":"2561",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 45":"2562",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 46":"2563",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 47":"2564",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 48":"2565",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 49":"2566",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 50":"2567",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 51":"2568",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 52":"2569",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 53":"2570",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 54":"2571",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 55":"2572",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 56":"2573",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 57":"2574",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 58":"2575",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 59":"2576",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 60":"2577",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 61":"2578",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 62":"2579",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 63":"2580",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 64":"2581",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 21E":"2582",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 24E":"2583",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 27E":"2584",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 30E":"2585",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 33E":"2586",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 36E":"2587",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 39E":"2588",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 42E":"2589",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 45E":"2590",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 48E":"2591",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 51E":"2592",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 54E":"2593",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 57E":"2594",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 60E":"2595",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 63E":"2596",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 66E":"2597",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 69E":"2598",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 72E":"2599",
"Lietuvos Koordinoei Sistema 1994":"2600",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 75E":"2601",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 78E":"2602",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 81E":"2603",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 84E":"2604",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 87E":"2605",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 90E":"2606",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 93E":"2607",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 96E":"2608",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 99E":"2609",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 102E":"2610",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 105E":"2611",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 108E":"2612",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 111E":"2613",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 114E":"2614",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 117E":"2615",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 120E":"2616",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 123E":"2617",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 126E":"2618",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 129E":"2619",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 132E":"2620",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 135E":"2621",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 138E":"2622",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 141E":"2623",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 144E":"2624",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 147E":"2625",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 150E":"2626",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 153E":"2627",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 156E":"2628",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 159E":"2629",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 162E":"2630",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 165E":"2631",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 168E":"2632",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 171E":"2633",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 174E":"2634",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 177E":"2635",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 180E":"2636",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 177W":"2637",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 174W":"2638",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 171W":"2639",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 168W":"2640",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 7":"2641",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 8":"2642",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 9":"2643",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 10":"2644",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 11":"2645",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 12":"2646",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 13":"2647",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 14":"2648",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 15":"2649",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 16":"2650",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 17":"2651",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 18":"2652",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 19":"2653",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 20":"2654",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 21":"2655",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 22":"2656",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 23":"2657",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 24":"2658",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 25":"2659",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 26":"2660",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 27":"2661",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 28":"2662",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 29":"2663",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 30":"2664",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 31":"2665",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 32":"2666",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 33":"2667",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 34":"2668",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 35":"2669",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 36":"2670",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 37":"2671",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 38":"2672",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 39":"2673",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 40":"2674",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 41":"2675",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 42":"2676",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 43":"2677",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 44":"2678",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 45":"2679",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 46":"2680",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 47":"2681",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 48":"2682",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 49":"2683",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 50":"2684",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 51":"2685",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 52":"2686",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 53":"2687",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 54":"2688",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 55":"2689",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 56":"2690",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 57":"2691",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 58":"2692",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 59":"2693",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 60":"2694",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 61":"2695",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 62":"2696",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 63":"2697",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 64":"2698",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 21E":"2699",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 24E":"2700",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 27E":"2701",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 30E":"2702",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 33E":"2703",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 36E":"2704",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 39E":"2705",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 42E":"2706",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 45E":"2707",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 48E":"2708",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 51E":"2709",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 54E":"2710",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 57E":"2711",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 60E":"2712",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 63E":"2713",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 66E":"2714",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 69E":"2715",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 72E":"2716",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 75E":"2717",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 78E":"2718",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 81E":"2719",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 84E":"2720",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 87E":"2721",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 90E":"2722",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 93E":"2723",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 96E":"2724",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 99E":"2725",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 102E":"2726",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 105E":"2727",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 108E":"2728",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 111E":"2729",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 114E":"2730",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 117E":"2731",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 120E":"2732",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 123E":"2733",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 126E":"2734",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 129E":"2735",
"Tete / UTM zone 36S":"2736",
"Tete / UTM zone 37S":"2737",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 132E":"2738",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 135E":"2739",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 138E":"2740",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 141E":"2741",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 144E":"2742",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 147E":"2743",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 150E":"2744",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 153E":"2745",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 156E":"2746",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 159E":"2747",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 162E":"2748",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 165E":"2749",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 168E":"2750",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 171E":"2751",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 174E":"2752",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 177E":"2753",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 180E":"2754",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 177W":"2755",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 174W":"2756",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 171W":"2757",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 168W":"2758",
"NAD83(HARN) / Alabama East":"2759",
"NAD83(HARN) / Alabama West":"2760",
"NAD83(HARN) / Arizona East":"2761",
"NAD83(HARN) / Arizona Central":"2762",
"NAD83(HARN) / Arizona West":"2763",
"NAD83(HARN) / Arkansas North":"2764",
"NAD83(HARN) / Arkansas South":"2765",
"NAD83(HARN) / California zone 1":"2766",
"NAD83(HARN) / California zone 2":"2767",
"NAD83(HARN) / California zone 3":"2768",
"NAD83(HARN) / California zone 4":"2769",
"NAD83(HARN) / California zone 5":"2770",
"NAD83(HARN) / California zone 6":"2771",
"NAD83(HARN) / Colorado North":"2772",
"NAD83(HARN) / Colorado Central":"2773",
"NAD83(HARN) / Colorado South":"2774",
"NAD83(HARN) / Connecticut":"2775",
"NAD83(HARN) / Delaware":"2776",
"NAD83(HARN) / Florida East":"2777",
"NAD83(HARN) / Florida West":"2778",
"NAD83(HARN) / Florida North":"2779",
"NAD83(HARN) / Georgia East":"2780",
"NAD83(HARN) / Georgia West":"2781",
"NAD83(HARN) / Hawaii zone 1":"2782",
"NAD83(HARN) / Hawaii zone 2":"2783",
"NAD83(HARN) / Hawaii zone 3":"2784",
"NAD83(HARN) / Hawaii zone 4":"2785",
"NAD83(HARN) / Hawaii zone 5":"2786",
"NAD83(HARN) / Idaho East":"2787",
"NAD83(HARN) / Idaho Central":"2788",
"NAD83(HARN) / Idaho West":"2789",
"NAD83(HARN) / Illinois East":"2790",
"NAD83(HARN) / Illinois West":"2791",
"NAD83(HARN) / Indiana East":"2792",
"NAD83(HARN) / Indiana West":"2793",
"NAD83(HARN) / Iowa North":"2794",
"NAD83(HARN) / Iowa South":"2795",
"NAD83(HARN) / Kansas North":"2796",
"NAD83(HARN) / Kansas South":"2797",
"NAD83(HARN) / Kentucky North":"2798",
"NAD83(HARN) / Kentucky South":"2799",
"NAD83(HARN) / Louisiana North":"2800",
"NAD83(HARN) / Louisiana South":"2801",
"NAD83(HARN) / Maine East":"2802",
"NAD83(HARN) / Maine West":"2803",
"NAD83(HARN) / Maryland":"2804",
"NAD83(HARN) / Massachusetts Mainland":"2805",
"NAD83(HARN) / Massachusetts Island":"2806",
"NAD83(HARN) / Michigan North":"2807",
"NAD83(HARN) / Michigan Central":"2808",
"NAD83(HARN) / Michigan South":"2809",
"NAD83(HARN) / Minnesota North":"2810",
"NAD83(HARN) / Minnesota Central":"2811",
"NAD83(HARN) / Minnesota South":"2812",
"NAD83(HARN) / Mississippi East":"2813",
"NAD83(HARN) / Mississippi West":"2814",
"NAD83(HARN) / Missouri East":"2815",
"NAD83(HARN) / Missouri Central":"2816",
"NAD83(HARN) / Missouri West":"2817",
"NAD83(HARN) / Montana":"2818",
"NAD83(HARN) / Nebraska":"2819",
"NAD83(HARN) / Nevada East":"2820",
"NAD83(HARN) / Nevada Central":"2821",
"NAD83(HARN) / Nevada West":"2822",
"NAD83(HARN) / New Hampshire":"2823",
"NAD83(HARN) / New Jersey":"2824",
"NAD83(HARN) / New Mexico East":"2825",
"NAD83(HARN) / New Mexico Central":"2826",
"NAD83(HARN) / New Mexico West":"2827",
"NAD83(HARN) / New York East":"2828",
"NAD83(HARN) / New York Central":"2829",
"NAD83(HARN) / New York West":"2830",
"NAD83(HARN) / New York Long Island":"2831",
"NAD83(HARN) / North Dakota North":"2832",
"NAD83(HARN) / North Dakota South":"2833",
"NAD83(HARN) / Ohio North":"2834",
"NAD83(HARN) / Ohio South":"2835",
"NAD83(HARN) / Oklahoma North":"2836",
"NAD83(HARN) / Oklahoma South":"2837",
"NAD83(HARN) / Oregon North":"2838",
"NAD83(HARN) / Oregon South":"2839",
"NAD83(HARN) / Rhode Island":"2840",
"NAD83(HARN) / South Dakota North":"2841",
"NAD83(HARN) / South Dakota South":"2842",
"NAD83(HARN) / Tennessee":"2843",
"NAD83(HARN) / Texas North":"2844",
"NAD83(HARN) / Texas North Central":"2845",
"NAD83(HARN) / Texas Central":"2846",
"NAD83(HARN) / Texas South Central":"2847",
"NAD83(HARN) / Texas South":"2848",
"NAD83(HARN) / Utah North":"2849",
"NAD83(HARN) / Utah Central":"2850",
"NAD83(HARN) / Utah South":"2851",
"NAD83(HARN) / Vermont":"2852",
"NAD83(HARN) / Virginia North":"2853",
"NAD83(HARN) / Virginia South":"2854",
"NAD83(HARN) / Washington North":"2855",
"NAD83(HARN) / Washington South":"2856",
"NAD83(HARN) / West Virginia North":"2857",
"NAD83(HARN) / West Virginia South":"2858",
"NAD83(HARN) / Wisconsin North":"2859",
"NAD83(HARN) / Wisconsin Central":"2860",
"NAD83(HARN) / Wisconsin South":"2861",
"NAD83(HARN) / Wyoming East":"2862",
"NAD83(HARN) / Wyoming East Central":"2863",
"NAD83(HARN) / Wyoming West Central":"2864",
"NAD83(HARN) / Wyoming West":"2865",
"NAD83(HARN) / Puerto Rico and Virgin Is.":"2866",
"NAD83(HARN) / Arizona East (ft)":"2867",
"NAD83(HARN) / Arizona Central (ft)":"2868",
"NAD83(HARN) / Arizona West (ft)":"2869",
"NAD83(HARN) / California zone 1 (ftUS)":"2870",
"NAD83(HARN) / California zone 2 (ftUS)":"2871",
"NAD83(HARN) / California zone 3 (ftUS)":"2872",
"NAD83(HARN) / California zone 4 (ftUS)":"2873",
"NAD83(HARN) / California zone 5 (ftUS)":"2874",
"NAD83(HARN) / California zone 6 (ftUS)":"2875",
"NAD83(HARN) / Colorado North (ftUS)":"2876",
"NAD83(HARN) / Colorado Central (ftUS)":"2877",
"NAD83(HARN) / Colorado South (ftUS)":"2878",
"NAD83(HARN) / Connecticut (ftUS)":"2879",
"NAD83(HARN) / Delaware (ftUS)":"2880",
"NAD83(HARN) / Florida East (ftUS)":"2881",
"NAD83(HARN) / Florida West (ftUS)":"2882",
"NAD83(HARN) / Florida North (ftUS)":"2883",
"NAD83(HARN) / Georgia East (ftUS)":"2884",
"NAD83(HARN) / Georgia West (ftUS)":"2885",
"NAD83(HARN) / Idaho East (ftUS)":"2886",
"NAD83(HARN) / Idaho Central (ftUS)":"2887",
"NAD83(HARN) / Idaho West (ftUS)":"2888",
"NAD83(HARN) / Indiana East (ftUS)":"2889",
"NAD83(HARN) / Indiana West (ftUS)":"2890",
"NAD83(HARN) / Kentucky North (ftUS)":"2891",
"NAD83(HARN) / Kentucky South (ftUS)":"2892",
"NAD83(HARN) / Maryland (ftUS)":"2893",
"NAD83(HARN) / Massachusetts Mainland (ftUS)":"2894",
"NAD83(HARN) / Massachusetts Island (ftUS)":"2895",
"NAD83(HARN) / Michigan North (ft)":"2896",
"NAD83(HARN) / Michigan Central (ft)":"2897",
"NAD83(HARN) / Michigan South (ft)":"2898",
"NAD83(HARN) / Mississippi East (ftUS)":"2899",
"NAD83(HARN) / Mississippi West (ftUS)":"2900",
"NAD83(HARN) / Montana (ft)":"2901",
"NAD83(HARN) / New Mexico East (ftUS)":"2902",
"NAD83(HARN) / New Mexico Central (ftUS)":"2903",
"NAD83(HARN) / New Mexico West (ftUS)":"2904",
"NAD83(HARN) / New York East (ftUS)":"2905",
"NAD83(HARN) / New York Central (ftUS)":"2906",
"NAD83(HARN) / New York West (ftUS)":"2907",
"NAD83(HARN) / New York Long Island (ftUS)":"2908",
"NAD83(HARN) / North Dakota North (ft)":"2909",
"NAD83(HARN) / North Dakota South (ft)":"2910",
"NAD83(HARN) / Oklahoma North (ftUS)":"2911",
"NAD83(HARN) / Oklahoma South (ftUS)":"2912",
"NAD83(HARN) / Oregon North (ft)":"2913",
"NAD83(HARN) / Oregon South (ft)":"2914",
"NAD83(HARN) / Tennessee (ftUS)":"2915",
"NAD83(HARN) / Texas North (ftUS)":"2916",
"NAD83(HARN) / Texas North Central (ftUS)":"2917",
"NAD83(HARN) / Texas Central (ftUS)":"2918",
"NAD83(HARN) / Texas South Central (ftUS)":"2919",
"NAD83(HARN) / Texas South (ftUS)":"2920",
"NAD83(HARN) / Utah North (ft)":"2921",
"NAD83(HARN) / Utah Central (ft)":"2922",
"NAD83(HARN) / Utah South (ft)":"2923",
"NAD83(HARN) / Virginia North (ftUS)":"2924",
"NAD83(HARN) / Virginia South (ftUS)":"2925",
"NAD83(HARN) / Washington North (ftUS)":"2926",
"NAD83(HARN) / Washington South (ftUS)":"2927",
"NAD83(HARN) / Wisconsin North (ftUS)":"2928",
"NAD83(HARN) / Wisconsin Central (ftUS)":"2929",
"NAD83(HARN) / Wisconsin South (ftUS)":"2930",
"Beduaram / TM 13 NE":"2931",
"QND95 / Qatar National Grid":"2932",
"Segara / UTM zone 50S":"2933",
"Segara (Jakarta) / NEIEZ":"2934",
"Pulkovo 1942 / CS63 zone A1":"2935",
"Pulkovo 1942 / CS63 zone A2":"2936",
"Pulkovo 1942 / CS63 zone A3":"2937",
"Pulkovo 1942 / CS63 zone A4":"2938",
"Pulkovo 1942 / CS63 zone K2":"2939",
"Pulkovo 1942 / CS63 zone K3":"2940",
"Pulkovo 1942 / CS63 zone K4":"2941",
"Porto Santo / UTM zone 28N":"2942",
"Selvagem Grande / UTM zone 28N":"2943",
"NAD83(CSRS) / SCoPQ zone 2":"2944",
"NAD83(CSRS) / MTM zone 3":"2945",
"NAD83(CSRS) / MTM zone 4":"2946",
"NAD83(CSRS) / MTM zone 5":"2947",
"NAD83(CSRS) / MTM zone 6":"2948",
"NAD83(CSRS) / MTM zone 7":"2949",
"NAD83(CSRS) / MTM zone 8":"2950",
"NAD83(CSRS) / MTM zone 9":"2951",
"NAD83(CSRS) / MTM zone 10":"2952",
"NAD83(CSRS) / New Brunswick Stereographic":"2953",
"NAD83(CSRS) / Prince Edward Isl. Stereographic (NAD83)":"2954",
"NAD83(CSRS) / UTM zone 11N":"2955",
"NAD83(CSRS) / UTM zone 12N":"2956",
"NAD83(CSRS) / UTM zone 13N":"2957",
"NAD83(CSRS) / UTM zone 17N":"2958",
"NAD83(CSRS) / UTM zone 18N":"2959",
"NAD83(CSRS) / UTM zone 19N":"2960",
"NAD83(CSRS) / UTM zone 20N":"2961",
"NAD83(CSRS) / UTM zone 21N":"2962",
"Lisbon 1890 (Lisbon) / Portugal Bonne":"2963",
"NAD27 / Alaska Albers":"2964",
"NAD83 / Indiana East (ftUS)":"2965",
"NAD83 / Indiana West (ftUS)":"2966",
"NAD83(HARN) / Indiana East (ftUS)":"2967",
"NAD83(HARN) / Indiana West (ftUS)":"2968",
"Fort Marigot / UTM zone 20N":"2969",
"Guadeloupe 1948 / UTM zone 20N":"2970",
"CSG67 / UTM zone 22N":"2971",
"RGFG95 / UTM zone 22N":"2972",
"Martinique 1938 / UTM zone 20N":"2973",
"RGR92 / UTM zone 40S":"2975",
"Tahiti 52 / UTM zone 6S":"2976",
"Tahaa 54 / UTM zone 5S":"2977",
"IGN72 Nuku Hiva / UTM zone 7S":"2978",
"K0 1949 / UTM zone 42S":"2979",
"Combani 1950 / UTM zone 38S":"2980",
"IGN56 Lifou / UTM zone 58S":"2981",
"IGN72 Grand Terre / UTM zone 58S":"2982",
"ST87 Ouvea / UTM zone 58S":"2983",
"RGNC 1991 / Lambert New Caledonia":"2984",
"Petrels 1972 / Terre Adelie Polar Stereographic":"2985",
"Perroud 1950 / Terre Adelie Polar Stereographic":"2986",
"Saint Pierre et Miquelon 1950 / UTM zone 21N":"2987",
"MOP78 / UTM zone 1S":"2988",
"RRAF 1991 / UTM zone 20N":"2989",
"Reunion 1947 / TM Reunion":"2990",
"NAD83 / Oregon LCC (m)":"2991",
"NAD83 / Oregon GIC Lambert (ft)":"2992",
"NAD83(HARN) / Oregon LCC (m)":"2993",
"NAD83(HARN) / Oregon GIC Lambert (ft)":"2994",
"IGN53 Mare / UTM zone 58S":"2995",
"ST84 Ile des Pins / UTM zone 58S":"2996",
"ST71 Belep / UTM zone 58S":"2997",
"NEA74 Noumea / UTM zone 58S":"2998",
"Grand Comoros / UTM zone 38S":"2999",
"Segara / NEIEZ":"3000",
"Batavia / NEIEZ":"3001",
"Makassar / NEIEZ":"3002",
"Monte Mario / Italy zone 1":"3003",
"Monte Mario / Italy zone 2":"3004",
"NAD83 / BC Albers":"3005",
"SWEREF99 TM":"3006",
"SWEREF99 12 00":"3007",
"SWEREF99 13 30":"3008",
"SWEREF99 15 00":"3009",
"SWEREF99 16 30":"3010",
"SWEREF99 18 00":"3011",
"SWEREF99 14 15":"3012",
"SWEREF99 15 45":"3013",
"SWEREF99 17 15":"3014",
"SWEREF99 18 45":"3015",
"SWEREF99 20 15":"3016",
"SWEREF99 21 45":"3017",
"SWEREF99 23 15":"3018",
"RT90 7.5 gon V":"3019",
"RT90 5 gon V":"3020",
"RT90 2.5 gon V":"3021",
"RT90 0 gon":"3022",
"RT90 2.5 gon O":"3023",
"RT90 5 gon O":"3024",
"RT38 7.5 gon V":"3025",
"RT38 5 gon V":"3026",
"RT38 2.5 gon V":"3027",
"RT38 0 gon":"3028",
"RT38 2.5 gon O":"3029",
"RT38 5 gon O":"3030",
"WGS 84 / Antarctic Polar Stereographic":"3031",
"WGS 84 / Australian Antarctic Polar Stereographic":"3032",
"WGS 84 / Australian Antarctic Lambert":"3033",
"ETRS89-extended / LCC Europe":"3034",
"ETRS89-extended / LAEA Europe":"3035",
"Moznet / UTM zone 36S":"3036",
"Moznet / UTM zone 37S":"3037",
"ETRS89 / TM26":"3038",
"ETRS89 / TM27":"3039",
"ETRS89 / UTM zone 28N (N-E)":"3040",
"ETRS89 / UTM zone 29N (N-E)":"3041",
"ETRS89 / UTM zone 30N (N-E)":"3042",
"ETRS89 / UTM zone 31N (N-E)":"3043",
"ETRS89 / UTM zone 32N (N-E)":"3044",
"ETRS89 / UTM zone 33N (N-E)":"3045",
"ETRS89 / UTM zone 34N (N-E)":"3046",
"ETRS89 / UTM zone 35N (N-E)":"3047",
"ETRS89 / UTM zone 36N (N-E)":"3048",
"ETRS89 / UTM zone 37N (N-E)":"3049",
"ETRS89 / TM38":"3050",
"ETRS89 / TM39":"3051",
"Reykjavik 1900 / Lambert 1900":"3052",
"Hjorsey 1955 / Lambert 1955":"3053",
"Hjorsey 1955 / UTM zone 26N":"3054",
"Hjorsey 1955 / UTM zone 27N":"3055",
"Hjorsey 1955 / UTM zone 28N":"3056",
"ISN93 / Lambert 1993":"3057",
"Helle 1954 / Jan Mayen Grid":"3058",
"LKS92 / Latvia TM":"3059",
"IGN72 Grande Terre / UTM zone 58S":"3060",
"Porto Santo 1995 / UTM zone 28N":"3061",
"Azores Oriental 1995 / UTM zone 26N":"3062",
"Azores Central 1995 / UTM zone 26N":"3063",
"IGM95 / UTM zone 32N":"3064",
"IGM95 / UTM zone 33N":"3065",
"ED50 / Jordan TM":"3066",
"ETRS89 / TM35FIN(E,N)":"3067",
"DHDN / Soldner Berlin":"3068",
"NAD27 / Wisconsin Transverse Mercator":"3069",
"NAD83 / Wisconsin Transverse Mercator":"3070",
"NAD83(HARN) / Wisconsin Transverse Mercator":"3071",
"NAD83 / Maine CS2000 East":"3072",
"NAD83 / Maine CS2000 Central":"3073",
"NAD83 / Maine CS2000 West":"3074",
"NAD83(HARN) / Maine CS2000 East":"3075",
"NAD83(HARN) / Maine CS2000 Central":"3076",
"NAD83(HARN) / Maine CS2000 West":"3077",
"NAD83 / Michigan Oblique Mercator":"3078",
"NAD83(HARN) / Michigan Oblique Mercator":"3079",
"NAD27 / Shackleford":"3080",
"NAD83 / Texas State Mapping System":"3081",
"NAD83 / Texas Centric Lambert Conformal":"3082",
"NAD83 / Texas Centric Albers Equal Area":"3083",
"NAD83(HARN) / Texas Centric Lambert Conformal":"3084",
"NAD83(HARN) / Texas Centric Albers Equal Area":"3085",
"NAD83 / Florida GDL Albers":"3086",
"NAD83(HARN) / Florida GDL Albers":"3087",
"NAD83 / Kentucky Single Zone":"3088",
"NAD83 / Kentucky Single Zone (ftUS)":"3089",
"NAD83(HARN) / Kentucky Single Zone":"3090",
"NAD83(HARN) / Kentucky Single Zone (ftUS)":"3091",
"Tokyo / UTM zone 51N":"3092",
"Tokyo / UTM zone 52N":"3093",
"Tokyo / UTM zone 53N":"3094",
"Tokyo / UTM zone 54N":"3095",
"Tokyo / UTM zone 55N":"3096",
"JGD2000 / UTM zone 51N":"3097",
"JGD2000 / UTM zone 52N":"3098",
"JGD2000 / UTM zone 53N":"3099",
"JGD2000 / UTM zone 54N":"3100",
"JGD2000 / UTM zone 55N":"3101",
"American Samoa 1962 / American Samoa Lambert":"3102",
"Mauritania 1999 / UTM zone 28N":"3103",
"Mauritania 1999 / UTM zone 29N":"3104",
"Mauritania 1999 / UTM zone 30N":"3105",
"Gulshan 303 / Bangladesh Transverse Mercator":"3106",
"GDA94 / SA Lambert":"3107",
"ETRS89 / Guernsey Grid":"3108",
"ETRS89 / Jersey Transverse Mercator":"3109",
"AGD66 / Vicgrid66":"3110",
"GDA94 / Vicgrid":"3111",
"GDA94 / Geoscience Australia Lambert":"3112",
"GDA94 / BCSG02":"3113",
"MAGNA-SIRGAS / Colombia Far West zone":"3114",
"MAGNA-SIRGAS / Colombia West zone":"3115",
"MAGNA-SIRGAS / Colombia Bogota zone":"3116",
"MAGNA-SIRGAS / Colombia East Central zone":"3117",
"MAGNA-SIRGAS / Colombia East zone":"3118",
"Douala 1948 / AEF west":"3119",
"Pulkovo 1942(58) / Poland zone I":"3120",
"PRS92 / Philippines zone 1":"3121",
"PRS92 / Philippines zone 2":"3122",
"PRS92 / Philippines zone 3":"3123",
"PRS92 / Philippines zone 4":"3124",
"PRS92 / Philippines zone 5":"3125",
"ETRS89 / ETRS-GK19FIN":"3126",
"ETRS89 / ETRS-GK20FIN":"3127",
"ETRS89 / ETRS-GK21FIN":"3128",
"ETRS89 / ETRS-GK22FIN":"3129",
"ETRS89 / ETRS-GK23FIN":"3130",
"ETRS89 / ETRS-GK24FIN":"3131",
"ETRS89 / ETRS-GK25FIN":"3132",
"ETRS89 / ETRS-GK26FIN":"3133",
"ETRS89 / ETRS-GK27FIN":"3134",
"ETRS89 / ETRS-GK28FIN":"3135",
"ETRS89 / ETRS-GK29FIN":"3136",
"ETRS89 / ETRS-GK30FIN":"3137",
"ETRS89 / ETRS-GK31FIN":"3138",
"Vanua Levu 1915 / Vanua Levu Grid":"3139",
"Viti Levu 1912 / Viti Levu Grid":"3140",
"Fiji 1956 / UTM zone 60S":"3141",
"Fiji 1956 / UTM zone 1S":"3142",
"Fiji 1986 / Fiji Map Grid":"3143",
"FD54 / Faroe Lambert":"3144",
"ETRS89 / Faroe Lambert":"3145",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 6":"3146",
"Pulkovo 1942 / 3-degree Gauss-Kruger CM 18E":"3147",
"Indian 1960 / UTM zone 48N":"3148",
"Indian 1960 / UTM zone 49N":"3149",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 6":"3150",
"Pulkovo 1995 / 3-degree Gauss-Kruger CM 18E":"3151",
"ST74":"3152",
"NAD83(CSRS) / BC Albers":"3153",
"NAD83(CSRS) / UTM zone 7N":"3154",
"NAD83(CSRS) / UTM zone 8N":"3155",
"NAD83(CSRS) / UTM zone 9N":"3156",
"NAD83(CSRS) / UTM zone 10N":"3157",
"NAD83(CSRS) / UTM zone 14N":"3158",
"NAD83(CSRS) / UTM zone 15N":"3159",
"NAD83(CSRS) / UTM zone 16N":"3160",
"NAD83 / Ontario MNR Lambert":"3161",
"NAD83(CSRS) / Ontario MNR Lambert":"3162",
"RGNC91-93 / Lambert New Caledonia":"3163",
"ST87 Ouvea / UTM zone 58S":"3164",
"NEA74 Noumea / Noumea Lambert":"3165",
"NEA74 Noumea / Noumea Lambert 2":"3166",
"Kertau (RSO) / RSO Malaya (ch)":"3167",
"Kertau (RSO) / RSO Malaya (m)":"3168",
"RGNC91-93 / UTM zone 57S":"3169",
"RGNC91-93 / UTM zone 58S":"3170",
"RGNC91-93 / UTM zone 59S":"3171",
"IGN53 Mare / UTM zone 59S":"3172",
"fk89 / Faroe Lambert FK89":"3173",
"NAD83 / Great Lakes Albers":"3174",
"NAD83 / Great Lakes and St Lawrence Albers":"3175",
"Indian 1960 / TM 106 NE":"3176",
"LGD2006 / Libya TM":"3177",
"GR96 / UTM zone 18N":"3178",
"GR96 / UTM zone 19N":"3179",
"GR96 / UTM zone 20N":"3180",
"GR96 / UTM zone 21N":"3181",
"GR96 / UTM zone 22N":"3182",
"GR96 / UTM zone 23N":"3183",
"GR96 / UTM zone 24N":"3184",
"GR96 / UTM zone 25N":"3185",
"GR96 / UTM zone 26N":"3186",
"GR96 / UTM zone 27N":"3187",
"GR96 / UTM zone 28N":"3188",
"GR96 / UTM zone 29N":"3189",
"LGD2006 / Libya TM zone 5":"3190",
"LGD2006 / Libya TM zone 6":"3191",
"LGD2006 / Libya TM zone 7":"3192",
"LGD2006 / Libya TM zone 8":"3193",
"LGD2006 / Libya TM zone 9":"3194",
"LGD2006 / Libya TM zone 10":"3195",
"LGD2006 / Libya TM zone 11":"3196",
"LGD2006 / Libya TM zone 12":"3197",
"LGD2006 / Libya TM zone 13":"3198",
"LGD2006 / UTM zone 32N":"3199",
"FD58 / Iraq zone":"3200",
"LGD2006 / UTM zone 33N":"3201",
"LGD2006 / UTM zone 34N":"3202",
"LGD2006 / UTM zone 35N":"3203",
"WGS 84 / SCAR IMW SP19-20":"3204",
"WGS 84 / SCAR IMW SP21-22":"3205",
"WGS 84 / SCAR IMW SP23-24":"3206",
"WGS 84 / SCAR IMW SQ01-02":"3207",
"WGS 84 / SCAR IMW SQ19-20":"3208",
"WGS 84 / SCAR IMW SQ21-22":"3209",
"WGS 84 / SCAR IMW SQ37-38":"3210",
"WGS 84 / SCAR IMW SQ39-40":"3211",
"WGS 84 / SCAR IMW SQ41-42":"3212",
"WGS 84 / SCAR IMW SQ43-44":"3213",
"WGS 84 / SCAR IMW SQ45-46":"3214",
"WGS 84 / SCAR IMW SQ47-48":"3215",
"WGS 84 / SCAR IMW SQ49-50":"3216",
"WGS 84 / SCAR IMW SQ51-52":"3217",
"WGS 84 / SCAR IMW SQ53-54":"3218",
"WGS 84 / SCAR IMW SQ55-56":"3219",
"WGS 84 / SCAR IMW SQ57-58":"3220",
"WGS 84 / SCAR IMW SR13-14":"3221",
"WGS 84 / SCAR IMW SR15-16":"3222",
"WGS 84 / SCAR IMW SR17-18":"3223",
"WGS 84 / SCAR IMW SR19-20":"3224",
"WGS 84 / SCAR IMW SR27-28":"3225",
"WGS 84 / SCAR IMW SR29-30":"3226",
"WGS 84 / SCAR IMW SR31-32":"3227",
"WGS 84 / SCAR IMW SR33-34":"3228",
"WGS 84 / SCAR IMW SR35-36":"3229",
"WGS 84 / SCAR IMW SR37-38":"3230",
"WGS 84 / SCAR IMW SR39-40":"3231",
"WGS 84 / SCAR IMW SR41-42":"3232",
"WGS 84 / SCAR IMW SR43-44":"3233",
"WGS 84 / SCAR IMW SR45-46":"3234",
"WGS 84 / SCAR IMW SR47-48":"3235",
"WGS 84 / SCAR IMW SR49-50":"3236",
"WGS 84 / SCAR IMW SR51-52":"3237",
"WGS 84 / SCAR IMW SR53-54":"3238",
"WGS 84 / SCAR IMW SR55-56":"3239",
"WGS 84 / SCAR IMW SR57-58":"3240",
"WGS 84 / SCAR IMW SR59-60":"3241",
"WGS 84 / SCAR IMW SS04-06":"3242",
"WGS 84 / SCAR IMW SS07-09":"3243",
"WGS 84 / SCAR IMW SS10-12":"3244",
"WGS 84 / SCAR IMW SS13-15":"3245",
"WGS 84 / SCAR IMW SS16-18":"3246",
"WGS 84 / SCAR IMW SS19-21":"3247",
"WGS 84 / SCAR IMW SS25-27":"3248",
"WGS 84 / SCAR IMW SS28-30":"3249",
"WGS 84 / SCAR IMW SS31-33":"3250",
"WGS 84 / SCAR IMW SS34-36":"3251",
"WGS 84 / SCAR IMW SS37-39":"3252",
"WGS 84 / SCAR IMW SS40-42":"3253",
"WGS 84 / SCAR IMW SS43-45":"3254",
"WGS 84 / SCAR IMW SS46-48":"3255",
"WGS 84 / SCAR IMW SS49-51":"3256",
"WGS 84 / SCAR IMW SS52-54":"3257",
"WGS 84 / SCAR IMW SS55-57":"3258",
"WGS 84 / SCAR IMW SS58-60":"3259",
"WGS 84 / SCAR IMW ST01-04":"3260",
"WGS 84 / SCAR IMW ST05-08":"3261",
"WGS 84 / SCAR IMW ST09-12":"3262",
"WGS 84 / SCAR IMW ST13-16":"3263",
"WGS 84 / SCAR IMW ST17-20":"3264",
"WGS 84 / SCAR IMW ST21-24":"3265",
"WGS 84 / SCAR IMW ST25-28":"3266",
"WGS 84 / SCAR IMW ST29-32":"3267",
"WGS 84 / SCAR IMW ST33-36":"3268",
"WGS 84 / SCAR IMW ST37-40":"3269",
"WGS 84 / SCAR IMW ST41-44":"3270",
"WGS 84 / SCAR IMW ST45-48":"3271",
"WGS 84 / SCAR IMW ST49-52":"3272",
"WGS 84 / SCAR IMW ST53-56":"3273",
"WGS 84 / SCAR IMW ST57-60":"3274",
"WGS 84 / SCAR IMW SU01-05":"3275",
"WGS 84 / SCAR IMW SU06-10":"3276",
"WGS 84 / SCAR IMW SU11-15":"3277",
"WGS 84 / SCAR IMW SU16-20":"3278",
"WGS 84 / SCAR IMW SU21-25":"3279",
"WGS 84 / SCAR IMW SU26-30":"3280",
"WGS 84 / SCAR IMW SU31-35":"3281",
"WGS 84 / SCAR IMW SU36-40":"3282",
"WGS 84 / SCAR IMW SU41-45":"3283",
"WGS 84 / SCAR IMW SU46-50":"3284",
"WGS 84 / SCAR IMW SU51-55":"3285",
"WGS 84 / SCAR IMW SU56-60":"3286",
"WGS 84 / SCAR IMW SV01-10":"3287",
"WGS 84 / SCAR IMW SV11-20":"3288",
"WGS 84 / SCAR IMW SV21-30":"3289",
"WGS 84 / SCAR IMW SV31-40":"3290",
"WGS 84 / SCAR IMW SV41-50":"3291",
"WGS 84 / SCAR IMW SV51-60":"3292",
"WGS 84 / SCAR IMW SW01-60":"3293",
"WGS 84 / USGS Transantarctic Mountains":"3294",
"Guam 1963 / Yap Islands":"3295",
"RGPF / UTM zone 5S":"3296",
"RGPF / UTM zone 6S":"3297",
"RGPF / UTM zone 7S":"3298",
"RGPF / UTM zone 8S":"3299",
"Estonian Coordinate System of 1992":"3300",
"Estonian Coordinate System of 1997":"3301",
"IGN63 Hiva Oa / UTM zone 7S":"3302",
"Fatu Iva 72 / UTM zone 7S":"3303",
"Tahiti 79 / UTM zone 6S":"3304",
"Moorea 87 / UTM zone 6S":"3305",
"Maupiti 83 / UTM zone 5S":"3306",
"Nakhl-e Ghanem / UTM zone 39N":"3307",
"GDA94 / NSW Lambert":"3308",
"NAD27 / California Albers":"3309",
"NAD83 / California Albers":"3310",
"NAD83(HARN) / California Albers":"3311",
"CSG67 / UTM zone 21N":"3312",
"RGFG95 / UTM zone 21N":"3313",
"Katanga 1955 / Katanga Lambert":"3314",
"Katanga 1955 / Katanga TM":"3315",
"Kasai 1953 / Congo TM zone 22":"3316",
"Kasai 1953 / Congo TM zone 24":"3317",
"IGC 1962 / Congo TM zone 12":"3318",
"IGC 1962 / Congo TM zone 14":"3319",
"IGC 1962 / Congo TM zone 16":"3320",
"IGC 1962 / Congo TM zone 18":"3321",
"IGC 1962 / Congo TM zone 20":"3322",
"IGC 1962 / Congo TM zone 22":"3323",
"IGC 1962 / Congo TM zone 24":"3324",
"IGC 1962 / Congo TM zone 26":"3325",
"IGC 1962 / Congo TM zone 28":"3326",
"IGC 1962 / Congo TM zone 30":"3327",
"Pulkovo 1942(58) / GUGiK-80":"3328",
"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 5":"3329",
"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 6":"3330",
"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 7":"3331",
"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 8":"3332",
"Pulkovo 1942(58) / Gauss-Kruger zone 3":"3333",
"Pulkovo 1942(58) / Gauss-Kruger zone 4":"3334",
"Pulkovo 1942(58) / Gauss-Kruger zone 5":"3335",
"IGN 1962 Kerguelen / UTM zone 42S":"3336",
"Le Pouce 1934 / Mauritius Grid":"3337",
"NAD83 / Alaska Albers":"3338",
"IGCB 1955 / Congo TM zone 12":"3339",
"IGCB 1955 / Congo TM zone 14":"3340",
"IGCB 1955 / Congo TM zone 16":"3341",
"IGCB 1955 / UTM zone 33S":"3342",
"Mauritania 1999 / UTM zone 28N":"3343",
"Mauritania 1999 / UTM zone 29N":"3344",
"Mauritania 1999 / UTM zone 30N":"3345",
"LKS94 / Lithuania TM":"3346",
"NAD83 / Statistics Canada Lambert":"3347",
"NAD83(CSRS) / Statistics Canada Lambert":"3348",
"WGS 84 / PDC Mercator":"3349",
"Pulkovo 1942 / CS63 zone C0":"3350",
"Pulkovo 1942 / CS63 zone C1":"3351",
"Pulkovo 1942 / CS63 zone C2":"3352",
"Mhast (onshore) / UTM zone 32S":"3353",
"Mhast (offshore) / UTM zone 32S":"3354",
"Egypt Gulf of Suez S-650 TL / Red Belt":"3355",
"Grand Cayman 1959 / UTM zone 17N":"3356",
"Little Cayman 1961 / UTM zone 17N":"3357",
"NAD83(HARN) / North Carolina":"3358",
"NAD83(HARN) / North Carolina (ftUS)":"3359",
"NAD83(HARN) / South Carolina":"3360",
"NAD83(HARN) / South Carolina (ft)":"3361",
"NAD83(HARN) / Pennsylvania North":"3362",
"NAD83(HARN) / Pennsylvania North (ftUS)":"3363",
"NAD83(HARN) / Pennsylvania South":"3364",
"NAD83(HARN) / Pennsylvania South (ftUS)":"3365",
"Hong Kong 1963 Grid System":"3366",
"IGN Astro 1960 / UTM zone 28N":"3367",
"IGN Astro 1960 / UTM zone 29N":"3368",
"IGN Astro 1960 / UTM zone 30N":"3369",
"NAD27 / UTM zone 59N":"3370",
"NAD27 / UTM zone 60N":"3371",
"NAD83 / UTM zone 59N":"3372",
"NAD83 / UTM zone 60N":"3373",
"FD54 / UTM zone 29N":"3374",
"GDM2000 / Peninsula RSO":"3375",
"GDM2000 / East Malaysia BRSO":"3376",
"GDM2000 / Johor Grid":"3377",
"GDM2000 / Sembilan and Melaka Grid":"3378",
"GDM2000 / Pahang Grid":"3379",
"GDM2000 / Selangor Grid":"3380",
"GDM2000 / Terengganu Grid":"3381",
"GDM2000 / Pinang Grid":"3382",
"GDM2000 / Kedah and Perlis Grid":"3383",
"GDM2000 / Perak Grid":"3384",
"GDM2000 / Kelantan Grid":"3385",
"KKJ / Finland zone 0":"3386",
"KKJ / Finland zone 5":"3387",
"Pulkovo 1942 / Caspian Sea Mercator":"3388",
"Pulkovo 1942 / 3-degree Gauss-Kruger zone 60":"3389",
"Pulkovo 1995 / 3-degree Gauss-Kruger zone 60":"3390",
"Karbala 1979 / UTM zone 37N":"3391",
"Karbala 1979 / UTM zone 38N":"3392",
"Karbala 1979 / UTM zone 39N":"3393",
"Nahrwan 1934 / Iraq zone":"3394",
"WGS 84 / World Mercator":"3395",
"PD/83 / 3-degree Gauss-Kruger zone 3":"3396",
"PD/83 / 3-degree Gauss-Kruger zone 4":"3397",
"RD/83 / 3-degree Gauss-Kruger zone 4":"3398",
"RD/83 / 3-degree Gauss-Kruger zone 5":"3399",
"NAD83 / Alberta 10-TM (Forest)":"3400",
"NAD83 / Alberta 10-TM (Resource)":"3401",
"NAD83(CSRS) / Alberta 10-TM (Forest)":"3402",
"NAD83(CSRS) / Alberta 10-TM (Resource)":"3403",
"NAD83(HARN) / North Carolina (ftUS)":"3404",
"VN-2000 / UTM zone 48N":"3405",
"VN-2000 / UTM zone 49N":"3406",
"Hong Kong 1963 Grid System":"3407",
"NSIDC EASE-Grid North":"3408",
"NSIDC EASE-Grid South":"3409",
"NSIDC EASE-Grid Global":"3410",
"NSIDC Sea Ice Polar Stereographic North":"3411",
"NSIDC Sea Ice Polar Stereographic South":"3412",
"WGS 84 / NSIDC Sea Ice Polar Stereographic North":"3413",
"SVY21 / Singapore TM":"3414",
"WGS 72BE / South China Sea Lambert":"3415",
"ETRS89 / Austria Lambert":"3416",
"NAD83 / Iowa North (ftUS)":"3417",
"NAD83 / Iowa South (ftUS)":"3418",
"NAD83 / Kansas North (ftUS)":"3419",
"NAD83 / Kansas South (ftUS)":"3420",
"NAD83 / Nevada East (ftUS)":"3421",
"NAD83 / Nevada Central (ftUS)":"3422",
"NAD83 / Nevada West (ftUS)":"3423",
"NAD83 / New Jersey (ftUS)":"3424",
"NAD83(HARN) / Iowa North (ftUS)":"3425",
"NAD83(HARN) / Iowa South (ftUS)":"3426",
"NAD83(HARN) / Kansas North (ftUS)":"3427",
"NAD83(HARN) / Kansas South (ftUS)":"3428",
"NAD83(HARN) / Nevada East (ftUS)":"3429",
"NAD83(HARN) / Nevada Central (ftUS)":"3430",
"NAD83(HARN) / Nevada West (ftUS)":"3431",
"NAD83(HARN) / New Jersey (ftUS)":"3432",
"NAD83 / Arkansas North (ftUS)":"3433",
"NAD83 / Arkansas South (ftUS)":"3434",
"NAD83 / Illinois East (ftUS)":"3435",
"NAD83 / Illinois West (ftUS)":"3436",
"NAD83 / New Hampshire (ftUS)":"3437",
"NAD83 / Rhode Island (ftUS)":"3438",
"PSD93 / UTM zone 39N":"3439",
"PSD93 / UTM zone 40N":"3440",
"NAD83(HARN) / Arkansas North (ftUS)":"3441",
"NAD83(HARN) / Arkansas South (ftUS)":"3442",
"NAD83(HARN) / Illinois East (ftUS)":"3443",
"NAD83(HARN) / Illinois West (ftUS)":"3444",
"NAD83(HARN) / New Hampshire (ftUS)":"3445",
"NAD83(HARN) / Rhode Island (ftUS)":"3446",
"ETRS89 / Belgian Lambert 2005":"3447",
"JAD2001 / Jamaica Metric Grid":"3448",
"JAD2001 / UTM zone 17N":"3449",
"JAD2001 / UTM zone 18N":"3450",
"NAD83 / Louisiana North (ftUS)":"3451",
"NAD83 / Louisiana South (ftUS)":"3452",
"NAD83 / Louisiana Offshore (ftUS)":"3453",
"NAD83 / South Dakota North (ftUS)":"3454",
"NAD83 / South Dakota South (ftUS)":"3455",
"NAD83(HARN) / Louisiana North (ftUS)":"3456",
"NAD83(HARN) / Louisiana South (ftUS)":"3457",
"NAD83(HARN) / South Dakota North (ftUS)":"3458",
"NAD83(HARN) / South Dakota South (ftUS)":"3459",
"Fiji 1986 / Fiji Map Grid":"3460",
"Dabola 1981 / UTM zone 28N":"3461",
"Dabola 1981 / UTM zone 29N":"3462",
"NAD83 / Maine CS2000 Central":"3463",
"NAD83(HARN) / Maine CS2000 Central":"3464",
"NAD83(NSRS2007) / Alabama East":"3465",
"NAD83(NSRS2007) / Alabama West":"3466",
"NAD83(NSRS2007) / Alaska Albers":"3467",
"NAD83(NSRS2007) / Alaska zone 1":"3468",
"NAD83(NSRS2007) / Alaska zone 2":"3469",
"NAD83(NSRS2007) / Alaska zone 3":"3470",
"NAD83(NSRS2007) / Alaska zone 4":"3471",
"NAD83(NSRS2007) / Alaska zone 5":"3472",
"NAD83(NSRS2007) / Alaska zone 6":"3473",
"NAD83(NSRS2007) / Alaska zone 7":"3474",
"NAD83(NSRS2007) / Alaska zone 8":"3475",
"NAD83(NSRS2007) / Alaska zone 9":"3476",
"NAD83(NSRS2007) / Alaska zone 10":"3477",
"NAD83(NSRS2007) / Arizona Central":"3478",
"NAD83(NSRS2007) / Arizona Central (ft)":"3479",
"NAD83(NSRS2007) / Arizona East":"3480",
"NAD83(NSRS2007) / Arizona East (ft)":"3481",
"NAD83(NSRS2007) / Arizona West":"3482",
"NAD83(NSRS2007) / Arizona West (ft)":"3483",
"NAD83(NSRS2007) / Arkansas North":"3484",
"NAD83(NSRS2007) / Arkansas North (ftUS)":"3485",
"NAD83(NSRS2007) / Arkansas South":"3486",
"NAD83(NSRS2007) / Arkansas South (ftUS)":"3487",
"NAD83(NSRS2007) / California Albers":"3488",
"NAD83(NSRS2007) / California zone 1":"3489",
"NAD83(NSRS2007) / California zone 1 (ftUS)":"3490",
"NAD83(NSRS2007) / California zone 2":"3491",
"NAD83(NSRS2007) / California zone 2 (ftUS)":"3492",
"NAD83(NSRS2007) / California zone 3":"3493",
"NAD83(NSRS2007) / California zone 3 (ftUS)":"3494",
"NAD83(NSRS2007) / California zone 4":"3495",
"NAD83(NSRS2007) / California zone 4 (ftUS)":"3496",
"NAD83(NSRS2007) / California zone 5":"3497",
"NAD83(NSRS2007) / California zone 5 (ftUS)":"3498",
"NAD83(NSRS2007) / California zone 6":"3499",
"NAD83(NSRS2007) / California zone 6 (ftUS)":"3500",
"NAD83(NSRS2007) / Colorado Central":"3501",
"NAD83(NSRS2007) / Colorado Central (ftUS)":"3502",
"NAD83(NSRS2007) / Colorado North":"3503",
"NAD83(NSRS2007) / Colorado North (ftUS)":"3504",
"NAD83(NSRS2007) / Colorado South":"3505",
"NAD83(NSRS2007) / Colorado South (ftUS)":"3506",
"NAD83(NSRS2007) / Connecticut":"3507",
"NAD83(NSRS2007) / Connecticut (ftUS)":"3508",
"NAD83(NSRS2007) / Delaware":"3509",
"NAD83(NSRS2007) / Delaware (ftUS)":"3510",
"NAD83(NSRS2007) / Florida East":"3511",
"NAD83(NSRS2007) / Florida East (ftUS)":"3512",
"NAD83(NSRS2007) / Florida GDL Albers":"3513",
"NAD83(NSRS2007) / Florida North":"3514",
"NAD83(NSRS2007) / Florida North (ftUS)":"3515",
"NAD83(NSRS2007) / Florida West":"3516",
"NAD83(NSRS2007) / Florida West (ftUS)":"3517",
"NAD83(NSRS2007) / Georgia East":"3518",
"NAD83(NSRS2007) / Georgia East (ftUS)":"3519",
"NAD83(NSRS2007) / Georgia West":"3520",
"NAD83(NSRS2007) / Georgia West (ftUS)":"3521",
"NAD83(NSRS2007) / Idaho Central":"3522",
"NAD83(NSRS2007) / Idaho Central (ftUS)":"3523",
"NAD83(NSRS2007) / Idaho East":"3524",
"NAD83(NSRS2007) / Idaho East (ftUS)":"3525",
"NAD83(NSRS2007) / Idaho West":"3526",
"NAD83(NSRS2007) / Idaho West (ftUS)":"3527",
"NAD83(NSRS2007) / Illinois East":"3528",
"NAD83(NSRS2007) / Illinois East (ftUS)":"3529",
"NAD83(NSRS2007) / Illinois West":"3530",
"NAD83(NSRS2007) / Illinois West (ftUS)":"3531",
"NAD83(NSRS2007) / Indiana East":"3532",
"NAD83(NSRS2007) / Indiana East (ftUS)":"3533",
"NAD83(NSRS2007) / Indiana West":"3534",
"NAD83(NSRS2007) / Indiana West (ftUS)":"3535",
"NAD83(NSRS2007) / Iowa North":"3536",
"NAD83(NSRS2007) / Iowa North (ftUS)":"3537",
"NAD83(NSRS2007) / Iowa South":"3538",
"NAD83(NSRS2007) / Iowa South (ftUS)":"3539",
"NAD83(NSRS2007) / Kansas North":"3540",
"NAD83(NSRS2007) / Kansas North (ftUS)":"3541",
"NAD83(NSRS2007) / Kansas South":"3542",
"NAD83(NSRS2007) / Kansas South (ftUS)":"3543",
"NAD83(NSRS2007) / Kentucky North":"3544",
"NAD83(NSRS2007) / Kentucky North (ftUS)":"3545",
"NAD83(NSRS2007) / Kentucky Single Zone":"3546",
"NAD83(NSRS2007) / Kentucky Single Zone (ftUS)":"3547",
"NAD83(NSRS2007) / Kentucky South":"3548",
"NAD83(NSRS2007) / Kentucky South (ftUS)":"3549",
"NAD83(NSRS2007) / Louisiana North":"3550",
"NAD83(NSRS2007) / Louisiana North (ftUS)":"3551",
"NAD83(NSRS2007) / Louisiana South":"3552",
"NAD83(NSRS2007) / Louisiana South (ftUS)":"3553",
"NAD83(NSRS2007) / Maine CS2000 Central":"3554",
"NAD83(NSRS2007) / Maine CS2000 East":"3555",
"NAD83(NSRS2007) / Maine CS2000 West":"3556",
"NAD83(NSRS2007) / Maine East":"3557",
"NAD83(NSRS2007) / Maine West":"3558",
"NAD83(NSRS2007) / Maryland":"3559",
"NAD83 / Utah North (ftUS)":"3560",
"Old Hawaiian / Hawaii zone 1":"3561",
"Old Hawaiian / Hawaii zone 2":"3562",
"Old Hawaiian / Hawaii zone 3":"3563",
"Old Hawaiian / Hawaii zone 4":"3564",
"Old Hawaiian / Hawaii zone 5":"3565",
"NAD83 / Utah Central (ftUS)":"3566",
"NAD83 / Utah South (ftUS)":"3567",
"NAD83(HARN) / Utah North (ftUS)":"3568",
"NAD83(HARN) / Utah Central (ftUS)":"3569",
"NAD83(HARN) / Utah South (ftUS)":"3570",
"WGS 84 / North Pole LAEA Bering Sea":"3571",
"WGS 84 / North Pole LAEA Alaska":"3572",
"WGS 84 / North Pole LAEA Canada":"3573",
"WGS 84 / North Pole LAEA Atlantic":"3574",
"WGS 84 / North Pole LAEA Europe":"3575",
"WGS 84 / North Pole LAEA Russia":"3576",
"GDA94 / Australian Albers":"3577",
"NAD83 / Yukon Albers":"3578",
"NAD83(CSRS) / Yukon Albers":"3579",
"NAD83 / NWT Lambert":"3580",
"NAD83(CSRS) / NWT Lambert":"3581",
"NAD83(NSRS2007) / Maryland (ftUS)":"3582",
"NAD83(NSRS2007) / Massachusetts Island":"3583",
"NAD83(NSRS2007) / Massachusetts Island (ftUS)":"3584",
"NAD83(NSRS2007) / Massachusetts Mainland":"3585",
"NAD83(NSRS2007) / Massachusetts Mainland (ftUS)":"3586",
"NAD83(NSRS2007) / Michigan Central":"3587",
"NAD83(NSRS2007) / Michigan Central (ft)":"3588",
"NAD83(NSRS2007) / Michigan North":"3589",
"NAD83(NSRS2007) / Michigan North (ft)":"3590",
"NAD83(NSRS2007) / Michigan Oblique Mercator":"3591",
"NAD83(NSRS2007) / Michigan South":"3592",
"NAD83(NSRS2007) / Michigan South (ft)":"3593",
"NAD83(NSRS2007) / Minnesota Central":"3594",
"NAD83(NSRS2007) / Minnesota North":"3595",
"NAD83(NSRS2007) / Minnesota South":"3596",
"NAD83(NSRS2007) / Mississippi East":"3597",
"NAD83(NSRS2007) / Mississippi East (ftUS)":"3598",
"NAD83(NSRS2007) / Mississippi West":"3599",
"NAD83(NSRS2007) / Mississippi West (ftUS)":"3600",
"NAD83(NSRS2007) / Missouri Central":"3601",
"NAD83(NSRS2007) / Missouri East":"3602",
"NAD83(NSRS2007) / Missouri West":"3603",
"NAD83(NSRS2007) / Montana":"3604",
"NAD83(NSRS2007) / Montana (ft)":"3605",
"NAD83(NSRS2007) / Nebraska":"3606",
"NAD83(NSRS2007) / Nevada Central":"3607",
"NAD83(NSRS2007) / Nevada Central (ftUS)":"3608",
"NAD83(NSRS2007) / Nevada East":"3609",
"NAD83(NSRS2007) / Nevada East (ftUS)":"3610",
"NAD83(NSRS2007) / Nevada West":"3611",
"NAD83(NSRS2007) / Nevada West (ftUS)":"3612",
"NAD83(NSRS2007) / New Hampshire":"3613",
"NAD83(NSRS2007) / New Hampshire (ftUS)":"3614",
"NAD83(NSRS2007) / New Jersey":"3615",
"NAD83(NSRS2007) / New Jersey (ftUS)":"3616",
"NAD83(NSRS2007) / New Mexico Central":"3617",
"NAD83(NSRS2007) / New Mexico Central (ftUS)":"3618",
"NAD83(NSRS2007) / New Mexico East":"3619",
"NAD83(NSRS2007) / New Mexico East (ftUS)":"3620",
"NAD83(NSRS2007) / New Mexico West":"3621",
"NAD83(NSRS2007) / New Mexico West (ftUS)":"3622",
"NAD83(NSRS2007) / New York Central":"3623",
"NAD83(NSRS2007) / New York Central (ftUS)":"3624",
"NAD83(NSRS2007) / New York East":"3625",
"NAD83(NSRS2007) / New York East (ftUS)":"3626",
"NAD83(NSRS2007) / New York Long Island":"3627",
"NAD83(NSRS2007) / New York Long Island (ftUS)":"3628",
"NAD83(NSRS2007) / New York West":"3629",
"NAD83(NSRS2007) / New York West (ftUS)":"3630",
"NAD83(NSRS2007) / North Carolina":"3631",
"NAD83(NSRS2007) / North Carolina (ftUS)":"3632",
"NAD83(NSRS2007) / North Dakota North":"3633",
"NAD83(NSRS2007) / North Dakota North (ft)":"3634",
"NAD83(NSRS2007) / North Dakota South":"3635",
"NAD83(NSRS2007) / North Dakota South (ft)":"3636",
"NAD83(NSRS2007) / Ohio North":"3637",
"NAD83(NSRS2007) / Ohio South":"3638",
"NAD83(NSRS2007) / Oklahoma North":"3639",
"NAD83(NSRS2007) / Oklahoma North (ftUS)":"3640",
"NAD83(NSRS2007) / Oklahoma South":"3641",
"NAD83(NSRS2007) / Oklahoma South (ftUS)":"3642",
"NAD83(NSRS2007) / Oregon LCC (m)":"3643",
"NAD83(NSRS2007) / Oregon GIC Lambert (ft)":"3644",
"NAD83(NSRS2007) / Oregon North":"3645",
"NAD83(NSRS2007) / Oregon North (ft)":"3646",
"NAD83(NSRS2007) / Oregon South":"3647",
"NAD83(NSRS2007) / Oregon South (ft)":"3648",
"NAD83(NSRS2007) / Pennsylvania North":"3649",
"NAD83(NSRS2007) / Pennsylvania North (ftUS)":"3650",
"NAD83(NSRS2007) / Pennsylvania South":"3651",
"NAD83(NSRS2007) / Pennsylvania South (ftUS)":"3652",
"NAD83(NSRS2007) / Rhode Island":"3653",
"NAD83(NSRS2007) / Rhode Island (ftUS)":"3654",
"NAD83(NSRS2007) / South Carolina":"3655",
"NAD83(NSRS2007) / South Carolina (ft)":"3656",
"NAD83(NSRS2007) / South Dakota North":"3657",
"NAD83(NSRS2007) / South Dakota North (ftUS)":"3658",
"NAD83(NSRS2007) / South Dakota South":"3659",
"NAD83(NSRS2007) / South Dakota South (ftUS)":"3660",
"NAD83(NSRS2007) / Tennessee":"3661",
"NAD83(NSRS2007) / Tennessee (ftUS)":"3662",
"NAD83(NSRS2007) / Texas Central":"3663",
"NAD83(NSRS2007) / Texas Central (ftUS)":"3664",
"NAD83(NSRS2007) / Texas Centric Albers Equal Area":"3665",
"NAD83(NSRS2007) / Texas Centric Lambert Conformal":"3666",
"NAD83(NSRS2007) / Texas North":"3667",
"NAD83(NSRS2007) / Texas North (ftUS)":"3668",
"NAD83(NSRS2007) / Texas North Central":"3669",
"NAD83(NSRS2007) / Texas North Central (ftUS)":"3670",
"NAD83(NSRS2007) / Texas South":"3671",
"NAD83(NSRS2007) / Texas South (ftUS)":"3672",
"NAD83(NSRS2007) / Texas South Central":"3673",
"NAD83(NSRS2007) / Texas South Central (ftUS)":"3674",
"NAD83(NSRS2007) / Utah Central":"3675",
"NAD83(NSRS2007) / Utah Central (ft)":"3676",
"NAD83(NSRS2007) / Utah Central (ftUS)":"3677",
"NAD83(NSRS2007) / Utah North":"3678",
"NAD83(NSRS2007) / Utah North (ft)":"3679",
"NAD83(NSRS2007) / Utah North (ftUS)":"3680",
"NAD83(NSRS2007) / Utah South":"3681",
"NAD83(NSRS2007) / Utah South (ft)":"3682",
"NAD83(NSRS2007) / Utah South (ftUS)":"3683",
"NAD83(NSRS2007) / Vermont":"3684",
"NAD83(NSRS2007) / Virginia North":"3685",
"NAD83(NSRS2007) / Virginia North (ftUS)":"3686",
"NAD83(NSRS2007) / Virginia South":"3687",
"NAD83(NSRS2007) / Virginia South (ftUS)":"3688",
"NAD83(NSRS2007) / Washington North":"3689",
"NAD83(NSRS2007) / Washington North (ftUS)":"3690",
"NAD83(NSRS2007) / Washington South":"3691",
"NAD83(NSRS2007) / Washington South (ftUS)":"3692",
"NAD83(NSRS2007) / West Virginia North":"3693",
"NAD83(NSRS2007) / West Virginia South":"3694",
"NAD83(NSRS2007) / Wisconsin Central":"3695",
"NAD83(NSRS2007) / Wisconsin Central (ftUS)":"3696",
"NAD83(NSRS2007) / Wisconsin North":"3697",
"NAD83(NSRS2007) / Wisconsin North (ftUS)":"3698",
"NAD83(NSRS2007) / Wisconsin South":"3699",
"NAD83(NSRS2007) / Wisconsin South (ftUS)":"3700",
"NAD83(NSRS2007) / Wisconsin Transverse Mercator":"3701",
"NAD83(NSRS2007) / Wyoming East":"3702",
"NAD83(NSRS2007) / Wyoming East Central":"3703",
"NAD83(NSRS2007) / Wyoming West Central":"3704",
"NAD83(NSRS2007) / Wyoming West":"3705",
"NAD83(NSRS2007) / UTM zone 59N":"3706",
"NAD83(NSRS2007) / UTM zone 60N":"3707",
"NAD83(NSRS2007) / UTM zone 1N":"3708",
"NAD83(NSRS2007) / UTM zone 2N":"3709",
"NAD83(NSRS2007) / UTM zone 3N":"3710",
"NAD83(NSRS2007) / UTM zone 4N":"3711",
"NAD83(NSRS2007) / UTM zone 5N":"3712",
"NAD83(NSRS2007) / UTM zone 6N":"3713",
"NAD83(NSRS2007) / UTM zone 7N":"3714",
"NAD83(NSRS2007) / UTM zone 8N":"3715",
"NAD83(NSRS2007) / UTM zone 9N":"3716",
"NAD83(NSRS2007) / UTM zone 10N":"3717",
"NAD83(NSRS2007) / UTM zone 11N":"3718",
"NAD83(NSRS2007) / UTM zone 12N":"3719",
"NAD83(NSRS2007) / UTM zone 13N":"3720",
"NAD83(NSRS2007) / UTM zone 14N":"3721",
"NAD83(NSRS2007) / UTM zone 15N":"3722",
"NAD83(NSRS2007) / UTM zone 16N":"3723",
"NAD83(NSRS2007) / UTM zone 17N":"3724",
"NAD83(NSRS2007) / UTM zone 18N":"3725",
"NAD83(NSRS2007) / UTM zone 19N":"3726",
"Reunion 1947 / TM Reunion":"3727",
"NAD83(NSRS2007) / Ohio North (ftUS)":"3728",
"NAD83(NSRS2007) / Ohio South (ftUS)":"3729",
"NAD83(NSRS2007) / Wyoming East (ftUS)":"3730",
"NAD83(NSRS2007) / Wyoming East Central (ftUS)":"3731",
"NAD83(NSRS2007) / Wyoming West Central (ftUS)":"3732",
"NAD83(NSRS2007) / Wyoming West (ftUS)":"3733",
"NAD83 / Ohio North (ftUS)":"3734",
"NAD83 / Ohio South (ftUS)":"3735",
"NAD83 / Wyoming East (ftUS)":"3736",
"NAD83 / Wyoming East Central (ftUS)":"3737",
"NAD83 / Wyoming West Central (ftUS)":"3738",
"NAD83 / Wyoming West (ftUS)":"3739",
"NAD83(HARN) / UTM zone 10N":"3740",
"NAD83(HARN) / UTM zone 11N":"3741",
"NAD83(HARN) / UTM zone 12N":"3742",
"NAD83(HARN) / UTM zone 13N":"3743",
"NAD83(HARN) / UTM zone 14N":"3744",
"NAD83(HARN) / UTM zone 15N":"3745",
"NAD83(HARN) / UTM zone 16N":"3746",
"NAD83(HARN) / UTM zone 17N":"3747",
"NAD83(HARN) / UTM zone 18N":"3748",
"NAD83(HARN) / UTM zone 19N":"3749",
"NAD83(HARN) / UTM zone 4N":"3750",
"NAD83(HARN) / UTM zone 5N":"3751",
"WGS 84 / Mercator 41":"3752",
"NAD83(HARN) / Ohio North (ftUS)":"3753",
"NAD83(HARN) / Ohio South (ftUS)":"3754",
"NAD83(HARN) / Wyoming East (ftUS)":"3755",
"NAD83(HARN) / Wyoming East Central (ftUS)":"3756",
"NAD83(HARN) / Wyoming West Central (ftUS)":"3757",
"NAD83(HARN) / Wyoming West (ftUS)":"3758",
"NAD83 / Hawaii zone 3 (ftUS)":"3759",
"NAD83(HARN) / Hawaii zone 3 (ftUS)":"3760",
"NAD83(CSRS) / UTM zone 22N":"3761",
"WGS 84 / South Georgia Lambert":"3762",
"ETRS89 / Portugal TM06":"3763",
"NZGD2000 / Chatham Island Circuit 2000":"3764",
"HTRS96 / Croatia TM":"3765",
"HTRS96 / Croatia LCC":"3766",
"HTRS96 / UTM zone 33N":"3767",
"HTRS96 / UTM zone 34N":"3768",
"Bermuda 1957 / UTM zone 20N":"3769",
"BDA2000 / Bermuda 2000 National Grid":"3770",
"NAD27 / Alberta 3TM ref merid 111 W":"3771",
"NAD27 / Alberta 3TM ref merid 114 W":"3772",
"NAD27 / Alberta 3TM ref merid 117 W":"3773",
"NAD27 / Alberta 3TM ref merid 120 W":"3774",
"NAD83 / Alberta 3TM ref merid 111 W":"3775",
"NAD83 / Alberta 3TM ref merid 114 W":"3776",
"NAD83 / Alberta 3TM ref merid 117 W":"3777",
"NAD83 / Alberta 3TM ref merid 120 W":"3778",
"NAD83(CSRS) / Alberta 3TM ref merid 111 W":"3779",
"NAD83(CSRS) / Alberta 3TM ref merid 114 W":"3780",
"NAD83(CSRS) / Alberta 3TM ref merid 117 W":"3781",
"NAD83(CSRS) / Alberta 3TM ref merid 120 W":"3782",
"Pitcairn 2006 / Pitcairn TM 2006":"3783",
"Pitcairn 1967 / UTM zone 9S":"3784",
"Popular Visualisation CRS / Mercator":"3785",
"World Equidistant Cylindrical (Sphere)":"3786",
"MGI / Slovene National Grid":"3787",
"NZGD2000 / Auckland Islands TM 2000":"3788",
"NZGD2000 / Campbell Island TM 2000":"3789",
"NZGD2000 / Antipodes Islands TM 2000":"3790",
"NZGD2000 / Raoul Island TM 2000":"3791",
"NZGD2000 / Chatham Islands TM 2000":"3793",
"Slovenia 1996 / Slovene National Grid":"3794",
"NAD27 / Cuba Norte":"3795",
"NAD27 / Cuba Sur":"3796",
"NAD27 / MTQ Lambert":"3797",
"NAD83 / MTQ Lambert":"3798",
"NAD83(CSRS) / MTQ Lambert":"3799",
"NAD27 / Alberta 3TM ref merid 120 W":"3800",
"NAD83 / Alberta 3TM ref merid 120 W":"3801",
"NAD83(CSRS) / Alberta 3TM ref merid 120 W":"3802",
"ETRS89 / Belgian Lambert 2008":"3812",
"NAD83 / Mississippi TM":"3814",
"NAD83(HARN) / Mississippi TM":"3815",
"NAD83(NSRS2007) / Mississippi TM":"3816",
"HD1909":"3819",
"TWD67":"3821",
"TWD97":"3822",
"TWD97":"3823",
"TWD97":"3824",
"TWD97 / TM2 zone 119":"3825",
"TWD97 / TM2 zone 121":"3826",
"TWD67 / TM2 zone 119":"3827",
"TWD67 / TM2 zone 121":"3828",
"Hu Tzu Shan 1950 / UTM zone 51N":"3829",
"WGS 84 / PDC Mercator":"3832",
"Pulkovo 1942(58) / Gauss-Kruger zone 2":"3833",
"Pulkovo 1942(83) / Gauss-Kruger zone 2":"3834",
"Pulkovo 1942(83) / Gauss-Kruger zone 3":"3835",
"Pulkovo 1942(83) / Gauss-Kruger zone 4":"3836",
"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 3":"3837",
"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 4":"3838",
"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 9":"3839",
"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 10":"3840",
"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 6":"3841",
"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 7":"3842",
"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 8":"3843",
"Pulkovo 1942(58) / Stereo70":"3844",
"SWEREF99 / RT90 7.5 gon V emulation":"3845",
"SWEREF99 / RT90 5 gon V emulation":"3846",
"SWEREF99 / RT90 2.5 gon V emulation":"3847",
"SWEREF99 / RT90 0 gon emulation":"3848",
"SWEREF99 / RT90 2.5 gon O emulation":"3849",
"SWEREF99 / RT90 5 gon O emulation":"3850",
"NZGD2000 / NZCS2000":"3851",
"RSRGD2000 / DGLC2000":"3852",
"County ST74":"3854",
"EGM2008 height":"3855",
"WGS 84 / Pseudo-Mercator":"3857",
"ETRS89 / GK19FIN":"3873",
"ETRS89 / GK20FIN":"3874",
"ETRS89 / GK21FIN":"3875",
"ETRS89 / GK22FIN":"3876",
"ETRS89 / GK23FIN":"3877",
"ETRS89 / GK24FIN":"3878",
"ETRS89 / GK25FIN":"3879",
"ETRS89 / GK26FIN":"3880",
"ETRS89 / GK27FIN":"3881",
"ETRS89 / GK28FIN":"3882",
"ETRS89 / GK29FIN":"3883",
"ETRS89 / GK30FIN":"3884",
"ETRS89 / GK31FIN":"3885",
"Fao 1979 height":"3886",
"IGRS":"3887",
"IGRS":"3888",
"IGRS":"3889",
"IGRS / UTM zone 37N":"3890",
"IGRS / UTM zone 38N":"3891",
"IGRS / UTM zone 39N":"3892",
"ED50 / Iraq National Grid":"3893",
"N2000 height":"3900",
"KKJ / Finland Uniform Coordinate System + N60 height":"3901",
"ETRS89 / TM35FIN(N,E) + N60 height":"3902",
"ETRS89 / TM35FIN(N,E) + N2000 height":"3903",
"MGI 1901":"3906",
"MGI 1901 / Balkans zone 5":"3907",
"MGI 1901 / Balkans zone 6":"3908",
"MGI 1901 / Balkans zone 7":"3909",
"MGI 1901 / Balkans zone 8":"3910",
"MGI 1901 / Slovenia Grid":"3911",
"MGI 1901 / Slovene National Grid":"3912",
"Puerto Rico / UTM zone 20N":"3920",
"RGF93 / CC42":"3942",
"RGF93 / CC43":"3943",
"RGF93 / CC44":"3944",
"RGF93 / CC45":"3945",
"RGF93 / CC46":"3946",
"RGF93 / CC47":"3947",
"RGF93 / CC48":"3948",
"RGF93 / CC49":"3949",
"RGF93 / CC50":"3950",
"NAD83 / Virginia Lambert":"3968",
"NAD83(HARN) / Virginia Lambert":"3969",
"NAD83(NSRS2007) / Virginia Lambert":"3970",
"WGS 84 / NSIDC EASE-Grid North":"3973",
"WGS 84 / NSIDC EASE-Grid South":"3974",
"WGS 84 / NSIDC EASE-Grid Global":"3975",
"WGS 84 / NSIDC Sea Ice Polar Stereographic South":"3976",
"NAD83 / Canada Atlas Lambert":"3978",
"NAD83(CSRS) / Canada Atlas Lambert":"3979",
"Katanga 1955 / Katanga Lambert":"3985",
"Katanga 1955 / Katanga Gauss zone A":"3986",
"Katanga 1955 / Katanga Gauss zone B":"3987",
"Katanga 1955 / Katanga Gauss zone C":"3988",
"Katanga 1955 / Katanga Gauss zone D":"3989",
"Puerto Rico State Plane CS of 1927":"3991",
"Puerto Rico / St. Croix":"3992",
"Guam 1963 / Guam SPCS":"3993",
"WGS 84 / Mercator 41":"3994",
"WGS 84 / Arctic Polar Stereographic":"3995",
"WGS 84 / IBCAO Polar Stereographic":"3996",
"WGS 84 / Dubai Local TM":"3997",
"MOLDREF99":"4000",
"Unknown datum based upon the Airy 1830 ellipsoid":"4001",
"Unknown datum based upon the Airy Modified 1849 ellipsoid":"4002",
"Unknown datum based upon the Australian National Spheroid":"4003",
"Unknown datum based upon the Bessel 1841 ellipsoid":"4004",
"Unknown datum based upon the Bessel Modified ellipsoid":"4005",
"Unknown datum based upon the Bessel Namibia ellipsoid":"4006",
"Unknown datum based upon the Clarke 1858 ellipsoid":"4007",
"Unknown datum based upon the Clarke 1866 ellipsoid":"4008",
"Unknown datum based upon the Clarke 1866 Michigan ellipsoid":"4009",
"Unknown datum based upon the Clarke 1880 (Benoit) ellipsoid":"4010",
"Unknown datum based upon the Clarke 1880 (IGN) ellipsoid":"4011",
"Unknown datum based upon the Clarke 1880 (RGS) ellipsoid":"4012",
"Unknown datum based upon the Clarke 1880 (Arc) ellipsoid":"4013",
"Unknown datum based upon the Clarke 1880 (SGA 1922) ellipsoid":"4014",
"Unknown datum based upon the Everest 1830 (1937 Adjustment) ellipsoid":"4015",
"Unknown datum based upon the Everest 1830 (1967 Definition) ellipsoid":"4016",
"MOLDREF99":"4017",
"Unknown datum based upon the Everest 1830 Modified ellipsoid":"4018",
"Unknown datum based upon the GRS 1980 ellipsoid":"4019",
"Unknown datum based upon the Helmert 1906 ellipsoid":"4020",
"Unknown datum based upon the Indonesian National Spheroid":"4021",
"Unknown datum based upon the International 1924 ellipsoid":"4022",
"MOLDREF99":"4023",
"Unknown datum based upon the Krassowsky 1940 ellipsoid":"4024",
"Unknown datum based upon the NWL 9D ellipsoid":"4025",
"MOLDREF99 / Moldova TM":"4026",
"Unknown datum based upon the Plessis 1817 ellipsoid":"4027",
"Unknown datum based upon the Struve 1860 ellipsoid":"4028",
"Unknown datum based upon the War Office ellipsoid":"4029",
"Unknown datum based upon the WGS 84 ellipsoid":"4030",
"Unknown datum based upon the GEM 10C ellipsoid":"4031",
"Unknown datum based upon the OSU86F ellipsoid":"4032",
"Unknown datum based upon the OSU91A ellipsoid":"4033",
"Unknown datum based upon the Clarke 1880 ellipsoid":"4034",
"Unknown datum based upon the Authalic Sphere":"4035",
"Unknown datum based upon the GRS 1967 ellipsoid":"4036",
"WGS 84 / TMzn35N":"4037",
"WGS 84 / TMzn36N":"4038",
"RGRDC 2005":"4039",
"RGRDC 2005":"4040",
"Unknown datum based upon the Average Terrestrial System 1977 ellipsoid":"4041",
"Unknown datum based upon the Everest (1830 Definition) ellipsoid":"4042",
"Unknown datum based upon the WGS 72 ellipsoid":"4043",
"Unknown datum based upon the Everest 1830 (1962 Definition) ellipsoid":"4044",
"Unknown datum based upon the Everest 1830 (1975 Definition) ellipsoid":"4045",
"RGRDC 2005":"4046",
"Unspecified datum based upon the GRS 1980 Authalic Sphere":"4047",
"RGRDC 2005 / Congo TM zone 12":"4048",
"RGRDC 2005 / Congo TM zone 14":"4049",
"RGRDC 2005 / Congo TM zone 16":"4050",
"RGRDC 2005 / Congo TM zone 18":"4051",
"Unspecified datum based upon the Clarke 1866 Authalic Sphere":"4052",
"Unspecified datum based upon the International 1924 Authalic Sphere":"4053",
"Unspecified datum based upon the Hughes 1980 ellipsoid":"4054",
"Popular Visualisation CRS":"4055",
"RGRDC 2005 / Congo TM zone 20":"4056",
"RGRDC 2005 / Congo TM zone 22":"4057",
"RGRDC 2005 / Congo TM zone 24":"4058",
"RGRDC 2005 / Congo TM zone 26":"4059",
"RGRDC 2005 / Congo TM zone 28":"4060",
"RGRDC 2005 / UTM zone 33S":"4061",
"RGRDC 2005 / UTM zone 34S":"4062",
"RGRDC 2005 / UTM zone 35S":"4063",
"Chua / UTM zone 23S":"4071",
"SREF98":"4073",
"SREF98":"4074",
"SREF98":"4075",
"REGCAN95":"4079",
"REGCAN95":"4080",
"REGCAN95":"4081",
"REGCAN95 / UTM zone 27N":"4082",
"REGCAN95 / UTM zone 28N":"4083",
"WGS 84 / World Equidistant Cylindrical":"4087",
"World Equidistant Cylindrical (Sphere)":"4088",
"ETRS89 / DKTM1":"4093",
"ETRS89 / DKTM2":"4094",
"ETRS89 / DKTM3":"4095",
"ETRS89 / DKTM4":"4096",
"ETRS89 / DKTM1 + DVR90 height":"4097",
"ETRS89 / DKTM2 + DVR90 height":"4098",
"ETRS89 / DKTM3 + DVR90 height":"4099",
"ETRS89 / DKTM4 + DVR90 height":"4100",
"Greek":"4120",
"GGRS87":"4121",
"ATS77":"4122",
"KKJ":"4123",
"RT90":"4124",
"Samboja":"4125",
"LKS94 (ETRS89)":"4126",
"Tete":"4127",
"Madzansua":"4128",
"Observatario":"4129",
"Moznet":"4130",
"Indian 1960":"4131",
"FD58":"4132",
"EST92":"4133",
"PSD93":"4134",
"Old Hawaiian":"4135",
"St. Lawrence Island":"4136",
"St. Paul Island":"4137",
"St. George Island":"4138",
"Puerto Rico":"4139",
"NAD83(CSRS98)":"4140",
"Israel 1993":"4141",
"Locodjo 1965":"4142",
"Abidjan 1987":"4143",
"Kalianpur 1937":"4144",
"Kalianpur 1962":"4145",
"Kalianpur 1975":"4146",
"Hanoi 1972":"4147",
"Hartebeesthoek94":"4148",
"CH1903":"4149",
"CH1903+":"4150",
"CHTRF95":"4151",
"NAD83(HARN)":"4152",
"Rassadiran":"4153",
"ED50(ED77)":"4154",
"Dabola 1981":"4155",
"S-JTSK":"4156",
"Mount Dillon":"4157",
"Naparima 1955":"4158",
"ELD79":"4159",
"Chos Malal 1914":"4160",
"Pampa del Castillo":"4161",
"Korean 1985":"4162",
"Yemen NGN96":"4163",
"South Yemen":"4164",
"Bissau":"4165",
"Korean 1995":"4166",
"NZGD2000":"4167",
"Accra":"4168",
"American Samoa 1962":"4169",
"SIRGAS 1995":"4170",
"RGF93":"4171",
"POSGAR":"4172",
"IRENET95":"4173",
"Sierra Leone 1924":"4174",
"Sierra Leone 1968":"4175",
"Australian Antarctic":"4176",
"Pulkovo 1942(83)":"4178",
"Pulkovo 1942(58)":"4179",
"EST97":"4180",
"Luxembourg 1930":"4181",
"Azores Occidental 1939":"4182",
"Azores Central 1948":"4183",
"Azores Oriental 1940":"4184",
"Madeira 1936":"4185",
"OSNI 1952":"4188",
"REGVEN":"4189",
"POSGAR 98":"4190",
"Albanian 1987":"4191",
"Douala 1948":"4192",
"Manoca 1962":"4193",
"Qornoq 1927":"4194",
"Scoresbysund 1952":"4195",
"Ammassalik 1958":"4196",
"Garoua":"4197",
"Kousseri":"4198",
"Egypt 1930":"4199",
"Pulkovo 1995":"4200",
"Adindan":"4201",
"AGD66":"4202",
"AGD84":"4203",
"Ain el Abd":"4204",
"Afgooye":"4205",
"Agadez":"4206",
"Lisbon":"4207",
"Aratu":"4208",
"Arc 1950":"4209",
"Arc 1960":"4210",
"Batavia":"4211",
"Barbados 1938":"4212",
"Beduaram":"4213",
"Beijing 1954":"4214",
"Belge 1950":"4215",
"Bermuda 1957":"4216",
"NAD83 / BLM 59N (ftUS)":"4217",
"Bogota 1975":"4218",
"Bukit Rimpah":"4219",
"Camacupa":"4220",
"Campo Inchauspe":"4221",
"Cape":"4222",
"Carthage":"4223",
"Chua":"4224",
"Corrego Alegre 1970-72":"4225",
"Cote d'Ivoire":"4226",
"Deir ez Zor":"4227",
"Douala":"4228",
"Egypt 1907":"4229",
"ED50":"4230",
"ED87":"4231",
"Fahud":"4232",
"Gandajika 1970":"4233",
"Garoua":"4234",
"Guyane Francaise":"4235",
"Hu Tzu Shan 1950":"4236",
"HD72":"4237",
"ID74":"4238",
"Indian 1954":"4239",
"Indian 1975":"4240",
"Jamaica 1875":"4241",
"JAD69":"4242",
"Kalianpur 1880":"4243",
"Kandawala":"4244",
"Kertau 1968":"4245",
"KOC":"4246",
"La Canoa":"4247",
"PSAD56":"4248",
"Lake":"4249",
"Leigon":"4250",
"Liberia 1964":"4251",
"Lome":"4252",
"Luzon 1911":"4253",
"Hito XVIII 1963":"4254",
"Herat North":"4255",
"Mahe 1971":"4256",
"Makassar":"4257",
"ETRS89":"4258",
"Malongo 1987":"4259",
"Manoca":"4260",
"Merchich":"4261",
"Massawa":"4262",
"Minna":"4263",
"Mhast":"4264",
"Monte Mario":"4265",
"M'poraloko":"4266",
"NAD27":"4267",
"NAD27 Michigan":"4268",
"NAD83":"4269",
"Nahrwan 1967":"4270",
"Naparima 1972":"4271",
"NZGD49":"4272",
"NGO 1948":"4273",
"Datum 73":"4274",
"NTF":"4275",
"NSWC 9Z-2":"4276",
"OSGB 1936":"4277",
"OSGB70":"4278",
"OS(SN)80":"4279",
"Padang":"4280",
"Palestine 1923":"4281",
"Pointe Noire":"4282",
"GDA94":"4283",
"Pulkovo 1942":"4284",
"Qatar 1974":"4285",
"Qatar 1948":"4286",
"Qornoq":"4287",
"Loma Quintana":"4288",
"Amersfoort":"4289",
"SAD69":"4291",
"Sapper Hill 1943":"4292",
"Schwarzeck":"4293",
"Segora":"4294",
"Serindung":"4295",
"Sudan":"4296",
"Tananarive":"4297",
"Timbalai 1948":"4298",
"TM65":"4299",
"TM75":"4300",
"Tokyo":"4301",
"Trinidad 1903":"4302",
"TC(1948)":"4303",
"Voirol 1875":"4304",
"Bern 1938":"4306",
"Nord Sahara 1959":"4307",
"RT38":"4308",
"Yacare":"4309",
"Yoff":"4310",
"Zanderij":"4311",
"MGI":"4312",
"Belge 1972":"4313",
"DHDN":"4314",
"Conakry 1905":"4315",
"Dealul Piscului 1930":"4316",
"Dealul Piscului 1970":"4317",
"NGN":"4318",
"KUDAMS":"4319",
"WGS 72":"4322",
"WGS 72BE":"4324",
"WGS 84":"4326",
"WGS 84 (geographic 3D)":"4327",
"WGS 84 (geocentric)":"4328",
"WGS 84 (3D)":"4329",
"ITRF88 (geocentric)":"4330",
"ITRF89 (geocentric)":"4331",
"ITRF90 (geocentric)":"4332",
"ITRF91 (geocentric)":"4333",
"ITRF92 (geocentric)":"4334",
"ITRF93 (geocentric)":"4335",
"ITRF94 (geocentric)":"4336",
"ITRF96 (geocentric)":"4337",
"ITRF97 (geocentric)":"4338",
"Australian Antarctic (3D)":"4339",
"Australian Antarctic (geocentric)":"4340",
"EST97 (3D)":"4341",
"EST97 (geocentric)":"4342",
"CHTRF95 (3D)":"4343",
"CHTRF95 (geocentric)":"4344",
"ETRS89 (3D)":"4345",
"ETRS89 (geocentric)":"4346",
"GDA94 (3D)":"4347",
"GDA94 (geocentric)":"4348",
"Hartebeesthoek94 (3D)":"4349",
"Hartebeesthoek94 (geocentric)":"4350",
"IRENET95 (3D)":"4351",
"IRENET95 (geocentric)":"4352",
"JGD2000 (3D)":"4353",
"JGD2000 (geocentric)":"4354",
"LKS94 (ETRS89) (3D)":"4355",
"LKS94 (ETRS89) (geocentric)":"4356",
"Moznet (3D)":"4357",
"Moznet (geocentric)":"4358",
"NAD83(CSRS) (3D)":"4359",
"NAD83(CSRS) (geocentric)":"4360",
"NAD83(HARN) (3D)":"4361",
"NAD83(HARN) (geocentric)":"4362",
"NZGD2000 (3D)":"4363",
"NZGD2000 (geocentric)":"4364",
"POSGAR 98 (3D)":"4365",
"POSGAR 98 (geocentric)":"4366",
"REGVEN (3D)":"4367",
"REGVEN (geocentric)":"4368",
"RGF93 (3D)":"4369",
"RGF93 (geocentric)":"4370",
"RGFG95 (3D)":"4371",
"RGFG95 (geocentric)":"4372",
"RGR92 (3D)":"4373",
"RGR92 (geocentric)":"4374",
"SIRGAS (3D)":"4375",
"SIRGAS (geocentric)":"4376",
"SWEREF99 (3D)":"4377",
"SWEREF99 (geocentric)":"4378",
"Yemen NGN96 (3D)":"4379",
"Yemen NGN96 (geocentric)":"4380",
"RGNC 1991 (3D)":"4381",
"RGNC 1991 (geocentric)":"4382",
"RRAF 1991 (3D)":"4383",
"RRAF 1991 (geocentric)":"4384",
"ITRF2000 (geocentric)":"4385",
"ISN93 (3D)":"4386",
"ISN93 (geocentric)":"4387",
"LKS92 (3D)":"4388",
"LKS92 (geocentric)":"4389",
"Kertau 1968 / Johor Grid":"4390",
"Kertau 1968 / Sembilan and Melaka Grid":"4391",
"Kertau 1968 / Pahang Grid":"4392",
"Kertau 1968 / Selangor Grid":"4393",
"Kertau 1968 / Terengganu Grid":"4394",
"Kertau 1968 / Pinang Grid":"4395",
"Kertau 1968 / Kedah and Perlis Grid":"4396",
"Kertau 1968 / Perak Revised Grid":"4397",
"Kertau 1968 / Kelantan Grid":"4398",
"NAD27 / BLM 59N (ftUS)":"4399",
"NAD27 / BLM 60N (ftUS)":"4400",
"NAD27 / BLM 1N (ftUS)":"4401",
"NAD27 / BLM 2N (ftUS)":"4402",
"NAD27 / BLM 3N (ftUS)":"4403",
"NAD27 / BLM 4N (ftUS)":"4404",
"NAD27 / BLM 5N (ftUS)":"4405",
"NAD27 / BLM 6N (ftUS)":"4406",
"NAD27 / BLM 7N (ftUS)":"4407",
"NAD27 / BLM 8N (ftUS)":"4408",
"NAD27 / BLM 9N (ftUS)":"4409",
"NAD27 / BLM 10N (ftUS)":"4410",
"NAD27 / BLM 11N (ftUS)":"4411",
"NAD27 / BLM 12N (ftUS)":"4412",
"NAD27 / BLM 13N (ftUS)":"4413",
"NAD83(HARN) / Guam Map Grid":"4414",
"Katanga 1955 / Katanga Lambert":"4415",
"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 7":"4417",
"NAD27 / BLM 18N (ftUS)":"4418",
"NAD27 / BLM 19N (ftUS)":"4419",
"NAD83 / BLM 60N (ftUS)":"4420",
"NAD83 / BLM 1N (ftUS)":"4421",
"NAD83 / BLM 2N (ftUS)":"4422",
"NAD83 / BLM 3N (ftUS)":"4423",
"NAD83 / BLM 4N (ftUS)":"4424",
"NAD83 / BLM 5N (ftUS)":"4425",
"NAD83 / BLM 6N (ftUS)":"4426",
"NAD83 / BLM 7N (ftUS)":"4427",
"NAD83 / BLM 8N (ftUS)":"4428",
"NAD83 / BLM 9N (ftUS)":"4429",
"NAD83 / BLM 10N (ftUS)":"4430",
"NAD83 / BLM 11N (ftUS)":"4431",
"NAD83 / BLM 12N (ftUS)":"4432",
"NAD83 / BLM 13N (ftUS)":"4433",
"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 8":"4434",
"NAD83(NSRS2007) / Puerto Rico and Virgin Is.":"4437",
"NAD83 / BLM 18N (ftUS)":"4438",
"NAD83 / BLM 19N (ftUS)":"4439",
"NZVD2009 height":"4440",
"NAD27 / Pennsylvania South":"4455",
"NAD27 / New York Long Island":"4456",
"NAD83 / South Dakota North (ftUS)":"4457",
"Dunedin-Bluff 1960 height":"4458",
"WGS 84 / Australian Centre for Remote Sensing Lambert":"4462",
"RGSPM06":"4463",
"RGSPM06":"4465",
"RGSPM06":"4466",
"RGSPM06 / UTM zone 21N":"4467",
"RGM04":"4468",
"RGM04":"4469",
"RGM04":"4470",
"RGM04 / UTM zone 38S":"4471",
"Cadastre 1997":"4472",
"Cadastre 1997":"4473",
"Cadastre 1997 / UTM zone 38S":"4474",
"Cadastre 1997":"4475",
"China Geodetic Coordinate System 2000":"4479",
"China Geodetic Coordinate System 2000":"4480",
"Mexico ITRF92":"4481",
"Mexico ITRF92":"4482",
"Mexico ITRF92":"4483",
"Mexico ITRF92 / UTM zone 11N":"4484",
"Mexico ITRF92 / UTM zone 12N":"4485",
"Mexico ITRF92 / UTM zone 13N":"4486",
"Mexico ITRF92 / UTM zone 14N":"4487",
"Mexico ITRF92 / UTM zone 15N":"4488",
"Mexico ITRF92 / UTM zone 16N":"4489",
"China Geodetic Coordinate System 2000":"4490",
"CGCS2000 / Gauss-Kruger zone 13":"4491",
"CGCS2000 / Gauss-Kruger zone 14":"4492",
"CGCS2000 / Gauss-Kruger zone 15":"4493",
"CGCS2000 / Gauss-Kruger zone 16":"4494",
"CGCS2000 / Gauss-Kruger zone 17":"4495",
"CGCS2000 / Gauss-Kruger zone 18":"4496",
"CGCS2000 / Gauss-Kruger zone 19":"4497",
"CGCS2000 / Gauss-Kruger zone 20":"4498",
"CGCS2000 / Gauss-Kruger zone 21":"4499",
"CGCS2000 / Gauss-Kruger zone 22":"4500",
"CGCS2000 / Gauss-Kruger zone 23":"4501",
"CGCS2000 / Gauss-Kruger CM 75E":"4502",
"CGCS2000 / Gauss-Kruger CM 81E":"4503",
"CGCS2000 / Gauss-Kruger CM 87E":"4504",
"CGCS2000 / Gauss-Kruger CM 93E":"4505",
"CGCS2000 / Gauss-Kruger CM 99E":"4506",
"CGCS2000 / Gauss-Kruger CM 105E":"4507",
"CGCS2000 / Gauss-Kruger CM 111E":"4508",
"CGCS2000 / Gauss-Kruger CM 117E":"4509",
"CGCS2000 / Gauss-Kruger CM 123E":"4510",
"CGCS2000 / Gauss-Kruger CM 129E":"4511",
"CGCS2000 / Gauss-Kruger CM 135E":"4512",
"CGCS2000 / 3-degree Gauss-Kruger zone 25":"4513",
"CGCS2000 / 3-degree Gauss-Kruger zone 26":"4514",
"CGCS2000 / 3-degree Gauss-Kruger zone 27":"4515",
"CGCS2000 / 3-degree Gauss-Kruger zone 28":"4516",
"CGCS2000 / 3-degree Gauss-Kruger zone 29":"4517",
"CGCS2000 / 3-degree Gauss-Kruger zone 30":"4518",
"CGCS2000 / 3-degree Gauss-Kruger zone 31":"4519",
"CGCS2000 / 3-degree Gauss-Kruger zone 32":"4520",
"CGCS2000 / 3-degree Gauss-Kruger zone 33":"4521",
"CGCS2000 / 3-degree Gauss-Kruger zone 34":"4522",
"CGCS2000 / 3-degree Gauss-Kruger zone 35":"4523",
"CGCS2000 / 3-degree Gauss-Kruger zone 36":"4524",
"CGCS2000 / 3-degree Gauss-Kruger zone 37":"4525",
"CGCS2000 / 3-degree Gauss-Kruger zone 38":"4526",
"CGCS2000 / 3-degree Gauss-Kruger zone 39":"4527",
"CGCS2000 / 3-degree Gauss-Kruger zone 40":"4528",
"CGCS2000 / 3-degree Gauss-Kruger zone 41":"4529",
"CGCS2000 / 3-degree Gauss-Kruger zone 42":"4530",
"CGCS2000 / 3-degree Gauss-Kruger zone 43":"4531",
"CGCS2000 / 3-degree Gauss-Kruger zone 44":"4532",
"CGCS2000 / 3-degree Gauss-Kruger zone 45":"4533",
"CGCS2000 / 3-degree Gauss-Kruger CM 75E":"4534",
"CGCS2000 / 3-degree Gauss-Kruger CM 78E":"4535",
"CGCS2000 / 3-degree Gauss-Kruger CM 81E":"4536",
"CGCS2000 / 3-degree Gauss-Kruger CM 84E":"4537",
"CGCS2000 / 3-degree Gauss-Kruger CM 87E":"4538",
"CGCS2000 / 3-degree Gauss-Kruger CM 90E":"4539",
"CGCS2000 / 3-degree Gauss-Kruger CM 93E":"4540",
"CGCS2000 / 3-degree Gauss-Kruger CM 96E":"4541",
"CGCS2000 / 3-degree Gauss-Kruger CM 99E":"4542",
"CGCS2000 / 3-degree Gauss-Kruger CM 102E":"4543",
"CGCS2000 / 3-degree Gauss-Kruger CM 105E":"4544",
"CGCS2000 / 3-degree Gauss-Kruger CM 108E":"4545",
"CGCS2000 / 3-degree Gauss-Kruger CM 111E":"4546",
"CGCS2000 / 3-degree Gauss-Kruger CM 114E":"4547",
"CGCS2000 / 3-degree Gauss-Kruger CM 117E":"4548",
"CGCS2000 / 3-degree Gauss-Kruger CM 120E":"4549",
"CGCS2000 / 3-degree Gauss-Kruger CM 123E":"4550",
"CGCS2000 / 3-degree Gauss-Kruger CM 126E":"4551",
"CGCS2000 / 3-degree Gauss-Kruger CM 129E":"4552",
"CGCS2000 / 3-degree Gauss-Kruger CM 132E":"4553",
"CGCS2000 / 3-degree Gauss-Kruger CM 135E":"4554",
"New Beijing":"4555",
"RRAF 1991":"4556",
"RRAF 1991":"4557",
"RRAF 1991":"4558",
"RRAF 1991 / UTM zone 20N":"4559",
"New Beijing / Gauss-Kruger zone 13":"4568",
"New Beijing / Gauss-Kruger zone 14":"4569",
"New Beijing / Gauss-Kruger zone 15":"4570",
"New Beijing / Gauss-Kruger zone 16":"4571",
"New Beijing / Gauss-Kruger zone 17":"4572",
"New Beijing / Gauss-Kruger zone 18":"4573",
"New Beijing / Gauss-Kruger zone 19":"4574",
"New Beijing / Gauss-Kruger zone 20":"4575",
"New Beijing / Gauss-Kruger zone 21":"4576",
"New Beijing / Gauss-Kruger zone 22":"4577",
"New Beijing / Gauss-Kruger zone 23":"4578",
"New Beijing / Gauss-Kruger CM 75E":"4579",
"New Beijing / Gauss-Kruger CM 81E":"4580",
"New Beijing / Gauss-Kruger CM 87E":"4581",
"New Beijing / Gauss-Kruger CM 93E":"4582",
"New Beijing / Gauss-Kruger CM 99E":"4583",
"New Beijing / Gauss-Kruger CM 105E":"4584",
"New Beijing / Gauss-Kruger CM 111E":"4585",
"New Beijing / Gauss-Kruger CM 117E":"4586",
"New Beijing / Gauss-Kruger CM 123E":"4587",
"New Beijing / Gauss-Kruger CM 129E":"4588",
"New Beijing / Gauss-Kruger CM 135E":"4589",
"Anguilla 1957":"4600",
"Antigua 1943":"4601",
"Dominica 1945":"4602",
"Grenada 1953":"4603",
"Montserrat 1958":"4604",
"St. Kitts 1955":"4605",
"St. Lucia 1955":"4606",
"St. Vincent 1945":"4607",
"NAD27(76)":"4608",
"NAD27(CGQ77)":"4609",
"Xian 1980":"4610",
"Hong Kong 1980":"4611",
"JGD2000":"4612",
"Segara":"4613",
"QND95":"4614",
"Porto Santo":"4615",
"Selvagem Grande":"4616",
"NAD83(CSRS)":"4617",
"SAD69":"4618",
"SWEREF99":"4619",
"Point 58":"4620",
"Fort Marigot":"4621",
"Guadeloupe 1948":"4622",
"CSG67":"4623",
"RGFG95":"4624",
"Martinique 1938":"4625",
"Reunion 1947":"4626",
"RGR92":"4627",
"Tahiti 52":"4628",
"Tahaa 54":"4629",
"IGN72 Nuku Hiva":"4630",
"K0 1949":"4631",
"Combani 1950":"4632",
"IGN56 Lifou":"4633",
"IGN72 Grand Terre":"4634",
"ST87 Ouvea":"4635",
"Petrels 1972":"4636",
"Perroud 1950":"4637",
"Saint Pierre et Miquelon 1950":"4638",
"MOP78":"4639",
"RRAF 1991":"4640",
"IGN53 Mare":"4641",
"ST84 Ile des Pins":"4642",
"ST71 Belep":"4643",
"NEA74 Noumea":"4644",
"RGNC 1991":"4645",
"Grand Comoros":"4646",
"ETRS89 / UTM zone 32N (zE-N)":"4647",
"New Beijing / 3-degree Gauss-Kruger zone 25":"4652",
"New Beijing / 3-degree Gauss-Kruger zone 26":"4653",
"New Beijing / 3-degree Gauss-Kruger zone 27":"4654",
"New Beijing / 3-degree Gauss-Kruger zone 28":"4655",
"New Beijing / 3-degree Gauss-Kruger zone 29":"4656",
"Reykjavik 1900":"4657",
"Hjorsey 1955":"4658",
"ISN93":"4659",
"Helle 1954":"4660",
"LKS92":"4661",
"IGN72 Grande Terre":"4662",
"Porto Santo 1995":"4663",
"Azores Oriental 1995":"4664",
"Azores Central 1995":"4665",
"Lisbon 1890":"4666",
"IKBD-92":"4667",
"ED79":"4668",
"LKS94":"4669",
"IGM95":"4670",
"Voirol 1879":"4671",
"Chatham Islands 1971":"4672",
"Chatham Islands 1979":"4673",
"SIRGAS 2000":"4674",
"Guam 1963":"4675",
"Vientiane 1982":"4676",
"Lao 1993":"4677",
"Lao 1997":"4678",
"Jouik 1961":"4679",
"Nouakchott 1965":"4680",
"Mauritania 1999":"4681",
"Gulshan 303":"4682",
"PRS92":"4683",
"Gan 1970":"4684",
"Gandajika":"4685",
"MAGNA-SIRGAS":"4686",
"RGPF":"4687",
"Fatu Iva 72":"4688",
"IGN63 Hiva Oa":"4689",
"Tahiti 79":"4690",
"Moorea 87":"4691",
"Maupiti 83":"4692",
"Nakhl-e Ghanem":"4693",
"POSGAR 94":"4694",
"Katanga 1955":"4695",
"Kasai 1953":"4696",
"IGC 1962 6th Parallel South":"4697",
"IGN 1962 Kerguelen":"4698",
"Le Pouce 1934":"4699",
"IGN Astro 1960":"4700",
"IGCB 1955":"4701",
"Mauritania 1999":"4702",
"Mhast 1951":"4703",
"Mhast (onshore)":"4704",
"Mhast (offshore)":"4705",
"Egypt Gulf of Suez S-650 TL":"4706",
"Tern Island 1961":"4707",
"Cocos Islands 1965":"4708",
"Iwo Jima 1945":"4709",
"Astro DOS 71":"4710",
"Marcus Island 1952":"4711",
"Ascension Island 1958":"4712",
"Ayabelle Lighthouse":"4713",
"Bellevue":"4714",
"Camp Area Astro":"4715",
"Phoenix Islands 1966":"4716",
"Cape Canaveral":"4717",
"Solomon 1968":"4718",
"Easter Island 1967":"4719",
"Fiji 1986":"4720",
"Fiji 1956":"4721",
"South Georgia 1968":"4722",
"GCGD59":"4723",
"Diego Garcia 1969":"4724",
"Johnston Island 1961":"4725",
"SIGD61":"4726",
"Midway 1961":"4727",
"Pico de las Nieves 1984":"4728",
"Pitcairn 1967":"4729",
"Santo 1965":"4730",
"Viti Levu 1916":"4731",
"Marshall Islands 1960":"4732",
"Wake Island 1952":"4733",
"Tristan 1968":"4734",
"Kusaie 1951":"4735",
"Deception Island":"4736",
"Korea 2000":"4737",
"Hong Kong 1963":"4738",
"Hong Kong 1963(67)":"4739",
"PZ-90":"4740",
"FD54":"4741",
"GDM2000":"4742",
"Karbala 1979":"4743",
"Nahrwan 1934":"4744",
"RD/83":"4745",
"PD/83":"4746",
"GR96":"4747",
"Vanua Levu 1915":"4748",
"RGNC91-93":"4749",
"ST87 Ouvea":"4750",
"Kertau (RSO)":"4751",
"Viti Levu 1912":"4752",
"fk89":"4753",
"LGD2006":"4754",
"DGN95":"4755",
"VN-2000":"4756",
"SVY21":"4757",
"JAD2001":"4758",
"NAD83(NSRS2007)":"4759",
"WGS 66":"4760",
"HTRS96":"4761",
"BDA2000":"4762",
"Pitcairn 2006":"4763",
"RSRGD2000":"4764",
"Slovenia 1996":"4765",
"New Beijing / 3-degree Gauss-Kruger zone 30":"4766",
"New Beijing / 3-degree Gauss-Kruger zone 31":"4767",
"New Beijing / 3-degree Gauss-Kruger zone 32":"4768",
"New Beijing / 3-degree Gauss-Kruger zone 33":"4769",
"New Beijing / 3-degree Gauss-Kruger zone 34":"4770",
"New Beijing / 3-degree Gauss-Kruger zone 35":"4771",
"New Beijing / 3-degree Gauss-Kruger zone 36":"4772",
"New Beijing / 3-degree Gauss-Kruger zone 37":"4773",
"New Beijing / 3-degree Gauss-Kruger zone 38":"4774",
"New Beijing / 3-degree Gauss-Kruger zone 39":"4775",
"New Beijing / 3-degree Gauss-Kruger zone 40":"4776",
"New Beijing / 3-degree Gauss-Kruger zone 41":"4777",
"New Beijing / 3-degree Gauss-Kruger zone 42":"4778",
"New Beijing / 3-degree Gauss-Kruger zone 43":"4779",
"New Beijing / 3-degree Gauss-Kruger zone 44":"4780",
"New Beijing / 3-degree Gauss-Kruger zone 45":"4781",
"New Beijing / 3-degree Gauss-Kruger CM 75E":"4782",
"New Beijing / 3-degree Gauss-Kruger CM 78E":"4783",
"New Beijing / 3-degree Gauss-Kruger CM 81E":"4784",
"New Beijing / 3-degree Gauss-Kruger CM 84E":"4785",
"New Beijing / 3-degree Gauss-Kruger CM 87E":"4786",
"New Beijing / 3-degree Gauss-Kruger CM 90E":"4787",
"New Beijing / 3-degree Gauss-Kruger CM 93E":"4788",
"New Beijing / 3-degree Gauss-Kruger CM 96E":"4789",
"New Beijing / 3-degree Gauss-Kruger CM 99E":"4790",
"New Beijing / 3-degree Gauss-Kruger CM 102E":"4791",
"New Beijing / 3-degree Gauss-Kruger CM 105E":"4792",
"New Beijing / 3-degree Gauss-Kruger CM 108E":"4793",
"New Beijing / 3-degree Gauss-Kruger CM 111E":"4794",
"New Beijing / 3-degree Gauss-Kruger CM 114E":"4795",
"New Beijing / 3-degree Gauss-Kruger CM 117E":"4796",
"New Beijing / 3-degree Gauss-Kruger CM 120E":"4797",
"New Beijing / 3-degree Gauss-Kruger CM 123E":"4798",
"New Beijing / 3-degree Gauss-Kruger CM 126E":"4799",
"New Beijing / 3-degree Gauss-Kruger CM 129E":"4800",
"Bern 1898 (Bern)":"4801",
"Bogota 1975 (Bogota)":"4802",
"Lisbon (Lisbon)":"4803",
"Makassar (Jakarta)":"4804",
"MGI (Ferro)":"4805",
"Monte Mario (Rome)":"4806",
"NTF (Paris)":"4807",
"Padang (Jakarta)":"4808",
"Belge 1950 (Brussels)":"4809",
"Tananarive (Paris)":"4810",
"Voirol 1875 (Paris)":"4811",
"New Beijing / 3-degree Gauss-Kruger CM 132E":"4812",
"Batavia (Jakarta)":"4813",
"RT38 (Stockholm)":"4814",
"Greek (Athens)":"4815",
"Carthage (Paris)":"4816",
"NGO 1948 (Oslo)":"4817",
"S-JTSK (Ferro)":"4818",
"Nord Sahara 1959 (Paris)":"4819",
"Segara (Jakarta)":"4820",
"Voirol 1879 (Paris)":"4821",
"New Beijing / 3-degree Gauss-Kruger CM 135E":"4822",
"Sao Tome":"4823",
"Principe":"4824",
"WGS 84 / Cape Verde National":"4826",
"ETRS89 / LCC Germany (N-E)":"4839",
"ETRS89 / NTM zone 5":"4855",
"ETRS89 / NTM zone 6":"4856",
"ETRS89 / NTM zone 7":"4857",
"ETRS89 / NTM zone 8":"4858",
"ETRS89 / NTM zone 9":"4859",
"ETRS89 / NTM zone 10":"4860",
"ETRS89 / NTM zone 11":"4861",
"ETRS89 / NTM zone 12":"4862",
"ETRS89 / NTM zone 13":"4863",
"ETRS89 / NTM zone 14":"4864",
"ETRS89 / NTM zone 15":"4865",
"ETRS89 / NTM zone 16":"4866",
"ETRS89 / NTM zone 17":"4867",
"ETRS89 / NTM zone 18":"4868",
"ETRS89 / NTM zone 19":"4869",
"ETRS89 / NTM zone 20":"4870",
"ETRS89 / NTM zone 21":"4871",
"ETRS89 / NTM zone 22":"4872",
"ETRS89 / NTM zone 23":"4873",
"ETRS89 / NTM zone 24":"4874",
"ETRS89 / NTM zone 25":"4875",
"ETRS89 / NTM zone 26":"4876",
"ETRS89 / NTM zone 27":"4877",
"ETRS89 / NTM zone 28":"4878",
"ETRS89 / NTM zone 29":"4879",
"ETRS89 / NTM zone 30":"4880",
"Slovenia 1996":"4882",
"Slovenia 1996":"4883",
"RSRGD2000":"4884",
"RSRGD2000":"4885",
"BDA2000":"4886",
"BDA2000":"4887",
"HTRS96":"4888",
"HTRS96":"4889",
"WGS 66":"4890",
"WGS 66":"4891",
"NAD83(NSRS2007)":"4892",
"NAD83(NSRS2007)":"4893",
"JAD2001":"4894",
"JAD2001":"4895",
"ITRF2005":"4896",
"DGN95":"4897",
"DGN95":"4898",
"LGD2006":"4899",
"LGD2006":"4900",
"ATF (Paris)":"4901",
"NDG (Paris)":"4902",
"Madrid 1870 (Madrid)":"4903",
"Lisbon 1890 (Lisbon)":"4904",
"RGNC91-93":"4906",
"RGNC91-93":"4907",
"GR96":"4908",
"GR96":"4909",
"ITRF88":"4910",
"ITRF89":"4911",
"ITRF90":"4912",
"ITRF91":"4913",
"ITRF92":"4914",
"ITRF93":"4915",
"ITRF94":"4916",
"ITRF96":"4917",
"ITRF97":"4918",
"ITRF2000":"4919",
"GDM2000":"4920",
"GDM2000":"4921",
"PZ-90":"4922",
"PZ-90":"4923",
"Mauritania 1999":"4924",
"Mauritania 1999":"4925",
"Korea 2000":"4926",
"Korea 2000":"4927",
"POSGAR 94":"4928",
"POSGAR 94":"4929",
"Australian Antarctic":"4930",
"Australian Antarctic":"4931",
"CHTRF95":"4932",
"CHTRF95":"4933",
"EST97":"4934",
"EST97":"4935",
"ETRS89":"4936",
"ETRS89":"4937",
"GDA94":"4938",
"GDA94":"4939",
"Hartebeesthoek94":"4940",
"Hartebeesthoek94":"4941",
"IRENET95":"4942",
"IRENET95":"4943",
"ISN93":"4944",
"ISN93":"4945",
"JGD2000":"4946",
"JGD2000":"4947",
"LKS92":"4948",
"LKS92":"4949",
"LKS94":"4950",
"LKS94":"4951",
"Moznet":"4952",
"Moznet":"4953",
"NAD83(CSRS)":"4954",
"NAD83(CSRS)":"4955",
"NAD83(HARN)":"4956",
"NAD83(HARN)":"4957",
"NZGD2000":"4958",
"NZGD2000":"4959",
"POSGAR 98":"4960",
"POSGAR 98":"4961",
"REGVEN":"4962",
"REGVEN":"4963",
"RGF93":"4964",
"RGF93":"4965",
"RGFG95":"4966",
"RGFG95":"4967",
"RGNC 1991":"4968",
"RGNC 1991":"4969",
"RGR92":"4970",
"RGR92":"4971",
"RRAF 1991":"4972",
"RRAF 1991":"4973",
"SIRGAS 1995":"4974",
"SIRGAS 1995":"4975",
"SWEREF99":"4976",
"SWEREF99":"4977",
"WGS 84":"4978",
"WGS 84":"4979",
"Yemen NGN96":"4980",
"Yemen NGN96":"4981",
"IGM95":"4982",
"IGM95":"4983",
"WGS 72":"4984",
"WGS 72":"4985",
"WGS 72BE":"4986",
"WGS 72BE":"4987",
"SIRGAS 2000":"4988",
"SIRGAS 2000":"4989",
"Lao 1993":"4990",
"Lao 1993":"4991",
"Lao 1997":"4992",
"Lao 1997":"4993",
"PRS92":"4994",
"PRS92":"4995",
"MAGNA-SIRGAS":"4996",
"MAGNA-SIRGAS":"4997",
"RGPF":"4998",
"RGPF":"4999",
"PTRA08":"5011",
"PTRA08":"5012",
"PTRA08":"5013",
"PTRA08 / UTM zone 25N":"5014",
"PTRA08 / UTM zone 26N":"5015",
"PTRA08 / UTM zone 28N":"5016",
"Lisbon 1890 / Portugal Bonne New":"5017",
"Lisbon / Portuguese Grid New":"5018",
"WGS 84 / UPS North (E,N)":"5041",
"WGS 84 / UPS South (E,N)":"5042",
"ETRS89 / TM35FIN(N,E)":"5048",
"NAD27 / Conus Albers":"5069",
"NAD83 / Conus Albers":"5070",
"NAD83(HARN) / Conus Albers":"5071",
"NAD83(NSRS2007) / Conus Albers":"5072",
"ETRS89 / NTM zone 5":"5105",
"ETRS89 / NTM zone 6":"5106",
"ETRS89 / NTM zone 7":"5107",
"ETRS89 / NTM zone 8":"5108",
"ETRS89 / NTM zone 9":"5109",
"ETRS89 / NTM zone 10":"5110",
"ETRS89 / NTM zone 11":"5111",
"ETRS89 / NTM zone 12":"5112",
"ETRS89 / NTM zone 13":"5113",
"ETRS89 / NTM zone 14":"5114",
"ETRS89 / NTM zone 15":"5115",
"ETRS89 / NTM zone 16":"5116",
"ETRS89 / NTM zone 17":"5117",
"ETRS89 / NTM zone 18":"5118",
"ETRS89 / NTM zone 19":"5119",
"ETRS89 / NTM zone 20":"5120",
"ETRS89 / NTM zone 21":"5121",
"ETRS89 / NTM zone 22":"5122",
"ETRS89 / NTM zone 23":"5123",
"ETRS89 / NTM zone 24":"5124",
"ETRS89 / NTM zone 25":"5125",
"ETRS89 / NTM zone 26":"5126",
"ETRS89 / NTM zone 27":"5127",
"ETRS89 / NTM zone 28":"5128",
"ETRS89 / NTM zone 29":"5129",
"ETRS89 / NTM zone 30":"5130",
"Tokyo 1892":"5132",
"Korean 1985 / East Sea Belt":"5167",
"Korean 1985 / Central Belt Jeju":"5168",
"Tokyo 1892 / Korea West Belt":"5169",
"Tokyo 1892 / Korea Central Belt":"5170",
"Tokyo 1892 / Korea East Belt":"5171",
"Tokyo 1892 / Korea East Sea Belt":"5172",
"Korean 1985 / Modified West Belt":"5173",
"Korean 1985 / Modified Central Belt":"5174",
"Korean 1985 / Modified Central Belt Jeju":"5175",
"Korean 1985 / Modified East Belt":"5176",
"Korean 1985 / Modified East Sea Belt":"5177",
"Korean 1985 / Unified CS":"5178",
"Korea 2000 / Unified CS":"5179",
"Korea 2000 / West Belt":"5180",
"Korea 2000 / Central Belt":"5181",
"Korea 2000 / Central Belt Jeju":"5182",
"Korea 2000 / East Belt":"5183",
"Korea 2000 / East Sea Belt":"5184",
"Korea 2000 / West Belt 2010":"5185",
"Korea 2000 / Central Belt 2010":"5186",
"Korea 2000 / East Belt 2010":"5187",
"Korea 2000 / East Sea Belt 2010":"5188",
"Incheon height":"5193",
"Trieste height":"5195",
"Genoa height":"5214",
"S-JTSK (Ferro) / Krovak East North":"5221",
"WGS 84 / Gabon TM":"5223",
"S-JTSK/05 (Ferro) / Modified Krovak":"5224",
"S-JTSK/05 (Ferro) / Modified Krovak East North":"5225",
"S-JTSK/05":"5228",
"S-JTSK/05 (Ferro)":"5229",
"SLD99":"5233",
"Kandawala / Sri Lanka Grid":"5234",
"SLD99 / Sri Lanka Grid 1999":"5235",
"SLVD height":"5237",
"ETRS89 / LCC Germany (E-N)":"5243",
"GDBD2009":"5244",
"GDBD2009":"5245",
"GDBD2009":"5246",
"GDBD2009 / Brunei BRSO":"5247",
"TUREF":"5250",
"TUREF":"5251",
"TUREF":"5252",
"TUREF / TM27":"5253",
"TUREF / TM30":"5254",
"TUREF / TM33":"5255",
"TUREF / TM36":"5256",
"TUREF / TM39":"5257",
"TUREF / TM42":"5258",
"TUREF / TM45":"5259",
"DRUKREF 03":"5262",
"DRUKREF 03":"5263",
"DRUKREF 03":"5264",
"DRUKREF 03 / Bhutan National Grid":"5266",
"TUREF / 3-degree Gauss-Kruger zone 9":"5269",
"TUREF / 3-degree Gauss-Kruger zone 10":"5270",
"TUREF / 3-degree Gauss-Kruger zone 11":"5271",
"TUREF / 3-degree Gauss-Kruger zone 12":"5272",
"TUREF / 3-degree Gauss-Kruger zone 13":"5273",
"TUREF / 3-degree Gauss-Kruger zone 14":"5274",
"TUREF / 3-degree Gauss-Kruger zone 15":"5275",
"DRUKREF 03 / Bumthang TM":"5292",
"DRUKREF 03 / Chhukha TM":"5293",
"DRUKREF 03 / Dagana TM":"5294",
"DRUKREF 03 / Gasa TM":"5295",
"DRUKREF 03 / Ha TM":"5296",
"DRUKREF 03 / Lhuentse TM":"5297",
"DRUKREF 03 / Mongar TM":"5298",
"DRUKREF 03 / Paro TM":"5299",
"DRUKREF 03 / Pemagatshel TM":"5300",
"DRUKREF 03 / Punakha TM":"5301",
"DRUKREF 03 / Samdrup Jongkhar TM":"5302",
"DRUKREF 03 / Samtse TM":"5303",
"DRUKREF 03 / Sarpang TM":"5304",
"DRUKREF 03 / Thimphu TM":"5305",
"DRUKREF 03 / Trashigang TM":"5306",
"DRUKREF 03 / Trongsa TM":"5307",
"DRUKREF 03 / Tsirang TM":"5308",
"DRUKREF 03 / Wangdue Phodrang TM":"5309",
"DRUKREF 03 / Yangtse TM":"5310",
"DRUKREF 03 / Zhemgang TM":"5311",
"ETRS89 / Faroe TM":"5316",
"FVR09 height":"5317",
"ETRS89 / Faroe TM + FVR09 height":"5318",
"NAD83 / Teranet Ontario Lambert":"5320",
"NAD83(CSRS) / Teranet Ontario Lambert":"5321",
"ISN2004":"5322",
"ISN2004":"5323",
"ISN2004":"5324",
"ISN2004 / Lambert 2004":"5325",
"Segara (Jakarta) / NEIEZ":"5329",
"Batavia (Jakarta) / NEIEZ":"5330",
"Makassar (Jakarta) / NEIEZ":"5331",
"ITRF2008":"5332",
"Black Sea depth":"5336",
"Aratu / UTM zone 25S":"5337",
"POSGAR 2007":"5340",
"POSGAR 2007":"5341",
"POSGAR 2007":"5342",
"POSGAR 2007 / Argentina 1":"5343",
"POSGAR 2007 / Argentina 2":"5344",
"POSGAR 2007 / Argentina 3":"5345",
"POSGAR 2007 / Argentina 4":"5346",
"POSGAR 2007 / Argentina 5":"5347",
"POSGAR 2007 / Argentina 6":"5348",
"POSGAR 2007 / Argentina 7":"5349",
"MARGEN":"5352",
"MARGEN":"5353",
"MARGEN":"5354",
"MARGEN / UTM zone 20S":"5355",
"MARGEN / UTM zone 19S":"5356",
"MARGEN / UTM zone 21S":"5357",
"SIRGAS-Chile":"5358",
"SIRGAS-Chile":"5359",
"SIRGAS-Chile":"5360",
"SIRGAS-Chile / UTM zone 19S":"5361",
"SIRGAS-Chile / UTM zone 18S":"5362",
"CR05":"5363",
"CR05":"5364",
"CR05":"5365",
"CR05 / CRTM05":"5367",
"MACARIO SOLIS":"5368",
"Peru96":"5369",
"MACARIO SOLIS":"5370",
"MACARIO SOLIS":"5371",
"Peru96":"5372",
"Peru96":"5373",
"SIRGAS-ROU98":"5379",
"SIRGAS-ROU98":"5380",
"SIRGAS-ROU98":"5381",
"SIRGAS-ROU98 / UTM zone 21S":"5382",
"SIRGAS-ROU98 / UTM zone 22S":"5383",
"Peru96 / UTM zone 18S":"5387",
"Peru96 / UTM zone 17S":"5388",
"Peru96 / UTM zone 19S":"5389",
"SIRGAS_ES2007.8":"5391",
"SIRGAS_ES2007.8":"5392",
"SIRGAS_ES2007.8":"5393",
"SIRGAS 2000 / UTM zone 26S":"5396",
"Ocotepeque 1935":"5451",
"Ocotepeque 1935 / Costa Rica Norte":"5456",
"Ocotepeque 1935 / Costa Rica Sur":"5457",
"Ocotepeque 1935 / Guatemala Norte":"5458",
"Ocotepeque 1935 / Guatemala Sur":"5459",
"Ocotepeque 1935 / El Salvador Lambert":"5460",
"Ocotepeque 1935 / Nicaragua Norte":"5461",
"Ocotepeque 1935 / Nicaragua Sur":"5462",
"SAD69 / UTM zone 17N":"5463",
"Sibun Gorge 1922":"5464",
"Sibun Gorge 1922 / Colony Grid":"5466",
"Panama-Colon 1911":"5467",
"Panama-Colon 1911 / Panama Lambert":"5469",
"Panama-Colon 1911 / Panama Polyconic":"5472",
"RSRGD2000 / MSLC2000":"5479",
"RSRGD2000 / BCLC2000":"5480",
"RSRGD2000 / PCLC2000":"5481",
"RSRGD2000 / RSPS2000":"5482",
"RGAF09":"5487",
"RGAF09":"5488",
"RGAF09":"5489",
"RGAF09 / UTM zone 20N":"5490",
"NAD83 + NAVD88 height":"5498",
"NAD83(HARN) + NAVD88 height":"5499",
"NAD83(NSRS2007) + NAVD88 height":"5500",
"S-JTSK / Krovak":"5513",
"S-JTSK / Krovak East North":"5514",
"S-JTSK/05 / Modified Krovak":"5515",
"S-JTSK/05 / Modified Krovak East North":"5516",
"CI1971 / Chatham Islands Map Grid":"5518",
"CI1979 / Chatham Islands Map Grid":"5519",
"DHDN / 3-degree Gauss-Kruger zone 1":"5520",
"WGS 84 / Gabon TM 2011":"5523",
"Corrego Alegre 1961":"5524",
"SAD69(96)":"5527",
"SAD69(96) / Brazil Polyconic":"5530",
"SAD69(96) / UTM zone 21S":"5531",
"SAD69(96) / UTM zone 22S":"5532",
"SAD69(96) / UTM zone 23S":"5533",
"SAD69(96) / UTM zone 24S":"5534",
"SAD69(96) / UTM zone 25S":"5535",
"Corrego Alegre 1961 / UTM zone 21S":"5536",
"Corrego Alegre 1961 / UTM zone 22S":"5537",
"Corrego Alegre 1961 / UTM zone 23S":"5538",
"Corrego Alegre 1961 / UTM zone 24S":"5539",
"PNG94":"5544",
"PNG94":"5545",
"PNG94":"5546",
"PNG94 / PNGMG94 zone 54":"5550",
"PNG94 / PNGMG94 zone 55":"5551",
"PNG94 / PNGMG94 zone 56":"5552",
"ETRS89 / UTM zone 31N + DHHN92 height":"5554",
"ETRS89 / UTM zone 32N + DHHN92 height":"5555",
"ETRS89 / UTM zone 33N + DHHN92 height":"5556",
"UCS-2000":"5558",
"Ocotepeque 1935 / Guatemala Norte":"5559",
"UCS-2000":"5560",
"UCS-2000":"5561",
"UCS-2000 / Gauss-Kruger zone 4":"5562",
"UCS-2000 / Gauss-Kruger zone 5":"5563",
"UCS-2000 / Gauss-Kruger zone 6":"5564",
"UCS-2000 / Gauss-Kruger zone 7":"5565",
"UCS-2000 / Gauss-Kruger CM 21E":"5566",
"UCS-2000 / Gauss-Kruger CM 27E":"5567",
"UCS-2000 / Gauss-Kruger CM 33E":"5568",
"UCS-2000 / Gauss-Kruger CM 39E":"5569",
"UCS-2000 / 3-degree Gauss-Kruger zone 7":"5570",
"UCS-2000 / 3-degree Gauss-Kruger zone 8":"5571",
"UCS-2000 / 3-degree Gauss-Kruger zone 9":"5572",
"UCS-2000 / 3-degree Gauss-Kruger zone 10":"5573",
"UCS-2000 / 3-degree Gauss-Kruger zone 11":"5574",
"UCS-2000 / 3-degree Gauss-Kruger zone 12":"5575",
"UCS-2000 / 3-degree Gauss-Kruger zone 13":"5576",
"UCS-2000 / 3-degree Gauss-Kruger CM 21E":"5577",
"UCS-2000 / 3-degree Gauss-Kruger CM 24E":"5578",
"UCS-2000 / 3-degree Gauss-Kruger CM 27E":"5579",
"UCS-2000 / 3-degree Gauss-Kruger CM 30E":"5580",
"UCS-2000 / 3-degree Gauss-Kruger CM 33E":"5581",
"UCS-2000 / 3-degree Gauss-Kruger CM 36E":"5582",
"UCS-2000 / 3-degree Gauss-Kruger CM 39E":"5583",
"NAD27 / New Brunswick Stereographic (NAD27)":"5588",
"Sibun Gorge 1922 / Colony Grid":"5589",
"FEH2010":"5591",
"FEH2010":"5592",
"FEH2010":"5593",
"FEH2010 / Fehmarnbelt TM":"5596",
"FCSVR10 height":"5597",
"FEH2010 / Fehmarnbelt TM + FCSVR10 height":"5598",
"NGPF height":"5600",
"IGN 1966 height":"5601",
"Moorea SAU 1981 height":"5602",
"Raiatea SAU 2001 height":"5603",
"Maupiti SAU 2001 height":"5604",
"Huahine SAU 2001 height":"5605",
"Tahaa SAU 2001 height":"5606",
"Bora Bora SAU 2001 height":"5607",
"IGLD 1955 height":"5608",
"IGLD 1985 height":"5609",
"HVRS71 height":"5610",
"Caspian height":"5611",
"Baltic 1977 depth":"5612",
"RH2000 height":"5613",
"KOC WD depth (ft)":"5614",
"RH00 height":"5615",
"IGN 1988 LS height":"5616",
"IGN 1988 MG height":"5617",
"IGN 1992 LD height":"5618",
"IGN 1988 SB height":"5619",
"IGN 1988 SM height":"5620",
"EVRF2007 height":"5621",
"NAD27 / Michigan East":"5623",
"NAD27 / Michigan Old Central":"5624",
"NAD27 / Michigan West":"5625",
"ED50 / TM 6 NE":"5627",
"SWEREF99 + RH2000 height":"5628",
"Moznet / UTM zone 38S":"5629",
"Pulkovo 1942(58) / Gauss-Kruger zone 2 (E-N)":"5631",
"PTRA08 / LCC Europe":"5632",
"PTRA08 / LAEA Europe":"5633",
"REGCAN95 / LCC Europe":"5634",
"REGCAN95 / LAEA Europe":"5635",
"TUREF / LAEA Europe":"5636",
"TUREF / LCC Europe":"5637",
"ISN2004 / LAEA Europe":"5638",
"ISN2004 / LCC Europe":"5639",
"SIRGAS 2000 / Brazil Mercator":"5641",
"ED50 / SPBA LCC":"5643",
"RGR92 / UTM zone 39S":"5644",
"NAD83 / Vermont (ftUS)":"5646",
"ETRS89 / UTM zone 31N (zE-N)":"5649",
"ETRS89 / UTM zone 33N (zE-N)":"5650",
"ETRS89 / UTM zone 31N (N-zE)":"5651",
"ETRS89 / UTM zone 32N (N-zE)":"5652",
"ETRS89 / UTM zone 33N (N-zE)":"5653",
"NAD83(HARN) / Vermont (ftUS)":"5654",
"NAD83(NSRS2007) / Vermont (ftUS)":"5655",
"Monte Mario / TM Emilia-Romagna":"5659",
"Pulkovo 1942(58) / Gauss-Kruger zone 3 (E-N)":"5663",
"Pulkovo 1942(83) / Gauss-Kruger zone 2 (E-N)":"5664",
"Pulkovo 1942(83) / Gauss-Kruger zone 3 (E-N)":"5665",
"PD/83 / 3-degree Gauss-Kruger zone 3 (E-N)":"5666",
"PD/83 / 3-degree Gauss-Kruger zone 4 (E-N)":"5667",
"RD/83 / 3-degree Gauss-Kruger zone 4 (E-N)":"5668",
"RD/83 / 3-degree Gauss-Kruger zone 5 (E-N)":"5669",
"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 3 (E-N)":"5670",
"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 4 (E-N)":"5671",
"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 5 (E-N)":"5672",
"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 3 (E-N)":"5673",
"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 4 (E-N)":"5674",
"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 5 (E-N)":"5675",
"DHDN / 3-degree Gauss-Kruger zone 2 (E-N)":"5676",
"DHDN / 3-degree Gauss-Kruger zone 3 (E-N)":"5677",
"DHDN / 3-degree Gauss-Kruger zone 4 (E-N)":"5678",
"DHDN / 3-degree Gauss-Kruger zone 5 (E-N)":"5679",
"DHDN / 3-degree Gauss-Kruger zone 1 (E-N)":"5680",
"DB_REF":"5681",
"DB_REF / 3-degree Gauss-Kruger zone 2 (E-N)":"5682",
"DB_REF / 3-degree Gauss-Kruger zone 3 (E-N)":"5683",
"DB_REF / 3-degree Gauss-Kruger zone 4 (E-N)":"5684",
"DB_REF / 3-degree Gauss-Kruger zone 5 (E-N)":"5685",
"RGF93 / Lambert-93 + NGF-IGN69 height":"5698",
"RGF93 / Lambert-93 + NGF-IGN78 height":"5699",
"NZGD2000 / UTM zone 1S":"5700",
"ODN height":"5701",
"NGVD29 height (ftUS)":"5702",
"NAVD88 height":"5703",
"Yellow Sea":"5704",
"Baltic 1977 height":"5705",
"Caspian depth":"5706",
"NTF (Paris) / Lambert zone I + NGF-IGN69 height":"5707",
"NTF (Paris) / Lambert zone IV + NGF-IGN78 height":"5708",
"NAP height":"5709",
"Ostend height":"5710",
"AHD height":"5711",
"AHD (Tasmania) height":"5712",
"CGVD28 height":"5713",
"MSL height":"5714",
"MSL depth":"5715",
"Piraeus height":"5716",
"N60 height":"5717",
"RH70 height":"5718",
"NGF Lallemand height":"5719",
"NGF-IGN69 height":"5720",
"NGF-IGN78 height":"5721",
"Maputo height":"5722",
"JSLD69 height":"5723",
"PHD93 height":"5724",
"Fahud HD height":"5725",
"Ha Tien 1960 height":"5726",
"Hon Dau 1992 height":"5727",
"LN02 height":"5728",
"LHN95 height":"5729",
"EVRF2000 height":"5730",
"Malin Head height":"5731",
"Belfast height":"5732",
"DNN height":"5733",
"AIOC95 depth":"5734",
"Black Sea height":"5735",
"Yellow Sea 1956 height":"5736",
"Yellow Sea 1985 height":"5737",
"HKPD height":"5738",
"HKCD depth":"5739",
"ODN Orkney height":"5740",
"Fair Isle height":"5741",
"Lerwick height":"5742",
"Foula height":"5743",
"Sule Skerry height":"5744",
"North Rona height":"5745",
"Stornoway height":"5746",
"St Kilda height":"5747",
"Flannan Isles height":"5748",
"St Marys height":"5749",
"Douglas height":"5750",
"Fao height":"5751",
"Bandar Abbas height":"5752",
"NGNC height":"5753",
"Poolbeg height (ft(Br36))":"5754",
"NGG1977 height":"5755",
"Martinique 1987 height":"5756",
"Guadeloupe 1988 height":"5757",
"Reunion 1989 height":"5758",
"Auckland 1946 height":"5759",
"Bluff 1955 height":"5760",
"Dunedin 1958 height":"5761",
"Gisborne 1926 height":"5762",
"Lyttelton 1937 height":"5763",
"Moturiki 1953 height":"5764",
"Napier 1962 height":"5765",
"Nelson 1955 height":"5766",
"One Tree Point 1964 height":"5767",
"Tararu 1952 height":"5768",
"Taranaki 1970 height":"5769",
"Wellington 1953 height":"5770",
"Chatham Island 1959 height":"5771",
"Stewart Island 1977 height":"5772",
"EGM96 height":"5773",
"NG-L height":"5774",
"Antalya height":"5775",
"NN54 height":"5776",
"Durres height":"5777",
"GHA height":"5778",
"SVS2000 height":"5779",
"Cascais height":"5780",
"Constanta height":"5781",
"Alicante height":"5782",
"DHHN92 height":"5783",
"DHHN85 height":"5784",
"SNN76 height":"5785",
"Baltic 1982 height":"5786",
"EOMA 1980 height":"5787",
"Kuwait PWD height":"5788",
"KOC WD depth":"5789",
"KOC CD height":"5790",
"NGC 1948 height":"5791",
"Danger 1950 height":"5792",
"Mayotte 1950 height":"5793",
"Martinique 1955 height":"5794",
"Guadeloupe 1951 height":"5795",
"Lagos 1955 height":"5796",
"AIOC95 height":"5797",
"EGM84 height":"5798",
"DVR90 height":"5799",
"Astra Minas Grid":"5800",
"Barcelona Grid B1":"5801",
"Barcelona Grid B2":"5802",
"Maturin Grid":"5803",
"EPSG seismic bin grid example A":"5804",
"EPSG seismic bin grid example B":"5805",
"EPSG local engineering grid example A":"5806",
"EPSG local engineering grid example B":"5807",
"Maracaibo Cross Grid M4":"5808",
"Maracaibo Cross Grid M5":"5809",
"La Rosa Grid":"5810",
"Mene Grande":"5811",
"El Cubo":"5812",
"Dabajuro":"5813",
"Tucupita":"5814",
"Santa Maria de Ipire":"5815",
"Barinas west base":"5816",
"Tombak LNG plant":"5817",
"[enter here name of (I = J+90°) bin grid]":"5818",
"EPSG topocentric example A":"5819",
"EPSG topocentric example B":"5820",
"EPSG vertical perspective example":"5821",
"AGD66 / ACT Standard Grid":"5825",
"DB_REF":"5828",
"Instantaneous Water Level height":"5829",
"DB_REF":"5830",
"Instantaneous Water Level depth":"5831",
"DB_REF / 3-degree Gauss-Kruger zone 2 (E-N) + DHHN92 height":"5832",
"DB_REF / 3-degree Gauss-Kruger zone 3 (E-N) + DHHN92 height":"5833",
"DB_REF / 3-degree Gauss-Kruger zone 4 (E-N) + DHHN92 height":"5834",
"DB_REF / 3-degree Gauss-Kruger zone 5 (E-N) + DHHN92 height":"5835",
"Yemen NGN96 / UTM zone 37N":"5836",
"Yemen NGN96 / UTM zone 40N":"5837",
"Peru96 / UTM zone 17S":"5839",
"WGS 84 / TM 12 SE":"5842",
"Ras Ghumays height":"5843",
"RGRDC 2005 / Congo TM zone 30":"5844",
"SWEREF99 TM + RH2000 height":"5845",
"SWEREF99 12 00 + RH2000 height":"5846",
"SWEREF99 13 30 + RH2000 height":"5847",
"SWEREF99 15 00 + RH2000 height":"5848",
"SWEREF99 16 30 + RH2000 height":"5849",
"SWEREF99 18 00 + RH2000 height":"5850",
"SWEREF99 14 15 + RH2000 height":"5851",
"SWEREF99 15 45 + RH2000 height":"5852",
"SWEREF99 17 15 + RH2000 height":"5853",
"SWEREF99 18 45 + RH2000 height":"5854",
"SWEREF99 20 15 + RH2000 height":"5855",
"SWEREF99 21 45 + RH2000 height":"5856",
"SWEREF99 23 15 + RH2000 height":"5857",
"SAD69(96) / UTM zone 22S":"5858",
"[enter here name of (I = J-90°) bin grid]":"5859",
"LAT depth":"5861",
"LLWLT depth":"5862",
"ISLW depth":"5863",
"MLLWS depth":"5864",
"MLWS depth":"5865",
"MLLW depth":"5866",
"MLW depth":"5867",
"MHW height":"5868",
"MHHW height":"5869",
"MHWS height":"5870",
"HHWLT height":"5871",
"HAT height":"5872",
"Low Water depth":"5873",
"High Water height":"5874",
"SAD69(96) / UTM zone 18S":"5875",
"SAD69(96) / UTM zone 19S":"5876",
"SAD69(96) / UTM zone 20S":"5877",
"Cadastre 1997 / UTM zone 38S":"5879",
"SIRGAS 2000 / Brazil Polyconic":"5880",
"TGD2005":"5884",
"TGD2005":"5885",
"TGD2005":"5886",
"TGD2005 / Tonga Map Grid":"5887",
"JAXA Snow Depth Polar Stereographic North":"5890",
"VN-2000 / TM-3 zone 481":"5896",
"VN-2000 / TM-3 zone 482":"5897",
"VN-2000 / TM-3 zone 491":"5898",
"VN-2000 / TM-3 Da Nang zone":"5899",
"WGS 84 / EPSG Arctic Regional zone A1":"5921",
"WGS 84 / EPSG Arctic Regional zone A2":"5922",
"WGS 84 / EPSG Arctic Regional zone A3":"5923",
"WGS 84 / EPSG Arctic Regional zone A4":"5924",
"WGS 84 / EPSG Arctic Regional zone A5":"5925",
"WGS 84 / EPSG Arctic Regional zone B1":"5926",
"WGS 84 / EPSG Arctic Regional zone B2":"5927",
"WGS 84 / EPSG Arctic Regional zone B3":"5928",
"WGS 84 / EPSG Arctic Regional zone B4":"5929",
"WGS 84 / EPSG Arctic Regional zone B5":"5930",
"WGS 84 / EPSG Arctic Regional zone C1":"5931",
"WGS 84 / EPSG Arctic Regional zone C2":"5932",
"WGS 84 / EPSG Arctic Regional zone C3":"5933",
"WGS 84 / EPSG Arctic Regional zone C4":"5934",
"WGS 84 / EPSG Arctic Regional zone C5":"5935",
"WGS 84 / EPSG Alaska Polar Stereographic":"5936",
"WGS 84 / EPSG Canada Polar Stereographic":"5937",
"WGS 84 / EPSG Greenland Polar Stereographic":"5938",
"WGS 84 / EPSG Norway Polar Stereographic":"5939",
"WGS 84 / EPSG Russia Polar Stereographic":"5940",
"NN2000 height":"5941",
"ETRS89 + NN2000 height":"5942",
"ETRS89 / NTM zone 5 + NN2000 height":"5945",
"ETRS89 / NTM zone 6 + NN2000 height":"5946",
"ETRS89 / NTM zone 7 + NN2000 height":"5947",
"ETRS89 / NTM zone 8 + NN2000 height":"5948",
"ETRS89 / NTM zone 9 + NN2000 height":"5949",
"ETRS89 / NTM zone 10 + NN2000 height":"5950",
"ETRS89 / NTM zone 11 + NN2000 height":"5951",
"ETRS89 / NTM zone 12 + NN2000 height":"5952",
"ETRS89 / NTM zone 13 + NN2000 height":"5953",
"ETRS89 / NTM zone 14 + NN2000 height":"5954",
"ETRS89 / NTM zone 15 + NN2000 height":"5955",
"ETRS89 / NTM zone 16 + NN2000 height":"5956",
"ETRS89 / NTM zone 17 + NN2000 height":"5957",
"ETRS89 / NTM zone 18 + NN2000 height":"5958",
"ETRS89 / NTM zone 19 + NN2000 height":"5959",
"ETRS89 / NTM zone 20 + NN2000 height":"5960",
"ETRS89 / NTM zone 21 + NN2000 height":"5961",
"ETRS89 / NTM zone 22 + NN2000 height":"5962",
"ETRS89 / NTM zone 23 + NN2000 height":"5963",
"ETRS89 / NTM zone 24 + NN2000 height":"5964",
"ETRS89 / NTM zone 25 + NN2000 height":"5965",
"ETRS89 / NTM zone 26 + NN2000 height":"5966",
"ETRS89 / NTM zone 27 + NN2000 height":"5967",
"ETRS89 / NTM zone 28 + NN2000 height":"5968",
"ETRS89 / NTM zone 29 + NN2000 height":"5969",
"ETRS89 / NTM zone 30 + NN2000 height":"5970",
"ETRS89 / UTM zone 31 + NN2000 height":"5971",
"ETRS89 / UTM zone 32 + NN2000 height":"5972",
"ETRS89 / UTM zone 33 + NN2000 height":"5973",
"ETRS89 / UTM zone 34 + NN2000 height":"5974",
"ETRS89 / UTM zone 35 + NN2000 height":"5975",
"ETRS89 / UTM zone 36 + NN2000 height":"5976",
"GR96 / EPSG Arctic zone 1-25":"6050",
"GR96 / EPSG Arctic zone 2-18":"6051",
"GR96 / EPSG Arctic zone 2-20":"6052",
"GR96 / EPSG Arctic zone 3-29":"6053",
"GR96 / EPSG Arctic zone 3-31":"6054",
"GR96 / EPSG Arctic zone 3-33":"6055",
"GR96 / EPSG Arctic zone 4-20":"6056",
"GR96 / EPSG Arctic zone 4-22":"6057",
"GR96 / EPSG Arctic zone 4-24":"6058",
"GR96 / EPSG Arctic zone 5-41":"6059",
"GR96 / EPSG Arctic zone 5-43":"6060",
"GR96 / EPSG Arctic zone 5-45":"6061",
"GR96 / EPSG Arctic zone 6-26":"6062",
"GR96 / EPSG Arctic zone 6-28":"6063",
"GR96 / EPSG Arctic zone 6-30":"6064",
"GR96 / EPSG Arctic zone 7-11":"6065",
"GR96 / EPSG Arctic zone 7-13":"6066",
"GR96 / EPSG Arctic zone 8-20":"6067",
"GR96 / EPSG Arctic zone 8-22":"6068",
"ETRS89 / EPSG Arctic zone 2-22":"6069",
"ETRS89 / EPSG Arctic zone 3-11":"6070",
"ETRS89 / EPSG Arctic zone 4-26":"6071",
"ETRS89 / EPSG Arctic zone 4-28":"6072",
"ETRS89 / EPSG Arctic zone 5-11":"6073",
"ETRS89 / EPSG Arctic zone 5-13":"6074",
"WGS 84 / EPSG Arctic zone 2-24":"6075",
"WGS 84 / EPSG Arctic zone 2-26":"6076",
"WGS 84 / EPSG Arctic zone 3-13":"6077",
"WGS 84 / EPSG Arctic zone 3-15":"6078",
"WGS 84 / EPSG Arctic zone 3-17":"6079",
"WGS 84 / EPSG Arctic zone 3-19":"6080",
"WGS 84 / EPSG Arctic zone 4-30":"6081",
"WGS 84 / EPSG Arctic zone 4-32":"6082",
"WGS 84 / EPSG Arctic zone 4-34":"6083",
"WGS 84 / EPSG Arctic zone 4-36":"6084",
"WGS 84 / EPSG Arctic zone 4-38":"6085",
"WGS 84 / EPSG Arctic zone 4-40":"6086",
"WGS 84 / EPSG Arctic zone 5-15":"6087",
"WGS 84 / EPSG Arctic zone 5-17":"6088",
"WGS 84 / EPSG Arctic zone 5-19":"6089",
"WGS 84 / EPSG Arctic zone 5-21":"6090",
"WGS 84 / EPSG Arctic zone 5-23":"6091",
"WGS 84 / EPSG Arctic zone 5-25":"6092",
"WGS 84 / EPSG Arctic zone 5-27":"6093",
"NAD83(NSRS2007) / EPSG Arctic zone 5-29":"6094",
"NAD83(NSRS2007) / EPSG Arctic zone 5-31":"6095",
"NAD83(NSRS2007) / EPSG Arctic zone 6-14":"6096",
"NAD83(NSRS2007) / EPSG Arctic zone 6-16":"6097",
"NAD83(CSRS) / EPSG Arctic zone 1-23":"6098",
"NAD83(CSRS) / EPSG Arctic zone 2-14":"6099",
"NAD83(CSRS) / EPSG Arctic zone 2-16":"6100",
"NAD83(CSRS) / EPSG Arctic zone 3-25":"6101",
"NAD83(CSRS) / EPSG Arctic zone 3-27":"6102",
"NAD83(CSRS) / EPSG Arctic zone 3-29":"6103",
"NAD83(CSRS) / EPSG Arctic zone 4-14":"6104",
"NAD83(CSRS) / EPSG Arctic zone 4-16":"6105",
"NAD83(CSRS) / EPSG Arctic zone 4-18":"6106",
"NAD83(CSRS) / EPSG Arctic zone 5-33":"6107",
"NAD83(CSRS) / EPSG Arctic zone 5-35":"6108",
"NAD83(CSRS) / EPSG Arctic zone 5-37":"6109",
"NAD83(CSRS) / EPSG Arctic zone 5-39":"6110",
"NAD83(CSRS) / EPSG Arctic zone 6-18":"6111",
"NAD83(CSRS) / EPSG Arctic zone 6-20":"6112",
"NAD83(CSRS) / EPSG Arctic zone 6-22":"6113",
"NAD83(CSRS) / EPSG Arctic zone 6-24":"6114",
"WGS 84 / EPSG Arctic zone 1-27":"6115",
"WGS 84 / EPSG Arctic zone 1-29":"6116",
"WGS 84 / EPSG Arctic zone 1-31":"6117",
"WGS 84 / EPSG Arctic zone 1-21":"6118",
"WGS 84 / EPSG Arctic zone 2-28":"6119",
"WGS 84 / EPSG Arctic zone 2-10":"6120",
"WGS 84 / EPSG Arctic zone 2-12":"6121",
"WGS 84 / EPSG Arctic zone 3-21":"6122",
"WGS 84 / EPSG Arctic zone 3-23":"6123",
"WGS 84 / EPSG Arctic zone 4-12":"6124",
"ETRS89 / EPSG Arctic zone 5-47":"6125",
"Grand Cayman National Grid 1959":"6128",
"Sister Islands National Grid 1961":"6129",
"GCVD54 height (ft)":"6130",
"LCVD61 height (ft)":"6131",
"CBVD61 height (ft)":"6132",
"CIGD11":"6133",
"CIGD11":"6134",
"CIGD11":"6135",
"Cayman Islands National Grid 2011":"6141",
"ETRS89 + NN54 height":"6144",
"ETRS89 / NTM zone 5 + NN54 height":"6145",
"ETRS89 / NTM zone 6 + NN54 height":"6146",
"ETRS89 / NTM zone 7 + NN54 height":"6147",
"ETRS89 / NTM zone 8 + NN54 height":"6148",
"ETRS89 / NTM zone 9 + NN54 height":"6149",
"ETRS89 / NTM zone 10 + NN54 height":"6150",
"ETRS89 / NTM zone 11 + NN54 height":"6151",
"ETRS89 / NTM zone 12 + NN54 height":"6152",
"ETRS89 / NTM zone 13 + NN54 height":"6153",
"ETRS89 / NTM zone 14 + NN54 height":"6154",
"ETRS89 / NTM zone 15 + NN54 height":"6155",
"ETRS89 / NTM zone 16 + NN54 height":"6156",
"ETRS89 / NTM zone 17 + NN54 height":"6157",
"ETRS89 / NTM zone 18 + NN54 height":"6158",
"ETRS89 / NTM zone 19 + NN54 height":"6159",
"ETRS89 / NTM zone 20 + NN54 height":"6160",
"ETRS89 / NTM zone 21 + NN54 height":"6161",
"ETRS89 / NTM zone 22 + NN54 height":"6162",
"ETRS89 / NTM zone 23 + NN54 height":"6163",
"ETRS89 / NTM zone 24 + NN54 height":"6164",
"ETRS89 / NTM zone 25 + NN54 height":"6165",
"ETRS89 / NTM zone 26 + NN54 height":"6166",
"ETRS89 / NTM zone 27 + NN54 height":"6167",
"ETRS89 / NTM zone 28 + NN54 height":"6168",
"ETRS89 / NTM zone 29 + NN54 height":"6169",
"ETRS89 / NTM zone 30 + NN54 height":"6170",
"ETRS89 / UTM zone 31 + NN54 height":"6171",
"ETRS89 / UTM zone 32 + NN54 height":"6172",
"ETRS89 / UTM zone 33 + NN54 height":"6173",
"ETRS89 / UTM zone 34 + NN54 height":"6174",
"ETRS89 / UTM zone 35 + NN54 height":"6175",
"ETRS89 / UTM zone 36 + NN54 height":"6176",
"Cais da Pontinha - Funchal height":"6178",
"Cais da Vila - Porto Santo height":"6179",
"Cais das Velas height":"6180",
"Horta height":"6181",
"Cais da Madalena height":"6182",
"Santa Cruz da Graciosa height":"6183",
"Cais da Figueirinha - Angra do Heroismo height":"6184",
"Santa Cruz das Flores height":"6185",
"Cais da Vila do Porto height":"6186",
"Ponta Delgada height":"6187",
"Belge 1972 / Belgian Lambert 72 + Ostend height":"6190",
"NAD27 / Michigan North":"6200",
"NAD27 / Michigan Central":"6201",
"NAD27 / Michigan South":"6202",
"Macedonia State Coordinate System":"6204",
"Nepal 1981":"6207",
"SIRGAS 2000 / UTM zone 23N":"6210",
"SIRGAS 2000 / UTM zone 24N":"6211",
"MAGNA-SIRGAS / Arauca urban grid":"6244",
"MAGNA-SIRGAS / Armenia urban grid":"6245",
"MAGNA-SIRGAS / Barranquilla urban grid":"6246",
"MAGNA-SIRGAS / Bogota urban grid":"6247",
"MAGNA-SIRGAS / Bucaramanga urban grid":"6248",
"MAGNA-SIRGAS / Cali urban grid":"6249",
"MAGNA-SIRGAS / Cartagena urban grid":"6250",
"MAGNA-SIRGAS / Cucuta urban grid":"6251",
"MAGNA-SIRGAS / Florencia urban grid":"6252",
"MAGNA-SIRGAS / Ibague urban grid":"6253",
"MAGNA-SIRGAS / Inirida urban grid":"6254",
"MAGNA-SIRGAS / Leticia urban grid":"6255",
"MAGNA-SIRGAS / Manizales urban grid":"6256",
"MAGNA-SIRGAS / Medellin urban grid":"6257",
"MAGNA-SIRGAS / Mitu urban grid":"6258",
"MAGNA-SIRGAS / Mocoa urban grid":"6259",
"MAGNA-SIRGAS / Monteria urban grid":"6260",
"MAGNA-SIRGAS / Neiva urban grid":"6261",
"MAGNA-SIRGAS / Pasto urban grid":"6262",
"MAGNA-SIRGAS / Pereira urban grid":"6263",
"MAGNA-SIRGAS / Popayan urban grid":"6264",
"MAGNA-SIRGAS / Puerto Carreno urban grid":"6265",
"MAGNA-SIRGAS / Quibdo urban grid":"6266",
"MAGNA-SIRGAS / Riohacha urban grid":"6267",
"MAGNA-SIRGAS / San Andres urban grid":"6268",
"MAGNA-SIRGAS / San Jose del Guaviare urban grid":"6269",
"MAGNA-SIRGAS / Santa Marta urban grid":"6270",
"MAGNA-SIRGAS / Sucre urban grid":"6271",
"MAGNA-SIRGAS / Tunja urban grid":"6272",
"MAGNA-SIRGAS / Valledupar urban grid":"6273",
"MAGNA-SIRGAS / Villavicencio urban grid":"6274",
"MAGNA-SIRGAS / Yopal urban grid":"6275",
"NAD83(CORS96) / Puerto Rico and Virgin Is.":"6307",
"CGRS93":"6309",
"CGRS93":"6310",
"CGRS93":"6311",
"CGRS93 / Cyprus Local Transverse Mercator":"6312",
"MGI 1901 / Balkans zone 7":"6316",
"NAD83(2011)":"6317",
"NAD83(2011)":"6318",
"NAD83(2011)":"6319",
"NAD83(PA11)":"6320",
"NAD83(PA11)":"6321",
"NAD83(PA11)":"6322",
"NAD83(MA11)":"6323",
"NAD83(MA11)":"6324",
"NAD83(MA11)":"6325",
"NAD83(2011) / UTM zone 59N":"6328",
"NAD83(2011) / UTM zone 60N":"6329",
"NAD83(2011) / UTM zone 1N":"6330",
"NAD83(2011) / UTM zone 2N":"6331",
"NAD83(2011) / UTM zone 3N":"6332",
"NAD83(2011) / UTM zone 4N":"6333",
"NAD83(2011) / UTM zone 5N":"6334",
"NAD83(2011) / UTM zone 6N":"6335",
"NAD83(2011) / UTM zone 7N":"6336",
"NAD83(2011) / UTM zone 8N":"6337",
"NAD83(2011) / UTM zone 9N":"6338",
"NAD83(2011) / UTM zone 10N":"6339",
"NAD83(2011) / UTM zone 11N":"6340",
"NAD83(2011) / UTM zone 12N":"6341",
"NAD83(2011) / UTM zone 13N":"6342",
"NAD83(2011) / UTM zone 14N":"6343",
"NAD83(2011) / UTM zone 15N":"6344",
"NAD83(2011) / UTM zone 16N":"6345",
"NAD83(2011) / UTM zone 17N":"6346",
"NAD83(2011) / UTM zone 18N":"6347",
"NAD83(2011) / UTM zone 19N":"6348",
"NAD83(2011) + NAVD88 height":"6349",
"NAD83(2011) / Conus Albers":"6350",
"NAD83(2011) / EPSG Arctic zone 5-29":"6351",
"NAD83(2011) / EPSG Arctic zone 5-31":"6352",
"NAD83(2011) / EPSG Arctic zone 6-14":"6353",
"NAD83(2011) / EPSG Arctic zone 6-16":"6354",
"NAD83(2011) / Alabama East":"6355",
"NAD83(2011) / Alabama West":"6356",
"NAVD88 depth":"6357",
"NAVD88 depth (ftUS)":"6358",
"NGVD29 depth (ftUS)":"6359",
"NAVD88 height (ftUS)":"6360",
"Mexico ITRF92 / LCC":"6362",
"Mexico ITRF2008":"6363",
"Mexico ITRF2008":"6364",
"Mexico ITRF2008":"6365",
"Mexico ITRF2008 / UTM zone 11N":"6366",
"Mexico ITRF2008 / UTM zone 12N":"6367",
"Mexico ITRF2008 / UTM zone 13N":"6368",
"Mexico ITRF2008 / UTM zone 14N":"6369",
"Mexico ITRF2008 / UTM zone 15N":"6370",
"Mexico ITRF2008 / UTM zone 16N":"6371",
"Mexico ITRF2008 / LCC":"6372",
"UCS-2000 / Ukraine TM zone 7":"6381",
"UCS-2000 / Ukraine TM zone 8":"6382",
"UCS-2000 / Ukraine TM zone 9":"6383",
"UCS-2000 / Ukraine TM zone 10":"6384",
"UCS-2000 / Ukraine TM zone 11":"6385",
"UCS-2000 / Ukraine TM zone 12":"6386",
"UCS-2000 / Ukraine TM zone 13":"6387",
"Cayman Islands National Grid 2011":"6391",
"NAD83(2011) / Alaska Albers":"6393",
"NAD83(2011) / Alaska zone 1":"6394",
"NAD83(2011) / Alaska zone 2":"6395",
"NAD83(2011) / Alaska zone 3":"6396",
"NAD83(2011) / Alaska zone 4":"6397",
"NAD83(2011) / Alaska zone 5":"6398",
"NAD83(2011) / Alaska zone 6":"6399",
"NAD83(2011) / Alaska zone 7":"6400",
"NAD83(2011) / Alaska zone 8":"6401",
"NAD83(2011) / Alaska zone 9":"6402",
"NAD83(2011) / Alaska zone 10":"6403",
"NAD83(2011) / Arizona Central":"6404",
"NAD83(2011) / Arizona Central (ft)":"6405",
"NAD83(2011) / Arizona East":"6406",
"NAD83(2011) / Arizona East (ft)":"6407",
"NAD83(2011) / Arizona West":"6408",
"NAD83(2011) / Arizona West (ft)":"6409",
"NAD83(2011) / Arkansas North":"6410",
"NAD83(2011) / Arkansas North (ftUS)":"6411",
"NAD83(2011) / Arkansas South":"6412",
"NAD83(2011) / Arkansas South (ftUS)":"6413",
"NAD83(2011) / California Albers":"6414",
"NAD83(2011) / California zone 1":"6415",
"NAD83(2011) / California zone 1 (ftUS)":"6416",
"NAD83(2011) / California zone 2":"6417",
"NAD83(2011) / California zone 2 (ftUS)":"6418",
"NAD83(2011) / California zone 3":"6419",
"NAD83(2011) / California zone 3 (ftUS)":"6420",
"NAD83(2011) / California zone 4":"6421",
"NAD83(2011) / California zone 4 (ftUS)":"6422",
"NAD83(2011) / California zone 5":"6423",
"NAD83(2011) / California zone 5 (ftUS)":"6424",
"NAD83(2011) / California zone 6":"6425",
"NAD83(2011) / California zone 6 (ftUS)":"6426",
"NAD83(2011) / Colorado Central":"6427",
"NAD83(2011) / Colorado Central (ftUS)":"6428",
"NAD83(2011) / Colorado North":"6429",
"NAD83(2011) / Colorado North (ftUS)":"6430",
"NAD83(2011) / Colorado South":"6431",
"NAD83(2011) / Colorado South (ftUS)":"6432",
"NAD83(2011) / Connecticut":"6433",
"NAD83(2011) / Connecticut (ftUS)":"6434",
"NAD83(2011) / Delaware":"6435",
"NAD83(2011) / Delaware (ftUS)":"6436",
"NAD83(2011) / Florida East":"6437",
"NAD83(2011) / Florida East (ftUS)":"6438",
"NAD83(2011) / Florida GDL Albers":"6439",
"NAD83(2011) / Florida North":"6440",
"NAD83(2011) / Florida North (ftUS)":"6441",
"NAD83(2011) / Florida West":"6442",
"NAD83(2011) / Florida West (ftUS)":"6443",
"NAD83(2011) / Georgia East":"6444",
"NAD83(2011) / Georgia East (ftUS)":"6445",
"NAD83(2011) / Georgia West":"6446",
"NAD83(2011) / Georgia West (ftUS)":"6447",
"NAD83(2011) / Idaho Central":"6448",
"NAD83(2011) / Idaho Central (ftUS)":"6449",
"NAD83(2011) / Idaho East":"6450",
"NAD83(2011) / Idaho East (ftUS)":"6451",
"NAD83(2011) / Idaho West":"6452",
"NAD83(2011) / Idaho West (ftUS)":"6453",
"NAD83(2011) / Illinois East":"6454",
"NAD83(2011) / Illinois East (ftUS)":"6455",
"NAD83(2011) / Illinois West":"6456",
"NAD83(2011) / Illinois West (ftUS)":"6457",
"NAD83(2011) / Indiana East":"6458",
"NAD83(2011) / Indiana East (ftUS)":"6459",
"NAD83(2011) / Indiana West":"6460",
"NAD83(2011) / Indiana West (ftUS)":"6461",
"NAD83(2011) / Iowa North":"6462",
"NAD83(2011) / Iowa North (ftUS)":"6463",
"NAD83(2011) / Iowa South":"6464",
"NAD83(2011) / Iowa South (ftUS)":"6465",
"NAD83(2011) / Kansas North":"6466",
"NAD83(2011) / Kansas North (ftUS)":"6467",
"NAD83(2011) / Kansas South":"6468",
"NAD83(2011) / Kansas South (ftUS)":"6469",
"NAD83(2011) / Kentucky North":"6470",
"NAD83(2011) / Kentucky North (ftUS)":"6471",
"NAD83(2011) / Kentucky Single Zone":"6472",
"NAD83(2011) / Kentucky Single Zone (ftUS)":"6473",
"NAD83(2011) / Kentucky South":"6474",
"NAD83(2011) / Kentucky South (ftUS)":"6475",
"NAD83(2011) / Louisiana North":"6476",
"NAD83(2011) / Louisiana North (ftUS)":"6477",
"NAD83(2011) / Louisiana South":"6478",
"NAD83(2011) / Louisiana South (ftUS)":"6479",
"NAD83(2011) / Maine CS2000 Central":"6480",
"NAD83(2011) / Maine CS2000 East":"6481",
"NAD83(2011) / Maine CS2000 West":"6482",
"NAD83(2011) / Maine East":"6483",
"NAD83(2011) / Maine East (ftUS)":"6484",
"NAD83(2011) / Maine West":"6485",
"NAD83(2011) / Maine West (ftUS)":"6486",
"NAD83(2011) / Maryland":"6487",
"NAD83(2011) / Maryland (ftUS)":"6488",
"NAD83(2011) / Massachusetts Island":"6489",
"NAD83(2011) / Massachusetts Island (ftUS)":"6490",
"NAD83(2011) / Massachusetts Mainland":"6491",
"NAD83(2011) / Massachusetts Mainland (ftUS)":"6492",
"NAD83(2011) / Michigan Central":"6493",
"NAD83(2011) / Michigan Central (ft)":"6494",
"NAD83(2011) / Michigan North":"6495",
"NAD83(2011) / Michigan North (ft)":"6496",
"NAD83(2011) / Michigan Oblique Mercator":"6497",
"NAD83(2011) / Michigan South":"6498",
"NAD83(2011) / Michigan South (ft)":"6499",
"NAD83(2011) / Minnesota Central":"6500",
"NAD83(2011) / Minnesota Central (ftUS)":"6501",
"NAD83(2011) / Minnesota North":"6502",
"NAD83(2011) / Minnesota North (ftUS)":"6503",
"NAD83(2011) / Minnesota South":"6504",
"NAD83(2011) / Minnesota South (ftUS)":"6505",
"NAD83(2011) / Mississippi East":"6506",
"NAD83(2011) / Mississippi East (ftUS)":"6507",
"NAD83(2011) / Mississippi TM":"6508",
"NAD83(2011) / Mississippi West":"6509",
"NAD83(2011) / Mississippi West (ftUS)":"6510",
"NAD83(2011) / Missouri Central":"6511",
"NAD83(2011) / Missouri East":"6512",
"NAD83(2011) / Missouri West":"6513",
"NAD83(2011) / Montana":"6514",
"NAD83(2011) / Montana (ft)":"6515",
"NAD83(2011) / Nebraska":"6516",
"NAD83(2011) / Nebraska (ftUS)":"6517",
"NAD83(2011) / Nevada Central":"6518",
"NAD83(2011) / Nevada Central (ftUS)":"6519",
"NAD83(2011) / Nevada East":"6520",
"NAD83(2011) / Nevada East (ftUS)":"6521",
"NAD83(2011) / Nevada West":"6522",
"NAD83(2011) / Nevada West (ftUS)":"6523",
"NAD83(2011) / New Hampshire":"6524",
"NAD83(2011) / New Hampshire (ftUS)":"6525",
"NAD83(2011) / New Jersey":"6526",
"NAD83(2011) / New Jersey (ftUS)":"6527",
"NAD83(2011) / New Mexico Central":"6528",
"NAD83(2011) / New Mexico Central (ftUS)":"6529",
"NAD83(2011) / New Mexico East":"6530",
"NAD83(2011) / New Mexico East (ftUS)":"6531",
"NAD83(2011) / New Mexico West":"6532",
"NAD83(2011) / New Mexico West (ftUS)":"6533",
"NAD83(2011) / New York Central":"6534",
"NAD83(2011) / New York Central (ftUS)":"6535",
"NAD83(2011) / New York East":"6536",
"NAD83(2011) / New York East (ftUS)":"6537",
"NAD83(2011) / New York Long Island":"6538",
"NAD83(2011) / New York Long Island (ftUS)":"6539",
"NAD83(2011) / New York West":"6540",
"NAD83(2011) / New York West (ftUS)":"6541",
"NAD83(2011) / North Carolina":"6542",
"NAD83(2011) / North Carolina (ftUS)":"6543",
"NAD83(2011) / North Dakota North":"6544",
"NAD83(2011) / North Dakota North (ft)":"6545",
"NAD83(2011) / North Dakota South":"6546",
"NAD83(2011) / North Dakota South (ft)":"6547",
"NAD83(2011) / Ohio North":"6548",
"NAD83(2011) / Ohio North (ftUS)":"6549",
"NAD83(2011) / Ohio South":"6550",
"NAD83(2011) / Ohio South (ftUS)":"6551",
"NAD83(2011) / Oklahoma North":"6552",
"NAD83(2011) / Oklahoma North (ftUS)":"6553",
"NAD83(2011) / Oklahoma South":"6554",
"NAD83(2011) / Oklahoma South (ftUS)":"6555",
"NAD83(2011) / Oregon LCC (m)":"6556",
"NAD83(2011) / Oregon GIC Lambert (ft)":"6557",
"NAD83(2011) / Oregon North":"6558",
"NAD83(2011) / Oregon North (ft)":"6559",
"NAD83(2011) / Oregon South":"6560",
"NAD83(2011) / Oregon South (ft)":"6561",
"NAD83(2011) / Pennsylvania North":"6562",
"NAD83(2011) / Pennsylvania North (ftUS)":"6563",
"NAD83(2011) / Pennsylvania South":"6564",
"NAD83(2011) / Pennsylvania South (ftUS)":"6565",
"NAD83(2011) / Puerto Rico and Virgin Is.":"6566",
"NAD83(2011) / Rhode Island":"6567",
"NAD83(2011) / Rhode Island (ftUS)":"6568",
"NAD83(2011) / South Carolina":"6569",
"NAD83(2011) / South Carolina (ft)":"6570",
"NAD83(2011) / South Dakota North":"6571",
"NAD83(2011) / South Dakota North (ftUS)":"6572",
"NAD83(2011) / South Dakota South":"6573",
"NAD83(2011) / South Dakota South (ftUS)":"6574",
"NAD83(2011) / Tennessee":"6575",
"NAD83(2011) / Tennessee (ftUS)":"6576",
"NAD83(2011) / Texas Central":"6577",
"NAD83(2011) / Texas Central (ftUS)":"6578",
"NAD83(2011) / Texas Centric Albers Equal Area":"6579",
"NAD83(2011) / Texas Centric Lambert Conformal":"6580",
"NAD83(2011) / Texas North":"6581",
"NAD83(2011) / Texas North (ftUS)":"6582",
"NAD83(2011) / Texas North Central":"6583",
"NAD83(2011) / Texas North Central (ftUS)":"6584",
"NAD83(2011) / Texas South":"6585",
"NAD83(2011) / Texas South (ftUS)":"6586",
"NAD83(2011) / Texas South Central":"6587",
"NAD83(2011) / Texas South Central (ftUS)":"6588",
"NAD83(2011) / Vermont":"6589",
"NAD83(2011) / Vermont (ftUS)":"6590",
"NAD83(2011) / Virginia Lambert":"6591",
"NAD83(2011) / Virginia North":"6592",
"NAD83(2011) / Virginia North (ftUS)":"6593",
"NAD83(2011) / Virginia South":"6594",
"NAD83(2011) / Virginia South (ftUS)":"6595",
"NAD83(2011) / Washington North":"6596",
"NAD83(2011) / Washington North (ftUS)":"6597",
"NAD83(2011) / Washington South":"6598",
"NAD83(2011) / Washington South (ftUS)":"6599",
"NAD83(2011) / West Virginia North":"6600",
"NAD83(2011) / West Virginia North (ftUS)":"6601",
"NAD83(2011) / West Virginia South":"6602",
"NAD83(2011) / West Virginia South (ftUS)":"6603",
"NAD83(2011) / Wisconsin Central":"6604",
"NAD83(2011) / Wisconsin Central (ftUS)":"6605",
"NAD83(2011) / Wisconsin North":"6606",
"NAD83(2011) / Wisconsin North (ftUS)":"6607",
"NAD83(2011) / Wisconsin South":"6608",
"NAD83(2011) / Wisconsin South (ftUS)":"6609",
"NAD83(2011) / Wisconsin Transverse Mercator":"6610",
"NAD83(2011) / Wyoming East":"6611",
"NAD83(2011) / Wyoming East (ftUS)":"6612",
"NAD83(2011) / Wyoming East Central":"6613",
"NAD83(2011) / Wyoming East Central (ftUS)":"6614",
"NAD83(2011) / Wyoming West":"6615",
"NAD83(2011) / Wyoming West (ftUS)":"6616",
"NAD83(2011) / Wyoming West Central":"6617",
"NAD83(2011) / Wyoming West Central (ftUS)":"6618",
"NAD83(2011) / Utah Central":"6619",
"NAD83(2011) / Utah North":"6620",
"NAD83(2011) / Utah South":"6621",
"NAD83(CSRS) / Quebec Lambert":"6622",
"NAD83 / Quebec Albers":"6623",
"NAD83(CSRS) / Quebec Albers":"6624",
"NAD83(2011) / Utah Central (ftUS)":"6625",
"NAD83(2011) / Utah North (ftUS)":"6626",
"NAD83(2011) / Utah South (ftUS)":"6627",
"NAD83(PA11) / Hawaii zone 1":"6628",
"NAD83(PA11) / Hawaii zone 2":"6629",
"NAD83(PA11) / Hawaii zone 3":"6630",
"NAD83(PA11) / Hawaii zone 4":"6631",
"NAD83(PA11) / Hawaii zone 5":"6632",
"NAD83(PA11) / Hawaii zone 3 (ftUS)":"6633",
"NAD83(PA11) / UTM zone 4N":"6634",
"NAD83(PA11) / UTM zone 5N":"6635",
"NAD83(PA11) / UTM zone 2S":"6636",
"NAD83(MA11) / Guam Map Grid":"6637",
"Tutuila 1962 height":"6638",
"Guam 1963 height":"6639",
"NMVD03 height":"6640",
"PRVD02 height":"6641",
"VIVD09 height":"6642",
"ASVD02 height":"6643",
"GUVD04 height":"6644",
"Karbala 1979 / Iraq National Grid":"6646",
"CGVD2013 height":"6647",
"NAD83(CSRS) + CGVD2013 height":"6649",
"NAD83(CSRS) / UTM zone 7N + CGVD2013 height":"6650",
"NAD83(CSRS) / UTM zone 8N + CGVD2013 height":"6651",
"NAD83(CSRS) / UTM zone 9N + CGVD2013 height":"6652",
"NAD83(CSRS) / UTM zone 10N + CGVD2013 height":"6653",
"NAD83(CSRS) / UTM zone 11N + CGVD2013 height":"6654",
"NAD83(CSRS) / UTM zone 12N + CGVD2013 height":"6655",
"NAD83(CSRS) / UTM zone 13N + CGVD2013 height":"6656",
"NAD83(CSRS) / UTM zone 14N + CGVD2013 height":"6657",
"NAD83(CSRS) / UTM zone 15N + CGVD2013 height":"6658",
"NAD83(CSRS) / UTM zone 16N + CGVD2013 height":"6659",
"NAD83(CSRS) / UTM zone 17N + CGVD2013 height":"6660",
"NAD83(CSRS) / UTM zone 18N + CGVD2013 height":"6661",
"NAD83(CSRS) / UTM zone 19N + CGVD2013 height":"6662",
"NAD83(CSRS) / UTM zone 20N + CGVD2013 height":"6663",
"NAD83(CSRS) / UTM zone 21N + CGVD2013 height":"6664",
"NAD83(CSRS) / UTM zone 22N + CGVD2013 height":"6665",
"JGD2011":"6666",
"JGD2011":"6667",
"JGD2011":"6668",
"JGD2011 / Japan Plane Rectangular CS I":"6669",
"JGD2011 / Japan Plane Rectangular CS II":"6670",
"JGD2011 / Japan Plane Rectangular CS III":"6671",
"JGD2011 / Japan Plane Rectangular CS IV":"6672",
"JGD2011 / Japan Plane Rectangular CS V":"6673",
"JGD2011 / Japan Plane Rectangular CS VI":"6674",
"JGD2011 / Japan Plane Rectangular CS VII":"6675",
"JGD2011 / Japan Plane Rectangular CS VIII":"6676",
"JGD2011 / Japan Plane Rectangular CS IX":"6677",
"JGD2011 / Japan Plane Rectangular CS X":"6678",
"JGD2011 / Japan Plane Rectangular CS XI":"6679",
"JGD2011 / Japan Plane Rectangular CS XII":"6680",
"JGD2011 / Japan Plane Rectangular CS XIII":"6681",
"JGD2011 / Japan Plane Rectangular CS XIV":"6682",
"JGD2011 / Japan Plane Rectangular CS XV":"6683",
"JGD2011 / Japan Plane Rectangular CS XVI":"6684",
"JGD2011 / Japan Plane Rectangular CS XVII":"6685",
"JGD2011 / Japan Plane Rectangular CS XVIII":"6686",
"JGD2011 / Japan Plane Rectangular CS XIX":"6687",
"JGD2011 / UTM zone 51N":"6688",
"JGD2011 / UTM zone 52N":"6689",
"JGD2011 / UTM zone 53N":"6690",
"JGD2011 / UTM zone 54N":"6691",
"JGD2011 / UTM zone 55N":"6692",
"JSLD72 height":"6693",
"JGD2000 (vertical) height":"6694",
"JGD2011 (vertical) height":"6695",
"JGD2000 + JGD2000 (vertical) height":"6696",
"JGD2011 + JGD2011 (vertical) height":"6697",
"Tokyo + JSLD72 height":"6700",
"WGS 84 / TM 60 SW":"6703",
"RDN2008":"6704",
"RDN2008":"6705",
"RDN2008":"6706",
"RDN2008 / UTM zone 32N (N-E)":"6707",
"RDN2008 / UTM zone 33N (N-E)":"6708",
"RDN2008 / UTM zone 34N (N-E)":"6709",
"Christmas Island Grid 1985":"6715",
"WGS 84 / CIG92":"6720",
"GDA94 / CIG94":"6721",
"WGS 84 / CKIG92":"6722",
"GDA94 / CKIG94":"6723",
"GDA94 / MGA zone 41":"6732",
"GDA94 / MGA zone 42":"6733",
"GDA94 / MGA zone 43":"6734",
"GDA94 / MGA zone 44":"6735",
"GDA94 / MGA zone 46":"6736",
"GDA94 / MGA zone 47":"6737",
"GDA94 / MGA zone 59":"6738",
"NAD83(CORS96)":"6781",
"NAD83(CORS96)":"6782",
"NAD83(CORS96)":"6783",
"NAD83(CORS96) / Oregon Baker zone (m)":"6784",
"NAD83(CORS96) / Oregon Baker zone (ft)":"6785",
"NAD83(2011) / Oregon Baker zone (m)":"6786",
"NAD83(2011) / Oregon Baker zone (ft)":"6787",
"NAD83(CORS96) / Oregon Bend-Klamath Falls zone (m)":"6788",
"NAD83(CORS96) / Oregon Bend-Klamath Falls zone (ft)":"6789",
"NAD83(2011) / Oregon Bend-Klamath Falls zone (m)":"6790",
"NAD83(2011) / Oregon Bend-Klamath Falls zone (ft)":"6791",
"NAD83(CORS96) / Oregon Bend-Redmond-Prineville zone (m)":"6792",
"NAD83(CORS96) / Oregon Bend-Redmond-Prineville zone (ft)":"6793",
"NAD83(2011) / Oregon Bend-Redmond-Prineville zone (m)":"6794",
"NAD83(2011) / Oregon Bend-Redmond-Prineville zone (ft)":"6795",
"NAD83(CORS96) / Oregon Bend-Burns zone (m)":"6796",
"NAD83(CORS96) / Oregon Bend-Burns zone (ft)":"6797",
"NAD83(2011) / Oregon Bend-Burns zone (m)":"6798",
"NAD83(2011) / Oregon Bend-Burns zone (ft)":"6799",
"NAD83(CORS96) / Oregon Canyonville-Grants Pass zone (m)":"6800",
"NAD83(CORS96) / Oregon Canyonville-Grants Pass zone (ft)":"6801",
"NAD83(2011) / Oregon Canyonville-Grants Pass zone (m)":"6802",
"NAD83(2011) / Oregon Canyonville-Grants Pass zone (ft)":"6803",
"NAD83(CORS96) / Oregon Columbia River East zone (m)":"6804",
"NAD83(CORS96) / Oregon Columbia River East zone (ft)":"6805",
"NAD83(2011) / Oregon Columbia River East zone (m)":"6806",
"NAD83(2011) / Oregon Columbia River East zone (ft)":"6807",
"NAD83(CORS96) / Oregon Columbia River West zone (m)":"6808",
"NAD83(CORS96) / Oregon Columbia River West zone (ft)":"6809",
"NAD83(2011) / Oregon Columbia River West zone (m)":"6810",
"NAD83(2011) / Oregon Columbia River West zone (ft)":"6811",
"NAD83(CORS96) / Oregon Cottage Grove-Canyonville zone (m)":"6812",
"NAD83(CORS96) / Oregon Cottage Grove-Canyonville zone (ft)":"6813",
"NAD83(2011) / Oregon Cottage Grove-Canyonville zone (m)":"6814",
"NAD83(2011) / Oregon Cottage Grove-Canyonville zone (ft)":"6815",
"NAD83(CORS96) / Oregon Dufur-Madras zone (m)":"6816",
"NAD83(CORS96) / Oregon Dufur-Madras zone (ft)":"6817",
"NAD83(2011) / Oregon Dufur-Madras zone (m)":"6818",
"NAD83(2011) / Oregon Dufur-Madras zone (ft)":"6819",
"NAD83(CORS96) / Oregon Eugene zone (m)":"6820",
"NAD83(CORS96) / Oregon Eugene zone (ft)":"6821",
"NAD83(2011) / Oregon Eugene zone (m)":"6822",
"NAD83(2011) / Oregon Eugene zone (ft)":"6823",
"NAD83(CORS96) / Oregon Grants Pass-Ashland zone (m)":"6824",
"NAD83(CORS96) / Oregon Grants Pass-Ashland zone (ft)":"6825",
"NAD83(2011) / Oregon Grants Pass-Ashland zone (m)":"6826",
"NAD83(2011) / Oregon Grants Pass-Ashland zone (ft)":"6827",
"NAD83(CORS96) / Oregon Gresham-Warm Springs zone (m)":"6828",
"NAD83(CORS96) / Oregon Gresham-Warm Springs zone (ft)":"6829",
"NAD83(2011) / Oregon Gresham-Warm Springs zone (m)":"6830",
"NAD83(2011) / Oregon Gresham-Warm Springs zone (ft)":"6831",
"NAD83(CORS96) / Oregon La Grande zone (m)":"6832",
"NAD83(CORS96) / Oregon La Grande zone (ft)":"6833",
"NAD83(2011) / Oregon La Grande zone (m)":"6834",
"NAD83(2011) / Oregon La Grande zone (ft)":"6835",
"NAD83(CORS96) / Oregon Ontario zone (m)":"6836",
"NAD83(CORS96) / Oregon Ontario zone (ft)":"6837",
"NAD83(2011) / Oregon Ontario zone (m)":"6838",
"NAD83(2011) / Oregon Ontario zone (ft)":"6839",
"NAD83(CORS96) / Oregon Coast zone (m)":"6840",
"NAD83(CORS96) / Oregon Coast zone (ft)":"6841",
"NAD83(2011) / Oregon Coast zone (m)":"6842",
"NAD83(2011) / Oregon Coast zone (ft)":"6843",
"NAD83(CORS96) / Oregon Pendleton zone (m)":"6844",
"NAD83(CORS96) / Oregon Pendleton zone (ft)":"6845",
"NAD83(2011) / Oregon Pendleton zone (m)":"6846",
"NAD83(2011) / Oregon Pendleton zone (ft)":"6847",
"NAD83(CORS96) / Oregon Pendleton-La Grande zone (m)":"6848",
"NAD83(CORS96) / Oregon Pendleton-La Grande zone (ft)":"6849",
"NAD83(2011) / Oregon Pendleton-La Grande zone (m)":"6850",
"NAD83(2011) / Oregon Pendleton-La Grande zone (ft)":"6851",
"NAD83(CORS96) / Oregon Portland zone (m)":"6852",
"NAD83(CORS96) / Oregon Portland zone (ft)":"6853",
"NAD83(2011) / Oregon Portland zone (m)":"6854",
"NAD83(2011) / Oregon Portland zone (ft)":"6855",
"NAD83(CORS96) / Oregon Salem zone (m)":"6856",
"NAD83(CORS96) / Oregon Salem zone (ft)":"6857",
"NAD83(2011) / Oregon Salem zone (m)":"6858",
"NAD83(2011) / Oregon Salem zone (ft)":"6859",
"NAD83(CORS96) / Oregon Santiam Pass zone (m)":"6860",
"NAD83(CORS96) / Oregon Santiam Pass zone (ft)":"6861",
"NAD83(2011) / Oregon Santiam Pass zone (m)":"6862",
"NAD83(2011) / Oregon Santiam Pass zone (ft)":"6863",
"NAD83(CORS96) / Oregon LCC (m)":"6867",
"NAD83(CORS96) / Oregon GIC Lambert (ft)":"6868",
"ETRS89 / Albania TM 2010":"6870",
"WGS 84 / Pseudo-Mercator +  EGM2008 geoid height":"6871",
"RDN2008 / Italy zone (N-E)":"6875",
"RDN2008 / Zone 12 (N-E)":"6876",
"NAD83(2011) / Wisconsin Central":"6879",
"NAD83(2011) / Nebraska (ftUS)":"6880",
"Aden 1925":"6881",
"Bekaa Valley 1920":"6882",
"Bioko":"6883",
"NAD83(CORS96) / Oregon North":"6884",
"NAD83(CORS96) / Oregon North (ft)":"6885",
"NAD83(CORS96) / Oregon South":"6886",
"NAD83(CORS96) / Oregon South (ft)":"6887",
"South East Island 1943":"6892",
"WGS 84 / World Mercator +  EGM2008 height":"6893",
"Gambia":"6894",
"South East Island 1943 / UTM zone 40N":"6915",
"SHD height":"6916",
"SVY21 + SHD height":"6917",
"NAD83 / Kansas LCC":"6922",
"NAD83 / Kansas LCC (ftUS)":"6923",
"NAD83(2011) / Kansas LCC":"6924",
"NAD83(2011) / Kansas LCC (ftUS)":"6925",
"SVY21 / Singapore TM + SHD height":"6927",
"WGS 84 / NSIDC EASE-Grid 2.0 North":"6931",
"WGS 84 / NSIDC EASE-Grid 2.0 South":"6932",
"WGS 84 / NSIDC EASE-Grid 2.0 Global":"6933",
"IGS08":"6934",
"VN-2000 / TM-3 zone 481":"6956",
"VN-2000 / TM-3 zone 482":"6957",
"VN-2000 / TM-3 zone 491":"6958",
"VN-2000 / TM-3 Da Nang zone":"6959",
"ETRS89 / Albania LCC 2010":"6962",
"NAD27 / Michigan North":"6966",
"IGD05":"6978",
"IGD05":"6979",
"IGD05":"6980",
"IG05 Intermediate CRS":"6981",
"IG05 Intermediate CRS":"6982",
"IG05 Intermediate CRS":"6983",
"Israeli Grid 05":"6984",
"IGD05/12":"6985",
"IGD05/12":"6986",
"IGD05/12":"6987",
"IG05/12 Intermediate CRS":"6988",
"IG05/12 Intermediate CRS":"6989",
"IG05/12 Intermediate CRS":"6990",
"Israeli Grid 05/12":"6991",
"NAD83(2011) / San Francisco CS13":"6996",
"NAD83(2011) / San Francisco CS13 (ftUS)":"6997",
"Nahrwan 1934 / UTM zone 37N":"7005",
"Nahrwan 1934 / UTM zone 38N":"7006",
"Nahrwan 1934 / UTM zone 39N":"7007",
"RGSPM06 (lon-lat)":"7034",
"RGSPM06 (lon-lat)":"7035",
"RGR92 (lon-lat)":"7036",
"RGR92 (lon-lat)":"7037",
"RGM04 (lon-lat)":"7038",
"RGM04 (lon-lat)":"7039",
"RGFG95 (lon-lat)":"7040",
"RGFG95 (lon-lat)":"7041",
"RGF93 (lon-lat)":"7042",
"NAD83(2011) / IaRCS zone 1":"7057",
"NAD83(2011) / IaRCS zone 2":"7058",
"NAD83(2011) / IaRCS zone 3":"7059",
"NAD83(2011) / IaRCS zone 4":"7060",
"NAD83(2011) / IaRCS zone 5":"7061",
"NAD83(2011) / IaRCS zone 6":"7062",
"NAD83(2011) / IaRCS zone 7":"7063",
"NAD83(2011) / IaRCS zone 8":"7064",
"NAD83(2011) / IaRCS zone 9":"7065",
"NAD83(2011) / IaRCS zone 10":"7066",
"NAD83(2011) / IaRCS zone 11":"7067",
"NAD83(2011) / IaRCS zone 12":"7068",
"NAD83(2011) / IaRCS zone 13":"7069",
"NAD83(2011) / IaRCS zone 14":"7070",
"RGTAAF07":"7071",
"RGTAAF07":"7072",
"RGTAAF07":"7073",
"RGTAAF07 / UTM zone 37S":"7074",
"RGTAAF07 / UTM zone 38S":"7075",
"RGTAAF07 / UTM zone 39S":"7076",
"RGTAAF07 / UTM zone 40S":"7077",
"RGTAAF07 / UTM zone 41S":"7078",
"RGTAAF07 / UTM zone 42S":"7079",
"RGTAAF07 / UTM zone 43S":"7080",
"RGTAAF07 / UTM zone 44S":"7081",
"RGTAAF07 / Terre Adelie Polar Stereographic":"7082",
"RGF93 (lon-lat)":"7084",
"RGAF09 (lon-lat)":"7085",
"RGAF09 (lon-lat)":"7086",
"RGTAAF07 (lon-lat)":"7087",
"RGTAAF07 (lon-lat)":"7088",
"NAD83(2011) / RMTCRS St Mary (m)":"7109",
"NAD83(2011) / RMTCRS Blackfeet (m)":"7110",
"NAD83(2011) / RMTCRS Milk River (m)":"7111",
"NAD83(2011) / RMTCRS Fort Belknap (m)":"7112",
"NAD83(2011) / RMTCRS Fort Peck Assiniboine (m)":"7113",
"NAD83(2011) / RMTCRS Fort Peck Sioux (m)":"7114",
"NAD83(2011) / RMTCRS Crow (m)":"7115",
"NAD83(2011) / RMTCRS Bobcat (m)":"7116",
"NAD83(2011) / RMTCRS Billings (m)":"7117",
"NAD83(2011) / RMTCRS Wind River (m)":"7118",
"NAD83(2011) / RMTCRS St Mary (ft)":"7119",
"NAD83(2011) / RMTCRS Blackfeet (ft)":"7120",
"NAD83(2011) / RMTCRS Milk River (ft)":"7121",
"NAD83(2011) / RMTCRS Fort Belknap (ft)":"7122",
"NAD83(2011) / RMTCRS Fort Peck Assiniboine (ft)":"7123",
"NAD83(2011) / RMTCRS Fort Peck Sioux (ft)":"7124",
"NAD83(2011) / RMTCRS Crow (ft)":"7125",
"NAD83(2011) / RMTCRS Bobcat (ft)":"7126",
"NAD83(2011) / RMTCRS Billings (ft)":"7127",
"NAD83(2011) / RMTCRS Wind River (ftUS)":"7128",
"NAD83(2011) / San Francisco CS13":"7131",
"NAD83(2011) / San Francisco CS13 (ftUS)":"7132",
"RGTAAF07 (lon-lat)":"7133",
"IGD05":"7134",
"IGD05":"7135",
"IGD05":"7136",
"IGD05/12":"7137",
"IGD05/12":"7138",
"IGD05/12":"7139",
"Palestine 1923 / Palestine Grid modified":"7142",
"NAD83(2011) / InGCS Adams (m)":"7257",
"NAD83(2011) / InGCS Adams (ftUS)":"7258",
"NAD83(2011) / InGCS Allen (m)":"7259",
"NAD83(2011) / InGCS Allen (ftUS)":"7260",
"NAD83(2011) / InGCS Bartholomew (m)":"7261",
"NAD83(2011) / InGCS Bartholomew (ftUS)":"7262",
"NAD83(2011) / InGCS Benton (m)":"7263",
"NAD83(2011) / InGCS Benton (ftUS)":"7264",
"NAD83(2011) / InGCS Blackford-Delaware (m)":"7265",
"NAD83(2011) / InGCS Blackford-Delaware (ftUS)":"7266",
"NAD83(2011) / InGCS Boone-Hendricks (m)":"7267",
"NAD83(2011) / InGCS Boone-Hendricks (ftUS)":"7268",
"NAD83(2011) / InGCS Brown (m)":"7269",
"NAD83(2011) / InGCS Brown (ftUS)":"7270",
"NAD83(2011) / InGCS Carroll (m)":"7271",
"NAD83(2011) / InGCS Carroll (ftUS)":"7272",
"NAD83(2011) / InGCS Cass (m)":"7273",
"NAD83(2011) / InGCS Cass (ftUS)":"7274",
"NAD83(2011) / InGCS Clark-Floyd-Scott (m)":"7275",
"NAD83(2011) / InGCS Clark-Floyd-Scott (ftUS)":"7276",
"NAD83(2011) / InGCS Clay (m)":"7277",
"NAD83(2011) / InGCS Clay (ftUS)":"7278",
"NAD83(2011) / InGCS Clinton (m)":"7279",
"NAD83(2011) / InGCS Clinton (ftUS)":"7280",
"NAD83(2011) / InGCS Crawford-Lawrence-Orange (m)":"7281",
"NAD83(2011) / InGCS Crawford-Lawrence-Orange (ftUS)":"7282",
"NAD83(2011) / InGCS Daviess-Greene (m)":"7283",
"NAD83(2011) / InGCS Daviess-Greene (ftUS)":"7284",
"NAD83(2011) / InGCS Dearborn-Ohio-Switzerland (m)":"7285",
"NAD83(2011) / InGCS Dearborn-Ohio-Switzerland (ftUS)":"7286",
"NAD83(2011) / InGCS Decatur-Rush (m)":"7287",
"NAD83(2011) / InGCS Decatur-Rush (ftUS)":"7288",
"NAD83(2011) / InGCS DeKalb (m)":"7289",
"NAD83(2011) / InGCS DeKalb (ftUS)":"7290",
"NAD83(2011) / InGCS Dubois-Martin (m)":"7291",
"NAD83(2011) / InGCS Dubois-Martin (ftUS)":"7292",
"NAD83(2011) / InGCS Elkhart-Kosciusko-Wabash (m)":"7293",
"NAD83(2011) / InGCS Elkhart-Kosciusko-Wabash (ftUS)":"7294",
"NAD83(2011) / InGCS Fayette-Franklin-Union (m)":"7295",
"NAD83(2011) / InGCS Fayette-Franklin-Union (ftUS)":"7296",
"NAD83(2011) / InGCS Fountain-Warren (m)":"7297",
"NAD83(2011) / InGCS Fountain-Warren (ftUS)":"7298",
"NAD83(2011) / InGCS Fulton-Marshall-St. Joseph (m)":"7299",
"NAD83(2011) / InGCS Fulton-Marshall-St. Joseph (ftUS)":"7300",
"NAD83(2011) / InGCS Gibson (m)":"7301",
"NAD83(2011) / InGCS Gibson (ftUS)":"7302",
"NAD83(2011) / InGCS Grant (m)":"7303",
"NAD83(2011) / InGCS Grant (ftUS)":"7304",
"NAD83(2011) / InGCS Hamilton-Tipton (m)":"7305",
"NAD83(2011) / InGCS Hamilton-Tipton (ftUS)":"7306",
"NAD83(2011) / InGCS Hancock-Madison (m)":"7307",
"NAD83(2011) / InGCS Hancock-Madison (ftUS)":"7308",
"NAD83(2011) / InGCS Harrison-Washington (m)":"7309",
"NAD83(2011) / InGCS Harrison-Washington (ftUS)":"7310",
"NAD83(2011) / InGCS Henry (m)":"7311",
"NAD83(2011) / InGCS Henry (ftUS)":"7312",
"NAD83(2011) / InGCS Howard-Miami (m)":"7313",
"NAD83(2011) / InGCS Howard-Miami (ftUS)":"7314",
"NAD83(2011) / InGCS Huntington-Whitley (m)":"7315",
"NAD83(2011) / InGCS Huntington-Whitley (ftUS)":"7316",
"NAD83(2011) / InGCS Jackson (m)":"7317",
"NAD83(2011) / InGCS Jackson (ftUS)":"7318",
"NAD83(2011) / InGCS Jasper-Porter (m)":"7319",
"NAD83(2011) / InGCS Jasper-Porter (ftUS)":"7320",
"NAD83(2011) / InGCS Jay (m)":"7321",
"NAD83(2011) / InGCS Jay (ftUS)":"7322",
"NAD83(2011) / InGCS Jefferson (m)":"7323",
"NAD83(2011) / InGCS Jefferson (ftUS)":"7324",
"NAD83(2011) / InGCS Jennings (m)":"7325",
"NAD83(2011) / InGCS Jennings (ftUS)":"7326",
"NAD83(2011) / InGCS Johnson-Marion (m)":"7327",
"NAD83(2011) / InGCS Johnson-Marion (ftUS)":"7328",
"NAD83(2011) / InGCS Knox (m)":"7329",
"NAD83(2011) / InGCS Knox (ftUS)":"7330",
"NAD83(2011) / InGCS LaGrange-Noble (m)":"7331",
"NAD83(2011) / InGCS LaGrange-Noble (ftUS)":"7332",
"NAD83(2011) / InGCS Lake-Newton (m)":"7333",
"NAD83(2011) / InGCS Lake-Newton (ftUS)":"7334",
"NAD83(2011) / InGCS LaPorte-Pulaski-Starke (m)":"7335",
"NAD83(2011) / InGCS LaPorte-Pulaski-Starke (ftUS)":"7336",
"NAD83(2011) / InGCS Monroe-Morgan (m)":"7337",
"NAD83(2011) / InGCS Monroe-Morgan (ftUS)":"7338",
"NAD83(2011) / InGCS Montgomery-Putnam (m)":"7339",
"NAD83(2011) / InGCS Montgomery-Putnam (ftUS)":"7340",
"NAD83(2011) / InGCS Owen (m)":"7341",
"NAD83(2011) / InGCS Owen (ftUS)":"7342",
"NAD83(2011) / InGCS Parke-Vermillion (m)":"7343",
"NAD83(2011) / InGCS Parke-Vermillion (ftUS)":"7344",
"NAD83(2011) / InGCS Perry (m)":"7345",
"NAD83(2011) / InGCS Perry (ftUS)":"7346",
"NAD83(2011) / InGCS Pike-Warrick (m)":"7347",
"NAD83(2011) / InGCS Pike-Warrick (ftUS)":"7348",
"NAD83(2011) / InGCS Posey (m)":"7349",
"NAD83(2011) / InGCS Posey (ftUS)":"7350",
"NAD83(2011) / InGCS Randolph-Wayne (m)":"7351",
"NAD83(2011) / InGCS Randolph-Wayne (ftUS)":"7352",
"NAD83(2011) / InGCS Ripley (m)":"7353",
"NAD83(2011) / InGCS Ripley (ftUS)":"7354",
"NAD83(2011) / InGCS Shelby (m)":"7355",
"NAD83(2011) / InGCS Shelby (ftUS)":"7356",
"NAD83(2011) / InGCS Spencer (m)":"7357",
"NAD83(2011) / InGCS Spencer (ftUS)":"7358",
"NAD83(2011) / InGCS Steuben (m)":"7359",
"NAD83(2011) / InGCS Steuben (ftUS)":"7360",
"NAD83(2011) / InGCS Sullivan (m)":"7361",
"NAD83(2011) / InGCS Sullivan (ftUS)":"7362",
"NAD83(2011) / InGCS Tippecanoe-White (m)":"7363",
"NAD83(2011) / InGCS Tippecanoe-White (ftUS)":"7364",
"NAD83(2011) / InGCS Vanderburgh (m)":"7365",
"NAD83(2011) / InGCS Vanderburgh (ftUS)":"7366",
"NAD83(2011) / InGCS Vigo (m)":"7367",
"NAD83(2011) / InGCS Vigo (ftUS)":"7368",
"NAD83(2011) / InGCS Wells (m)":"7369",
"NAD83(2011) / InGCS Wells (ftUS)":"7370",
"ONGD14":"7371",
"ONGD14":"7372",
"ONGD14":"7373",
"ONGD14 / UTM zone 39N":"7374",
"ONGD14 / UTM zone 40N":"7375",
"ONGD14 / UTM zone 41N":"7376",
"NTF (Paris) + NGF IGN69 height":"7400",
"NTF (Paris) / France II + NGF Lallemand":"7401",
"NTF (Paris) / France II + NGF IGN69":"7402",
"NTF (Paris) / France III + NGF IGN69":"7403",
"RT90 + RH70 height":"7404",
"OSGB 1936 / British National Grid + ODN height":"7405",
"NAD27 + NGVD29 height (ftUS)":"7406",
"NAD27 / Texas North + NGVD29 height (ftUS)":"7407",
"RD/NAP":"7408",
"ETRS89 + EVRF2000 height":"7409",
"PSHD93":"7410",
"NTF (Paris) / Lambert zone II + NGF Lallemand height":"7411",
"NTF (Paris) / Lambert zone II + NGF IGN69":"7412",
"NTF (Paris) / Lambert zone III + NGF IGN69":"7413",
"Tokyo + JSLD69 height":"7414",
"Amersfoort / RD New + NAP height":"7415",
"ETRS89 / UTM zone 32N + DVR90 height":"7416",
"ETRS89 / UTM zone 33N + DVR90 height":"7417",
"ETRS89 / Kp2000 Jutland + DVR90 height":"7418",
"ETRS89 / Kp2000 Zealand + DVR90 height":"7419",
"ETRS89 / Kp2000 Bornholm + DVR90 height":"7420",
"NTF (Paris) / Lambert zone II + NGF-IGN69 height":"7421",
"NTF (Paris) / Lambert zone III + NGF-IGN69 height":"7422",
"ETRS89 + EVRF2007 height":"7423",
"Famagusta 1960 height":"7446",
"PNG08 height":"7447",
"NAD83(2011) / WISCRS Adams and Juneau (m)":"7528",
"NAD83(2011) / WISCRS Ashland (m)":"7529",
"NAD83(2011) / WISCRS Barron (m)":"7530",
"NAD83(2011) / WISCRS Bayfield (m)":"7531",
"NAD83(2011) / WISCRS Brown (m)":"7532",
"NAD83(2011) / WISCRS Buffalo (m)":"7533",
"NAD83(2011) / WISCRS Burnett (m)":"7534",
"NAD83(2011) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (m)":"7535",
"NAD83(2011) / WISCRS Chippewa (m)":"7536",
"NAD83(2011) / WISCRS Clark (m)":"7537",
"NAD83(2011) / WISCRS Columbia (m)":"7538",
"NAD83(2011) / WISCRS Crawford (m)":"7539",
"NAD83(2011) / WISCRS Dane (m)":"7540",
"NAD83(2011) / WISCRS Dodge and Jefferson (m)":"7541",
"NAD83(2011) / WISCRS Door (m)":"7542",
"NAD83(2011) / WISCRS Douglas (m)":"7543",
"NAD83(2011) / WISCRS Dunn (m)":"7544",
"NAD83(2011) / WISCRS Eau Claire (m)":"7545",
"NAD83(2011) / WISCRS Florence (m)":"7546",
"NAD83(2011) / WISCRS Forest (m)":"7547",
"NAD83(2011) / WISCRS Grant (m)":"7548",
"NAD83(2011) / WISCRS Green and Lafayette (m)":"7549",
"NAD83(2011) / WISCRS Green Lake and Marquette (m)":"7550",
"NAD83(2011) / WISCRS Iowa (m)":"7551",
"NAD83(2011) / WISCRS Iron (m)":"7552",
"NAD83(2011) / WISCRS Jackson (m)":"7553",
"NAD83(2011) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (m)":"7554",
"NAD83(2011) / WISCRS Kewaunee, Manitowoc and Sheboygan (m)":"7555",
"NAD83(2011) / WISCRS La Crosse (m)":"7556",
"NAD83(2011) / WISCRS Langlade (m)":"7557",
"NAD83(2011) / WISCRS Lincoln (m)":"7558",
"NAD83(2011) / WISCRS Marathon (m)":"7559",
"NAD83(2011) / WISCRS Marinette (m)":"7560",
"NAD83(2011) / WISCRS Menominee (m)":"7561",
"NAD83(2011) / WISCRS Monroe (m)":"7562",
"NAD83(2011) / WISCRS Oconto (m)":"7563",
"NAD83(2011) / WISCRS Oneida (m)":"7564",
"NAD83(2011) / WISCRS Pepin and Pierce (m)":"7565",
"NAD83(2011) / WISCRS Polk (m)":"7566",
"NAD83(2011) / WISCRS Portage (m)":"7567",
"NAD83(2011) / WISCRS Price (m)":"7568",
"NAD83(2011) / WISCRS Richland (m)":"7569",
"NAD83(2011) / WISCRS Rock (m)":"7570",
"NAD83(2011) / WISCRS Rusk (m)":"7571",
"NAD83(2011) / WISCRS Sauk (m)":"7572",
"NAD83(2011) / WISCRS Sawyer (m)":"7573",
"NAD83(2011) / WISCRS Shawano (m)":"7574",
"NAD83(2011) / WISCRS St. Croix (m)":"7575",
"NAD83(2011) / WISCRS Taylor (m)":"7576",
"NAD83(2011) / WISCRS Trempealeau (m)":"7577",
"NAD83(2011) / WISCRS Vernon (m)":"7578",
"NAD83(2011) / WISCRS Vilas (m)":"7579",
"NAD83(2011) / WISCRS Walworth (m)":"7580",
"NAD83(2011) / WISCRS Washburn (m)":"7581",
"NAD83(2011) / WISCRS Washington (m)":"7582",
"NAD83(2011) / WISCRS Waukesha (m)":"7583",
"NAD83(2011) / WISCRS Waupaca (m)":"7584",
"NAD83(2011) / WISCRS Waushara (m)":"7585",
"NAD83(2011) / WISCRS Wood (m)":"7586",
"NAD83(2011) / WISCRS Adams and Juneau (ftUS)":"7587",
"NAD83(2011) / WISCRS Ashland (ftUS)":"7588",
"NAD83(2011) / WISCRS Barron (ftUS)":"7589",
"NAD83(2011) / WISCRS Bayfield (ftUS)":"7590",
"NAD83(2011) / WISCRS Brown (ftUS)":"7591",
"NAD83(2011) / WISCRS Buffalo (ftUS)":"7592",
"NAD83(2011) / WISCRS Burnett (ftUS)":"7593",
"NAD83(2011) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (ftUS)":"7594",
"NAD83(2011) / WISCRS Chippewa (ftUS)":"7595",
"NAD83(2011) / WISCRS Clark (ftUS)":"7596",
"NAD83(2011) / WISCRS Columbia (ftUS)":"7597",
"NAD83(2011) / WISCRS Crawford (ftUS)":"7598",
"NAD83(2011) / WISCRS Dane (ftUS)":"7599",
"NAD83(2011) / WISCRS Dodge and Jefferson (ftUS)":"7600",
"NAD83(2011) / WISCRS Door (ftUS)":"7601",
"NAD83(2011) / WISCRS Douglas (ftUS)":"7602",
"NAD83(2011) / WISCRS Dunn (ftUS)":"7603",
"NAD83(2011) / WISCRS Eau Claire (ftUS)":"7604",
"NAD83(2011) / WISCRS Florence (ftUS)":"7605",
"NAD83(2011) / WISCRS Forest (ftUS)":"7606",
"NAD83(2011) / WISCRS Grant (ftUS)":"7607",
"NAD83(2011) / WISCRS Green and Lafayette (ftUS)":"7608",
"NAD83(2011) / WISCRS Green Lake and Marquette (ftUS)":"7609",
"NAD83(2011) / WISCRS Iowa (ftUS)":"7610",
"NAD83(2011) / WISCRS Iron (ftUS)":"7611",
"NAD83(2011) / WISCRS Jackson (ftUS)":"7612",
"NAD83(2011) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (ftUS)":"7613",
"NAD83(2011) / WISCRS Kewaunee, Manitowoc and Sheboygan (ftUS)":"7614",
"NAD83(2011) / WISCRS La Crosse (ftUS)":"7615",
"NAD83(2011) / WISCRS Langlade (ftUS)":"7616",
"NAD83(2011) / WISCRS Lincoln (ftUS)":"7617",
"NAD83(2011) / WISCRS Marathon (ftUS)":"7618",
"NAD83(2011) / WISCRS Marinette (ftUS)":"7619",
"NAD83(2011) / WISCRS Menominee (ftUS)":"7620",
"NAD83(2011) / WISCRS Monroe (ftUS)":"7621",
"NAD83(2011) / WISCRS Oconto (ftUS)":"7622",
"NAD83(2011) / WISCRS Oneida (ftUS)":"7623",
"NAD83(2011) / WISCRS Pepin and Pierce (ftUS)":"7624",
"NAD83(2011) / WISCRS Polk (ftUS)":"7625",
"NAD83(2011) / WISCRS Portage (ftUS)":"7626",
"NAD83(2011) / WISCRS Price (ftUS)":"7627",
"NAD83(2011) / WISCRS Richland (ftUS)":"7628",
"NAD83(2011) / WISCRS Rock (ftUS)":"7629",
"NAD83(2011) / WISCRS Rusk (ftUS)":"7630",
"NAD83(2011) / WISCRS Sauk (ftUS)":"7631",
"NAD83(2011) / WISCRS Sawyer (ftUS)":"7632",
"NAD83(2011) / WISCRS Shawano (ftUS)":"7633",
"NAD83(2011) / WISCRS St. Croix (ftUS)":"7634",
"NAD83(2011) / WISCRS Taylor (ftUS)":"7635",
"NAD83(2011) / WISCRS Trempealeau (ftUS)":"7636",
"NAD83(2011) / WISCRS Vernon (ftUS)":"7637",
"NAD83(2011) / WISCRS Vilas (ftUS)":"7638",
"NAD83(2011) / WISCRS Walworth (ftUS)":"7639",
"NAD83(2011) / WISCRS Washburn (ftUS)":"7640",
"NAD83(2011) / WISCRS Washington (ftUS)":"7641",
"NAD83(2011) / WISCRS Waukesha (ftUS)":"7642",
"NAD83(2011) / WISCRS Waupaca (ftUS)":"7643",
"NAD83(2011) / WISCRS Waushara (ftUS)":"7644",
"NAD83(2011) / WISCRS Wood (ftUS)":"7645",
"Kumul 34 height":"7651",
"Kiunga height":"7652",
"WGS 84 (G730)":"7656",
"WGS 84 (G730)":"7657",
"WGS 84 (G873)":"7658",
"WGS 84 (G873)":"7659",
"WGS 84 (G1150)":"7660",
"WGS 84 (G1150)":"7661",
"WGS 84 (G1674)":"7662",
"WGS 84 (G1674)":"7663",
"WGS 84 (G1762)":"7664",
"WGS 84 (G1762)":"7665",
"PZ-90.02":"7677",
"PZ-90.02":"7678",
"PZ-90.11":"7679",
"PZ-90.11":"7680",
"GSK-2011":"7681",
"GSK-2011":"7682",
"GSK-2011":"7683",
"Kyrg-06":"7684",
"Kyrg-06":"7685",
"Kyrg-06":"7686",
"Kyrg-06 / zone 1":"7692",
"Kyrg-06 / zone 2":"7693",
"Kyrg-06 / zone 3":"7694",
"Kyrg-06 / zone 4":"7695",
"Kyrg-06 / zone 5":"7696",
"DHHN12 height":"7699",
"Latvia 2000 height":"7700",
"EPSG moving platform example":"7706",
"ODN (Offshore) height":"7707",
"WGS 84 / India NSF LCC":"7755",
"WGS 84 / Andhra Pradesh":"7756",
"WGS 84 / Arunachal Pradesh":"7757",
"WGS 84 / Assam":"7758",
"WGS 84 / Bihar":"7759",
"WGS 84 / Delhi":"7760",
"WGS 84 / Gujarat":"7761",
"WGS 84 / Haryana":"7762",
"WGS 84 / Himachal Pradesh":"7763",
"WGS 84 / Jammu and Kashmir":"7764",
"WGS 84 / Jharkhand":"7765",
"WGS 84 / Madhya Pradesh":"7766",
"WGS 84 / Maharashtra":"7767",
"WGS 84 / Manipur":"7768",
"WGS 84 / Meghalaya":"7769",
"WGS 84 / Nagaland":"7770",
"WGS 84 / India Northeast":"7771",
"WGS 84 / Orissa":"7772",
"WGS 84 / Punjab":"7773",
"WGS 84 / Rajasthan":"7774",
"WGS 84 / Uttar Pradesh":"7775",
"WGS 84 / Uttaranchal":"7776",
"WGS 84 / Andaman and Nicobar":"7777",
"WGS 84 / Chhattisgarh":"7778",
"WGS 84 / Goa":"7779",
"WGS 84 / Karnataka":"7780",
"WGS 84 / Kerala":"7781",
"WGS 84 / Lakshadweep":"7782",
"WGS 84 / Mizoram":"7783",
"WGS 84 / Sikkim":"7784",
"WGS 84 / Tamil Nadu":"7785",
"WGS 84 / Tripura":"7786",
"WGS 84 / West Bengal":"7787",
"ITRF2014":"7789",
"RDN2008 / UTM zone 32N":"7791",
"RDN2008 / UTM zone 33N":"7792",
"RDN2008 / UTM zone 34N":"7793",
"RDN2008 / Italy zone (E-N)":"7794",
"RDN2008 / Zone 12 (E-N)":"7795",
"BGS2005":"7796",
"BGS2005":"7797",
"BGS2005":"7798",
"BGS2005 / UTM zone 34N (N-E)":"7799",
"BGS2005 / UTM zone 35N (N-E)":"7800",
"BGS2005 / CCS2005":"7801",
"BGS2005 / UTM zone 34N":"7803",
"BGS2005 / UTM zone 35N":"7804",
"BGS2005 / UTM zone 36N":"7805",
"WGS 84 (Transit)":"7815",
"WGS 84 (Transit)":"7816",
"Pulkovo 1942 / CS63 zone X1":"7825",
"Pulkovo 1942 / CS63 zone X2":"7826",
"Pulkovo 1942 / CS63 zone X3":"7827",
"Pulkovo 1942 / CS63 zone X4":"7828",
"Pulkovo 1942 / CS63 zone X5":"7829",
"Pulkovo 1942 / CS63 zone X6":"7830",
"Pulkovo 1942 / CS63 zone X7":"7831",
"POM96 height":"7832",
"DHHN2016 height":"7837",
"NZVD2016 height":"7839",
"POM08 height":"7841",
"GDA2020":"7842",
"GDA2020":"7843",
"GDA2020":"7844",
"GDA2020 / GA LCC":"7845",
"GDA2020 / MGA zone 46":"7846",
"GDA2020 / MGA zone 47":"7847",
"GDA2020 / MGA zone 48":"7848",
"GDA2020 / MGA zone 49":"7849",
"GDA2020 / MGA zone 50":"7850",
"GDA2020 / MGA zone 51":"7851",
"GDA2020 / MGA zone 52":"7852",
"GDA2020 / MGA zone 53":"7853",
"GDA2020 / MGA zone 54":"7854",
"GDA2020 / MGA zone 55":"7855",
"GDA2020 / MGA zone 56":"7856",
"GDA2020 / MGA zone 57":"7857",
"GDA2020 / MGA zone 58":"7858",
"GDA2020 / MGA zone 59":"7859",
"Astro DOS 71 / SHLG71":"7877",
"Astro DOS 71 / UTM zone 30S":"7878",
"St. Helena Tritan":"7879",
"St. Helena Tritan":"7880",
"St. Helena Tritan":"7881",
"St. Helena Tritan / SHLG(Tritan)":"7882",
"St. Helena Tritan / UTM zone 30S":"7883",
"SHGD2015":"7884",
"SHGD2015":"7885",
"SHGD2015":"7886",
"SHMG2015":"7887",
"Jamestown 1971 height":"7888",
"St. Helena Tritan 2011 height":"7889",
"SHVD2015 height":"7890",
"GDA2020 / Vicgrid":"7899",
"ITRF88":"7900",
"ITRF89":"7901",
"ITRF90":"7902",
"ITRF91":"7903",
"ITRF92":"7904",
"ITRF93":"7905",
"ITRF94":"7906",
"ITRF96":"7907",
"ITRF97":"7908",
"ITRF2000":"7909",
"ITRF2005":"7910",
"ITRF2008":"7911",
"ITRF2014":"7912",
"ETRF89":"7914",
"ETRF89":"7915",
"ETRF90":"7916",
"ETRF90":"7917",
"ETRF91":"7918",
"ETRF91":"7919",
"ETRF92":"7920",
"ETRF92":"7921",
"ETRF93":"7922",
"ETRF93":"7923",
"ETRF94":"7924",
"ETRF94":"7925",
"ETRF96":"7926",
"ETRF96":"7927",
"ETRF97":"7928",
"ETRF97":"7929",
"ETRF2000":"7930",
"ETRF2000":"7931",
"Astro DOS 71 / UTM zone 30S + Jamestown 1971 height":"7954",
"St. Helena Tritan / UTM zone 30S +  Tritan 2011 height":"7955",
"SHMG2015 +  SHVD2015 height":"7956",
"Poolbeg height (m)":"7962",
"NGVD29 height (m)":"7968",
"HKPD depth":"7976",
"KOC WD height":"7979",
"NAD27 / MTM zone 10":"7991",
"Malongo 1987 / UTM zone 33S":"7992",
"GDA2020 / ALB2020":"8013",
"GDA2020 / BIO2020":"8014",
"GDA2020 / BRO2020":"8015",
"GDA2020 / BCG2020":"8016",
"GDA2020 / CARN2020":"8017",
"GDA2020 / CIG2020":"8018",
"GDA2020 / CKIG2020":"8019",
"GDA2020 / COL2020":"8020",
"GDA2020 / ESP2020":"8021",
"GDA2020 / EXM2020":"8022",
"GDA2020 / GCG2020":"8023",
"GDA2020 / GOLD2020":"8024",
"GDA2020 / JCG2020":"8025",
"GDA2020 / KALB2020":"8026",
"GDA2020 / KAR2020":"8027",
"GDA2020 / KUN2020":"8028",
"GDA2020 / LCG2020":"8029",
"GDA2020 / MRCG2020":"8030",
"GDA2020 / PCG2020":"8031",
"GDA2020 / PHG2020":"8032",
"WGS 84 / TM Zone 20N (ftUS)":"8035",
"WGS 84 / TM Zone 21N (ftUS)":"8036",
"Gusterberg (Ferro)":"8042",
"St. Stephen (Ferro)":"8043",
"Gusterberg Grid (Ferro)":"8044",
"St. Stephen Grid (Ferro)":"8045",
"MSL height (ft)":"8050",
"MSL depth (ft)":"8051",
"MSL height (ftUS)":"8052",
"MSL depth (ftUS)":"8053",
"GDA2020 / NSW Lambert":"8058",
"GDA2020 / SA Lambert":"8059",
"NAD83(2011) / PCCS zone 1 (ft)":"8065",
"NAD83(2011) / PCCS zone 2 (ft)":"8066",
"NAD83(2011) / PCCS zone 3 (ft)":"8067",
"NAD83(2011) / PCCS zone 4 (ft)":"8068",
"NAD83(CSRS)v6 / MTM Nova Scotia zone 4":"8082",
"NAD83(CSRS)v6 / MTM Nova Scotia zone 5":"8083",
"ISN2016":"8084",
"ISN2016":"8085",
"ISN2016":"8086",
"ISN2016 / Lambert 2016":"8088",
"ISH2004 height":"8089",
"NAD83(HARN) / WISCRS Florence (m)":"8090",
"NAD83(HARN) / WISCRS Florence (ftUS)":"8091",
"NAD83(HARN) / WISCRS Eau Claire (m)":"8092",
"NAD83(HARN) / WISCRS Eau Claire (ftUS)":"8093",
"NAD83(HARN) / WISCRS Wood (m)":"8095",
"NAD83(HARN) / WISCRS Wood (ftUS)":"8096",
"NAD83(HARN) / WISCRS Waushara (m)":"8097",
"NAD83(HARN) / WISCRS Waushara (ftUS)":"8098",
"NAD83(HARN) / WISCRS Waupaca (m)":"8099",
"NAD83(HARN) / WISCRS Waupaca (ftUS)":"8100",
"NAD83(HARN) / WISCRS Waukesha (m)":"8101",
"NAD83(HARN) / WISCRS Waukesha (ftUS)":"8102",
"NAD83(HARN) / WISCRS Washington (m)":"8103",
"NAD83(HARN) / WISCRS Washington (ftUS)":"8104",
"NAD83(HARN) / WISCRS Washburn (m)":"8105",
"NAD83(HARN) / WISCRS Washburn (ftUS)":"8106",
"NAD83(HARN) / WISCRS Walworth (m)":"8107",
"NAD83(HARN) / WISCRS Walworth (ftUS)":"8108",
"NAD83(HARN) / WISCRS Vilas (m)":"8109",
"NAD83(HARN) / WISCRS Vilas (ftUS)":"8110",
"NAD83(HARN) / WISCRS Vernon (m)":"8111",
"NAD83(HARN) / WISCRS Vernon (ftUS)":"8112",
"NAD83(HARN) / WISCRS Trempealeau (m)":"8113",
"NAD83(HARN) / WISCRS Trempealeau (ftUS)":"8114",
"NAD83(HARN) / WISCRS Taylor (m)":"8115",
"NAD83(HARN) / WISCRS Taylor (ftUS)":"8116",
"NAD83(HARN) / WISCRS St. Croix (m)":"8117",
"NAD83(HARN) / WISCRS St. Croix (ftUS)":"8118",
"NAD83(HARN) / WISCRS Shawano (m)":"8119",
"NAD83(HARN) / WISCRS Shawano (ftUS)":"8120",
"NAD83(HARN) / WISCRS Sawyer (m)":"8121",
"NAD83(HARN) / WISCRS Sawyer (ftUS)":"8122",
"NAD83(HARN) / WISCRS Sauk (m)":"8123",
"NAD83(HARN) / WISCRS Sauk (ftUS)":"8124",
"NAD83(HARN) / WISCRS Rusk (m)":"8125",
"NAD83(HARN) / WISCRS Rusk (ftUS)":"8126",
"NAD83(HARN) / WISCRS Rock (m)":"8127",
"NAD83(HARN) / WISCRS Rock (ftUS)":"8128",
"NAD83(HARN) / WISCRS Richland (m)":"8129",
"NAD83(HARN) / WISCRS Richland (ftUS)":"8130",
"NAD83(HARN) / WISCRS Price (m)":"8131",
"NAD83(HARN) / WISCRS Price (ftUS)":"8132",
"NAD83(HARN) / WISCRS Portage (m)":"8133",
"NAD83(HARN) / WISCRS Portage (ftUS)":"8134",
"NAD83(HARN) / WISCRS Polk (m)":"8135",
"NAD83(HARN) / WISCRS Polk (ftUS)":"8136",
"NAD83(HARN) / WISCRS Pepin and Pierce (m)":"8137",
"NAD83(HARN) / WISCRS Pepin and Pierce (ftUS)":"8138",
"NAD83(HARN) / WISCRS Oneida (m)":"8139",
"NAD83(HARN) / WISCRS Oneida (ftUS)":"8140",
"NAD83(HARN) / WISCRS Oconto (m)":"8141",
"NAD83(HARN) / WISCRS Oconto (ftUS)":"8142",
"NAD83(HARN) / WISCRS Monroe (m)":"8143",
"NAD83(HARN) / WISCRS Monroe (ftUS)":"8144",
"NAD83(HARN) / WISCRS Menominee (m)":"8145",
"NAD83(HARN) / WISCRS Menominee (ftUS)":"8146",
"NAD83(HARN) / WISCRS Marinette (m)":"8147",
"NAD83(HARN) / WISCRS Marinette (ftUS)":"8148",
"NAD83(HARN) / WISCRS Marathon (m)":"8149",
"NAD83(HARN) / WISCRS Marathon (ftUS)":"8150",
"NAD83(HARN) / WISCRS Lincoln (m)":"8151",
"NAD83(HARN) / WISCRS Lincoln (ftUS)":"8152",
"NAD83(HARN) / WISCRS Langlade (m)":"8153",
"NAD83(HARN) / WISCRS Langlade (ftUS)":"8154",
"NAD83(HARN) / WISCRS La Crosse (m)":"8155",
"NAD83(HARN) / WISCRS La Crosse (ftUS)":"8156",
"NAD83(HARN) / WISCRS Kewaunee, Manitowoc and Sheboygan (m)":"8157",
"NAD83(HARN) / WISCRS Kewaunee, Manitowoc and Sheboygan (ftUS)":"8158",
"NAD83(HARN) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (m)":"8159",
"NAD83(HARN) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (ftUS)":"8160",
"NAD83(HARN) / WISCRS Jackson (m)":"8161",
"NAD83(HARN) / WISCRS Jackson (ftUS)":"8162",
"NAD83(HARN) / WISCRS Iron (m)":"8163",
"NAD83(HARN) / WISCRS Iron (ftUS)":"8164",
"NAD83(HARN) / WISCRS Iowa (m)":"8165",
"NAD83(HARN) / WISCRS Iowa (ftUS)":"8166",
"NAD83(HARN) / WISCRS Green Lake and Marquette (m)":"8167",
"NAD83(HARN) / WISCRS Green Lake and Marquette (ftUS)":"8168",
"NAD83(HARN) / WISCRS Green and Lafayette (m)":"8169",
"NAD83(HARN) / WISCRS Green and Lafayette (ftUS)":"8170",
"NAD83(HARN) / WISCRS Grant (m)":"8171",
"NAD83(HARN) / WISCRS Grant (ftUS)":"8172",
"NAD83(HARN) / WISCRS Forest (m)":"8173",
"NAD83(HARN) / WISCRS Forest (ftUS)":"8177",
"NAD83(HARN) / WISCRS Dunn (m)":"8179",
"NAD83(HARN) / WISCRS Dunn (ftUS)":"8180",
"NAD83(HARN) / WISCRS Douglas (m)":"8181",
"NAD83(HARN) / WISCRS Douglas (ftUS)":"8182",
"NAD83(HARN) / WISCRS Door (m)":"8184",
"NAD83(HARN) / WISCRS Door (ftUS)":"8185",
"NAD83(HARN) / WISCRS Dodge and Jefferson (m)":"8187",
"NAD83(HARN) / WISCRS Dodge and Jefferson (ftUS)":"8189",
"NAD83(HARN) / WISCRS Dane (m)":"8191",
"NAD83(HARN) / WISCRS Dane (ftUS)":"8193",
"NAD83(HARN) / WISCRS Crawford (m)":"8196",
"NAD83(HARN) / WISCRS Crawford (ftUS)":"8197",
"NAD83(HARN) / WISCRS Columbia (m)":"8198",
"NAD83(HARN) / WISCRS Columbia (ftUS)":"8200",
"NAD83(HARN) / WISCRS Clark (m)":"8201",
"NAD83(HARN) / WISCRS Clark (ftUS)":"8202",
"NAD83(HARN) / WISCRS Chippewa (m)":"8203",
"NAD83(HARN) / WISCRS Chippewa (ftUS)":"8204",
"NAD83(HARN) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (m)":"8205",
"NAD83(HARN) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (ftUS)":"8206",
"NAD83(HARN) / WISCRS Burnett (m)":"8207",
"NAD83(HARN) / WISCRS Burnett (ftUS)":"8208",
"NAD83(HARN) / WISCRS Buffalo (m)":"8209",
"NAD83(HARN) / WISCRS Buffalo (ftUS)":"8210",
"NAD83(HARN) / WISCRS Brown (m)":"8212",
"NAD83(HARN) / WISCRS Brown (ftUS)":"8213",
"NAD83(HARN) / WISCRS Bayfield (m)":"8214",
"NAD83(HARN) / WISCRS Bayfield (ftUS)":"8216",
"NAD83(HARN) / WISCRS Barron (m)":"8218",
"NAD83(HARN) / WISCRS Barron (ftUS)":"8220",
"NAD83(HARN) / WISCRS Ashland (m)":"8222",
"NAD83(HARN) / WISCRS Ashland (ftUS)":"8224",
"NAD83(HARN) / WISCRS Adams and Juneau (m)":"8225",
"NAD83(HARN) / WISCRS Adams and Juneau (ftUS)":"8226",
"IGS14":"8227",
"NAVD88 height (ft)":"8228",
"NAD83(CSRS96)":"8230",
"NAD83(CSRS96)":"8231",
"NAD83(CSRS96)":"8232",
"NAD83(CSRS)v2":"8233",
"NAD83(CSRS)v2":"8235",
"NAD83(CSRS)v2":"8237",
"NAD83(CSRS)v3":"8238",
"NAD83(CSRS)v3":"8239",
"NAD83(CSRS)v3":"8240",
"NAD83(CSRS)v4":"8242",
"NAD83(CSRS)v4":"8244",
"NAD83(CSRS)v4":"8246",
"NAD83(CSRS)v5":"8247",
"NAD83(CSRS)v5":"8248",
"NAD83(CSRS)v5":"8249",
"NAD83(CSRS)v6":"8250",
"NAD83(CSRS)v6":"8251",
"NAD83(CSRS)v6":"8252",
"NAD83(CSRS)v7":"8253",
"NAD83(CSRS)v7":"8254",
"NAD83(CSRS)v7":"8255",
"GVR2000 height":"8266",
"GVR2016 height":"8267",
"NAD83(2011) / Oregon Burns-Harper zone (m)":"8311",
"NAD83(2011) / Oregon Burns-Harper zone (ft)":"8312",
"NAD83(2011) / Oregon Canyon City-Burns zone (m)":"8313",
"NAD83(2011) / Oregon Canyon City-Burns zone (ft)":"8314",
"NAD83(2011) / Oregon Coast Range North zone (m)":"8315",
"NAD83(2011) / Oregon Coast Range North zone (ft)":"8316",
"NAD83(2011) / Oregon Dayville-Prairie City zone (m)":"8317",
"NAD83(2011) / Oregon Dayville-Prairie City zone (ft)":"8318",
"NAD83(2011) / Oregon Denio-Burns zone (m)":"8319",
"NAD83(2011) / Oregon Denio-Burns zone (ft)":"8320",
"NAD83(2011) / Oregon Halfway zone (m)":"8321",
"NAD83(2011) / Oregon Halfway zone (ft)":"8322",
"NAD83(2011) / Oregon Medford-Diamond Lake zone (m)":"8323",
"NAD83(2011) / Oregon Medford-Diamond Lake zone (ft)":"8324",
"NAD83(2011) / Oregon Mitchell zone (m)":"8325",
"NAD83(2011) / Oregon Mitchell zone (ft)":"8326",
"NAD83(2011) / Oregon North Central zone (m)":"8327",
"NAD83(2011) / Oregon North Central zone (ft)":"8328",
"NAD83(2011) / Oregon Ochoco Summit zone (m)":"8329",
"NAD83(2011) / Oregon Ochoco Summit zone (ft)":"8330",
"NAD83(2011) / Oregon Owyhee zone (m)":"8331",
"NAD83(2011) / Oregon Owyhee zone (ft)":"8332",
"NAD83(2011) / Oregon Pilot Rock-Ukiah zone (m)":"8333",
"NAD83(2011) / Oregon Pilot Rock-Ukiah zone (ft)":"8334",
"NAD83(2011) / Oregon Prairie City-Brogan zone (m)":"8335",
"NAD83(2011) / Oregon Prairie City-Brogan zone (ft)":"8336",
"NAD83(2011) / Oregon Riley-Lakeview zone (m)":"8337",
"NAD83(2011) / Oregon Riley-Lakeview zone (ft)":"8338",
"NAD83(2011) / Oregon Siskiyou Pass zone (m)":"8339",
"NAD83(2011) / Oregon Siskiyou Pass zone (ft)":"8340",
"NAD83(2011) / Oregon Ukiah-Fox zone (m)":"8341",
"NAD83(2011) / Oregon Ukiah-Fox zone (ft)":"8342",
"NAD83(2011) / Oregon Wallowa zone (m)":"8343",
"NAD83(2011) / Oregon Wallowa zone (ft)":"8344",
"NAD83(2011) / Oregon Warner Highway zone (m)":"8345",
"NAD83(2011) / Oregon Warner Highway zone (ft)":"8346",
"NAD83(2011) / Oregon Willamette Pass zone (m)":"8347",
"NAD83(2011) / Oregon Willamette Pass zone (ft)":"8348",
"GR96 + GVR2000 height":"8349",
"GR96 + GVR2016 height":"8350",
"S-JTSK [JTSK03]":"8351",
"S-JTSK [JTSK03] / Krovak":"8352",
"S-JTSK [JTSK03] / Krovak East North":"8353",
"Baltic 1957 height":"8357",
"Baltic 1957 depth":"8358",
"ETRS89 + Baltic 1957 height":"8360",
"ETRS89 / Belgian Lambert 2008 + Ostend height":"8370",
"EPSG example wellbore local horizontal CRS - true north":"8377",
"EPSG example wellbore local vertical CRS":"8378",
"NAD83 / NCRS Las Vegas (m)":"8379",
"NAD83 / NCRS Las Vegas (ftUS)":"8380",
"NAD83 / NCRS Las Vegas high (m)":"8381",
"NAD83 / NCRS Las Vegas high (ftUS)":"8382",
"NAD83(2011) / NCRS Las Vegas (m)":"8383",
"NAD83(2011) / NCRS Las Vegas (ftUS)":"8384",
"NAD83(2011) / NCRS Las Vegas high (m)":"8385",
"NAD83(2011) / NCRS Las Vegas high (ftUS)":"8387",
"GDA94 / WEIPA94":"8391",
"ETRS89 / Gauss-Kruger CM 9E":"8395",
"ETRF2005":"8397",
"ETRF2005":"8399",
"ETRF2014":"8401",
"ETRF2014":"8403",
"Hong Kong Geodetic CS":"8425",
"Hong Kong Geodetic CS":"8426",
"Hong Kong Geodetic CS":"8427",
"Macao 1920":"8428",
"Macao 2008":"8429",
"Macao 2008":"8430",
"Macao 2008":"8431",
"Macao 1920 / Macao Grid":"8433",
"Macao height":"8434",
"Tananarive / Laborde Grid":"8441",
"NAD83(FBN)":"8449",
"RGTAAF07 / UTM zone 53S":"8455",
"RGTAAF07 / UTM zone 54S":"8456",
"NAD83(2011) / KS RCS zone 1":"8518",
"NAD83(2011) / KS RCS zone 2":"8519",
"NAD83(2011) / KS RCS zone 3":"8520",
"NAD83(2011) / KS RCS zone 4":"8521",
"NAD83(2011) / KS RCS zone 5":"8522",
"NAD83(2011) / KS RCS zone 6":"8523",
"NAD83(2011) / KS RCS zone 7":"8524",
"NAD83(2011) / KS RCS zone 8":"8525",
"NAD83(2011) / KS RCS zone 9":"8526",
"NAD83(2011) / KS RCS zone 10":"8527",
"NAD83(2011) / KS RCS zone 11":"8528",
"NAD83(2011) / KS RCS zone 12":"8529",
"NAD83(2011) / KS RCS zone 13":"8531",
"NAD83(2011) / KS RCS zone 14":"8533",
"NAD83(2011) / KS RCS zone 15":"8534",
"NAD83(2011) / KS RCS zone 16":"8535",
"NAD83(2011) / KS RCS zone 17":"8536",
"NAD83(2011) / KS RCS zone 18":"8538",
"NAD83(2011) / KS RCS zone 19":"8539",
"NAD83(2011) / KS RCS zone 20":"8540",
"NAD83(FBN)":"8541",
"NAD83(FBN)":"8542",
"NAD83(HARN Corrected)":"8543",
"NAD83(HARN Corrected)":"8544",
"NAD83(HARN Corrected)":"8545",
"N43 height":"8675",
"MGI 1901 / Balkans zone 5":"8677",
"MGI 1901 / Balkans zone 6":"8678",
"MGI 1901 / Balkans zone 8":"8679",
"SRB_ETRS89 / UTM zone 34N":"8682",
"SRB_ETRS89":"8683",
"SRB_ETRS89":"8684",
"SRB_ETRS89":"8685",
"MGI 1901 / Slovenia Grid":"8686",
"Slovenia 1996 / UTM zone 33N":"8687",
"SVS2010 height":"8690",
"SRB_VRS12 height":"8691",
"NAD83(MA11) / UTM zone 54N":"8692",
"NAD83(MA11) / UTM zone 55N":"8693",
"NAD83 / Arizona East (ft) + NAVD88 height (ft)":"8700",
"NAD83 / Arizona Central (ft) + NAVD88 height (ft)":"8701",
"NAD83 / Arizona West (ft) + NAVD88 height (ft)":"8702",
"NAD83 / Michigan North (ft) + NAVD88 height (ft)":"8703",
"NAD83 / Michigan Central (ft) + NAVD88 height (ft)":"8704",
"NAD83 / Michigan South (ft) + NAVD88 height (ft)":"8705",
"NAD83 / Montana (ft) + NAVD88 height (ft)":"8706",
"NAD83 / North Dakota North (ft) + NAVD88 height (ft)":"8707",
"NAD83 / North Dakota South (ft) + NAVD88 height (ft)":"8708",
"NAD83 / Oregon North (ft) + NAVD88 height (ft)":"8709",
"NAD83 / Oregon South (ft) + NAVD88 height (ft)":"8710",
"NAD83 / South Carolina (ft) + NAVD88 height (ft)":"8711",
"NAD83 / Arkansas North (ftUS) + NAVD88 height (ftUS)":"8712",
"NAD83 / Arkansas South (ftUS) + NAVD88 height (ftUS)":"8713",
"NAD83 / California zone 1 (ftUS) + NAVD88 height (ftUS)":"8714",
"NAD83 / California zone 2 (ftUS) + NAVD88 height (ftUS)":"8715",
"NAD83 / California zone 3 (ftUS) + NAVD88 height (ftUS)":"8716",
"NAD83 / California zone 4 (ftUS) + NAVD88 height (ftUS)":"8717",
"NAD83 / California zone 5 (ftUS) + NAVD88 height (ftUS)":"8718",
"NAD83 / California zone 6 (ftUS) + NAVD88 height (ftUS)":"8719",
"NAD83 / Colorado North (ftUS) + NAVD88 height (ftUS)":"8720",
"NAD83 / Colorado Central (ftUS) + NAVD88 height (ftUS)":"8721",
"NAD83 / Colorado South (ftUS) + NAVD88 height (ftUS)":"8722",
"NAD83 / Connecticut (ftUS) + NAVD88 height (ftUS)":"8723",
"NAD83 / Delaware (ftUS) + NAVD88 height (ftUS)":"8724",
"NAD83 / Florida North (ftUS) + NAVD88 height (ftUS)":"8725",
"NAD83 / Florida East (ftUS) + NAVD88 height (ftUS)":"8726",
"NAD83 / Florida West (ftUS) + NAVD88 height (ftUS)":"8727",
"NAD83 / Georgia East (ftUS) + NAVD88 height (ftUS)":"8728",
"NAD83 / Georgia West (ftUS) + NAVD88 height (ftUS)":"8729",
"NAD83 / Idaho East (ftUS) + NAVD88 height (ftUS)":"8730",
"NAD83 / Idaho Central (ftUS) + NAVD88 height (ftUS)":"8731",
"NAD83 / Idaho West (ftUS) + NAVD88 height (ftUS)":"8732",
"NAD83 / Illinois East (ftUS) + NAVD88 height (ftUS)":"8733",
"NAD83 / Illinois West (ftUS) + NAVD88 height (ftUS)":"8734",
"NAD83 / Indiana East (ftUS) + NAVD88 height (ftUS)":"8735",
"NAD83 / Indiana West (ftUS) + NAVD88 height (ftUS)":"8736",
"NAD83 / Iowa North (ftUS) + NAVD88 height (ftUS)":"8737",
"NAD83 / Iowa South (ftUS) + NAVD88 height (ftUS)":"8738",
"NAD83 / Kansas North (ftUS) + NAVD88 height (ftUS)":"8739",
"NAD83 / Kansas South (ftUS) + NAVD88 height (ftUS)":"8740",
"NAD83 / Kentucky North (ftUS) + NAVD88 height (ftUS)":"8741",
"NAD83 / Kentucky South (ftUS) + NAVD88 height (ftUS)":"8742",
"NAD83 / Louisiana North (ftUS) + NAVD88 height (ftUS)":"8743",
"NAD83 / Louisiana South (ftUS) + NAVD88 height (ftUS)":"8744",
"NAD83 / Maine East (ftUS) + NAVD88 height (ftUS)":"8745",
"NAD83 / Maine West (ftUS) + NAVD88 height (ftUS)":"8746",
"NAD83 / Maryland (ftUS) + NAVD88 height (ftUS)":"8747",
"NAD83 / Massachusetts Mainland (ftUS) + NAVD88 height (ftUS)":"8748",
"NAD83 / Massachusetts Island (ftUS) + NAVD88 height (ftUS)":"8749",
"NAD83 / Minnesota North (ftUS) + NAVD88 height (ftUS)":"8750",
"NAD83 / Minnesota Central (ftUS) + NAVD88 height (ftUS)":"8751",
"NAD83 / Minnesota South (ftUS) + NAVD88 height (ftUS)":"8752",
"NAD83 / Mississippi East (ftUS) + NAVD88 height (ftUS)":"8753",
"NAD83 / Mississippi West (ftUS) + NAVD88 height (ftUS)":"8754",
"NAD83 / Nebraska (ftUS) + NAVD88 height (ftUS)":"8755",
"NAD83 / Nevada East (ftUS) + NAVD88 height (ftUS)":"8756",
"NAD83 / Nevada Central (ftUS) + NAVD88 height (ftUS)":"8757",
"NAD83 / Nevada West (ftUS) + NAVD88 height (ftUS)":"8758",
"NAD83 / New Hampshire (ftUS) + NAVD88 height (ftUS)":"8759",
"NAD83 / New Jersey (ftUS) + NAVD88 height (ftUS)":"8760",
"NAD83 / New Mexico East (ftUS) + NAVD88 height (ftUS)":"8761",
"NAD83 / New Mexico Central (ftUS) + NAVD88 height (ftUS)":"8762",
"NAD83 / New Mexico West (ftUS) + NAVD88 height (ftUS)":"8763",
"NAD83 / New York East (ftUS) + NAVD88 height (ftUS)":"8764",
"NAD83 / New York Central (ftUS) + NAVD88 height (ftUS)":"8765",
"NAD83 / New York West (ftUS) + NAVD88 height (ftUS)":"8766",
"NAD83 / New York Long Island (ftUS) + NAVD88 height (ftUS)":"8767",
"NAD83 / North Carolina (ftUS) + NAVD88 height (ftUS)":"8768",
"NAD83 / Ohio North (ftUS) + NAVD88 height (ftUS)":"8769",
"NAD83 / Ohio South (ftUS) + NAVD88 height (ftUS)":"8770",
"NAD83 / Oklahoma North (ftUS) + NAVD88 height (ftUS)":"8771",
"NAD83 / Oklahoma South (ftUS) + NAVD88 height (ftUS)":"8772",
"NAD83 / Pennsylvania North (ftUS) + NAVD88 height (ftUS)":"8773",
"NAD83 / Pennsylvania South (ftUS) + NAVD88 height (ftUS)":"8774",
"NAD83 / Rhode Island (ftUS) + NAVD88 height (ftUS)":"8775",
"NAD83 / South Dakota North (ftUS) + NAVD88 height (ftUS)":"8776",
"NAD83 / South Dakota South (ftUS) + NAVD88 height (ftUS)":"8777",
"NAD83 / Tennessee (ftUS) + NAVD88 height (ftUS)":"8778",
"NAD83 / Texas North (ftUS) + NAVD88 height (ftUS)":"8779",
"NAD83 / Texas North Central (ftUS) + NAVD88 height (ftUS)":"8780",
"NAD83 / Texas Central (ftUS) + NAVD88 height (ftUS)":"8781",
"NAD83 / Texas South Central (ftUS) + NAVD88 height (ftUS)":"8782",
"NAD83 / Texas South (ftUS) + NAVD88 height (ftUS)":"8783",
"NAD83 / Utah North (ftUS) + NAVD88 height (ftUS)":"8784",
"NAD83 / Utah Central (ftUS) + NAVD88 height (ftUS)":"8785",
"NAD83 / Utah South (ftUS) + NAVD88 height (ftUS)":"8786",
"NAD83 / Vermont (ftUS) + NAVD88 height (ftUS)":"8787",
"NAD83 / Virginia North (ftUS) + NAVD88 height (ftUS)":"8788",
"NAD83 / Virginia South (ftUS) + NAVD88 height (ftUS)":"8789",
"NAD83 / Washington North (ftUS) + NAVD88 height (ftUS)":"8790",
"NAD83 / Washington South (ftUS) + NAVD88 height (ftUS)":"8791",
"NAD83 / West Virginia North (ftUS) + NAVD88 height (ftUS)":"8792",
"NAD83 / West Virginia South (ftUS) + NAVD88 height (ftUS)":"8793",
"NAD83 / Wisconsin North (ftUS) + NAVD88 height (ftUS)":"8794",
"NAD83 / Wisconsin Central (ftUS) + NAVD88 height (ftUS)":"8795",
"NAD83 / Wisconsin South (ftUS) + NAVD88 height (ftUS)":"8796",
"NAD83 / Wyoming East (ftUS) + NAVD88 height (ftUS)":"8797",
"NAD83 / Wyoming East Central (ftUS) + NAVD88 height (ftUS)":"8798",
"NAD83 / Wyoming West Central (ftUS) + NAVD88 height (ftUS)":"8799",
"NAD83 / Wyoming West (ftUS) + NAVD88 height (ftUS)":"8800",
"NAD83 / Alabama East + NAVD88 height":"8801",
"NAD83 / Alabama West + NAVD88 height":"8802",
"NAD83 / Alaska zone 1 + NAVD88 height":"8803",
"NAD83 / Alaska zone 2 + NAVD88 height":"8804",
"NAD83 / Alaska zone 3 + NAVD88 height":"8805",
"NAD83 / Alaska zone 4 + NAVD88 height":"8806",
"NAD83 / Alaska zone 5 + NAVD88 height":"8807",
"NAD83 / Alaska zone 6 + NAVD88 height":"8808",
"NAD83 / Alaska zone 7 + NAVD88 height":"8809",
"NAD83 / Alaska zone 8 + NAVD88 height":"8810",
"NAD83 / Alaska zone 9 + NAVD88 height":"8811",
"NAD83 / Alaska zone 10 + NAVD88 height":"8812",
"NAD83 / Missouri East + NAVD88 height":"8813",
"NAD83 / Missouri Central + NAVD88 height":"8814",
"NAD83 / Missouri West + NAVD88 height":"8815",
"MTRF-2000":"8816",
"MTRF-2000":"8817",
"MTRF-2000":"8818",
"EPSG example wellbore local cubic CRS - true north":"8820",
"EPSG example wellbore local cubic CRS - grid north (ft)":"8821",
"NAD83 / Idaho Transverse Mercator":"8826",
"MTRF-2000 / UTM zone 36N":"8836",
"MTRF-2000 / UTM zone 37N":"8837",
"MTRF-2000 / UTM zone 38N":"8838",
"MTRF-2000 / UTM zone 39N":"8839",
"MTRF-2000 / UTM zone 40N":"8840",
"MVGC height":"8841",
"WGS 84 / Equal Earth Greenwich":"8857",
"WGS 84 / Equal Earth Americas":"8858",
"WGS 84 / Equal Earth Asia-Pacific":"8859",
"NAD83(FBN)":"8860",
"WGS 84 (Transit)":"8888",
"EPSG example wellbore local horizontal CRS - grid north (ft)":"8896",
"EPSG example wellbore local vertical CRS (ft)":"8897",
"RGWF96":"8898",
"RGWF96":"8899",
"RGWF96":"8900",
"RGWF96 (lon-lat)":"8901",
"RGWF96 (lon-lat)":"8902",
"RGWF96 / UTM zone 1S":"8903",
"TWVD 2001 height":"8904",
"CR-SIRGAS":"8905",
"CR-SIRGAS":"8906",
"CR-SIRGAS":"8907",
"CR-SIRGAS / CRTM05":"8908",
"CR-SIRGAS / UTM zone 16N":"8909",
"CR-SIRGAS / UTM zone 17N":"8910",
"DACR52 height":"8911",
"CR-SIRGAS / CRTM05 + DACR52 height":"8912",
"SIRGAS-CON DGF00P01":"8915",
"SIRGAS-CON DGF00P01":"8916",
"SIRGAS-CON DGF01P01":"8917",
"SIRGAS-CON DGF01P01":"8918",
"SIRGAS-CON DGF01P02":"8919",
"SIRGAS-CON DGF01P02":"8920",
"SIRGAS-CON DGF02P01":"8921",
"SIRGAS-CON DGF02P01":"8922",
"SIRGAS-CON DGF04P01":"8923",
"SIRGAS-CON DGF04P01":"8924",
"SIRGAS-CON DGF05P01":"8925",
"SIRGAS-CON DGF05P01":"8926",
"SIRGAS-CON DGF06P01":"8927",
"SIRGAS-CON DGF06P01":"8928",
"SIRGAS-CON DGF07P01":"8929",
"SIRGAS-CON DGF07P01":"8930",
"SIRGAS-CON DGF08P01":"8931",
"SIRGAS-CON DGF08P01":"8932",
"SIRGAS-CON SIR09P01":"8933",
"SIRGAS-CON SIR09P01":"8934",
"SIRGAS-CON SIR10P01":"8935",
"SIRGAS-CON SIR10P01":"8936",
"SIRGAS-CON SIR11P01":"8937",
"SIRGAS-CON SIR11P01":"8938",
"SIRGAS-CON SIR13P01":"8939",
"SIRGAS-CON SIR13P01":"8940",
"SIRGAS-CON SIR14P01":"8941",
"SIRGAS-CON SIR14P01":"8942",
"SIRGAS-CON SIR15P01":"8943",
"SIRGAS-CON SIR15P01":"8944",
"SIRGAS-CON SIR17P01":"8945",
"SIRGAS-CON SIR17P01":"8946",
"SIRGAS-CON DGF00P01":"8972",
"SIRGAS-CON DGF01P01":"8973",
"SIRGAS-CON DGF01P02":"8974",
"SIRGAS-CON DGF02P01":"8975",
"SIRGAS-CON DGF04P01":"8976",
"SIRGAS-CON DGF05P01":"8977",
"SIRGAS-CON DGF06P01":"8978",
"SIRGAS-CON DGF07P01":"8979",
"SIRGAS-CON DGF08P01":"8980",
"SIRGAS-CON SIR09P01":"8981",
"SIRGAS-CON SIR10P01":"8982",
"SIRGAS-CON SIR11P01":"8983",
"SIRGAS-CON SIR13P01":"8984",
"SIRGAS-CON SIR14P01":"8985",
"SIRGAS-CON SIR15P01":"8986",
"SIRGAS-CON SIR17P01":"8987",
"ITRF88":"8988",
"ITRF89":"8989",
"ITRF90":"8990",
"ITRF91":"8991",
"ITRF92":"8992",
"ITRF93":"8993",
"ITRF94":"8994",
"ITRF96":"8995",
"ITRF97":"8996",
"ITRF2000":"8997",
"ITRF2005":"8998",
"ITRF2008":"8999",
"ITRF2014":"9000",
"IGS97":"9001",
"IGS97":"9002",
"IGS97":"9003",
"IGS00":"9004",
"IGS00":"9005",
"IGS00":"9006",
"IGb00":"9007",
"IGb00":"9008",
"IGb00":"9009",
"IGS05":"9010",
"IGS05":"9011",
"IGS05":"9012",
"IGS08":"9013",
"IGS08":"9014",
"IGb08":"9015",
"IGb08":"9016",
"IGb08":"9017",
"IGS14":"9018",
"IGS14":"9019",
"ISN2016 / LAEA Europe":"9039",
"ISN2016 / LCC Europe":"9040",
"WGS 84 (G730)":"9053",
"WGS 84 (G873)":"9054",
"WGS 84 (G1150)":"9055",
"WGS 84 (G1674)":"9056",
"WGS 84 (G1762)":"9057",
"ETRF89":"9059",
"ETRF90":"9060",
"ETRF91":"9061",
"ETRF92":"9062",
"ETRF93":"9063",
"ETRF94":"9064",
"ETRF96":"9065",
"ETRF97":"9066",
"ETRF2000":"9067",
"ETRF2005":"9068",
"ETRF2014":"9069",
"IGN 2008 LD height":"9130",
"KOSOVAREF01":"9138",
"KOSOVAREF01":"9139",
"KOSOVAREF01":"9140",
"KOSOVAREF01 / Balkans zone 7":"9141",
"Pulkovo 1995 / Gauss-Kruger zone 4":"20004",
"Pulkovo 1995 / Gauss-Kruger zone 5":"20005",
"Pulkovo 1995 / Gauss-Kruger zone 6":"20006",
"Pulkovo 1995 / Gauss-Kruger zone 7":"20007",
"Pulkovo 1995 / Gauss-Kruger zone 8":"20008",
"Pulkovo 1995 / Gauss-Kruger zone 9":"20009",
"Pulkovo 1995 / Gauss-Kruger zone 10":"20010",
"Pulkovo 1995 / Gauss-Kruger zone 11":"20011",
"Pulkovo 1995 / Gauss-Kruger zone 12":"20012",
"Pulkovo 1995 / Gauss-Kruger zone 13":"20013",
"Pulkovo 1995 / Gauss-Kruger zone 14":"20014",
"Pulkovo 1995 / Gauss-Kruger zone 15":"20015",
"Pulkovo 1995 / Gauss-Kruger zone 16":"20016",
"Pulkovo 1995 / Gauss-Kruger zone 17":"20017",
"Pulkovo 1995 / Gauss-Kruger zone 18":"20018",
"Pulkovo 1995 / Gauss-Kruger zone 19":"20019",
"Pulkovo 1995 / Gauss-Kruger zone 20":"20020",
"Pulkovo 1995 / Gauss-Kruger zone 21":"20021",
"Pulkovo 1995 / Gauss-Kruger zone 22":"20022",
"Pulkovo 1995 / Gauss-Kruger zone 23":"20023",
"Pulkovo 1995 / Gauss-Kruger zone 24":"20024",
"Pulkovo 1995 / Gauss-Kruger zone 25":"20025",
"Pulkovo 1995 / Gauss-Kruger zone 26":"20026",
"Pulkovo 1995 / Gauss-Kruger zone 27":"20027",
"Pulkovo 1995 / Gauss-Kruger zone 28":"20028",
"Pulkovo 1995 / Gauss-Kruger zone 29":"20029",
"Pulkovo 1995 / Gauss-Kruger zone 30":"20030",
"Pulkovo 1995 / Gauss-Kruger zone 31":"20031",
"Pulkovo 1995 / Gauss-Kruger zone 32":"20032",
"Pulkovo 1995 / Gauss-Kruger 4N":"20064",
"Pulkovo 1995 / Gauss-Kruger 5N":"20065",
"Pulkovo 1995 / Gauss-Kruger 6N":"20066",
"Pulkovo 1995 / Gauss-Kruger 7N":"20067",
"Pulkovo 1995 / Gauss-Kruger 8N":"20068",
"Pulkovo 1995 / Gauss-Kruger 9N":"20069",
"Pulkovo 1995 / Gauss-Kruger 10N":"20070",
"Pulkovo 1995 / Gauss-Kruger 11N":"20071",
"Pulkovo 1995 / Gauss-Kruger 12N":"20072",
"Pulkovo 1995 / Gauss-Kruger 13N":"20073",
"Pulkovo 1995 / Gauss-Kruger 14N":"20074",
"Pulkovo 1995 / Gauss-Kruger 15N":"20075",
"Pulkovo 1995 / Gauss-Kruger 16N":"20076",
"Pulkovo 1995 / Gauss-Kruger 17N":"20077",
"Pulkovo 1995 / Gauss-Kruger 18N":"20078",
"Pulkovo 1995 / Gauss-Kruger 19N":"20079",
"Pulkovo 1995 / Gauss-Kruger 20N":"20080",
"Pulkovo 1995 / Gauss-Kruger 21N":"20081",
"Pulkovo 1995 / Gauss-Kruger 22N":"20082",
"Pulkovo 1995 / Gauss-Kruger 23N":"20083",
"Pulkovo 1995 / Gauss-Kruger 24N":"20084",
"Pulkovo 1995 / Gauss-Kruger 25N":"20085",
"Pulkovo 1995 / Gauss-Kruger 26N":"20086",
"Pulkovo 1995 / Gauss-Kruger 27N":"20087",
"Pulkovo 1995 / Gauss-Kruger 28N":"20088",
"Pulkovo 1995 / Gauss-Kruger 29N":"20089",
"Pulkovo 1995 / Gauss-Kruger 30N":"20090",
"Pulkovo 1995 / Gauss-Kruger 31N":"20091",
"Pulkovo 1995 / Gauss-Kruger 32N":"20092",
"Adindan / UTM zone 35N":"20135",
"Adindan / UTM zone 36N":"20136",
"Adindan / UTM zone 37N":"20137",
"Adindan / UTM zone 38N":"20138",
"AGD66 / AMG zone 48":"20248",
"AGD66 / AMG zone 49":"20249",
"AGD66 / AMG zone 50":"20250",
"AGD66 / AMG zone 51":"20251",
"AGD66 / AMG zone 52":"20252",
"AGD66 / AMG zone 53":"20253",
"AGD66 / AMG zone 54":"20254",
"AGD66 / AMG zone 55":"20255",
"AGD66 / AMG zone 56":"20256",
"AGD66 / AMG zone 57":"20257",
"AGD66 / AMG zone 58":"20258",
"AGD84 / AMG zone 48":"20348",
"AGD84 / AMG zone 49":"20349",
"AGD84 / AMG zone 50":"20350",
"AGD84 / AMG zone 51":"20351",
"AGD84 / AMG zone 52":"20352",
"AGD84 / AMG zone 53":"20353",
"AGD84 / AMG zone 54":"20354",
"AGD84 / AMG zone 55":"20355",
"AGD84 / AMG zone 56":"20356",
"AGD84 / AMG zone 57":"20357",
"AGD84 / AMG zone 58":"20358",
"Ain el Abd / UTM zone 36N":"20436",
"Ain el Abd / UTM zone 37N":"20437",
"Ain el Abd / UTM zone 38N":"20438",
"Ain el Abd / UTM zone 39N":"20439",
"Ain el Abd / UTM zone 40N":"20440",
"Ain el Abd / Bahrain Grid":"20499",
"Afgooye / UTM zone 38N":"20538",
"Afgooye / UTM zone 39N":"20539",
"Lisbon (Lisbon) / Portuguese National Grid":"20790",
"Lisbon (Lisbon) / Portuguese Grid":"20791",
"Aratu / UTM zone 22S":"20822",
"Aratu / UTM zone 23S":"20823",
"Aratu / UTM zone 24S":"20824",
"Arc 1950 / UTM zone 34S":"20934",
"Arc 1950 / UTM zone 35S":"20935",
"Arc 1950 / UTM zone 36S":"20936",
"Arc 1960 / UTM zone 35S":"21035",
"Arc 1960 / UTM zone 36S":"21036",
"Arc 1960 / UTM zone 37S":"21037",
"Arc 1960 / UTM zone 35N":"21095",
"Arc 1960 / UTM zone 36N":"21096",
"Arc 1960 / UTM zone 37N":"21097",
"Batavia (Jakarta) / NEIEZ":"21100",
"Batavia / UTM zone 48S":"21148",
"Batavia / UTM zone 49S":"21149",
"Batavia / UTM zone 50S":"21150",
"Barbados 1938 / British West Indies Grid":"21291",
"Barbados 1938 / Barbados National Grid":"21292",
"Beijing 1954 / Gauss-Kruger zone 13":"21413",
"Beijing 1954 / Gauss-Kruger zone 14":"21414",
"Beijing 1954 / Gauss-Kruger zone 15":"21415",
"Beijing 1954 / Gauss-Kruger zone 16":"21416",
"Beijing 1954 / Gauss-Kruger zone 17":"21417",
"Beijing 1954 / Gauss-Kruger zone 18":"21418",
"Beijing 1954 / Gauss-Kruger zone 19":"21419",
"Beijing 1954 / Gauss-Kruger zone 20":"21420",
"Beijing 1954 / Gauss-Kruger zone 21":"21421",
"Beijing 1954 / Gauss-Kruger zone 22":"21422",
"Beijing 1954 / Gauss-Kruger zone 23":"21423",
"Beijing 1954 / Gauss-Kruger CM 75E":"21453",
"Beijing 1954 / Gauss-Kruger CM 81E":"21454",
"Beijing 1954 / Gauss-Kruger CM 87E":"21455",
"Beijing 1954 / Gauss-Kruger CM 93E":"21456",
"Beijing 1954 / Gauss-Kruger CM 99E":"21457",
"Beijing 1954 / Gauss-Kruger CM 105E":"21458",
"Beijing 1954 / Gauss-Kruger CM 111E":"21459",
"Beijing 1954 / Gauss-Kruger CM 117E":"21460",
"Beijing 1954 / Gauss-Kruger CM 123E":"21461",
"Beijing 1954 / Gauss-Kruger CM 129E":"21462",
"Beijing 1954 / Gauss-Kruger CM 135E":"21463",
"Beijing 1954 / Gauss-Kruger 13N":"21473",
"Beijing 1954 / Gauss-Kruger 14N":"21474",
"Beijing 1954 / Gauss-Kruger 15N":"21475",
"Beijing 1954 / Gauss-Kruger 16N":"21476",
"Beijing 1954 / Gauss-Kruger 17N":"21477",
"Beijing 1954 / Gauss-Kruger 18N":"21478",
"Beijing 1954 / Gauss-Kruger 19N":"21479",
"Beijing 1954 / Gauss-Kruger 20N":"21480",
"Beijing 1954 / Gauss-Kruger 21N":"21481",
"Beijing 1954 / Gauss-Kruger 22N":"21482",
"Beijing 1954 / Gauss-Kruger 23N":"21483",
"Belge 1950 (Brussels) / Belge Lambert 50":"21500",
"Bern 1898 (Bern) / LV03C":"21780",
"CH1903 / LV03":"21781",
"CH1903 / LV03C-G":"21782",
"Bogota 1975 / UTM zone 17N":"21817",
"Bogota 1975 / UTM zone 18N":"21818",
"Bogota 1975 / Colombia West zone":"21891",
"Bogota 1975 / Colombia Bogota zone":"21892",
"Bogota 1975 / Colombia East Central zone":"21893",
"Bogota 1975 / Colombia East":"21894",
"Bogota 1975 / Colombia West zone":"21896",
"Bogota 1975 / Colombia Bogota zone":"21897",
"Bogota 1975 / Colombia East Central zone":"21898",
"Bogota 1975 / Colombia East zone":"21899",
"Camacupa / UTM zone 32S":"22032",
"Camacupa / UTM zone 33S":"22033",
"Camacupa / TM 11.30 SE":"22091",
"Camacupa / TM 12 SE":"22092",
"POSGAR 98 / Argentina 1":"22171",
"POSGAR 98 / Argentina 2":"22172",
"POSGAR 98 / Argentina 3":"22173",
"POSGAR 98 / Argentina 4":"22174",
"POSGAR 98 / Argentina 5":"22175",
"POSGAR 98 / Argentina 6":"22176",
"POSGAR 98 / Argentina 7":"22177",
"POSGAR 94 / Argentina 1":"22181",
"POSGAR 94 / Argentina 2":"22182",
"POSGAR 94 / Argentina 3":"22183",
"POSGAR 94 / Argentina 4":"22184",
"POSGAR 94 / Argentina 5":"22185",
"POSGAR 94 / Argentina 6":"22186",
"POSGAR 94 / Argentina 7":"22187",
"Campo Inchauspe / Argentina 1":"22191",
"Campo Inchauspe / Argentina 2":"22192",
"Campo Inchauspe / Argentina 3":"22193",
"Campo Inchauspe / Argentina 4":"22194",
"Campo Inchauspe / Argentina 5":"22195",
"Campo Inchauspe / Argentina 6":"22196",
"Campo Inchauspe / Argentina 7":"22197",
"Cape / UTM zone 34S":"22234",
"Cape / UTM zone 35S":"22235",
"Cape / UTM zone 36S":"22236",
"Cape / Lo15":"22275",
"Cape / Lo17":"22277",
"Cape / Lo19":"22279",
"Cape / Lo21":"22281",
"Cape / Lo23":"22283",
"Cape / Lo25":"22285",
"Cape / Lo27":"22287",
"Cape / Lo29":"22289",
"Cape / Lo31":"22291",
"Cape / Lo33":"22293",
"Carthage (Paris) / Tunisia Mining Grid":"22300",
"Carthage / UTM zone 32N":"22332",
"Carthage / Nord Tunisie":"22391",
"Carthage / Sud Tunisie":"22392",
"Corrego Alegre 1970-72 / UTM zone 21S":"22521",
"Corrego Alegre 1970-72 / UTM zone 22S":"22522",
"Corrego Alegre 1970-72 / UTM zone 23S":"22523",
"Corrego Alegre 1970-72 / UTM zone 24S":"22524",
"Corrego Alegre 1970-72 / UTM zone 25S":"22525",
"Deir ez Zor / Levant Zone":"22700",
"Deir ez Zor / Syria Lambert":"22770",
"Deir ez Zor / Levant Stereographic":"22780",
"Douala / UTM zone 32N":"22832",
"Egypt 1907 / Blue Belt":"22991",
"Egypt 1907 / Red Belt":"22992",
"Egypt 1907 / Purple Belt":"22993",
"Egypt 1907 / Extended Purple Belt":"22994",
"ED50 / UTM zone 28N":"23028",
"ED50 / UTM zone 29N":"23029",
"ED50 / UTM zone 30N":"23030",
"ED50 / UTM zone 31N":"23031",
"ED50 / UTM zone 32N":"23032",
"ED50 / UTM zone 33N":"23033",
"ED50 / UTM zone 34N":"23034",
"ED50 / UTM zone 35N":"23035",
"ED50 / UTM zone 36N":"23036",
"ED50 / UTM zone 37N":"23037",
"ED50 / UTM zone 38N":"23038",
"ED50 / TM 0 N":"23090",
"ED50 / TM 5 NE":"23095",
"Fahud / UTM zone 39N":"23239",
"Fahud / UTM zone 40N":"23240",
"Garoua / UTM zone 33N":"23433",
"HD72 / EOV":"23700",
"DGN95 / Indonesia TM-3 zone 46.2":"23830",
"DGN95 / Indonesia TM-3 zone 47.1":"23831",
"DGN95 / Indonesia TM-3 zone 47.2":"23832",
"DGN95 / Indonesia TM-3 zone 48.1":"23833",
"DGN95 / Indonesia TM-3 zone 48.2":"23834",
"DGN95 / Indonesia TM-3 zone 49.1":"23835",
"DGN95 / Indonesia TM-3 zone 49.2":"23836",
"DGN95 / Indonesia TM-3 zone 50.1":"23837",
"DGN95 / Indonesia TM-3 zone 50.2":"23838",
"DGN95 / Indonesia TM-3 zone 51.1":"23839",
"DGN95 / Indonesia TM-3 zone 51.2":"23840",
"DGN95 / Indonesia TM-3 zone 52.1":"23841",
"DGN95 / Indonesia TM-3 zone 52.2":"23842",
"DGN95 / Indonesia TM-3 zone 53.1":"23843",
"DGN95 / Indonesia TM-3 zone 53.2":"23844",
"DGN95 / Indonesia TM-3 zone 54.1":"23845",
"ID74 / UTM zone 46N":"23846",
"ID74 / UTM zone 47N":"23847",
"ID74 / UTM zone 48N":"23848",
"ID74 / UTM zone 49N":"23849",
"ID74 / UTM zone 50N":"23850",
"ID74 / UTM zone 51N":"23851",
"ID74 / UTM zone 52N":"23852",
"ID74 / UTM zone 53N":"23853",
"DGN95 / UTM zone 46N":"23866",
"DGN95 / UTM zone 47N":"23867",
"DGN95 / UTM zone 48N":"23868",
"DGN95 / UTM zone 49N":"23869",
"DGN95 / UTM zone 50N":"23870",
"DGN95 / UTM zone 51N":"23871",
"DGN95 / UTM zone 52N":"23872",
"DGN95 / UTM zone 47S":"23877",
"DGN95 / UTM zone 48S":"23878",
"DGN95 / UTM zone 49S":"23879",
"DGN95 / UTM zone 50S":"23880",
"DGN95 / UTM zone 51S":"23881",
"DGN95 / UTM zone 52S":"23882",
"DGN95 / UTM zone 53S":"23883",
"DGN95 / UTM zone 54S":"23884",
"ID74 / UTM zone 46S":"23886",
"ID74 / UTM zone 47S":"23887",
"ID74 / UTM zone 48S":"23888",
"ID74 / UTM zone 49S":"23889",
"ID74 / UTM zone 50S":"23890",
"ID74 / UTM zone 51S":"23891",
"ID74 / UTM zone 52S":"23892",
"ID74 / UTM zone 53S":"23893",
"ID74 / UTM zone 54S":"23894",
"Indian 1954 / UTM zone 46N":"23946",
"Indian 1954 / UTM zone 47N":"23947",
"Indian 1954 / UTM zone 48N":"23948",
"Indian 1975 / UTM zone 47N":"24047",
"Indian 1975 / UTM zone 48N":"24048",
"Jamaica 1875 / Jamaica (Old Grid)":"24100",
"JAD69 / Jamaica National Grid":"24200",
"Kalianpur 1937 / UTM zone 45N":"24305",
"Kalianpur 1937 / UTM zone 46N":"24306",
"Kalianpur 1962 / UTM zone 41N":"24311",
"Kalianpur 1962 / UTM zone 42N":"24312",
"Kalianpur 1962 / UTM zone 43N":"24313",
"Kalianpur 1975 / UTM zone 42N":"24342",
"Kalianpur 1975 / UTM zone 43N":"24343",
"Kalianpur 1975 / UTM zone 44N":"24344",
"Kalianpur 1975 / UTM zone 45N":"24345",
"Kalianpur 1975 / UTM zone 46N":"24346",
"Kalianpur 1975 / UTM zone 47N":"24347",
"Kalianpur 1880 / India zone 0":"24370",
"Kalianpur 1880 / India zone I":"24371",
"Kalianpur 1880 / India zone IIa":"24372",
"Kalianpur 1880 / India zone IIIa":"24373",
"Kalianpur 1880 / India zone IVa":"24374",
"Kalianpur 1937 / India zone IIb":"24375",
"Kalianpur 1962 / India zone I":"24376",
"Kalianpur 1962 / India zone IIa":"24377",
"Kalianpur 1975 / India zone I":"24378",
"Kalianpur 1975 / India zone IIa":"24379",
"Kalianpur 1975 / India zone IIb":"24380",
"Kalianpur 1975 / India zone IIIa":"24381",
"Kalianpur 1880 / India zone IIb":"24382",
"Kalianpur 1975 / India zone IVa":"24383",
"Kertau 1968 / Singapore Grid":"24500",
"Kertau 1968 / UTM zone 47N":"24547",
"Kertau 1968 / UTM zone 48N":"24548",
"Kertau / R.S.O. Malaya (ch)":"24571",
"KOC Lambert":"24600",
"La Canoa / UTM zone 18N":"24718",
"La Canoa / UTM zone 19N":"24719",
"La Canoa / UTM zone 20N":"24720",
"PSAD56 / UTM zone 17N":"24817",
"PSAD56 / UTM zone 18N":"24818",
"PSAD56 / UTM zone 19N":"24819",
"PSAD56 / UTM zone 20N":"24820",
"PSAD56 / UTM zone 21N":"24821",
"PSAD56 / UTM zone 17S":"24877",
"PSAD56 / UTM zone 18S":"24878",
"PSAD56 / UTM zone 19S":"24879",
"PSAD56 / UTM zone 20S":"24880",
"PSAD56 / UTM zone 21S":"24881",
"PSAD56 / UTM zone 22S":"24882",
"PSAD56 / Peru west zone":"24891",
"PSAD56 / Peru central zone":"24892",
"PSAD56 / Peru east zone":"24893",
"Leigon / Ghana Metre Grid":"25000",
"Lome / UTM zone 31N":"25231",
"Luzon 1911 / Philippines zone I":"25391",
"Luzon 1911 / Philippines zone II":"25392",
"Luzon 1911 / Philippines zone III":"25393",
"Luzon 1911 / Philippines zone IV":"25394",
"Luzon 1911 / Philippines zone V":"25395",
"Makassar (Jakarta) / NEIEZ":"25700",
"ETRS89 / UTM zone 28N":"25828",
"ETRS89 / UTM zone 29N":"25829",
"ETRS89 / UTM zone 30N":"25830",
"ETRS89 / UTM zone 31N":"25831",
"ETRS89 / UTM zone 32N":"25832",
"ETRS89 / UTM zone 33N":"25833",
"ETRS89 / UTM zone 34N":"25834",
"ETRS89 / UTM zone 35N":"25835",
"ETRS89 / UTM zone 36N":"25836",
"ETRS89 / UTM zone 37N":"25837",
"ETRS89 / UTM zone 38N":"25838",
"ETRS89 / TM Baltic93":"25884",
"Malongo 1987 / UTM zone 32S":"25932",
"Merchich / Nord Maroc":"26191",
"Merchich / Sud Maroc":"26192",
"Merchich / Sahara":"26193",
"Merchich / Sahara Nord":"26194",
"Merchich / Sahara Sud":"26195",
"Massawa / UTM zone 37N":"26237",
"Minna / UTM zone 31N":"26331",
"Minna / UTM zone 32N":"26332",
"Minna / Nigeria West Belt":"26391",
"Minna / Nigeria Mid Belt":"26392",
"Minna / Nigeria East Belt":"26393",
"Mhast / UTM zone 32S":"26432",
"Monte Mario (Rome) / Italy zone 1":"26591",
"Monte Mario (Rome) / Italy zone 2":"26592",
"M'poraloko / UTM zone 32N":"26632",
"M'poraloko / UTM zone 32S":"26692",
"NAD27 / UTM zone 1N":"26701",
"NAD27 / UTM zone 2N":"26702",
"NAD27 / UTM zone 3N":"26703",
"NAD27 / UTM zone 4N":"26704",
"NAD27 / UTM zone 5N":"26705",
"NAD27 / UTM zone 6N":"26706",
"NAD27 / UTM zone 7N":"26707",
"NAD27 / UTM zone 8N":"26708",
"NAD27 / UTM zone 9N":"26709",
"NAD27 / UTM zone 10N":"26710",
"NAD27 / UTM zone 11N":"26711",
"NAD27 / UTM zone 12N":"26712",
"NAD27 / UTM zone 13N":"26713",
"NAD27 / UTM zone 14N":"26714",
"NAD27 / UTM zone 15N":"26715",
"NAD27 / UTM zone 16N":"26716",
"NAD27 / UTM zone 17N":"26717",
"NAD27 / UTM zone 18N":"26718",
"NAD27 / UTM zone 19N":"26719",
"NAD27 / UTM zone 20N":"26720",
"NAD27 / UTM zone 21N":"26721",
"NAD27 / UTM zone 22N":"26722",
"NAD27 / Alabama East":"26729",
"NAD27 / Alabama West":"26730",
"NAD27 / Alaska zone 1":"26731",
"NAD27 / Alaska zone 2":"26732",
"NAD27 / Alaska zone 3":"26733",
"NAD27 / Alaska zone 4":"26734",
"NAD27 / Alaska zone 5":"26735",
"NAD27 / Alaska zone 6":"26736",
"NAD27 / Alaska zone 7":"26737",
"NAD27 / Alaska zone 8":"26738",
"NAD27 / Alaska zone 9":"26739",
"NAD27 / Alaska zone 10":"26740",
"NAD27 / California zone I":"26741",
"NAD27 / California zone II":"26742",
"NAD27 / California zone III":"26743",
"NAD27 / California zone IV":"26744",
"NAD27 / California zone V":"26745",
"NAD27 / California zone VI":"26746",
"NAD27 / California zone VII":"26747",
"NAD27 / Arizona East":"26748",
"NAD27 / Arizona Central":"26749",
"NAD27 / Arizona West":"26750",
"NAD27 / Arkansas North":"26751",
"NAD27 / Arkansas South":"26752",
"NAD27 / Colorado North":"26753",
"NAD27 / Colorado Central":"26754",
"NAD27 / Colorado South":"26755",
"NAD27 / Connecticut":"26756",
"NAD27 / Delaware":"26757",
"NAD27 / Florida East":"26758",
"NAD27 / Florida West":"26759",
"NAD27 / Florida North":"26760",
"NAD27 / Georgia East":"26766",
"NAD27 / Georgia West":"26767",
"NAD27 / Idaho East":"26768",
"NAD27 / Idaho Central":"26769",
"NAD27 / Idaho West":"26770",
"NAD27 / Illinois East":"26771",
"NAD27 / Illinois West":"26772",
"NAD27 / Indiana East":"26773",
"NAD27 / Indiana West":"26774",
"NAD27 / Iowa North":"26775",
"NAD27 / Iowa South":"26776",
"NAD27 / Kansas North":"26777",
"NAD27 / Kansas South":"26778",
"NAD27 / Kentucky North":"26779",
"NAD27 / Kentucky South":"26780",
"NAD27 / Louisiana North":"26781",
"NAD27 / Louisiana South":"26782",
"NAD27 / Maine East":"26783",
"NAD27 / Maine West":"26784",
"NAD27 / Maryland":"26785",
"NAD27 / Massachusetts Mainland":"26786",
"NAD27 / Massachusetts Island":"26787",
"NAD27 / Minnesota North":"26791",
"NAD27 / Minnesota Central":"26792",
"NAD27 / Minnesota South":"26793",
"NAD27 / Mississippi East":"26794",
"NAD27 / Mississippi West":"26795",
"NAD27 / Missouri East":"26796",
"NAD27 / Missouri Central":"26797",
"NAD27 / Missouri West":"26798",
"NAD27 / California zone VII":"26799",
"NAD Michigan / Michigan East":"26801",
"NAD Michigan / Michigan Old Central":"26802",
"NAD Michigan / Michigan West":"26803",
"NAD Michigan / Michigan North":"26811",
"NAD Michigan / Michigan Central":"26812",
"NAD Michigan / Michigan South":"26813",
"NAD83 / Maine East (ftUS)":"26814",
"NAD83 / Maine West (ftUS)":"26815",
"NAD83 / Minnesota North (ftUS)":"26819",
"NAD83 / Minnesota Central (ftUS)":"26820",
"NAD83 / Minnesota South (ftUS)":"26821",
"NAD83 / Nebraska (ftUS)":"26822",
"NAD83 / West Virginia North (ftUS)":"26823",
"NAD83 / West Virginia South (ftUS)":"26824",
"NAD83(HARN) / Maine East (ftUS)":"26825",
"NAD83(HARN) / Maine West (ftUS)":"26826",
"NAD83(HARN) / Minnesota North (ftUS)":"26830",
"NAD83(HARN) / Minnesota Central (ftUS)":"26831",
"NAD83(HARN) / Minnesota South (ftUS)":"26832",
"NAD83(HARN) / Nebraska (ftUS)":"26833",
"NAD83(HARN) / West Virginia North (ftUS)":"26834",
"NAD83(HARN) / West Virginia South (ftUS)":"26835",
"NAD83(NSRS2007) / Maine East (ftUS)":"26836",
"NAD83(NSRS2007) / Maine West (ftUS)":"26837",
"NAD83(NSRS2007) / Minnesota North (ftUS)":"26841",
"NAD83(NSRS2007) / Minnesota Central (ftUS)":"26842",
"NAD83(NSRS2007) / Minnesota South (ftUS)":"26843",
"NAD83(NSRS2007) / Nebraska (ftUS)":"26844",
"NAD83(NSRS2007) / West Virginia North (ftUS)":"26845",
"NAD83(NSRS2007) / West Virginia South (ftUS)":"26846",
"NAD83 / Maine East (ftUS)":"26847",
"NAD83 / Maine West (ftUS)":"26848",
"NAD83 / Minnesota North (ftUS)":"26849",
"NAD83 / Minnesota Central (ftUS)":"26850",
"NAD83 / Minnesota South (ftUS)":"26851",
"NAD83 / Nebraska (ftUS)":"26852",
"NAD83 / West Virginia North (ftUS)":"26853",
"NAD83 / West Virginia South (ftUS)":"26854",
"NAD83(HARN) / Maine East (ftUS)":"26855",
"NAD83(HARN) / Maine West (ftUS)":"26856",
"NAD83(HARN) / Minnesota North (ftUS)":"26857",
"NAD83(HARN) / Minnesota Central (ftUS)":"26858",
"NAD83(HARN) / Minnesota South (ftUS)":"26859",
"NAD83(HARN) / Nebraska (ftUS)":"26860",
"NAD83(HARN) / West Virginia North (ftUS)":"26861",
"NAD83(HARN) / West Virginia South (ftUS)":"26862",
"NAD83(NSRS2007) / Maine East (ftUS)":"26863",
"NAD83(NSRS2007) / Maine West (ftUS)":"26864",
"NAD83(NSRS2007) / Minnesota North (ftUS)":"26865",
"NAD83(NSRS2007) / Minnesota Central (ftUS)":"26866",
"NAD83(NSRS2007) / Minnesota South (ftUS)":"26867",
"NAD83(NSRS2007) / Nebraska (ftUS)":"26868",
"NAD83(NSRS2007) / West Virginia North (ftUS)":"26869",
"NAD83(NSRS2007) / West Virginia South (ftUS)":"26870",
"NAD83(CSRS) / MTM zone 11":"26891",
"NAD83(CSRS) / MTM zone 12":"26892",
"NAD83(CSRS) / MTM zone 13":"26893",
"NAD83(CSRS) / MTM zone 14":"26894",
"NAD83(CSRS) / MTM zone 15":"26895",
"NAD83(CSRS) / MTM zone 16":"26896",
"NAD83(CSRS) / MTM zone 17":"26897",
"NAD83(CSRS) / MTM zone 1":"26898",
"NAD83(CSRS) / MTM zone 2":"26899",
"NAD83 / UTM zone 1N":"26901",
"NAD83 / UTM zone 2N":"26902",
"NAD83 / UTM zone 3N":"26903",
"NAD83 / UTM zone 4N":"26904",
"NAD83 / UTM zone 5N":"26905",
"NAD83 / UTM zone 6N":"26906",
"NAD83 / UTM zone 7N":"26907",
"NAD83 / UTM zone 8N":"26908",
"NAD83 / UTM zone 9N":"26909",
"NAD83 / UTM zone 10N":"26910",
"NAD83 / UTM zone 11N":"26911",
"NAD83 / UTM zone 12N":"26912",
"NAD83 / UTM zone 13N":"26913",
"NAD83 / UTM zone 14N":"26914",
"NAD83 / UTM zone 15N":"26915",
"NAD83 / UTM zone 16N":"26916",
"NAD83 / UTM zone 17N":"26917",
"NAD83 / UTM zone 18N":"26918",
"NAD83 / UTM zone 19N":"26919",
"NAD83 / UTM zone 20N":"26920",
"NAD83 / UTM zone 21N":"26921",
"NAD83 / UTM zone 22N":"26922",
"NAD83 / UTM zone 23N":"26923",
"NAD83 / Alabama East":"26929",
"NAD83 / Alabama West":"26930",
"NAD83 / Alaska zone 1":"26931",
"NAD83 / Alaska zone 2":"26932",
"NAD83 / Alaska zone 3":"26933",
"NAD83 / Alaska zone 4":"26934",
"NAD83 / Alaska zone 5":"26935",
"NAD83 / Alaska zone 6":"26936",
"NAD83 / Alaska zone 7":"26937",
"NAD83 / Alaska zone 8":"26938",
"NAD83 / Alaska zone 9":"26939",
"NAD83 / Alaska zone 10":"26940",
"NAD83 / California zone 1":"26941",
"NAD83 / California zone 2":"26942",
"NAD83 / California zone 3":"26943",
"NAD83 / California zone 4":"26944",
"NAD83 / California zone 5":"26945",
"NAD83 / California zone 6":"26946",
"NAD83 / Arizona East":"26948",
"NAD83 / Arizona Central":"26949",
"NAD83 / Arizona West":"26950",
"NAD83 / Arkansas North":"26951",
"NAD83 / Arkansas South":"26952",
"NAD83 / Colorado North":"26953",
"NAD83 / Colorado Central":"26954",
"NAD83 / Colorado South":"26955",
"NAD83 / Connecticut":"26956",
"NAD83 / Delaware":"26957",
"NAD83 / Florida East":"26958",
"NAD83 / Florida West":"26959",
"NAD83 / Florida North":"26960",
"NAD83 / Hawaii zone 1":"26961",
"NAD83 / Hawaii zone 2":"26962",
"NAD83 / Hawaii zone 3":"26963",
"NAD83 / Hawaii zone 4":"26964",
"NAD83 / Hawaii zone 5":"26965",
"NAD83 / Georgia East":"26966",
"NAD83 / Georgia West":"26967",
"NAD83 / Idaho East":"26968",
"NAD83 / Idaho Central":"26969",
"NAD83 / Idaho West":"26970",
"NAD83 / Illinois East":"26971",
"NAD83 / Illinois West":"26972",
"NAD83 / Indiana East":"26973",
"NAD83 / Indiana West":"26974",
"NAD83 / Iowa North":"26975",
"NAD83 / Iowa South":"26976",
"NAD83 / Kansas North":"26977",
"NAD83 / Kansas South":"26978",
"NAD83 / Kentucky North":"26979",
"NAD83 / Kentucky South":"26980",
"NAD83 / Louisiana North":"26981",
"NAD83 / Louisiana South":"26982",
"NAD83 / Maine East":"26983",
"NAD83 / Maine West":"26984",
"NAD83 / Maryland":"26985",
"NAD83 / Massachusetts Mainland":"26986",
"NAD83 / Massachusetts Island":"26987",
"NAD83 / Michigan North":"26988",
"NAD83 / Michigan Central":"26989",
"NAD83 / Michigan South":"26990",
"NAD83 / Minnesota North":"26991",
"NAD83 / Minnesota Central":"26992",
"NAD83 / Minnesota South":"26993",
"NAD83 / Mississippi East":"26994",
"NAD83 / Mississippi West":"26995",
"NAD83 / Missouri East":"26996",
"NAD83 / Missouri Central":"26997",
"NAD83 / Missouri West":"26998",
"Nahrwan 1967 / UTM zone 37N":"27037",
"Nahrwan 1967 / UTM zone 38N":"27038",
"Nahrwan 1967 / UTM zone 39N":"27039",
"Nahrwan 1967 / UTM zone 40N":"27040",
"Naparima 1972 / UTM zone 20N":"27120",
"NZGD49 / New Zealand Map Grid":"27200",
"NZGD49 / Mount Eden Circuit":"27205",
"NZGD49 / Bay of Plenty Circuit":"27206",
"NZGD49 / Poverty Bay Circuit":"27207",
"NZGD49 / Hawkes Bay Circuit":"27208",
"NZGD49 / Taranaki Circuit":"27209",
"NZGD49 / Tuhirangi Circuit":"27210",
"NZGD49 / Wanganui Circuit":"27211",
"NZGD49 / Wairarapa Circuit":"27212",
"NZGD49 / Wellington Circuit":"27213",
"NZGD49 / Collingwood Circuit":"27214",
"NZGD49 / Nelson Circuit":"27215",
"NZGD49 / Karamea Circuit":"27216",
"NZGD49 / Buller Circuit":"27217",
"NZGD49 / Grey Circuit":"27218",
"NZGD49 / Amuri Circuit":"27219",
"NZGD49 / Marlborough Circuit":"27220",
"NZGD49 / Hokitika Circuit":"27221",
"NZGD49 / Okarito Circuit":"27222",
"NZGD49 / Jacksons Bay Circuit":"27223",
"NZGD49 / Mount Pleasant Circuit":"27224",
"NZGD49 / Gawler Circuit":"27225",
"NZGD49 / Timaru Circuit":"27226",
"NZGD49 / Lindis Peak Circuit":"27227",
"NZGD49 / Mount Nicholas Circuit":"27228",
"NZGD49 / Mount York Circuit":"27229",
"NZGD49 / Observation Point Circuit":"27230",
"NZGD49 / North Taieri Circuit":"27231",
"NZGD49 / Bluff Circuit":"27232",
"NZGD49 / UTM zone 58S":"27258",
"NZGD49 / UTM zone 59S":"27259",
"NZGD49 / UTM zone 60S":"27260",
"NZGD49 / North Island Grid":"27291",
"NZGD49 / South Island Grid":"27292",
"NGO 1948 (Oslo) / NGO zone I":"27391",
"NGO 1948 (Oslo) / NGO zone II":"27392",
"NGO 1948 (Oslo) / NGO zone III":"27393",
"NGO 1948 (Oslo) / NGO zone IV":"27394",
"NGO 1948 (Oslo) / NGO zone V":"27395",
"NGO 1948 (Oslo) / NGO zone VI":"27396",
"NGO 1948 (Oslo) / NGO zone VII":"27397",
"NGO 1948 (Oslo) / NGO zone VIII":"27398",
"Datum 73 / UTM zone 29N":"27429",
"Datum 73 / Modified Portuguese Grid":"27492",
"Datum 73 / Modified Portuguese Grid":"27493",
"ATF (Paris) / Nord de Guerre":"27500",
"NTF (Paris) / Lambert Nord France":"27561",
"NTF (Paris) / Lambert Centre France":"27562",
"NTF (Paris) / Lambert Sud France":"27563",
"NTF (Paris) / Lambert Corse":"27564",
"NTF (Paris) / Lambert zone I":"27571",
"NTF (Paris) / Lambert zone II":"27572",
"NTF (Paris) / Lambert zone III":"27573",
"NTF (Paris) / Lambert zone IV":"27574",
"NTF (Paris) / France I":"27581",
"NTF (Paris) / France II":"27582",
"NTF (Paris) / France III":"27583",
"NTF (Paris) / France IV":"27584",
"NTF (Paris) / Nord France":"27591",
"NTF (Paris) / Centre France":"27592",
"NTF (Paris) / Sud France":"27593",
"NTF (Paris) / Corse":"27594",
"OSGB 1936 / British National Grid":"27700",
"Palestine 1923 / Palestine Grid":"28191",
"Palestine 1923 / Palestine Belt":"28192",
"Palestine 1923 / Israeli CS Grid":"28193",
"Pointe Noire / UTM zone 32S":"28232",
"GDA94 / MGA zone 48":"28348",
"GDA94 / MGA zone 49":"28349",
"GDA94 / MGA zone 50":"28350",
"GDA94 / MGA zone 51":"28351",
"GDA94 / MGA zone 52":"28352",
"GDA94 / MGA zone 53":"28353",
"GDA94 / MGA zone 54":"28354",
"GDA94 / MGA zone 55":"28355",
"GDA94 / MGA zone 56":"28356",
"GDA94 / MGA zone 57":"28357",
"GDA94 / MGA zone 58":"28358",
"Pulkovo 1942 / Gauss-Kruger zone 2":"28402",
"Pulkovo 1942 / Gauss-Kruger zone 3":"28403",
"Pulkovo 1942 / Gauss-Kruger zone 4":"28404",
"Pulkovo 1942 / Gauss-Kruger zone 5":"28405",
"Pulkovo 1942 / Gauss-Kruger zone 6":"28406",
"Pulkovo 1942 / Gauss-Kruger zone 7":"28407",
"Pulkovo 1942 / Gauss-Kruger zone 8":"28408",
"Pulkovo 1942 / Gauss-Kruger zone 9":"28409",
"Pulkovo 1942 / Gauss-Kruger zone 10":"28410",
"Pulkovo 1942 / Gauss-Kruger zone 11":"28411",
"Pulkovo 1942 / Gauss-Kruger zone 12":"28412",
"Pulkovo 1942 / Gauss-Kruger zone 13":"28413",
"Pulkovo 1942 / Gauss-Kruger zone 14":"28414",
"Pulkovo 1942 / Gauss-Kruger zone 15":"28415",
"Pulkovo 1942 / Gauss-Kruger zone 16":"28416",
"Pulkovo 1942 / Gauss-Kruger zone 17":"28417",
"Pulkovo 1942 / Gauss-Kruger zone 18":"28418",
"Pulkovo 1942 / Gauss-Kruger zone 19":"28419",
"Pulkovo 1942 / Gauss-Kruger zone 20":"28420",
"Pulkovo 1942 / Gauss-Kruger zone 21":"28421",
"Pulkovo 1942 / Gauss-Kruger zone 22":"28422",
"Pulkovo 1942 / Gauss-Kruger zone 23":"28423",
"Pulkovo 1942 / Gauss-Kruger zone 24":"28424",
"Pulkovo 1942 / Gauss-Kruger zone 25":"28425",
"Pulkovo 1942 / Gauss-Kruger zone 26":"28426",
"Pulkovo 1942 / Gauss-Kruger zone 27":"28427",
"Pulkovo 1942 / Gauss-Kruger zone 28":"28428",
"Pulkovo 1942 / Gauss-Kruger zone 29":"28429",
"Pulkovo 1942 / Gauss-Kruger zone 30":"28430",
"Pulkovo 1942 / Gauss-Kruger zone 31":"28431",
"Pulkovo 1942 / Gauss-Kruger zone 32":"28432",
"Pulkovo 1942 / Gauss-Kruger 2N":"28462",
"Pulkovo 1942 / Gauss-Kruger 3N":"28463",
"Pulkovo 1942 / Gauss-Kruger 4N":"28464",
"Pulkovo 1942 / Gauss-Kruger 5N":"28465",
"Pulkovo 1942 / Gauss-Kruger 6N":"28466",
"Pulkovo 1942 / Gauss-Kruger 7N":"28467",
"Pulkovo 1942 / Gauss-Kruger 8N":"28468",
"Pulkovo 1942 / Gauss-Kruger 9N":"28469",
"Pulkovo 1942 / Gauss-Kruger 10N":"28470",
"Pulkovo 1942 / Gauss-Kruger 11N":"28471",
"Pulkovo 1942 / Gauss-Kruger 12N":"28472",
"Pulkovo 1942 / Gauss-Kruger 13N":"28473",
"Pulkovo 1942 / Gauss-Kruger 14N":"28474",
"Pulkovo 1942 / Gauss-Kruger 15N":"28475",
"Pulkovo 1942 / Gauss-Kruger 16N":"28476",
"Pulkovo 1942 / Gauss-Kruger 17N":"28477",
"Pulkovo 1942 / Gauss-Kruger 18N":"28478",
"Pulkovo 1942 / Gauss-Kruger 19N":"28479",
"Pulkovo 1942 / Gauss-Kruger 20N":"28480",
"Pulkovo 1942 / Gauss-Kruger 21N":"28481",
"Pulkovo 1942 / Gauss-Kruger 22N":"28482",
"Pulkovo 1942 / Gauss-Kruger 23N":"28483",
"Pulkovo 1942 / Gauss-Kruger 24N":"28484",
"Pulkovo 1942 / Gauss-Kruger 25N":"28485",
"Pulkovo 1942 / Gauss-Kruger 26N":"28486",
"Pulkovo 1942 / Gauss-Kruger 27N":"28487",
"Pulkovo 1942 / Gauss-Kruger 28N":"28488",
"Pulkovo 1942 / Gauss-Kruger 29N":"28489",
"Pulkovo 1942 / Gauss-Kruger 30N":"28490",
"Pulkovo 1942 / Gauss-Kruger 31N":"28491",
"Pulkovo 1942 / Gauss-Kruger 32N":"28492",
"Qatar 1974 / Qatar National Grid":"28600",
"Amersfoort / RD Old":"28991",
"Amersfoort / RD New":"28992",
"SAD69 / Brazil Polyconic":"29100",
"SAD69 / Brazil Polyconic":"29101",
"SAD69 / UTM zone 18N":"29118",
"SAD69 / UTM zone 19N":"29119",
"SAD69 / UTM zone 20N":"29120",
"SAD69 / UTM zone 21N":"29121",
"SAD69 / UTM zone 22N":"29122",
"SAD69 / UTM zone 18N":"29168",
"SAD69 / UTM zone 19N":"29169",
"SAD69 / UTM zone 20N":"29170",
"SAD69 / UTM zone 21N":"29171",
"SAD69 / UTM zone 22N":"29172",
"SAD69 / UTM zone 17S":"29177",
"SAD69 / UTM zone 18S":"29178",
"SAD69 / UTM zone 19S":"29179",
"SAD69 / UTM zone 20S":"29180",
"SAD69 / UTM zone 21S":"29181",
"SAD69 / UTM zone 22S":"29182",
"SAD69 / UTM zone 23S":"29183",
"SAD69 / UTM zone 24S":"29184",
"SAD69 / UTM zone 25S":"29185",
"SAD69 / UTM zone 17S":"29187",
"SAD69 / UTM zone 18S":"29188",
"SAD69 / UTM zone 19S":"29189",
"SAD69 / UTM zone 20S":"29190",
"SAD69 / UTM zone 21S":"29191",
"SAD69 / UTM zone 22S":"29192",
"SAD69 / UTM zone 23S":"29193",
"SAD69 / UTM zone 24S":"29194",
"SAD69 / UTM zone 25S":"29195",
"Sapper Hill 1943 / UTM zone 20S":"29220",
"Sapper Hill 1943 / UTM zone 21S":"29221",
"Schwarzeck / UTM zone 33S":"29333",
"Schwarzeck / Lo22/11":"29371",
"Schwarzeck / Lo22/13":"29373",
"Schwarzeck / Lo22/15":"29375",
"Schwarzeck / Lo22/17":"29377",
"Schwarzeck / Lo22/19":"29379",
"Schwarzeck / Lo22/21":"29381",
"Schwarzeck / Lo22/23":"29383",
"Schwarzeck / Lo22/25":"29385",
"Sudan / UTM zone 35N":"29635",
"Sudan / UTM zone 36N":"29636",
"Tananarive (Paris) / Laborde Grid":"29700",
"Tananarive (Paris) / Laborde Grid":"29701",
"Tananarive (Paris) / Laborde Grid approximation":"29702",
"Tananarive / UTM zone 38S":"29738",
"Tananarive / UTM zone 39S":"29739",
"Timbalai 1948 / UTM zone 49N":"29849",
"Timbalai 1948 / UTM zone 50N":"29850",
"Timbalai 1948 / RSO Borneo (ch)":"29871",
"Timbalai 1948 / RSO Borneo (ftSe)":"29872",
"Timbalai 1948 / RSO Borneo (m)":"29873",
"TM65 / Irish National Grid":"29900",
"OSNI 1952 / Irish National Grid":"29901",
"TM65 / Irish Grid":"29902",
"TM75 / Irish Grid":"29903",
"Tokyo / Japan Plane Rectangular CS I":"30161",
"Tokyo / Japan Plane Rectangular CS II":"30162",
"Tokyo / Japan Plane Rectangular CS III":"30163",
"Tokyo / Japan Plane Rectangular CS IV":"30164",
"Tokyo / Japan Plane Rectangular CS V":"30165",
"Tokyo / Japan Plane Rectangular CS VI":"30166",
"Tokyo / Japan Plane Rectangular CS VII":"30167",
"Tokyo / Japan Plane Rectangular CS VIII":"30168",
"Tokyo / Japan Plane Rectangular CS IX":"30169",
"Tokyo / Japan Plane Rectangular CS X":"30170",
"Tokyo / Japan Plane Rectangular CS XI":"30171",
"Tokyo / Japan Plane Rectangular CS XII":"30172",
"Tokyo / Japan Plane Rectangular CS XIII":"30173",
"Tokyo / Japan Plane Rectangular CS XIV":"30174",
"Tokyo / Japan Plane Rectangular CS XV":"30175",
"Tokyo / Japan Plane Rectangular CS XVI":"30176",
"Tokyo / Japan Plane Rectangular CS XVII":"30177",
"Tokyo / Japan Plane Rectangular CS XVIII":"30178",
"Tokyo / Japan Plane Rectangular CS XIX":"30179",
"Trinidad 1903 / Trinidad Grid":"30200",
"TC(1948) / UTM zone 39N":"30339",
"TC(1948) / UTM zone 40N":"30340",
"Voirol 1875 / Nord Algerie (ancienne)":"30491",
"Voirol 1875 / Sud Algerie (ancienne)":"30492",
"Voirol 1879 / Nord Algerie (ancienne)":"30493",
"Voirol 1879 / Sud Algerie (ancienne)":"30494",
"Nord Sahara 1959 / UTM zone 29N":"30729",
"Nord Sahara 1959 / UTM zone 30N":"30730",
"Nord Sahara 1959 / UTM zone 31N":"30731",
"Nord Sahara 1959 / UTM zone 32N":"30732",
"Nord Sahara 1959 / Nord Algerie":"30791",
"Nord Sahara 1959 / Sud Algerie":"30792",
"RT38 2.5 gon W":"30800",
"Yoff / UTM zone 28N":"31028",
"Zanderij / UTM zone 21N":"31121",
"Zanderij / TM 54 NW":"31154",
"Zanderij / Suriname Old TM":"31170",
"Zanderij / Suriname TM":"31171",
"MGI (Ferro) / Austria GK West Zone":"31251",
"MGI (Ferro) / Austria GK Central Zone":"31252",
"MGI (Ferro) / Austria GK East Zone":"31253",
"MGI / Austria GK West":"31254",
"MGI / Austria GK Central":"31255",
"MGI / Austria GK East":"31256",
"MGI / Austria GK M28":"31257",
"MGI / Austria GK M31":"31258",
"MGI / Austria GK M34":"31259",
"MGI / 3-degree Gauss zone 5":"31265",
"MGI / 3-degree Gauss zone 6":"31266",
"MGI / 3-degree Gauss zone 7":"31267",
"MGI / 3-degree Gauss zone 8":"31268",
"MGI / Balkans zone 5":"31275",
"MGI / Balkans zone 6":"31276",
"MGI / Balkans zone 7":"31277",
"MGI / Balkans zone 8":"31278",
"MGI / Balkans zone 8":"31279",
"MGI (Ferro) / Austria West Zone":"31281",
"MGI (Ferro) / Austria Central Zone":"31282",
"MGI (Ferro) / Austria East Zone":"31283",
"MGI / Austria M28":"31284",
"MGI / Austria M31":"31285",
"MGI / Austria M34":"31286",
"MGI / Austria Lambert":"31287",
"MGI (Ferro) / M28":"31288",
"MGI (Ferro) / M31":"31289",
"MGI (Ferro) / M34":"31290",
"MGI (Ferro) / Austria West Zone":"31291",
"MGI (Ferro) / Austria Central Zone":"31292",
"MGI (Ferro) / Austria East Zone":"31293",
"MGI / M28":"31294",
"MGI / M31":"31295",
"MGI / M34":"31296",
"MGI / Austria Lambert":"31297",
"Belge 1972 / Belge Lambert 72":"31300",
"Belge 1972 / Belgian Lambert 72":"31370",
"DHDN / 3-degree Gauss zone 1":"31461",
"DHDN / 3-degree Gauss zone 2":"31462",
"DHDN / 3-degree Gauss zone 3":"31463",
"DHDN / 3-degree Gauss zone 4":"31464",
"DHDN / 3-degree Gauss zone 5":"31465",
"DHDN / 3-degree Gauss-Kruger zone 2":"31466",
"DHDN / 3-degree Gauss-Kruger zone 3":"31467",
"DHDN / 3-degree Gauss-Kruger zone 4":"31468",
"DHDN / 3-degree Gauss-Kruger zone 5":"31469",
"Conakry 1905 / UTM zone 28N":"31528",
"Conakry 1905 / UTM zone 29N":"31529",
"Dealul Piscului 1930 / Stereo 33":"31600",
"Dealul Piscului 1970/ Stereo 70":"31700",
"NGN / UTM zone 38N":"31838",
"NGN / UTM zone 39N":"31839",
"KUDAMS / KTM":"31900",
"KUDAMS / KTM":"31901",
"SIRGAS 2000 / UTM zone 11N":"31965",
"SIRGAS 2000 / UTM zone 12N":"31966",
"SIRGAS 2000 / UTM zone 13N":"31967",
"SIRGAS 2000 / UTM zone 14N":"31968",
"SIRGAS 2000 / UTM zone 15N":"31969",
"SIRGAS 2000 / UTM zone 16N":"31970",
"SIRGAS 2000 / UTM zone 17N":"31971",
"SIRGAS 2000 / UTM zone 18N":"31972",
"SIRGAS 2000 / UTM zone 19N":"31973",
"SIRGAS 2000 / UTM zone 20N":"31974",
"SIRGAS 2000 / UTM zone 21N":"31975",
"SIRGAS 2000 / UTM zone 22N":"31976",
"SIRGAS 2000 / UTM zone 17S":"31977",
"SIRGAS 2000 / UTM zone 18S":"31978",
"SIRGAS 2000 / UTM zone 19S":"31979",
"SIRGAS 2000 / UTM zone 20S":"31980",
"SIRGAS 2000 / UTM zone 21S":"31981",
"SIRGAS 2000 / UTM zone 22S":"31982",
"SIRGAS 2000 / UTM zone 23S":"31983",
"SIRGAS 2000 / UTM zone 24S":"31984",
"SIRGAS 2000 / UTM zone 25S":"31985",
"SIRGAS 1995 / UTM zone 17N":"31986",
"SIRGAS 1995 / UTM zone 18N":"31987",
"SIRGAS 1995 / UTM zone 19N":"31988",
"SIRGAS 1995 / UTM zone 20N":"31989",
"SIRGAS 1995 / UTM zone 21N":"31990",
"SIRGAS 1995 / UTM zone 22N":"31991",
"SIRGAS 1995 / UTM zone 17S":"31992",
"SIRGAS 1995 / UTM zone 18S":"31993",
"SIRGAS 1995 / UTM zone 19S":"31994",
"SIRGAS 1995 / UTM zone 20S":"31995",
"SIRGAS 1995 / UTM zone 21S":"31996",
"SIRGAS 1995 / UTM zone 22S":"31997",
"SIRGAS 1995 / UTM zone 23S":"31998",
"SIRGAS 1995 / UTM zone 24S":"31999",
"SIRGAS 1995 / UTM zone 25S":"32000",
"NAD27 / Montana North":"32001",
"NAD27 / Montana Central":"32002",
"NAD27 / Montana South":"32003",
"NAD27 / Nebraska North":"32005",
"NAD27 / Nebraska South":"32006",
"NAD27 / Nevada East":"32007",
"NAD27 / Nevada Central":"32008",
"NAD27 / Nevada West":"32009",
"NAD27 / New Hampshire":"32010",
"NAD27 / New Jersey":"32011",
"NAD27 / New Mexico East":"32012",
"NAD27 / New Mexico Central":"32013",
"NAD27 / New Mexico West":"32014",
"NAD27 / New York East":"32015",
"NAD27 / New York Central":"32016",
"NAD27 / New York West":"32017",
"NAD27 / New York Long Island":"32018",
"NAD27 / North Carolina":"32019",
"NAD27 / North Dakota North":"32020",
"NAD27 / North Dakota South":"32021",
"NAD27 / Ohio North":"32022",
"NAD27 / Ohio South":"32023",
"NAD27 / Oklahoma North":"32024",
"NAD27 / Oklahoma South":"32025",
"NAD27 / Oregon North":"32026",
"NAD27 / Oregon South":"32027",
"NAD27 / Pennsylvania North":"32028",
"NAD27 / Pennsylvania South":"32029",
"NAD27 / Rhode Island":"32030",
"NAD27 / South Carolina North":"32031",
"NAD27 / South Carolina South":"32033",
"NAD27 / South Dakota North":"32034",
"NAD27 / South Dakota South":"32035",
"NAD27 / Tennessee":"32036",
"NAD27 / Texas North":"32037",
"NAD27 / Texas North Central":"32038",
"NAD27 / Texas Central":"32039",
"NAD27 / Texas South Central":"32040",
"NAD27 / Texas South":"32041",
"NAD27 / Utah North":"32042",
"NAD27 / Utah Central":"32043",
"NAD27 / Utah South":"32044",
"NAD27 / Vermont":"32045",
"NAD27 / Virginia North":"32046",
"NAD27 / Virginia South":"32047",
"NAD27 / Washington North":"32048",
"NAD27 / Washington South":"32049",
"NAD27 / West Virginia North":"32050",
"NAD27 / West Virginia South":"32051",
"NAD27 / Wisconsin North":"32052",
"NAD27 / Wisconsin Central":"32053",
"NAD27 / Wisconsin South":"32054",
"NAD27 / Wyoming East":"32055",
"NAD27 / Wyoming East Central":"32056",
"NAD27 / Wyoming West Central":"32057",
"NAD27 / Wyoming West":"32058",
"NAD27 / Guatemala Norte":"32061",
"NAD27 / Guatemala Sur":"32062",
"NAD27 / BLM 14N (ftUS)":"32064",
"NAD27 / BLM 15N (ftUS)":"32065",
"NAD27 / BLM 16N (ftUS)":"32066",
"NAD27 / BLM 17N (ftUS)":"32067",
"NAD27 / BLM 14N (feet)":"32074",
"NAD27 / BLM 15N (feet)":"32075",
"NAD27 / BLM 16N (feet)":"32076",
"NAD27 / BLM 17N (feet)":"32077",
"NAD27 / MTM zone 1":"32081",
"NAD27 / MTM zone 2":"32082",
"NAD27 / MTM zone 3":"32083",
"NAD27 / MTM zone 4":"32084",
"NAD27 / MTM zone 5":"32085",
"NAD27 / MTM zone 6":"32086",
"NAD27 / Quebec Lambert":"32098",
"NAD27 / Louisiana Offshore":"32099",
"NAD83 / Montana":"32100",
"NAD83 / Nebraska":"32104",
"NAD83 / Nevada East":"32107",
"NAD83 / Nevada Central":"32108",
"NAD83 / Nevada West":"32109",
"NAD83 / New Hampshire":"32110",
"NAD83 / New Jersey":"32111",
"NAD83 / New Mexico East":"32112",
"NAD83 / New Mexico Central":"32113",
"NAD83 / New Mexico West":"32114",
"NAD83 / New York East":"32115",
"NAD83 / New York Central":"32116",
"NAD83 / New York West":"32117",
"NAD83 / New York Long Island":"32118",
"NAD83 / North Carolina":"32119",
"NAD83 / North Dakota North":"32120",
"NAD83 / North Dakota South":"32121",
"NAD83 / Ohio North":"32122",
"NAD83 / Ohio South":"32123",
"NAD83 / Oklahoma North":"32124",
"NAD83 / Oklahoma South":"32125",
"NAD83 / Oregon North":"32126",
"NAD83 / Oregon South":"32127",
"NAD83 / Pennsylvania North":"32128",
"NAD83 / Pennsylvania South":"32129",
"NAD83 / Rhode Island":"32130",
"NAD83 / South Carolina":"32133",
"NAD83 / South Dakota North":"32134",
"NAD83 / South Dakota South":"32135",
"NAD83 / Tennessee":"32136",
"NAD83 / Texas North":"32137",
"NAD83 / Texas North Central":"32138",
"NAD83 / Texas Central":"32139",
"NAD83 / Texas South Central":"32140",
"NAD83 / Texas South":"32141",
"NAD83 / Utah North":"32142",
"NAD83 / Utah Central":"32143",
"NAD83 / Utah South":"32144",
"NAD83 / Vermont":"32145",
"NAD83 / Virginia North":"32146",
"NAD83 / Virginia South":"32147",
"NAD83 / Washington North":"32148",
"NAD83 / Washington South":"32149",
"NAD83 / West Virginia North":"32150",
"NAD83 / West Virginia South":"32151",
"NAD83 / Wisconsin North":"32152",
"NAD83 / Wisconsin Central":"32153",
"NAD83 / Wisconsin South":"32154",
"NAD83 / Wyoming East":"32155",
"NAD83 / Wyoming East Central":"32156",
"NAD83 / Wyoming West Central":"32157",
"NAD83 / Wyoming West":"32158",
"NAD83 / Puerto Rico & Virgin Is.":"32161",
"NAD83 / BLM 14N (ftUS)":"32164",
"NAD83 / BLM 15N (ftUS)":"32165",
"NAD83 / BLM 16N (ftUS)":"32166",
"NAD83 / BLM 17N (ftUS)":"32167",
"NAD83 / SCoPQ zone 2":"32180",
"NAD83 / MTM zone 1":"32181",
"NAD83 / MTM zone 2":"32182",
"NAD83 / MTM zone 3":"32183",
"NAD83 / MTM zone 4":"32184",
"NAD83 / MTM zone 5":"32185",
"NAD83 / MTM zone 6":"32186",
"NAD83 / MTM zone 7":"32187",
"NAD83 / MTM zone 8":"32188",
"NAD83 / MTM zone 9":"32189",
"NAD83 / MTM zone 10":"32190",
"NAD83 / MTM zone 11":"32191",
"NAD83 / MTM zone 12":"32192",
"NAD83 / MTM zone 13":"32193",
"NAD83 / MTM zone 14":"32194",
"NAD83 / MTM zone 15":"32195",
"NAD83 / MTM zone 16":"32196",
"NAD83 / MTM zone 17":"32197",
"NAD83 / Quebec Lambert":"32198",
"NAD83 / Louisiana Offshore":"32199",
"WGS 72 / UTM zone 1N":"32201",
"WGS 72 / UTM zone 2N":"32202",
"WGS 72 / UTM zone 3N":"32203",
"WGS 72 / UTM zone 4N":"32204",
"WGS 72 / UTM zone 5N":"32205",
"WGS 72 / UTM zone 6N":"32206",
"WGS 72 / UTM zone 7N":"32207",
"WGS 72 / UTM zone 8N":"32208",
"WGS 72 / UTM zone 9N":"32209",
"WGS 72 / UTM zone 10N":"32210",
"WGS 72 / UTM zone 11N":"32211",
"WGS 72 / UTM zone 12N":"32212",
"WGS 72 / UTM zone 13N":"32213",
"WGS 72 / UTM zone 14N":"32214",
"WGS 72 / UTM zone 15N":"32215",
"WGS 72 / UTM zone 16N":"32216",
"WGS 72 / UTM zone 17N":"32217",
"WGS 72 / UTM zone 18N":"32218",
"WGS 72 / UTM zone 19N":"32219",
"WGS 72 / UTM zone 20N":"32220",
"WGS 72 / UTM zone 21N":"32221",
"WGS 72 / UTM zone 22N":"32222",
"WGS 72 / UTM zone 23N":"32223",
"WGS 72 / UTM zone 24N":"32224",
"WGS 72 / UTM zone 25N":"32225",
"WGS 72 / UTM zone 26N":"32226",
"WGS 72 / UTM zone 27N":"32227",
"WGS 72 / UTM zone 28N":"32228",
"WGS 72 / UTM zone 29N":"32229",
"WGS 72 / UTM zone 30N":"32230",
"WGS 72 / UTM zone 31N":"32231",
"WGS 72 / UTM zone 32N":"32232",
"WGS 72 / UTM zone 33N":"32233",
"WGS 72 / UTM zone 34N":"32234",
"WGS 72 / UTM zone 35N":"32235",
"WGS 72 / UTM zone 36N":"32236",
"WGS 72 / UTM zone 37N":"32237",
"WGS 72 / UTM zone 38N":"32238",
"WGS 72 / UTM zone 39N":"32239",
"WGS 72 / UTM zone 40N":"32240",
"WGS 72 / UTM zone 41N":"32241",
"WGS 72 / UTM zone 42N":"32242",
"WGS 72 / UTM zone 43N":"32243",
"WGS 72 / UTM zone 44N":"32244",
"WGS 72 / UTM zone 45N":"32245",
"WGS 72 / UTM zone 46N":"32246",
"WGS 72 / UTM zone 47N":"32247",
"WGS 72 / UTM zone 48N":"32248",
"WGS 72 / UTM zone 49N":"32249",
"WGS 72 / UTM zone 50N":"32250",
"WGS 72 / UTM zone 51N":"32251",
"WGS 72 / UTM zone 52N":"32252",
"WGS 72 / UTM zone 53N":"32253",
"WGS 72 / UTM zone 54N":"32254",
"WGS 72 / UTM zone 55N":"32255",
"WGS 72 / UTM zone 56N":"32256",
"WGS 72 / UTM zone 57N":"32257",
"WGS 72 / UTM zone 58N":"32258",
"WGS 72 / UTM zone 59N":"32259",
"WGS 72 / UTM zone 60N":"32260",
"WGS 72 / UTM zone 1S":"32301",
"WGS 72 / UTM zone 2S":"32302",
"WGS 72 / UTM zone 3S":"32303",
"WGS 72 / UTM zone 4S":"32304",
"WGS 72 / UTM zone 5S":"32305",
"WGS 72 / UTM zone 6S":"32306",
"WGS 72 / UTM zone 7S":"32307",
"WGS 72 / UTM zone 8S":"32308",
"WGS 72 / UTM zone 9S":"32309",
"WGS 72 / UTM zone 10S":"32310",
"WGS 72 / UTM zone 11S":"32311",
"WGS 72 / UTM zone 12S":"32312",
"WGS 72 / UTM zone 13S":"32313",
"WGS 72 / UTM zone 14S":"32314",
"WGS 72 / UTM zone 15S":"32315",
"WGS 72 / UTM zone 16S":"32316",
"WGS 72 / UTM zone 17S":"32317",
"WGS 72 / UTM zone 18S":"32318",
"WGS 72 / UTM zone 19S":"32319",
"WGS 72 / UTM zone 20S":"32320",
"WGS 72 / UTM zone 21S":"32321",
"WGS 72 / UTM zone 22S":"32322",
"WGS 72 / UTM zone 23S":"32323",
"WGS 72 / UTM zone 24S":"32324",
"WGS 72 / UTM zone 25S":"32325",
"WGS 72 / UTM zone 26S":"32326",
"WGS 72 / UTM zone 27S":"32327",
"WGS 72 / UTM zone 28S":"32328",
"WGS 72 / UTM zone 29S":"32329",
"WGS 72 / UTM zone 30S":"32330",
"WGS 72 / UTM zone 31S":"32331",
"WGS 72 / UTM zone 32S":"32332",
"WGS 72 / UTM zone 33S":"32333",
"WGS 72 / UTM zone 34S":"32334",
"WGS 72 / UTM zone 35S":"32335",
"WGS 72 / UTM zone 36S":"32336",
"WGS 72 / UTM zone 37S":"32337",
"WGS 72 / UTM zone 38S":"32338",
"WGS 72 / UTM zone 39S":"32339",
"WGS 72 / UTM zone 40S":"32340",
"WGS 72 / UTM zone 41S":"32341",
"WGS 72 / UTM zone 42S":"32342",
"WGS 72 / UTM zone 43S":"32343",
"WGS 72 / UTM zone 44S":"32344",
"WGS 72 / UTM zone 45S":"32345",
"WGS 72 / UTM zone 46S":"32346",
"WGS 72 / UTM zone 47S":"32347",
"WGS 72 / UTM zone 48S":"32348",
"WGS 72 / UTM zone 49S":"32349",
"WGS 72 / UTM zone 50S":"32350",
"WGS 72 / UTM zone 51S":"32351",
"WGS 72 / UTM zone 52S":"32352",
"WGS 72 / UTM zone 53S":"32353",
"WGS 72 / UTM zone 54S":"32354",
"WGS 72 / UTM zone 55S":"32355",
"WGS 72 / UTM zone 56S":"32356",
"WGS 72 / UTM zone 57S":"32357",
"WGS 72 / UTM zone 58S":"32358",
"WGS 72 / UTM zone 59S":"32359",
"WGS 72 / UTM zone 60S":"32360",
"WGS 72BE / UTM zone 1N":"32401",
"WGS 72BE / UTM zone 2N":"32402",
"WGS 72BE / UTM zone 3N":"32403",
"WGS 72BE / UTM zone 4N":"32404",
"WGS 72BE / UTM zone 5N":"32405",
"WGS 72BE / UTM zone 6N":"32406",
"WGS 72BE / UTM zone 7N":"32407",
"WGS 72BE / UTM zone 8N":"32408",
"WGS 72BE / UTM zone 9N":"32409",
"WGS 72BE / UTM zone 10N":"32410",
"WGS 72BE / UTM zone 11N":"32411",
"WGS 72BE / UTM zone 12N":"32412",
"WGS 72BE / UTM zone 13N":"32413",
"WGS 72BE / UTM zone 14N":"32414",
"WGS 72BE / UTM zone 15N":"32415",
"WGS 72BE / UTM zone 16N":"32416",
"WGS 72BE / UTM zone 17N":"32417",
"WGS 72BE / UTM zone 18N":"32418",
"WGS 72BE / UTM zone 19N":"32419",
"WGS 72BE / UTM zone 20N":"32420",
"WGS 72BE / UTM zone 21N":"32421",
"WGS 72BE / UTM zone 22N":"32422",
"WGS 72BE / UTM zone 23N":"32423",
"WGS 72BE / UTM zone 24N":"32424",
"WGS 72BE / UTM zone 25N":"32425",
"WGS 72BE / UTM zone 26N":"32426",
"WGS 72BE / UTM zone 27N":"32427",
"WGS 72BE / UTM zone 28N":"32428",
"WGS 72BE / UTM zone 29N":"32429",
"WGS 72BE / UTM zone 30N":"32430",
"WGS 72BE / UTM zone 31N":"32431",
"WGS 72BE / UTM zone 32N":"32432",
"WGS 72BE / UTM zone 33N":"32433",
"WGS 72BE / UTM zone 34N":"32434",
"WGS 72BE / UTM zone 35N":"32435",
"WGS 72BE / UTM zone 36N":"32436",
"WGS 72BE / UTM zone 37N":"32437",
"WGS 72BE / UTM zone 38N":"32438",
"WGS 72BE / UTM zone 39N":"32439",
"WGS 72BE / UTM zone 40N":"32440",
"WGS 72BE / UTM zone 41N":"32441",
"WGS 72BE / UTM zone 42N":"32442",
"WGS 72BE / UTM zone 43N":"32443",
"WGS 72BE / UTM zone 44N":"32444",
"WGS 72BE / UTM zone 45N":"32445",
"WGS 72BE / UTM zone 46N":"32446",
"WGS 72BE / UTM zone 47N":"32447",
"WGS 72BE / UTM zone 48N":"32448",
"WGS 72BE / UTM zone 49N":"32449",
"WGS 72BE / UTM zone 50N":"32450",
"WGS 72BE / UTM zone 51N":"32451",
"WGS 72BE / UTM zone 52N":"32452",
"WGS 72BE / UTM zone 53N":"32453",
"WGS 72BE / UTM zone 54N":"32454",
"WGS 72BE / UTM zone 55N":"32455",
"WGS 72BE / UTM zone 56N":"32456",
"WGS 72BE / UTM zone 57N":"32457",
"WGS 72BE / UTM zone 58N":"32458",
"WGS 72BE / UTM zone 59N":"32459",
"WGS 72BE / UTM zone 60N":"32460",
"WGS 72BE / UTM zone 1S":"32501",
"WGS 72BE / UTM zone 2S":"32502",
"WGS 72BE / UTM zone 3S":"32503",
"WGS 72BE / UTM zone 4S":"32504",
"WGS 72BE / UTM zone 5S":"32505",
"WGS 72BE / UTM zone 6S":"32506",
"WGS 72BE / UTM zone 7S":"32507",
"WGS 72BE / UTM zone 8S":"32508",
"WGS 72BE / UTM zone 9S":"32509",
"WGS 72BE / UTM zone 10S":"32510",
"WGS 72BE / UTM zone 11S":"32511",
"WGS 72BE / UTM zone 12S":"32512",
"WGS 72BE / UTM zone 13S":"32513",
"WGS 72BE / UTM zone 14S":"32514",
"WGS 72BE / UTM zone 15S":"32515",
"WGS 72BE / UTM zone 16S":"32516",
"WGS 72BE / UTM zone 17S":"32517",
"WGS 72BE / UTM zone 18S":"32518",
"WGS 72BE / UTM zone 19S":"32519",
"WGS 72BE / UTM zone 20S":"32520",
"WGS 72BE / UTM zone 21S":"32521",
"WGS 72BE / UTM zone 22S":"32522",
"WGS 72BE / UTM zone 23S":"32523",
"WGS 72BE / UTM zone 24S":"32524",
"WGS 72BE / UTM zone 25S":"32525",
"WGS 72BE / UTM zone 26S":"32526",
"WGS 72BE / UTM zone 27S":"32527",
"WGS 72BE / UTM zone 28S":"32528",
"WGS 72BE / UTM zone 29S":"32529",
"WGS 72BE / UTM zone 30S":"32530",
"WGS 72BE / UTM zone 31S":"32531",
"WGS 72BE / UTM zone 32S":"32532",
"WGS 72BE / UTM zone 33S":"32533",
"WGS 72BE / UTM zone 34S":"32534",
"WGS 72BE / UTM zone 35S":"32535",
"WGS 72BE / UTM zone 36S":"32536",
"WGS 72BE / UTM zone 37S":"32537",
"WGS 72BE / UTM zone 38S":"32538",
"WGS 72BE / UTM zone 39S":"32539",
"WGS 72BE / UTM zone 40S":"32540",
"WGS 72BE / UTM zone 41S":"32541",
"WGS 72BE / UTM zone 42S":"32542",
"WGS 72BE / UTM zone 43S":"32543",
"WGS 72BE / UTM zone 44S":"32544",
"WGS 72BE / UTM zone 45S":"32545",
"WGS 72BE / UTM zone 46S":"32546",
"WGS 72BE / UTM zone 47S":"32547",
"WGS 72BE / UTM zone 48S":"32548",
"WGS 72BE / UTM zone 49S":"32549",
"WGS 72BE / UTM zone 50S":"32550",
"WGS 72BE / UTM zone 51S":"32551",
"WGS 72BE / UTM zone 52S":"32552",
"WGS 72BE / UTM zone 53S":"32553",
"WGS 72BE / UTM zone 54S":"32554",
"WGS 72BE / UTM zone 55S":"32555",
"WGS 72BE / UTM zone 56S":"32556",
"WGS 72BE / UTM zone 57S":"32557",
"WGS 72BE / UTM zone 58S":"32558",
"WGS 72BE / UTM zone 59S":"32559",
"WGS 72BE / UTM zone 60S":"32560",
"WGS 84 / UTM grid system (northern hemisphere)":"32600",
"WGS 84 / UTM zone 1N":"32601",
"WGS 84 / UTM zone 2N":"32602",
"WGS 84 / UTM zone 3N":"32603",
"WGS 84 / UTM zone 4N":"32604",
"WGS 84 / UTM zone 5N":"32605",
"WGS 84 / UTM zone 6N":"32606",
"WGS 84 / UTM zone 7N":"32607",
"WGS 84 / UTM zone 8N":"32608",
"WGS 84 / UTM zone 9N":"32609",
"WGS 84 / UTM zone 10N":"32610",
"WGS 84 / UTM zone 11N":"32611",
"WGS 84 / UTM zone 12N":"32612",
"WGS 84 / UTM zone 13N":"32613",
"WGS 84 / UTM zone 14N":"32614",
"WGS 84 / UTM zone 15N":"32615",
"WGS 84 / UTM zone 16N":"32616",
"WGS 84 / UTM zone 17N":"32617",
"WGS 84 / UTM zone 18N":"32618",
"WGS 84 / UTM zone 19N":"32619",
"WGS 84 / UTM zone 20N":"32620",
"WGS 84 / UTM zone 21N":"32621",
"WGS 84 / UTM zone 22N":"32622",
"WGS 84 / UTM zone 23N":"32623",
"WGS 84 / UTM zone 24N":"32624",
"WGS 84 / UTM zone 25N":"32625",
"WGS 84 / UTM zone 26N":"32626",
"WGS 84 / UTM zone 27N":"32627",
"WGS 84 / UTM zone 28N":"32628",
"WGS 84 / UTM zone 29N":"32629",
"WGS 84 / UTM zone 30N":"32630",
"WGS 84 / UTM zone 31N":"32631",
"WGS 84 / UTM zone 32N":"32632",
"WGS 84 / UTM zone 33N":"32633",
"WGS 84 / UTM zone 34N":"32634",
"WGS 84 / UTM zone 35N":"32635",
"WGS 84 / UTM zone 36N":"32636",
"WGS 84 / UTM zone 37N":"32637",
"WGS 84 / UTM zone 38N":"32638",
"WGS 84 / UTM zone 39N":"32639",
"WGS 84 / UTM zone 40N":"32640",
"WGS 84 / UTM zone 41N":"32641",
"WGS 84 / UTM zone 42N":"32642",
"WGS 84 / UTM zone 43N":"32643",
"WGS 84 / UTM zone 44N":"32644",
"WGS 84 / UTM zone 45N":"32645",
"WGS 84 / UTM zone 46N":"32646",
"WGS 84 / UTM zone 47N":"32647",
"WGS 84 / UTM zone 48N":"32648",
"WGS 84 / UTM zone 49N":"32649",
"WGS 84 / UTM zone 50N":"32650",
"WGS 84 / UTM zone 51N":"32651",
"WGS 84 / UTM zone 52N":"32652",
"WGS 84 / UTM zone 53N":"32653",
"WGS 84 / UTM zone 54N":"32654",
"WGS 84 / UTM zone 55N":"32655",
"WGS 84 / UTM zone 56N":"32656",
"WGS 84 / UTM zone 57N":"32657",
"WGS 84 / UTM zone 58N":"32658",
"WGS 84 / UTM zone 59N":"32659",
"WGS 84 / UTM zone 60N":"32660",
"WGS 84 / UPS North (N,E)":"32661",
"WGS 84 / Plate Carree":"32662",
"WGS 84 / World Equidistant Cylindrical":"32663",
"WGS 84 / BLM 14N (ftUS)":"32664",
"WGS 84 / BLM 15N (ftUS)":"32665",
"WGS 84 / BLM 16N (ftUS)":"32666",
"WGS 84 / BLM 17N (ftUS)":"32667",
"WGS 84 / UTM grid system (southern hemisphere)":"32700",
"WGS 84 / UTM zone 1S":"32701",
"WGS 84 / UTM zone 2S":"32702",
"WGS 84 / UTM zone 3S":"32703",
"WGS 84 / UTM zone 4S":"32704",
"WGS 84 / UTM zone 5S":"32705",
"WGS 84 / UTM zone 6S":"32706",
"WGS 84 / UTM zone 7S":"32707",
"WGS 84 / UTM zone 8S":"32708",
"WGS 84 / UTM zone 9S":"32709",
"WGS 84 / UTM zone 10S":"32710",
"WGS 84 / UTM zone 11S":"32711",
"WGS 84 / UTM zone 12S":"32712",
"WGS 84 / UTM zone 13S":"32713",
"WGS 84 / UTM zone 14S":"32714",
"WGS 84 / UTM zone 15S":"32715",
"WGS 84 / UTM zone 16S":"32716",
"WGS 84 / UTM zone 17S":"32717",
"WGS 84 / UTM zone 18S":"32718",
"WGS 84 / UTM zone 19S":"32719",
"WGS 84 / UTM zone 20S":"32720",
"WGS 84 / UTM zone 21S":"32721",
"WGS 84 / UTM zone 22S":"32722",
"WGS 84 / UTM zone 23S":"32723",
"WGS 84 / UTM zone 24S":"32724",
"WGS 84 / UTM zone 25S":"32725",
"WGS 84 / UTM zone 26S":"32726",
"WGS 84 / UTM zone 27S":"32727",
"WGS 84 / UTM zone 28S":"32728",
"WGS 84 / UTM zone 29S":"32729",
"WGS 84 / UTM zone 30S":"32730",
"WGS 84 / UTM zone 31S":"32731",
"WGS 84 / UTM zone 32S":"32732",
"WGS 84 / UTM zone 33S":"32733",
"WGS 84 / UTM zone 34S":"32734",
"WGS 84 / UTM zone 35S":"32735",
"WGS 84 / UTM zone 36S":"32736",
"WGS 84 / UTM zone 37S":"32737",
"WGS 84 / UTM zone 38S":"32738",
"WGS 84 / UTM zone 39S":"32739",
"WGS 84 / UTM zone 40S":"32740",
"WGS 84 / UTM zone 41S":"32741",
"WGS 84 / UTM zone 42S":"32742",
"WGS 84 / UTM zone 43S":"32743",
"WGS 84 / UTM zone 44S":"32744",
"WGS 84 / UTM zone 45S":"32745",
"WGS 84 / UTM zone 46S":"32746",
"WGS 84 / UTM zone 47S":"32747",
"WGS 84 / UTM zone 48S":"32748",
"WGS 84 / UTM zone 49S":"32749",
"WGS 84 / UTM zone 50S":"32750",
"WGS 84 / UTM zone 51S":"32751",
"WGS 84 / UTM zone 52S":"32752",
"WGS 84 / UTM zone 53S":"32753",
"WGS 84 / UTM zone 54S":"32754",
"WGS 84 / UTM zone 55S":"32755",
"WGS 84 / UTM zone 56S":"32756",
"WGS 84 / UTM zone 57S":"32757",
"WGS 84 / UTM zone 58S":"32758",
"WGS 84 / UTM zone 59S":"32759",
"WGS 84 / UTM zone 60S":"32760",
"WGS 84 / UPS South (N,E)":"32761",
"WGS 84 / TM 36 SE":"32766",
"Greek (deg)":"61206405",
"GGRS87 (deg)":"61216405",
"ATS77 (deg)":"61226405",
"KKJ (deg)":"61236405",
"RT90 (deg)":"61246405",
"LKS94 (ETRS89) (deg)":"61266405",
"LKS94 (ETRS89) (3D deg)":"61266413",
"Tete (deg)":"61276405",
"Madzansua (deg)":"61286405",
"Observatario (deg)":"61296405",
"Moznet (deg)":"61306405",
"Moznet (3D deg)":"61306413",
"Indian 1960 (deg)":"61316405",
"FD58 (deg)":"61326405",
"EST92 (deg)":"61336405",
"PDO Survey Datum 1993 (deg)":"61346405",
"Old Hawaiian (deg)":"61356405",
"St. Lawrence Island (deg)":"61366405",
"St. Paul Island (deg)":"61376405",
"St. George Island (deg)":"61386405",
"Puerto Rico (deg)":"61396405",
"NAD83(CSRS) (deg)":"61406405",
"NAD83(CSRS) (3D deg)":"61406413",
"Israel (deg)":"61416405",
"Locodjo 1965 (deg)":"61426405",
"Abidjan 1987 (deg)":"61436405",
"Kalianpur 1937 (deg)":"61446405",
"Kalianpur 1962 (deg)":"61456405",
"Kalianpur 1975 (deg)":"61466405",
"Hanoi 1972 (deg)":"61476405",
"Hartebeesthoek94 (deg)":"61486405",
"Hartebeesthoek94 (3D deg)":"61486413",
"CH1903 (deg)":"61496405",
"CH1903+ (deg)":"61506405",
"CHTRF95 (deg)":"61516405",
"CHTRF95 (3D deg)":"61516413",
"NAD83(HARN) (deg)":"61526405",
"NAD83(HARN) (3D deg)":"61526413",
"Rassadiran (deg)":"61536405",
"ED50(ED77) (deg)":"61546405",
"Dabola 1981 (deg)":"61556405",
"S-JTSK (deg)":"61566405",
"Mount Dillon (deg)":"61576405",
"Naparima 1955 (deg)":"61586405",
"ELD79 (deg)":"61596405",
"Chos Malal 1914 (deg)":"61606405",
"Pampa del Castillo (deg)":"61616405",
"Korean 1985 (deg)":"61626405",
"Yemen NGN96 (deg)":"61636405",
"Yemen NGN96 (3D deg)":"61636413",
"South Yemen (deg)":"61646405",
"Bissau (deg)":"61656405",
"Korean 1995 (deg)":"61666405",
"NZGD2000 (deg)":"61676405",
"NZGD2000 (3D deg)":"61676413",
"Accra (deg)":"61686405",
"American Samoa 1962 (deg)":"61696405",
"SIRGAS (deg)":"61706405",
"SIRGAS (3D deg)":"61706413",
"RGF93 (deg)":"61716405",
"RGF93 (3D deg)":"61716413",
"IRENET95 (deg)":"61736405",
"IRENET95 (3D deg)":"61736413",
"Sierra Leone 1924 (deg)":"61746405",
"Sierra Leone 1968 (deg)":"61756405",
"Australian Antarctic (deg)":"61766405",
"Australian Antarctic (3D deg)":"61766413",
"Pulkovo 1942(83) (deg)":"61786405",
"Pulkovo 1942(58) (deg)":"61796405",
"EST97 (deg)":"61806405",
"EST97 (3D deg)":"61806413",
"Luxembourg 1930 (deg)":"61816405",
"Azores Occidental 1939 (deg)":"61826405",
"Azores Central 1948 (deg)":"61836405",
"Azores Oriental 1940 (deg)":"61846405",
"OSNI 1952 (deg)":"61886405",
"REGVEN (deg)":"61896405",
"REGVEN (3D deg)":"61896413",
"POSGAR 98 (deg)":"61906405",
"POSGAR 98 (3D deg)":"61906413",
"Albanian 1987 (deg)":"61916405",
"Douala 1948 (deg)":"61926405",
"Manoca 1962 (deg)":"61936405",
"Qornoq 1927 (deg)":"61946405",
"Scoresbysund 1952 (deg)":"61956405",
"Ammassalik 1958 (deg)":"61966405",
"Garoua (deg)":"61976405",
"Kousseri (deg)":"61986405",
"Egypt 1930 (deg)":"61996405",
"Pulkovo 1995 (deg)":"62006405",
"Adindan (deg)":"62016405",
"AGD66 (deg)":"62026405",
"AGD84 (deg)":"62036405",
"Ain el Abd (deg)":"62046405",
"Afgooye (deg)":"62056405",
"Agadez (deg)":"62066405",
"Lisbon (deg)":"62076405",
"Aratu (deg)":"62086405",
"Arc 1950 (deg)":"62096405",
"Arc 1960 (deg)":"62106405",
"Batavia (deg)":"62116405",
"Barbados 1938 (deg)":"62126405",
"Beduaram (deg)":"62136405",
"Beijing 1954 (deg)":"62146405",
"Belge 1950 (deg)":"62156405",
"Bermuda 1957 (deg)":"62166405",
"Bogota 1975 (deg)":"62186405",
"Bukit Rimpah (deg)":"62196405",
"Camacupa (deg)":"62206405",
"Campo Inchauspe (deg)":"62216405",
"Cape (deg)":"62226405",
"Carthage (deg)":"62236405",
"Chua (deg)":"62246405",
"Corrego Alegre (deg)":"62256405",
"Deir ez Zor (deg)":"62276405",
"Egypt 1907 (deg)":"62296405",
"ED50 (deg)":"62306405",
"ED87 (deg)":"62316405",
"Fahud (deg)":"62326405",
"Gandajika 1970 (deg)":"62336405",
"Hu Tzu Shan (deg)":"62366405",
"HD72 (deg)":"62376405",
"ID74 (deg)":"62386405",
"Indian 1954 (deg)":"62396405",
"Indian 1975 (deg)":"62406405",
"Jamaica 1875 (deg)":"62416405",
"JAD69 (deg)":"62426405",
"Kalianpur 1880 (deg)":"62436405",
"Kandawala (deg)":"62446405",
"Kertau (deg)":"62456405",
"KOC (deg)":"62466405",
"La Canoa (deg)":"62476405",
"PSAD56 (deg)":"62486405",
"Lake (deg)":"62496405",
"Leigon (deg)":"62506405",
"Liberia 1964 (deg)":"62516405",
"Lome (deg)":"62526405",
"Luzon 1911 (deg)":"62536405",
"Hito XVIII 1963 (deg)":"62546405",
"Herat North (deg)":"62556405",
"Mahe 1971 (deg)":"62566405",
"Makassar (deg)":"62576405",
"ETRS89 (deg)":"62586405",
"ETRS89 (3D deg)":"62586413",
"Malongo 1987 (deg)":"62596405",
"Merchich (deg)":"62616405",
"Massawa (deg)":"62626405",
"Minna (deg)":"62636405",
"Mhast (deg)":"62646405",
"Monte Mario (deg)":"62656405",
"M'poraloko (deg)":"62666405",
"NAD27 (deg)":"62676405",
"NAD27 Michigan (deg)":"62686405",
"NAD83 (deg)":"62696405",
"Nahrwan 1967 (deg)":"62706405",
"Naparima 1972 (deg)":"62716405",
"NZGD49 (deg)":"62726405",
"NGO 1948 (deg)":"62736405",
"Datum 73 (deg)":"62746405",
"NTF (deg)":"62756405",
"NSWC 9Z-2 (deg)":"62766405",
"OSGB 1936 (deg)":"62776405",
"OSGB70 (deg)":"62786405",
"OS(SN)80 (deg)":"62796405",
"Padang (deg)":"62806405",
"Palestine 1923 (deg)":"62816405",
"Pointe Noire (deg)":"62826405",
"GDA94 (deg)":"62836405",
"GDA94 (3D deg)":"62836413",
"Pulkovo 1942 (deg)":"62846405",
"Qatar 1974 (deg)":"62856405",
"Qatar 1948 (deg)":"62866405",
"Loma Quintana (deg)":"62886405",
"Amersfoort (deg)":"62896405",
"Sapper Hill 1943 (deg)":"62926405",
"Schwarzeck (deg)":"62936405",
"Serindung (deg)":"62956405",
"Tananarive (deg)":"62976405",
"Timbalai 1948 (deg)":"62986405",
"TM65 (deg)":"62996405",
"TM75 (deg)":"63006405",
"Tokyo (deg)":"63016405",
"Trinidad 1903 (deg)":"63026405",
"TC(1948) (deg)":"63036405",
"Voirol 1875 (deg)":"63046405",
"Bern 1938 (deg)":"63066405",
"Nord Sahara 1959 (deg)":"63076405",
"RT38 (deg)":"63086405",
"Yacare (deg)":"63096405",
"Yoff (deg)":"63106405",
"Zanderij (deg)":"63116405",
"MGI (deg)":"63126405",
"Belge 1972 (deg)":"63136405",
"DHDN (deg)":"63146405",
"Conakry 1905 (deg)":"63156405",
"Dealul Piscului 1933 (deg)":"63166405",
"Dealul Piscului 1970 (deg)":"63176405",
"NGN (deg)":"63186405",
"KUDAMS (deg)":"63196405",
"WGS 72 (deg)":"63226405",
"WGS 72BE (deg)":"63246405",
"WGS 84 (deg)":"63266405",
"WGS 84 (degH)":"63266406",
"WGS 84 (Hdeg)":"63266407",
"WGS 84 (DM)":"63266408",
"WGS 84 (DMH)":"63266409",
"WGS 84 (HDM)":"63266410",
"WGS 84 (DMS)":"63266411",
"WGS 84 (HDMS)":"63266412",
"WGS 84 (3D deg)":"63266413",
"WGS 84 (3D degH)":"63266414",
"WGS 84 (3D Hdeg)":"63266415",
"WGS 84 (3D DM)":"63266416",
"WGS 84 (3D DMH)":"63266417",
"WGS 84 (3D HDM)":"63266418",
"WGS 84 (3D DMS)":"63266419",
"WGS 84 (3D HDMS)":"63266420",
"Anguilla 1957 (deg)":"66006405",
"Antigua 1943 (deg)":"66016405",
"Dominica 1945 (deg)":"66026405",
"Grenada 1953 (deg)":"66036405",
"Montserrat 1958 (deg)":"66046405",
"St. Kitts 1955 (deg)":"66056405",
"St. Lucia 1955 (deg)":"66066405",
"St. Vincent 1945 (deg)":"66076405",
"NAD27(76) (deg)":"66086405",
"NAD27(CGQ77) (deg)":"66096405",
"Xian 1980 (deg)":"66106405",
"Hong Kong 1980 (deg)":"66116405",
"JGD2000 (deg)":"66126405",
"JGD2000 (3D deg)":"66126413",
"Segara (deg)":"66136405",
"QND95 (deg)":"66146405",
"Porto Santo (deg)":"66156405",
"Selvagem Grande (deg)":"66166405",
"SAD69 (deg)":"66186405",
"SWEREF99 (deg)":"66196405",
"SWEREF99 (3D deg)":"66196413",
"Point 58 (deg)":"66206405",
"Fort Marigot (deg)":"66216405",
"Sainte Anne (deg)":"66226405",
"CSG67 (deg)":"66236405",
"RGFG95 (deg)":"66246405",
"RGFG95 (3D deg)":"66246413",
"Fort Desaix (deg)":"66256405",
"Piton des Neiges (deg)":"66266405",
"RGR92 (deg)":"66276405",
"RGR92 (3D deg)":"66276413",
"Tahiti (deg)":"66286405",
"Tahaa (deg)":"66296405",
"IGN72 Nuku Hiva (deg)":"66306405",
"K0 1949 (deg)":"66316405",
"Combani 1950 (deg)":"66326405",
"IGN56 Lifou (deg)":"66336405",
"IGN72 Grande Terre (deg)":"66346405",
"ST87 Ouvea (deg)":"66356405",
"Petrels 1972 (deg)":"66366405",
"Perroud 1950 (deg)":"66376405",
"Saint Pierre et Miquelon 1950 (deg)":"66386405",
"MOP78 (deg)":"66396405",
"RRAF 1991 (deg)":"66406405",
"RRAF 1991 (3D deg)":"66406413",
"IGN53 Mare (deg)":"66416405",
"ST84 Ile des Pins (deg)":"66426405",
"ST71 Belep (deg)":"66436405",
"NEA74 Noumea (deg)":"66446405",
"RGNC 1991 (deg)":"66456405",
"RGNC 1991 (3D deg)":"66456413",
"Grand Comoros (deg)":"66466405",
"Reykjavik 1900 (deg)":"66576405",
"Hjorsey 1955 (deg)":"66586405",
"ISN93 (deg)":"66596405",
"ISN93 (3D deg)":"66596413",
"Helle 1954 (deg)":"66606405",
"LKS92 (deg)":"66616405",
"LKS92 (3D deg)":"66616413",
"Porto Santo 1995 (deg)":"66636405",
"Azores Oriental 1995 (deg)":"66646405",
"Azores Central 1995 (deg)":"66656405",
"Lisbon 1890 (deg)":"66666405",
"IKBD-92 (deg)":"66676405",
"Bern 1898 (Bern) (deg)":"68016405",
"Bogota 1975 (Bogota) (deg)":"68026405",
"Lisbon (Lisbon) (deg)":"68036405",
"Makassar (Jakarta) (deg)":"68046405",
"MGI (Ferro) (deg)":"68056405",
"Monte Mario (Rome) (deg)":"68066405",
"Padang (Jakarta) (deg)":"68086405",
"Belge 1950 (Brussels) (deg)":"68096405",
"Batavia (Jakarta) (deg)":"68136405",
"RT38 (Stockholm) (deg)":"68146405",
"Greek (Athens) (deg)":"68156405",
"S-JTSK (Ferro) (deg)":"68186405",
"Segara (Jakarta) (deg)":"68206405",
"Madrid 1870 (Madrid) (deg)":"69036405",
}

epsg2crs = {
"2000":"Anguilla 1957 / British West Indies Grid",
"2001":"Antigua 1943 / British West Indies Grid",
"2002":"Dominica 1945 / British West Indies Grid",
"2003":"Grenada 1953 / British West Indies Grid",
"2004":"Montserrat 1958 / British West Indies Grid",
"2005":"St. Kitts 1955 / British West Indies Grid",
"2006":"St. Lucia 1955 / British West Indies Grid",
"2007":"St. Vincent 45 / British West Indies Grid",
"2008":"NAD27(CGQ77) / SCoPQ zone 2",
"2009":"NAD27(CGQ77) / SCoPQ zone 3",
"2010":"NAD27(CGQ77) / SCoPQ zone 4",
"2011":"NAD27(CGQ77) / SCoPQ zone 5",
"2012":"NAD27(CGQ77) / SCoPQ zone 6",
"2013":"NAD27(CGQ77) / SCoPQ zone 7",
"2014":"NAD27(CGQ77) / SCoPQ zone 8",
"2015":"NAD27(CGQ77) / SCoPQ zone 9",
"2016":"NAD27(CGQ77) / SCoPQ zone 10",
"2017":"NAD27(76) / MTM zone 8",
"2018":"NAD27(76) / MTM zone 9",
"2019":"NAD27(76) / MTM zone 10",
"2020":"NAD27(76) / MTM zone 11",
"2021":"NAD27(76) / MTM zone 12",
"2022":"NAD27(76) / MTM zone 13",
"2023":"NAD27(76) / MTM zone 14",
"2024":"NAD27(76) / MTM zone 15",
"2025":"NAD27(76) / MTM zone 16",
"2026":"NAD27(76) / MTM zone 17",
"2027":"NAD27(76) / UTM zone 15N",
"2028":"NAD27(76) / UTM zone 16N",
"2029":"NAD27(76) / UTM zone 17N",
"2030":"NAD27(76) / UTM zone 18N",
"2031":"NAD27(CGQ77) / UTM zone 17N",
"2032":"NAD27(CGQ77) / UTM zone 18N",
"2033":"NAD27(CGQ77) / UTM zone 19N",
"2034":"NAD27(CGQ77) / UTM zone 20N",
"2035":"NAD27(CGQ77) / UTM zone 21N",
"2036":"NAD83(CSRS98) / New Brunswick Stereo",
"2037":"NAD83(CSRS98) / UTM zone 19N",
"2038":"NAD83(CSRS98) / UTM zone 20N",
"2039":"Israel 1993 / Israeli TM Grid",
"2040":"Locodjo 1965 / UTM zone 30N",
"2041":"Abidjan 1987 / UTM zone 30N",
"2042":"Locodjo 1965 / UTM zone 29N",
"2043":"Abidjan 1987 / UTM zone 29N",
"2044":"Hanoi 1972 / Gauss-Kruger zone 18",
"2045":"Hanoi 1972 / Gauss-Kruger zone 19",
"2046":"Hartebeesthoek94 / Lo15",
"2047":"Hartebeesthoek94 / Lo17",
"2048":"Hartebeesthoek94 / Lo19",
"2049":"Hartebeesthoek94 / Lo21",
"2050":"Hartebeesthoek94 / Lo23",
"2051":"Hartebeesthoek94 / Lo25",
"2052":"Hartebeesthoek94 / Lo27",
"2053":"Hartebeesthoek94 / Lo29",
"2054":"Hartebeesthoek94 / Lo31",
"2055":"Hartebeesthoek94 / Lo33",
"2056":"CH1903+ / LV95",
"2057":"Rassadiran / Nakhl e Taqi",
"2058":"ED50(ED77) / UTM zone 38N",
"2059":"ED50(ED77) / UTM zone 39N",
"2060":"ED50(ED77) / UTM zone 40N",
"2061":"ED50(ED77) / UTM zone 41N",
"2062":"Madrid 1870 (Madrid) / Spain",
"2063":"Dabola 1981 / UTM zone 28N",
"2064":"Dabola 1981 / UTM zone 29N",
"2065":"S-JTSK (Ferro) / Krovak",
"2066":"Mount Dillon / Tobago Grid",
"2067":"Naparima 1955 / UTM zone 20N",
"2068":"ELD79 / Libya zone 5",
"2069":"ELD79 / Libya zone 6",
"2070":"ELD79 / Libya zone 7",
"2071":"ELD79 / Libya zone 8",
"2072":"ELD79 / Libya zone 9",
"2073":"ELD79 / Libya zone 10",
"2074":"ELD79 / Libya zone 11",
"2075":"ELD79 / Libya zone 12",
"2076":"ELD79 / Libya zone 13",
"2077":"ELD79 / UTM zone 32N",
"2078":"ELD79 / UTM zone 33N",
"2079":"ELD79 / UTM zone 34N",
"2080":"ELD79 / UTM zone 35N",
"2081":"Chos Malal 1914 / Argentina 2",
"2082":"Pampa del Castillo / Argentina 2",
"2083":"Hito XVIII 1963 / Argentina 2",
"2084":"Hito XVIII 1963 / UTM zone 19S",
"2085":"NAD27 / Cuba Norte",
"2086":"NAD27 / Cuba Sur",
"2087":"ELD79 / TM 12 NE",
"2088":"Carthage / TM 11 NE",
"2089":"Yemen NGN96 / UTM zone 38N",
"2090":"Yemen NGN96 / UTM zone 39N",
"2091":"South Yemen / Gauss Kruger zone 8",
"2092":"South Yemen / Gauss Kruger zone 9",
"2093":"Hanoi 1972 / GK 106 NE",
"2094":"WGS 72BE / TM 106 NE",
"2095":"Bissau / UTM zone 28N",
"2096":"Korean 1985 / East Belt",
"2097":"Korean 1985 / Central Belt",
"2098":"Korean 1985 / West Belt",
"2099":"Qatar 1948 / Qatar Grid",
"2100":"GGRS87 / Greek Grid",
"2101":"Lake / Maracaibo Grid M1",
"2102":"Lake / Maracaibo Grid",
"2103":"Lake / Maracaibo Grid M3",
"2104":"Lake / Maracaibo La Rosa Grid",
"2105":"NZGD2000 / Mount Eden 2000",
"2106":"NZGD2000 / Bay of Plenty 2000",
"2107":"NZGD2000 / Poverty Bay 2000",
"2108":"NZGD2000 / Hawkes Bay 2000",
"2109":"NZGD2000 / Taranaki 2000",
"2110":"NZGD2000 / Tuhirangi 2000",
"2111":"NZGD2000 / Wanganui 2000",
"2112":"NZGD2000 / Wairarapa 2000",
"2113":"NZGD2000 / Wellington 2000",
"2114":"NZGD2000 / Collingwood 2000",
"2115":"NZGD2000 / Nelson 2000",
"2116":"NZGD2000 / Karamea 2000",
"2117":"NZGD2000 / Buller 2000",
"2118":"NZGD2000 / Grey 2000",
"2119":"NZGD2000 / Amuri 2000",
"2120":"NZGD2000 / Marlborough 2000",
"2121":"NZGD2000 / Hokitika 2000",
"2122":"NZGD2000 / Okarito 2000",
"2123":"NZGD2000 / Jacksons Bay 2000",
"2124":"NZGD2000 / Mount Pleasant 2000",
"2125":"NZGD2000 / Gawler 2000",
"2126":"NZGD2000 / Timaru 2000",
"2127":"NZGD2000 / Lindis Peak 2000",
"2128":"NZGD2000 / Mount Nicholas 2000",
"2129":"NZGD2000 / Mount York 2000",
"2130":"NZGD2000 / Observation Point 2000",
"2131":"NZGD2000 / North Taieri 2000",
"2132":"NZGD2000 / Bluff 2000",
"2133":"NZGD2000 / UTM zone 58S",
"2134":"NZGD2000 / UTM zone 59S",
"2135":"NZGD2000 / UTM zone 60S",
"2136":"Accra / Ghana National Grid",
"2137":"Accra / TM 1 NW",
"2138":"NAD27(CGQ77) / Quebec Lambert",
"2139":"NAD83(CSRS98) / SCoPQ zone 2",
"2140":"NAD83(CSRS98) / MTM zone 3",
"2141":"NAD83(CSRS98) / MTM zone 4",
"2142":"NAD83(CSRS98) / MTM zone 5",
"2143":"NAD83(CSRS98) / MTM zone 6",
"2144":"NAD83(CSRS98) / MTM zone 7",
"2145":"NAD83(CSRS98) / MTM zone 8",
"2146":"NAD83(CSRS98) / MTM zone 9",
"2147":"NAD83(CSRS98) / MTM zone 10",
"2148":"NAD83(CSRS98) / UTM zone 21N",
"2149":"NAD83(CSRS98) / UTM zone 18N",
"2150":"NAD83(CSRS98) / UTM zone 17N",
"2151":"NAD83(CSRS98) / UTM zone 13N",
"2152":"NAD83(CSRS98) / UTM zone 12N",
"2153":"NAD83(CSRS98) / UTM zone 11N",
"2154":"RGF93 / Lambert-93",
"2155":"American Samoa 1962 / American Samoa Lambert",
"2156":"NAD83(HARN) / UTM zone 59S",
"2157":"IRENET95 / Irish Transverse Mercator",
"2158":"IRENET95 / UTM zone 29N",
"2159":"Sierra Leone 1924 / New Colony Grid",
"2160":"Sierra Leone 1924 / New War Office Grid",
"2161":"Sierra Leone 1968 / UTM zone 28N",
"2162":"Sierra Leone 1968 / UTM zone 29N",
"2163":"US National Atlas Equal Area",
"2164":"Locodjo 1965 / TM 5 NW",
"2165":"Abidjan 1987 / TM 5 NW",
"2166":"Pulkovo 1942(83) / Gauss Kruger zone 3",
"2167":"Pulkovo 1942(83) / Gauss Kruger zone 4",
"2168":"Pulkovo 1942(83) / Gauss Kruger zone 5",
"2169":"Luxembourg 1930 / Gauss",
"2170":"MGI / Slovenia Grid",
"2171":"Pulkovo 1942(58) / Poland zone I",
"2172":"Pulkovo 1942(58) / Poland zone II",
"2173":"Pulkovo 1942(58) / Poland zone III",
"2174":"Pulkovo 1942(58) / Poland zone IV",
"2175":"Pulkovo 1942(58) / Poland zone V",
"2176":"ETRS89 / Poland CS2000 zone 5",
"2177":"ETRS89 / Poland CS2000 zone 6",
"2178":"ETRS89 / Poland CS2000 zone 7",
"2179":"ETRS89 / Poland CS2000 zone 8",
"2180":"ETRS89 / Poland CS92",
"2188":"Azores Occidental 1939 / UTM zone 25N",
"2189":"Azores Central 1948 / UTM zone 26N",
"2190":"Azores Oriental 1940 / UTM zone 26N",
"2191":"Madeira 1936 / UTM zone 28N",
"2192":"ED50 / France EuroLambert",
"2193":"NZGD2000 / New Zealand Transverse Mercator 2000",
"2194":"American Samoa 1962 / American Samoa Lambert",
"2195":"NAD83(HARN) / UTM zone 2S",
"2196":"ETRS89 / Kp2000 Jutland",
"2197":"ETRS89 / Kp2000 Zealand",
"2198":"ETRS89 / Kp2000 Bornholm",
"2199":"Albanian 1987 / Gauss Kruger zone 4",
"2200":"ATS77 / New Brunswick Stereographic (ATS77)",
"2201":"REGVEN / UTM zone 18N",
"2202":"REGVEN / UTM zone 19N",
"2203":"REGVEN / UTM zone 20N",
"2204":"NAD27 / Tennessee",
"2205":"NAD83 / Kentucky North",
"2206":"ED50 / 3-degree Gauss-Kruger zone 9",
"2207":"ED50 / 3-degree Gauss-Kruger zone 10",
"2208":"ED50 / 3-degree Gauss-Kruger zone 11",
"2209":"ED50 / 3-degree Gauss-Kruger zone 12",
"2210":"ED50 / 3-degree Gauss-Kruger zone 13",
"2211":"ED50 / 3-degree Gauss-Kruger zone 14",
"2212":"ED50 / 3-degree Gauss-Kruger zone 15",
"2213":"ETRS89 / TM 30 NE",
"2214":"Douala 1948 / AOF west",
"2215":"Manoca 1962 / UTM zone 32N",
"2216":"Qornoq 1927 / UTM zone 22N",
"2217":"Qornoq 1927 / UTM zone 23N",
"2218":"Scoresbysund 1952 / Greenland zone 5 east",
"2219":"ATS77 / UTM zone 19N",
"2220":"ATS77 / UTM zone 20N",
"2221":"Scoresbysund 1952 / Greenland zone 6 east",
"2222":"NAD83 / Arizona East (ft)",
"2223":"NAD83 / Arizona Central (ft)",
"2224":"NAD83 / Arizona West (ft)",
"2225":"NAD83 / California zone 1 (ftUS)",
"2226":"NAD83 / California zone 2 (ftUS)",
"2227":"NAD83 / California zone 3 (ftUS)",
"2228":"NAD83 / California zone 4 (ftUS)",
"2229":"NAD83 / California zone 5 (ftUS)",
"2230":"NAD83 / California zone 6 (ftUS)",
"2231":"NAD83 / Colorado North (ftUS)",
"2232":"NAD83 / Colorado Central (ftUS)",
"2233":"NAD83 / Colorado South (ftUS)",
"2234":"NAD83 / Connecticut (ftUS)",
"2235":"NAD83 / Delaware (ftUS)",
"2236":"NAD83 / Florida East (ftUS)",
"2237":"NAD83 / Florida West (ftUS)",
"2238":"NAD83 / Florida North (ftUS)",
"2239":"NAD83 / Georgia East (ftUS)",
"2240":"NAD83 / Georgia West (ftUS)",
"2241":"NAD83 / Idaho East (ftUS)",
"2242":"NAD83 / Idaho Central (ftUS)",
"2243":"NAD83 / Idaho West (ftUS)",
"2244":"NAD83 / Indiana East (ftUS)",
"2245":"NAD83 / Indiana West (ftUS)",
"2246":"NAD83 / Kentucky North (ftUS)",
"2247":"NAD83 / Kentucky South (ftUS)",
"2248":"NAD83 / Maryland (ftUS)",
"2249":"NAD83 / Massachusetts Mainland (ftUS)",
"2250":"NAD83 / Massachusetts Island (ftUS)",
"2251":"NAD83 / Michigan North (ft)",
"2252":"NAD83 / Michigan Central (ft)",
"2253":"NAD83 / Michigan South (ft)",
"2254":"NAD83 / Mississippi East (ftUS)",
"2255":"NAD83 / Mississippi West (ftUS)",
"2256":"NAD83 / Montana (ft)",
"2257":"NAD83 / New Mexico East (ftUS)",
"2258":"NAD83 / New Mexico Central (ftUS)",
"2259":"NAD83 / New Mexico West (ftUS)",
"2260":"NAD83 / New York East (ftUS)",
"2261":"NAD83 / New York Central (ftUS)",
"2262":"NAD83 / New York West (ftUS)",
"2263":"NAD83 / New York Long Island (ftUS)",
"2264":"NAD83 / North Carolina (ftUS)",
"2265":"NAD83 / North Dakota North (ft)",
"2266":"NAD83 / North Dakota South (ft)",
"2267":"NAD83 / Oklahoma North (ftUS)",
"2268":"NAD83 / Oklahoma South (ftUS)",
"2269":"NAD83 / Oregon North (ft)",
"2270":"NAD83 / Oregon South (ft)",
"2271":"NAD83 / Pennsylvania North (ftUS)",
"2272":"NAD83 / Pennsylvania South (ftUS)",
"2273":"NAD83 / South Carolina (ft)",
"2274":"NAD83 / Tennessee (ftUS)",
"2275":"NAD83 / Texas North (ftUS)",
"2276":"NAD83 / Texas North Central (ftUS)",
"2277":"NAD83 / Texas Central (ftUS)",
"2278":"NAD83 / Texas South Central (ftUS)",
"2279":"NAD83 / Texas South (ftUS)",
"2280":"NAD83 / Utah North (ft)",
"2281":"NAD83 / Utah Central (ft)",
"2282":"NAD83 / Utah South (ft)",
"2283":"NAD83 / Virginia North (ftUS)",
"2284":"NAD83 / Virginia South (ftUS)",
"2285":"NAD83 / Washington North (ftUS)",
"2286":"NAD83 / Washington South (ftUS)",
"2287":"NAD83 / Wisconsin North (ftUS)",
"2288":"NAD83 / Wisconsin Central (ftUS)",
"2289":"NAD83 / Wisconsin South (ftUS)",
"2290":"ATS77 / Prince Edward Isl. Stereographic (ATS77)",
"2291":"NAD83(CSRS98) / Prince Edward Isl. Stereographic (NAD83)",
"2292":"NAD83(CSRS98) / Prince Edward Isl. Stereographic (NAD83)",
"2294":"ATS77 / MTM Nova Scotia zone 4",
"2295":"ATS77 / MTM Nova Scotia zone 5",
"2296":"Ammassalik 1958 / Greenland zone 7 east",
"2297":"Qornoq 1927 / Greenland zone 1 east",
"2298":"Qornoq 1927 / Greenland zone 2 east",
"2299":"Qornoq 1927 / Greenland zone 2 west",
"2300":"Qornoq 1927 / Greenland zone 3 east",
"2301":"Qornoq 1927 / Greenland zone 3 west",
"2302":"Qornoq 1927 / Greenland zone 4 east",
"2303":"Qornoq 1927 / Greenland zone 4 west",
"2304":"Qornoq 1927 / Greenland zone 5 west",
"2305":"Qornoq 1927 / Greenland zone 6 west",
"2306":"Qornoq 1927 / Greenland zone 7 west",
"2307":"Qornoq 1927 / Greenland zone 8 east",
"2308":"Batavia / TM 109 SE",
"2309":"WGS 84 / TM 116 SE",
"2310":"WGS 84 / TM 132 SE",
"2311":"WGS 84 / TM 6 NE",
"2312":"Garoua / UTM zone 33N",
"2313":"Kousseri / UTM zone 33N",
"2314":"Trinidad 1903 / Trinidad Grid (ftCla)",
"2315":"Campo Inchauspe / UTM zone 19S",
"2316":"Campo Inchauspe / UTM zone 20S",
"2317":"PSAD56 / ICN Regional",
"2318":"Ain el Abd / Aramco Lambert",
"2319":"ED50 / TM27",
"2320":"ED50 / TM30",
"2321":"ED50 / TM33",
"2322":"ED50 / TM36",
"2323":"ED50 / TM39",
"2324":"ED50 / TM42",
"2325":"ED50 / TM45",
"2326":"Hong Kong 1980 Grid System",
"2327":"Xian 1980 / Gauss-Kruger zone 13",
"2328":"Xian 1980 / Gauss-Kruger zone 14",
"2329":"Xian 1980 / Gauss-Kruger zone 15",
"2330":"Xian 1980 / Gauss-Kruger zone 16",
"2331":"Xian 1980 / Gauss-Kruger zone 17",
"2332":"Xian 1980 / Gauss-Kruger zone 18",
"2333":"Xian 1980 / Gauss-Kruger zone 19",
"2334":"Xian 1980 / Gauss-Kruger zone 20",
"2335":"Xian 1980 / Gauss-Kruger zone 21",
"2336":"Xian 1980 / Gauss-Kruger zone 22",
"2337":"Xian 1980 / Gauss-Kruger zone 23",
"2338":"Xian 1980 / Gauss-Kruger CM 75E",
"2339":"Xian 1980 / Gauss-Kruger CM 81E",
"2340":"Xian 1980 / Gauss-Kruger CM 87E",
"2341":"Xian 1980 / Gauss-Kruger CM 93E",
"2342":"Xian 1980 / Gauss-Kruger CM 99E",
"2343":"Xian 1980 / Gauss-Kruger CM 105E",
"2344":"Xian 1980 / Gauss-Kruger CM 111E",
"2345":"Xian 1980 / Gauss-Kruger CM 117E",
"2346":"Xian 1980 / Gauss-Kruger CM 123E",
"2347":"Xian 1980 / Gauss-Kruger CM 129E",
"2348":"Xian 1980 / Gauss-Kruger CM 135E",
"2349":"Xian 1980 / 3-degree Gauss-Kruger zone 25",
"2350":"Xian 1980 / 3-degree Gauss-Kruger zone 26",
"2351":"Xian 1980 / 3-degree Gauss-Kruger zone 27",
"2352":"Xian 1980 / 3-degree Gauss-Kruger zone 28",
"2353":"Xian 1980 / 3-degree Gauss-Kruger zone 29",
"2354":"Xian 1980 / 3-degree Gauss-Kruger zone 30",
"2355":"Xian 1980 / 3-degree Gauss-Kruger zone 31",
"2356":"Xian 1980 / 3-degree Gauss-Kruger zone 32",
"2357":"Xian 1980 / 3-degree Gauss-Kruger zone 33",
"2358":"Xian 1980 / 3-degree Gauss-Kruger zone 34",
"2359":"Xian 1980 / 3-degree Gauss-Kruger zone 35",
"2360":"Xian 1980 / 3-degree Gauss-Kruger zone 36",
"2361":"Xian 1980 / 3-degree Gauss-Kruger zone 37",
"2362":"Xian 1980 / 3-degree Gauss-Kruger zone 38",
"2363":"Xian 1980 / 3-degree Gauss-Kruger zone 39",
"2364":"Xian 1980 / 3-degree Gauss-Kruger zone 40",
"2365":"Xian 1980 / 3-degree Gauss-Kruger zone 41",
"2366":"Xian 1980 / 3-degree Gauss-Kruger zone 42",
"2367":"Xian 1980 / 3-degree Gauss-Kruger zone 43",
"2368":"Xian 1980 / 3-degree Gauss-Kruger zone 44",
"2369":"Xian 1980 / 3-degree Gauss-Kruger zone 45",
"2370":"Xian 1980 / 3-degree Gauss-Kruger CM 75E",
"2371":"Xian 1980 / 3-degree Gauss-Kruger CM 78E",
"2372":"Xian 1980 / 3-degree Gauss-Kruger CM 81E",
"2373":"Xian 1980 / 3-degree Gauss-Kruger CM 84E",
"2374":"Xian 1980 / 3-degree Gauss-Kruger CM 87E",
"2375":"Xian 1980 / 3-degree Gauss-Kruger CM 90E",
"2376":"Xian 1980 / 3-degree Gauss-Kruger CM 93E",
"2377":"Xian 1980 / 3-degree Gauss-Kruger CM 96E",
"2378":"Xian 1980 / 3-degree Gauss-Kruger CM 99E",
"2379":"Xian 1980 / 3-degree Gauss-Kruger CM 102E",
"2380":"Xian 1980 / 3-degree Gauss-Kruger CM 105E",
"2381":"Xian 1980 / 3-degree Gauss-Kruger CM 108E",
"2382":"Xian 1980 / 3-degree Gauss-Kruger CM 111E",
"2383":"Xian 1980 / 3-degree Gauss-Kruger CM 114E",
"2384":"Xian 1980 / 3-degree Gauss-Kruger CM 117E",
"2385":"Xian 1980 / 3-degree Gauss-Kruger CM 120E",
"2386":"Xian 1980 / 3-degree Gauss-Kruger CM 123E",
"2387":"Xian 1980 / 3-degree Gauss-Kruger CM 126E",
"2388":"Xian 1980 / 3-degree Gauss-Kruger CM 129E",
"2389":"Xian 1980 / 3-degree Gauss-Kruger CM 132E",
"2390":"Xian 1980 / 3-degree Gauss-Kruger CM 135E",
"2391":"KKJ / Finland zone 1",
"2392":"KKJ / Finland zone 2",
"2393":"KKJ / Finland Uniform Coordinate System",
"2394":"KKJ / Finland zone 4",
"2395":"South Yemen / Gauss-Kruger zone 8",
"2396":"South Yemen / Gauss-Kruger zone 9",
"2397":"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 3",
"2398":"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 4",
"2399":"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 5",
"2400":"RT90 2.5 gon W",
"2401":"Beijing 1954 / 3-degree Gauss-Kruger zone 25",
"2402":"Beijing 1954 / 3-degree Gauss-Kruger zone 26",
"2403":"Beijing 1954 / 3-degree Gauss-Kruger zone 27",
"2404":"Beijing 1954 / 3-degree Gauss-Kruger zone 28",
"2405":"Beijing 1954 / 3-degree Gauss-Kruger zone 29",
"2406":"Beijing 1954 / 3-degree Gauss-Kruger zone 30",
"2407":"Beijing 1954 / 3-degree Gauss-Kruger zone 31",
"2408":"Beijing 1954 / 3-degree Gauss-Kruger zone 32",
"2409":"Beijing 1954 / 3-degree Gauss-Kruger zone 33",
"2410":"Beijing 1954 / 3-degree Gauss-Kruger zone 34",
"2411":"Beijing 1954 / 3-degree Gauss-Kruger zone 35",
"2412":"Beijing 1954 / 3-degree Gauss-Kruger zone 36",
"2413":"Beijing 1954 / 3-degree Gauss-Kruger zone 37",
"2414":"Beijing 1954 / 3-degree Gauss-Kruger zone 38",
"2415":"Beijing 1954 / 3-degree Gauss-Kruger zone 39",
"2416":"Beijing 1954 / 3-degree Gauss-Kruger zone 40",
"2417":"Beijing 1954 / 3-degree Gauss-Kruger zone 41",
"2418":"Beijing 1954 / 3-degree Gauss-Kruger zone 42",
"2419":"Beijing 1954 / 3-degree Gauss-Kruger zone 43",
"2420":"Beijing 1954 / 3-degree Gauss-Kruger zone 44",
"2421":"Beijing 1954 / 3-degree Gauss-Kruger zone 45",
"2422":"Beijing 1954 / 3-degree Gauss-Kruger CM 75E",
"2423":"Beijing 1954 / 3-degree Gauss-Kruger CM 78E",
"2424":"Beijing 1954 / 3-degree Gauss-Kruger CM 81E",
"2425":"Beijing 1954 / 3-degree Gauss-Kruger CM 84E",
"2426":"Beijing 1954 / 3-degree Gauss-Kruger CM 87E",
"2427":"Beijing 1954 / 3-degree Gauss-Kruger CM 90E",
"2428":"Beijing 1954 / 3-degree Gauss-Kruger CM 93E",
"2429":"Beijing 1954 / 3-degree Gauss-Kruger CM 96E",
"2430":"Beijing 1954 / 3-degree Gauss-Kruger CM 99E",
"2431":"Beijing 1954 / 3-degree Gauss-Kruger CM 102E",
"2432":"Beijing 1954 / 3-degree Gauss-Kruger CM 105E",
"2433":"Beijing 1954 / 3-degree Gauss-Kruger CM 108E",
"2434":"Beijing 1954 / 3-degree Gauss-Kruger CM 111E",
"2435":"Beijing 1954 / 3-degree Gauss-Kruger CM 114E",
"2436":"Beijing 1954 / 3-degree Gauss-Kruger CM 117E",
"2437":"Beijing 1954 / 3-degree Gauss-Kruger CM 120E",
"2438":"Beijing 1954 / 3-degree Gauss-Kruger CM 123E",
"2439":"Beijing 1954 / 3-degree Gauss-Kruger CM 126E",
"2440":"Beijing 1954 / 3-degree Gauss-Kruger CM 129E",
"2441":"Beijing 1954 / 3-degree Gauss-Kruger CM 132E",
"2442":"Beijing 1954 / 3-degree Gauss-Kruger CM 135E",
"2443":"JGD2000 / Japan Plane Rectangular CS I",
"2444":"JGD2000 / Japan Plane Rectangular CS II",
"2445":"JGD2000 / Japan Plane Rectangular CS III",
"2446":"JGD2000 / Japan Plane Rectangular CS IV",
"2447":"JGD2000 / Japan Plane Rectangular CS V",
"2448":"JGD2000 / Japan Plane Rectangular CS VI",
"2449":"JGD2000 / Japan Plane Rectangular CS VII",
"2450":"JGD2000 / Japan Plane Rectangular CS VIII",
"2451":"JGD2000 / Japan Plane Rectangular CS IX",
"2452":"JGD2000 / Japan Plane Rectangular CS X",
"2453":"JGD2000 / Japan Plane Rectangular CS XI",
"2454":"JGD2000 / Japan Plane Rectangular CS XII",
"2455":"JGD2000 / Japan Plane Rectangular CS XIII",
"2456":"JGD2000 / Japan Plane Rectangular CS XIV",
"2457":"JGD2000 / Japan Plane Rectangular CS XV",
"2458":"JGD2000 / Japan Plane Rectangular CS XVI",
"2459":"JGD2000 / Japan Plane Rectangular CS XVII",
"2460":"JGD2000 / Japan Plane Rectangular CS XVIII",
"2461":"JGD2000 / Japan Plane Rectangular CS XIX",
"2462":"Albanian 1987 / Gauss-Kruger zone 4",
"2463":"Pulkovo 1995 / Gauss-Kruger CM 21E",
"2464":"Pulkovo 1995 / Gauss-Kruger CM 27E",
"2465":"Pulkovo 1995 / Gauss-Kruger CM 33E",
"2466":"Pulkovo 1995 / Gauss-Kruger CM 39E",
"2467":"Pulkovo 1995 / Gauss-Kruger CM 45E",
"2468":"Pulkovo 1995 / Gauss-Kruger CM 51E",
"2469":"Pulkovo 1995 / Gauss-Kruger CM 57E",
"2470":"Pulkovo 1995 / Gauss-Kruger CM 63E",
"2471":"Pulkovo 1995 / Gauss-Kruger CM 69E",
"2472":"Pulkovo 1995 / Gauss-Kruger CM 75E",
"2473":"Pulkovo 1995 / Gauss-Kruger CM 81E",
"2474":"Pulkovo 1995 / Gauss-Kruger CM 87E",
"2475":"Pulkovo 1995 / Gauss-Kruger CM 93E",
"2476":"Pulkovo 1995 / Gauss-Kruger CM 99E",
"2477":"Pulkovo 1995 / Gauss-Kruger CM 105E",
"2478":"Pulkovo 1995 / Gauss-Kruger CM 111E",
"2479":"Pulkovo 1995 / Gauss-Kruger CM 117E",
"2480":"Pulkovo 1995 / Gauss-Kruger CM 123E",
"2481":"Pulkovo 1995 / Gauss-Kruger CM 129E",
"2482":"Pulkovo 1995 / Gauss-Kruger CM 135E",
"2483":"Pulkovo 1995 / Gauss-Kruger CM 141E",
"2484":"Pulkovo 1995 / Gauss-Kruger CM 147E",
"2485":"Pulkovo 1995 / Gauss-Kruger CM 153E",
"2486":"Pulkovo 1995 / Gauss-Kruger CM 159E",
"2487":"Pulkovo 1995 / Gauss-Kruger CM 165E",
"2488":"Pulkovo 1995 / Gauss-Kruger CM 171E",
"2489":"Pulkovo 1995 / Gauss-Kruger CM 177E",
"2490":"Pulkovo 1995 / Gauss-Kruger CM 177W",
"2491":"Pulkovo 1995 / Gauss-Kruger CM 171W",
"2492":"Pulkovo 1942 / Gauss-Kruger CM 9E",
"2493":"Pulkovo 1942 / Gauss-Kruger CM 15E",
"2494":"Pulkovo 1942 / Gauss-Kruger CM 21E",
"2495":"Pulkovo 1942 / Gauss-Kruger CM 27E",
"2496":"Pulkovo 1942 / Gauss-Kruger CM 33E",
"2497":"Pulkovo 1942 / Gauss-Kruger CM 39E",
"2498":"Pulkovo 1942 / Gauss-Kruger CM 45E",
"2499":"Pulkovo 1942 / Gauss-Kruger CM 51E",
"2500":"Pulkovo 1942 / Gauss-Kruger CM 57E",
"2501":"Pulkovo 1942 / Gauss-Kruger CM 63E",
"2502":"Pulkovo 1942 / Gauss-Kruger CM 69E",
"2503":"Pulkovo 1942 / Gauss-Kruger CM 75E",
"2504":"Pulkovo 1942 / Gauss-Kruger CM 81E",
"2505":"Pulkovo 1942 / Gauss-Kruger CM 87E",
"2506":"Pulkovo 1942 / Gauss-Kruger CM 93E",
"2507":"Pulkovo 1942 / Gauss-Kruger CM 99E",
"2508":"Pulkovo 1942 / Gauss-Kruger CM 105E",
"2509":"Pulkovo 1942 / Gauss-Kruger CM 111E",
"2510":"Pulkovo 1942 / Gauss-Kruger CM 117E",
"2511":"Pulkovo 1942 / Gauss-Kruger CM 123E",
"2512":"Pulkovo 1942 / Gauss-Kruger CM 129E",
"2513":"Pulkovo 1942 / Gauss-Kruger CM 135E",
"2514":"Pulkovo 1942 / Gauss-Kruger CM 141E",
"2515":"Pulkovo 1942 / Gauss-Kruger CM 147E",
"2516":"Pulkovo 1942 / Gauss-Kruger CM 153E",
"2517":"Pulkovo 1942 / Gauss-Kruger CM 159E",
"2518":"Pulkovo 1942 / Gauss-Kruger CM 165E",
"2519":"Pulkovo 1942 / Gauss-Kruger CM 171E",
"2520":"Pulkovo 1942 / Gauss-Kruger CM 177E",
"2521":"Pulkovo 1942 / Gauss-Kruger CM 177W",
"2522":"Pulkovo 1942 / Gauss-Kruger CM 171W",
"2523":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 7",
"2524":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 8",
"2525":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 9",
"2526":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 10",
"2527":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 11",
"2528":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 12",
"2529":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 13",
"2530":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 14",
"2531":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 15",
"2532":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 16",
"2533":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 17",
"2534":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 18",
"2535":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 19",
"2536":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 20",
"2537":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 21",
"2538":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 22",
"2539":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 23",
"2540":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 24",
"2541":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 25",
"2542":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 26",
"2543":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 27",
"2544":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 28",
"2545":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 29",
"2546":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 30",
"2547":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 31",
"2548":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 32",
"2549":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 33",
"2550":"Samboja / UTM zone 50S",
"2551":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 34",
"2552":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 35",
"2553":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 36",
"2554":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 37",
"2555":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 38",
"2556":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 39",
"2557":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 40",
"2558":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 41",
"2559":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 42",
"2560":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 43",
"2561":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 44",
"2562":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 45",
"2563":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 46",
"2564":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 47",
"2565":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 48",
"2566":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 49",
"2567":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 50",
"2568":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 51",
"2569":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 52",
"2570":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 53",
"2571":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 54",
"2572":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 55",
"2573":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 56",
"2574":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 57",
"2575":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 58",
"2576":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 59",
"2577":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 60",
"2578":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 61",
"2579":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 62",
"2580":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 63",
"2581":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 64",
"2582":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 21E",
"2583":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 24E",
"2584":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 27E",
"2585":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 30E",
"2586":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 33E",
"2587":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 36E",
"2588":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 39E",
"2589":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 42E",
"2590":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 45E",
"2591":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 48E",
"2592":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 51E",
"2593":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 54E",
"2594":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 57E",
"2595":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 60E",
"2596":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 63E",
"2597":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 66E",
"2598":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 69E",
"2599":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 72E",
"2600":"Lietuvos Koordinoei Sistema 1994",
"2601":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 75E",
"2602":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 78E",
"2603":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 81E",
"2604":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 84E",
"2605":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 87E",
"2606":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 90E",
"2607":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 93E",
"2608":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 96E",
"2609":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 99E",
"2610":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 102E",
"2611":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 105E",
"2612":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 108E",
"2613":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 111E",
"2614":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 114E",
"2615":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 117E",
"2616":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 120E",
"2617":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 123E",
"2618":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 126E",
"2619":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 129E",
"2620":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 132E",
"2621":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 135E",
"2622":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 138E",
"2623":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 141E",
"2624":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 144E",
"2625":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 147E",
"2626":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 150E",
"2627":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 153E",
"2628":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 156E",
"2629":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 159E",
"2630":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 162E",
"2631":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 165E",
"2632":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 168E",
"2633":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 171E",
"2634":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 174E",
"2635":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 177E",
"2636":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 180E",
"2637":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 177W",
"2638":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 174W",
"2639":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 171W",
"2640":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 168W",
"2641":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 7",
"2642":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 8",
"2643":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 9",
"2644":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 10",
"2645":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 11",
"2646":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 12",
"2647":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 13",
"2648":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 14",
"2649":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 15",
"2650":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 16",
"2651":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 17",
"2652":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 18",
"2653":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 19",
"2654":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 20",
"2655":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 21",
"2656":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 22",
"2657":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 23",
"2658":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 24",
"2659":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 25",
"2660":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 26",
"2661":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 27",
"2662":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 28",
"2663":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 29",
"2664":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 30",
"2665":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 31",
"2666":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 32",
"2667":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 33",
"2668":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 34",
"2669":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 35",
"2670":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 36",
"2671":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 37",
"2672":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 38",
"2673":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 39",
"2674":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 40",
"2675":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 41",
"2676":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 42",
"2677":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 43",
"2678":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 44",
"2679":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 45",
"2680":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 46",
"2681":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 47",
"2682":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 48",
"2683":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 49",
"2684":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 50",
"2685":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 51",
"2686":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 52",
"2687":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 53",
"2688":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 54",
"2689":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 55",
"2690":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 56",
"2691":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 57",
"2692":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 58",
"2693":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 59",
"2694":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 60",
"2695":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 61",
"2696":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 62",
"2697":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 63",
"2698":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 64",
"2699":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 21E",
"2700":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 24E",
"2701":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 27E",
"2702":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 30E",
"2703":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 33E",
"2704":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 36E",
"2705":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 39E",
"2706":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 42E",
"2707":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 45E",
"2708":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 48E",
"2709":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 51E",
"2710":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 54E",
"2711":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 57E",
"2712":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 60E",
"2713":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 63E",
"2714":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 66E",
"2715":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 69E",
"2716":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 72E",
"2717":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 75E",
"2718":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 78E",
"2719":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 81E",
"2720":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 84E",
"2721":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 87E",
"2722":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 90E",
"2723":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 93E",
"2724":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 96E",
"2725":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 99E",
"2726":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 102E",
"2727":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 105E",
"2728":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 108E",
"2729":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 111E",
"2730":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 114E",
"2731":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 117E",
"2732":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 120E",
"2733":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 123E",
"2734":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 126E",
"2735":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 129E",
"2736":"Tete / UTM zone 36S",
"2737":"Tete / UTM zone 37S",
"2738":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 132E",
"2739":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 135E",
"2740":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 138E",
"2741":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 141E",
"2742":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 144E",
"2743":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 147E",
"2744":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 150E",
"2745":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 153E",
"2746":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 156E",
"2747":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 159E",
"2748":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 162E",
"2749":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 165E",
"2750":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 168E",
"2751":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 171E",
"2752":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 174E",
"2753":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 177E",
"2754":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 180E",
"2755":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 177W",
"2756":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 174W",
"2757":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 171W",
"2758":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 168W",
"2759":"NAD83(HARN) / Alabama East",
"2760":"NAD83(HARN) / Alabama West",
"2761":"NAD83(HARN) / Arizona East",
"2762":"NAD83(HARN) / Arizona Central",
"2763":"NAD83(HARN) / Arizona West",
"2764":"NAD83(HARN) / Arkansas North",
"2765":"NAD83(HARN) / Arkansas South",
"2766":"NAD83(HARN) / California zone 1",
"2767":"NAD83(HARN) / California zone 2",
"2768":"NAD83(HARN) / California zone 3",
"2769":"NAD83(HARN) / California zone 4",
"2770":"NAD83(HARN) / California zone 5",
"2771":"NAD83(HARN) / California zone 6",
"2772":"NAD83(HARN) / Colorado North",
"2773":"NAD83(HARN) / Colorado Central",
"2774":"NAD83(HARN) / Colorado South",
"2775":"NAD83(HARN) / Connecticut",
"2776":"NAD83(HARN) / Delaware",
"2777":"NAD83(HARN) / Florida East",
"2778":"NAD83(HARN) / Florida West",
"2779":"NAD83(HARN) / Florida North",
"2780":"NAD83(HARN) / Georgia East",
"2781":"NAD83(HARN) / Georgia West",
"2782":"NAD83(HARN) / Hawaii zone 1",
"2783":"NAD83(HARN) / Hawaii zone 2",
"2784":"NAD83(HARN) / Hawaii zone 3",
"2785":"NAD83(HARN) / Hawaii zone 4",
"2786":"NAD83(HARN) / Hawaii zone 5",
"2787":"NAD83(HARN) / Idaho East",
"2788":"NAD83(HARN) / Idaho Central",
"2789":"NAD83(HARN) / Idaho West",
"2790":"NAD83(HARN) / Illinois East",
"2791":"NAD83(HARN) / Illinois West",
"2792":"NAD83(HARN) / Indiana East",
"2793":"NAD83(HARN) / Indiana West",
"2794":"NAD83(HARN) / Iowa North",
"2795":"NAD83(HARN) / Iowa South",
"2796":"NAD83(HARN) / Kansas North",
"2797":"NAD83(HARN) / Kansas South",
"2798":"NAD83(HARN) / Kentucky North",
"2799":"NAD83(HARN) / Kentucky South",
"2800":"NAD83(HARN) / Louisiana North",
"2801":"NAD83(HARN) / Louisiana South",
"2802":"NAD83(HARN) / Maine East",
"2803":"NAD83(HARN) / Maine West",
"2804":"NAD83(HARN) / Maryland",
"2805":"NAD83(HARN) / Massachusetts Mainland",
"2806":"NAD83(HARN) / Massachusetts Island",
"2807":"NAD83(HARN) / Michigan North",
"2808":"NAD83(HARN) / Michigan Central",
"2809":"NAD83(HARN) / Michigan South",
"2810":"NAD83(HARN) / Minnesota North",
"2811":"NAD83(HARN) / Minnesota Central",
"2812":"NAD83(HARN) / Minnesota South",
"2813":"NAD83(HARN) / Mississippi East",
"2814":"NAD83(HARN) / Mississippi West",
"2815":"NAD83(HARN) / Missouri East",
"2816":"NAD83(HARN) / Missouri Central",
"2817":"NAD83(HARN) / Missouri West",
"2818":"NAD83(HARN) / Montana",
"2819":"NAD83(HARN) / Nebraska",
"2820":"NAD83(HARN) / Nevada East",
"2821":"NAD83(HARN) / Nevada Central",
"2822":"NAD83(HARN) / Nevada West",
"2823":"NAD83(HARN) / New Hampshire",
"2824":"NAD83(HARN) / New Jersey",
"2825":"NAD83(HARN) / New Mexico East",
"2826":"NAD83(HARN) / New Mexico Central",
"2827":"NAD83(HARN) / New Mexico West",
"2828":"NAD83(HARN) / New York East",
"2829":"NAD83(HARN) / New York Central",
"2830":"NAD83(HARN) / New York West",
"2831":"NAD83(HARN) / New York Long Island",
"2832":"NAD83(HARN) / North Dakota North",
"2833":"NAD83(HARN) / North Dakota South",
"2834":"NAD83(HARN) / Ohio North",
"2835":"NAD83(HARN) / Ohio South",
"2836":"NAD83(HARN) / Oklahoma North",
"2837":"NAD83(HARN) / Oklahoma South",
"2838":"NAD83(HARN) / Oregon North",
"2839":"NAD83(HARN) / Oregon South",
"2840":"NAD83(HARN) / Rhode Island",
"2841":"NAD83(HARN) / South Dakota North",
"2842":"NAD83(HARN) / South Dakota South",
"2843":"NAD83(HARN) / Tennessee",
"2844":"NAD83(HARN) / Texas North",
"2845":"NAD83(HARN) / Texas North Central",
"2846":"NAD83(HARN) / Texas Central",
"2847":"NAD83(HARN) / Texas South Central",
"2848":"NAD83(HARN) / Texas South",
"2849":"NAD83(HARN) / Utah North",
"2850":"NAD83(HARN) / Utah Central",
"2851":"NAD83(HARN) / Utah South",
"2852":"NAD83(HARN) / Vermont",
"2853":"NAD83(HARN) / Virginia North",
"2854":"NAD83(HARN) / Virginia South",
"2855":"NAD83(HARN) / Washington North",
"2856":"NAD83(HARN) / Washington South",
"2857":"NAD83(HARN) / West Virginia North",
"2858":"NAD83(HARN) / West Virginia South",
"2859":"NAD83(HARN) / Wisconsin North",
"2860":"NAD83(HARN) / Wisconsin Central",
"2861":"NAD83(HARN) / Wisconsin South",
"2862":"NAD83(HARN) / Wyoming East",
"2863":"NAD83(HARN) / Wyoming East Central",
"2864":"NAD83(HARN) / Wyoming West Central",
"2865":"NAD83(HARN) / Wyoming West",
"2866":"NAD83(HARN) / Puerto Rico and Virgin Is.",
"2867":"NAD83(HARN) / Arizona East (ft)",
"2868":"NAD83(HARN) / Arizona Central (ft)",
"2869":"NAD83(HARN) / Arizona West (ft)",
"2870":"NAD83(HARN) / California zone 1 (ftUS)",
"2871":"NAD83(HARN) / California zone 2 (ftUS)",
"2872":"NAD83(HARN) / California zone 3 (ftUS)",
"2873":"NAD83(HARN) / California zone 4 (ftUS)",
"2874":"NAD83(HARN) / California zone 5 (ftUS)",
"2875":"NAD83(HARN) / California zone 6 (ftUS)",
"2876":"NAD83(HARN) / Colorado North (ftUS)",
"2877":"NAD83(HARN) / Colorado Central (ftUS)",
"2878":"NAD83(HARN) / Colorado South (ftUS)",
"2879":"NAD83(HARN) / Connecticut (ftUS)",
"2880":"NAD83(HARN) / Delaware (ftUS)",
"2881":"NAD83(HARN) / Florida East (ftUS)",
"2882":"NAD83(HARN) / Florida West (ftUS)",
"2883":"NAD83(HARN) / Florida North (ftUS)",
"2884":"NAD83(HARN) / Georgia East (ftUS)",
"2885":"NAD83(HARN) / Georgia West (ftUS)",
"2886":"NAD83(HARN) / Idaho East (ftUS)",
"2887":"NAD83(HARN) / Idaho Central (ftUS)",
"2888":"NAD83(HARN) / Idaho West (ftUS)",
"2889":"NAD83(HARN) / Indiana East (ftUS)",
"2890":"NAD83(HARN) / Indiana West (ftUS)",
"2891":"NAD83(HARN) / Kentucky North (ftUS)",
"2892":"NAD83(HARN) / Kentucky South (ftUS)",
"2893":"NAD83(HARN) / Maryland (ftUS)",
"2894":"NAD83(HARN) / Massachusetts Mainland (ftUS)",
"2895":"NAD83(HARN) / Massachusetts Island (ftUS)",
"2896":"NAD83(HARN) / Michigan North (ft)",
"2897":"NAD83(HARN) / Michigan Central (ft)",
"2898":"NAD83(HARN) / Michigan South (ft)",
"2899":"NAD83(HARN) / Mississippi East (ftUS)",
"2900":"NAD83(HARN) / Mississippi West (ftUS)",
"2901":"NAD83(HARN) / Montana (ft)",
"2902":"NAD83(HARN) / New Mexico East (ftUS)",
"2903":"NAD83(HARN) / New Mexico Central (ftUS)",
"2904":"NAD83(HARN) / New Mexico West (ftUS)",
"2905":"NAD83(HARN) / New York East (ftUS)",
"2906":"NAD83(HARN) / New York Central (ftUS)",
"2907":"NAD83(HARN) / New York West (ftUS)",
"2908":"NAD83(HARN) / New York Long Island (ftUS)",
"2909":"NAD83(HARN) / North Dakota North (ft)",
"2910":"NAD83(HARN) / North Dakota South (ft)",
"2911":"NAD83(HARN) / Oklahoma North (ftUS)",
"2912":"NAD83(HARN) / Oklahoma South (ftUS)",
"2913":"NAD83(HARN) / Oregon North (ft)",
"2914":"NAD83(HARN) / Oregon South (ft)",
"2915":"NAD83(HARN) / Tennessee (ftUS)",
"2916":"NAD83(HARN) / Texas North (ftUS)",
"2917":"NAD83(HARN) / Texas North Central (ftUS)",
"2918":"NAD83(HARN) / Texas Central (ftUS)",
"2919":"NAD83(HARN) / Texas South Central (ftUS)",
"2920":"NAD83(HARN) / Texas South (ftUS)",
"2921":"NAD83(HARN) / Utah North (ft)",
"2922":"NAD83(HARN) / Utah Central (ft)",
"2923":"NAD83(HARN) / Utah South (ft)",
"2924":"NAD83(HARN) / Virginia North (ftUS)",
"2925":"NAD83(HARN) / Virginia South (ftUS)",
"2926":"NAD83(HARN) / Washington North (ftUS)",
"2927":"NAD83(HARN) / Washington South (ftUS)",
"2928":"NAD83(HARN) / Wisconsin North (ftUS)",
"2929":"NAD83(HARN) / Wisconsin Central (ftUS)",
"2930":"NAD83(HARN) / Wisconsin South (ftUS)",
"2931":"Beduaram / TM 13 NE",
"2932":"QND95 / Qatar National Grid",
"2933":"Segara / UTM zone 50S",
"2934":"Segara (Jakarta) / NEIEZ",
"2935":"Pulkovo 1942 / CS63 zone A1",
"2936":"Pulkovo 1942 / CS63 zone A2",
"2937":"Pulkovo 1942 / CS63 zone A3",
"2938":"Pulkovo 1942 / CS63 zone A4",
"2939":"Pulkovo 1942 / CS63 zone K2",
"2940":"Pulkovo 1942 / CS63 zone K3",
"2941":"Pulkovo 1942 / CS63 zone K4",
"2942":"Porto Santo / UTM zone 28N",
"2943":"Selvagem Grande / UTM zone 28N",
"2944":"NAD83(CSRS) / SCoPQ zone 2",
"2945":"NAD83(CSRS) / MTM zone 3",
"2946":"NAD83(CSRS) / MTM zone 4",
"2947":"NAD83(CSRS) / MTM zone 5",
"2948":"NAD83(CSRS) / MTM zone 6",
"2949":"NAD83(CSRS) / MTM zone 7",
"2950":"NAD83(CSRS) / MTM zone 8",
"2951":"NAD83(CSRS) / MTM zone 9",
"2952":"NAD83(CSRS) / MTM zone 10",
"2953":"NAD83(CSRS) / New Brunswick Stereographic",
"2954":"NAD83(CSRS) / Prince Edward Isl. Stereographic (NAD83)",
"2955":"NAD83(CSRS) / UTM zone 11N",
"2956":"NAD83(CSRS) / UTM zone 12N",
"2957":"NAD83(CSRS) / UTM zone 13N",
"2958":"NAD83(CSRS) / UTM zone 17N",
"2959":"NAD83(CSRS) / UTM zone 18N",
"2960":"NAD83(CSRS) / UTM zone 19N",
"2961":"NAD83(CSRS) / UTM zone 20N",
"2962":"NAD83(CSRS) / UTM zone 21N",
"2963":"Lisbon 1890 (Lisbon) / Portugal Bonne",
"2964":"NAD27 / Alaska Albers",
"2965":"NAD83 / Indiana East (ftUS)",
"2966":"NAD83 / Indiana West (ftUS)",
"2967":"NAD83(HARN) / Indiana East (ftUS)",
"2968":"NAD83(HARN) / Indiana West (ftUS)",
"2969":"Fort Marigot / UTM zone 20N",
"2970":"Guadeloupe 1948 / UTM zone 20N",
"2971":"CSG67 / UTM zone 22N",
"2972":"RGFG95 / UTM zone 22N",
"2973":"Martinique 1938 / UTM zone 20N",
"2975":"RGR92 / UTM zone 40S",
"2976":"Tahiti 52 / UTM zone 6S",
"2977":"Tahaa 54 / UTM zone 5S",
"2978":"IGN72 Nuku Hiva / UTM zone 7S",
"2979":"K0 1949 / UTM zone 42S",
"2980":"Combani 1950 / UTM zone 38S",
"2981":"IGN56 Lifou / UTM zone 58S",
"2982":"IGN72 Grand Terre / UTM zone 58S",
"2983":"ST87 Ouvea / UTM zone 58S",
"2984":"RGNC 1991 / Lambert New Caledonia",
"2985":"Petrels 1972 / Terre Adelie Polar Stereographic",
"2986":"Perroud 1950 / Terre Adelie Polar Stereographic",
"2987":"Saint Pierre et Miquelon 1950 / UTM zone 21N",
"2988":"MOP78 / UTM zone 1S",
"2989":"RRAF 1991 / UTM zone 20N",
"2990":"Reunion 1947 / TM Reunion",
"2991":"NAD83 / Oregon LCC (m)",
"2992":"NAD83 / Oregon GIC Lambert (ft)",
"2993":"NAD83(HARN) / Oregon LCC (m)",
"2994":"NAD83(HARN) / Oregon GIC Lambert (ft)",
"2995":"IGN53 Mare / UTM zone 58S",
"2996":"ST84 Ile des Pins / UTM zone 58S",
"2997":"ST71 Belep / UTM zone 58S",
"2998":"NEA74 Noumea / UTM zone 58S",
"2999":"Grand Comoros / UTM zone 38S",
"3000":"Segara / NEIEZ",
"3001":"Batavia / NEIEZ",
"3002":"Makassar / NEIEZ",
"3003":"Monte Mario / Italy zone 1",
"3004":"Monte Mario / Italy zone 2",
"3005":"NAD83 / BC Albers",
"3006":"SWEREF99 TM",
"3007":"SWEREF99 12 00",
"3008":"SWEREF99 13 30",
"3009":"SWEREF99 15 00",
"3010":"SWEREF99 16 30",
"3011":"SWEREF99 18 00",
"3012":"SWEREF99 14 15",
"3013":"SWEREF99 15 45",
"3014":"SWEREF99 17 15",
"3015":"SWEREF99 18 45",
"3016":"SWEREF99 20 15",
"3017":"SWEREF99 21 45",
"3018":"SWEREF99 23 15",
"3019":"RT90 7.5 gon V",
"3020":"RT90 5 gon V",
"3021":"RT90 2.5 gon V",
"3022":"RT90 0 gon",
"3023":"RT90 2.5 gon O",
"3024":"RT90 5 gon O",
"3025":"RT38 7.5 gon V",
"3026":"RT38 5 gon V",
"3027":"RT38 2.5 gon V",
"3028":"RT38 0 gon",
"3029":"RT38 2.5 gon O",
"3030":"RT38 5 gon O",
"3031":"WGS 84 / Antarctic Polar Stereographic",
"3032":"WGS 84 / Australian Antarctic Polar Stereographic",
"3033":"WGS 84 / Australian Antarctic Lambert",
"3034":"ETRS89-extended / LCC Europe",
"3035":"ETRS89-extended / LAEA Europe",
"3036":"Moznet / UTM zone 36S",
"3037":"Moznet / UTM zone 37S",
"3038":"ETRS89 / TM26",
"3039":"ETRS89 / TM27",
"3040":"ETRS89 / UTM zone 28N (N-E)",
"3041":"ETRS89 / UTM zone 29N (N-E)",
"3042":"ETRS89 / UTM zone 30N (N-E)",
"3043":"ETRS89 / UTM zone 31N (N-E)",
"3044":"ETRS89 / UTM zone 32N (N-E)",
"3045":"ETRS89 / UTM zone 33N (N-E)",
"3046":"ETRS89 / UTM zone 34N (N-E)",
"3047":"ETRS89 / UTM zone 35N (N-E)",
"3048":"ETRS89 / UTM zone 36N (N-E)",
"3049":"ETRS89 / UTM zone 37N (N-E)",
"3050":"ETRS89 / TM38",
"3051":"ETRS89 / TM39",
"3052":"Reykjavik 1900 / Lambert 1900",
"3053":"Hjorsey 1955 / Lambert 1955",
"3054":"Hjorsey 1955 / UTM zone 26N",
"3055":"Hjorsey 1955 / UTM zone 27N",
"3056":"Hjorsey 1955 / UTM zone 28N",
"3057":"ISN93 / Lambert 1993",
"3058":"Helle 1954 / Jan Mayen Grid",
"3059":"LKS92 / Latvia TM",
"3060":"IGN72 Grande Terre / UTM zone 58S",
"3061":"Porto Santo 1995 / UTM zone 28N",
"3062":"Azores Oriental 1995 / UTM zone 26N",
"3063":"Azores Central 1995 / UTM zone 26N",
"3064":"IGM95 / UTM zone 32N",
"3065":"IGM95 / UTM zone 33N",
"3066":"ED50 / Jordan TM",
"3067":"ETRS89 / TM35FIN(E,N)",
"3068":"DHDN / Soldner Berlin",
"3069":"NAD27 / Wisconsin Transverse Mercator",
"3070":"NAD83 / Wisconsin Transverse Mercator",
"3071":"NAD83(HARN) / Wisconsin Transverse Mercator",
"3072":"NAD83 / Maine CS2000 East",
"3073":"NAD83 / Maine CS2000 Central",
"3074":"NAD83 / Maine CS2000 West",
"3075":"NAD83(HARN) / Maine CS2000 East",
"3076":"NAD83(HARN) / Maine CS2000 Central",
"3077":"NAD83(HARN) / Maine CS2000 West",
"3078":"NAD83 / Michigan Oblique Mercator",
"3079":"NAD83(HARN) / Michigan Oblique Mercator",
"3080":"NAD27 / Shackleford",
"3081":"NAD83 / Texas State Mapping System",
"3082":"NAD83 / Texas Centric Lambert Conformal",
"3083":"NAD83 / Texas Centric Albers Equal Area",
"3084":"NAD83(HARN) / Texas Centric Lambert Conformal",
"3085":"NAD83(HARN) / Texas Centric Albers Equal Area",
"3086":"NAD83 / Florida GDL Albers",
"3087":"NAD83(HARN) / Florida GDL Albers",
"3088":"NAD83 / Kentucky Single Zone",
"3089":"NAD83 / Kentucky Single Zone (ftUS)",
"3090":"NAD83(HARN) / Kentucky Single Zone",
"3091":"NAD83(HARN) / Kentucky Single Zone (ftUS)",
"3092":"Tokyo / UTM zone 51N",
"3093":"Tokyo / UTM zone 52N",
"3094":"Tokyo / UTM zone 53N",
"3095":"Tokyo / UTM zone 54N",
"3096":"Tokyo / UTM zone 55N",
"3097":"JGD2000 / UTM zone 51N",
"3098":"JGD2000 / UTM zone 52N",
"3099":"JGD2000 / UTM zone 53N",
"3100":"JGD2000 / UTM zone 54N",
"3101":"JGD2000 / UTM zone 55N",
"3102":"American Samoa 1962 / American Samoa Lambert",
"3103":"Mauritania 1999 / UTM zone 28N",
"3104":"Mauritania 1999 / UTM zone 29N",
"3105":"Mauritania 1999 / UTM zone 30N",
"3106":"Gulshan 303 / Bangladesh Transverse Mercator",
"3107":"GDA94 / SA Lambert",
"3108":"ETRS89 / Guernsey Grid",
"3109":"ETRS89 / Jersey Transverse Mercator",
"3110":"AGD66 / Vicgrid66",
"3111":"GDA94 / Vicgrid",
"3112":"GDA94 / Geoscience Australia Lambert",
"3113":"GDA94 / BCSG02",
"3114":"MAGNA-SIRGAS / Colombia Far West zone",
"3115":"MAGNA-SIRGAS / Colombia West zone",
"3116":"MAGNA-SIRGAS / Colombia Bogota zone",
"3117":"MAGNA-SIRGAS / Colombia East Central zone",
"3118":"MAGNA-SIRGAS / Colombia East zone",
"3119":"Douala 1948 / AEF west",
"3120":"Pulkovo 1942(58) / Poland zone I",
"3121":"PRS92 / Philippines zone 1",
"3122":"PRS92 / Philippines zone 2",
"3123":"PRS92 / Philippines zone 3",
"3124":"PRS92 / Philippines zone 4",
"3125":"PRS92 / Philippines zone 5",
"3126":"ETRS89 / ETRS-GK19FIN",
"3127":"ETRS89 / ETRS-GK20FIN",
"3128":"ETRS89 / ETRS-GK21FIN",
"3129":"ETRS89 / ETRS-GK22FIN",
"3130":"ETRS89 / ETRS-GK23FIN",
"3131":"ETRS89 / ETRS-GK24FIN",
"3132":"ETRS89 / ETRS-GK25FIN",
"3133":"ETRS89 / ETRS-GK26FIN",
"3134":"ETRS89 / ETRS-GK27FIN",
"3135":"ETRS89 / ETRS-GK28FIN",
"3136":"ETRS89 / ETRS-GK29FIN",
"3137":"ETRS89 / ETRS-GK30FIN",
"3138":"ETRS89 / ETRS-GK31FIN",
"3139":"Vanua Levu 1915 / Vanua Levu Grid",
"3140":"Viti Levu 1912 / Viti Levu Grid",
"3141":"Fiji 1956 / UTM zone 60S",
"3142":"Fiji 1956 / UTM zone 1S",
"3143":"Fiji 1986 / Fiji Map Grid",
"3144":"FD54 / Faroe Lambert",
"3145":"ETRS89 / Faroe Lambert",
"3146":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 6",
"3147":"Pulkovo 1942 / 3-degree Gauss-Kruger CM 18E",
"3148":"Indian 1960 / UTM zone 48N",
"3149":"Indian 1960 / UTM zone 49N",
"3150":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 6",
"3151":"Pulkovo 1995 / 3-degree Gauss-Kruger CM 18E",
"3152":"ST74",
"3153":"NAD83(CSRS) / BC Albers",
"3154":"NAD83(CSRS) / UTM zone 7N",
"3155":"NAD83(CSRS) / UTM zone 8N",
"3156":"NAD83(CSRS) / UTM zone 9N",
"3157":"NAD83(CSRS) / UTM zone 10N",
"3158":"NAD83(CSRS) / UTM zone 14N",
"3159":"NAD83(CSRS) / UTM zone 15N",
"3160":"NAD83(CSRS) / UTM zone 16N",
"3161":"NAD83 / Ontario MNR Lambert",
"3162":"NAD83(CSRS) / Ontario MNR Lambert",
"3163":"RGNC91-93 / Lambert New Caledonia",
"3164":"ST87 Ouvea / UTM zone 58S",
"3165":"NEA74 Noumea / Noumea Lambert",
"3166":"NEA74 Noumea / Noumea Lambert 2",
"3167":"Kertau (RSO) / RSO Malaya (ch)",
"3168":"Kertau (RSO) / RSO Malaya (m)",
"3169":"RGNC91-93 / UTM zone 57S",
"3170":"RGNC91-93 / UTM zone 58S",
"3171":"RGNC91-93 / UTM zone 59S",
"3172":"IGN53 Mare / UTM zone 59S",
"3173":"fk89 / Faroe Lambert FK89",
"3174":"NAD83 / Great Lakes Albers",
"3175":"NAD83 / Great Lakes and St Lawrence Albers",
"3176":"Indian 1960 / TM 106 NE",
"3177":"LGD2006 / Libya TM",
"3178":"GR96 / UTM zone 18N",
"3179":"GR96 / UTM zone 19N",
"3180":"GR96 / UTM zone 20N",
"3181":"GR96 / UTM zone 21N",
"3182":"GR96 / UTM zone 22N",
"3183":"GR96 / UTM zone 23N",
"3184":"GR96 / UTM zone 24N",
"3185":"GR96 / UTM zone 25N",
"3186":"GR96 / UTM zone 26N",
"3187":"GR96 / UTM zone 27N",
"3188":"GR96 / UTM zone 28N",
"3189":"GR96 / UTM zone 29N",
"3190":"LGD2006 / Libya TM zone 5",
"3191":"LGD2006 / Libya TM zone 6",
"3192":"LGD2006 / Libya TM zone 7",
"3193":"LGD2006 / Libya TM zone 8",
"3194":"LGD2006 / Libya TM zone 9",
"3195":"LGD2006 / Libya TM zone 10",
"3196":"LGD2006 / Libya TM zone 11",
"3197":"LGD2006 / Libya TM zone 12",
"3198":"LGD2006 / Libya TM zone 13",
"3199":"LGD2006 / UTM zone 32N",
"3200":"FD58 / Iraq zone",
"3201":"LGD2006 / UTM zone 33N",
"3202":"LGD2006 / UTM zone 34N",
"3203":"LGD2006 / UTM zone 35N",
"3204":"WGS 84 / SCAR IMW SP19-20",
"3205":"WGS 84 / SCAR IMW SP21-22",
"3206":"WGS 84 / SCAR IMW SP23-24",
"3207":"WGS 84 / SCAR IMW SQ01-02",
"3208":"WGS 84 / SCAR IMW SQ19-20",
"3209":"WGS 84 / SCAR IMW SQ21-22",
"3210":"WGS 84 / SCAR IMW SQ37-38",
"3211":"WGS 84 / SCAR IMW SQ39-40",
"3212":"WGS 84 / SCAR IMW SQ41-42",
"3213":"WGS 84 / SCAR IMW SQ43-44",
"3214":"WGS 84 / SCAR IMW SQ45-46",
"3215":"WGS 84 / SCAR IMW SQ47-48",
"3216":"WGS 84 / SCAR IMW SQ49-50",
"3217":"WGS 84 / SCAR IMW SQ51-52",
"3218":"WGS 84 / SCAR IMW SQ53-54",
"3219":"WGS 84 / SCAR IMW SQ55-56",
"3220":"WGS 84 / SCAR IMW SQ57-58",
"3221":"WGS 84 / SCAR IMW SR13-14",
"3222":"WGS 84 / SCAR IMW SR15-16",
"3223":"WGS 84 / SCAR IMW SR17-18",
"3224":"WGS 84 / SCAR IMW SR19-20",
"3225":"WGS 84 / SCAR IMW SR27-28",
"3226":"WGS 84 / SCAR IMW SR29-30",
"3227":"WGS 84 / SCAR IMW SR31-32",
"3228":"WGS 84 / SCAR IMW SR33-34",
"3229":"WGS 84 / SCAR IMW SR35-36",
"3230":"WGS 84 / SCAR IMW SR37-38",
"3231":"WGS 84 / SCAR IMW SR39-40",
"3232":"WGS 84 / SCAR IMW SR41-42",
"3233":"WGS 84 / SCAR IMW SR43-44",
"3234":"WGS 84 / SCAR IMW SR45-46",
"3235":"WGS 84 / SCAR IMW SR47-48",
"3236":"WGS 84 / SCAR IMW SR49-50",
"3237":"WGS 84 / SCAR IMW SR51-52",
"3238":"WGS 84 / SCAR IMW SR53-54",
"3239":"WGS 84 / SCAR IMW SR55-56",
"3240":"WGS 84 / SCAR IMW SR57-58",
"3241":"WGS 84 / SCAR IMW SR59-60",
"3242":"WGS 84 / SCAR IMW SS04-06",
"3243":"WGS 84 / SCAR IMW SS07-09",
"3244":"WGS 84 / SCAR IMW SS10-12",
"3245":"WGS 84 / SCAR IMW SS13-15",
"3246":"WGS 84 / SCAR IMW SS16-18",
"3247":"WGS 84 / SCAR IMW SS19-21",
"3248":"WGS 84 / SCAR IMW SS25-27",
"3249":"WGS 84 / SCAR IMW SS28-30",
"3250":"WGS 84 / SCAR IMW SS31-33",
"3251":"WGS 84 / SCAR IMW SS34-36",
"3252":"WGS 84 / SCAR IMW SS37-39",
"3253":"WGS 84 / SCAR IMW SS40-42",
"3254":"WGS 84 / SCAR IMW SS43-45",
"3255":"WGS 84 / SCAR IMW SS46-48",
"3256":"WGS 84 / SCAR IMW SS49-51",
"3257":"WGS 84 / SCAR IMW SS52-54",
"3258":"WGS 84 / SCAR IMW SS55-57",
"3259":"WGS 84 / SCAR IMW SS58-60",
"3260":"WGS 84 / SCAR IMW ST01-04",
"3261":"WGS 84 / SCAR IMW ST05-08",
"3262":"WGS 84 / SCAR IMW ST09-12",
"3263":"WGS 84 / SCAR IMW ST13-16",
"3264":"WGS 84 / SCAR IMW ST17-20",
"3265":"WGS 84 / SCAR IMW ST21-24",
"3266":"WGS 84 / SCAR IMW ST25-28",
"3267":"WGS 84 / SCAR IMW ST29-32",
"3268":"WGS 84 / SCAR IMW ST33-36",
"3269":"WGS 84 / SCAR IMW ST37-40",
"3270":"WGS 84 / SCAR IMW ST41-44",
"3271":"WGS 84 / SCAR IMW ST45-48",
"3272":"WGS 84 / SCAR IMW ST49-52",
"3273":"WGS 84 / SCAR IMW ST53-56",
"3274":"WGS 84 / SCAR IMW ST57-60",
"3275":"WGS 84 / SCAR IMW SU01-05",
"3276":"WGS 84 / SCAR IMW SU06-10",
"3277":"WGS 84 / SCAR IMW SU11-15",
"3278":"WGS 84 / SCAR IMW SU16-20",
"3279":"WGS 84 / SCAR IMW SU21-25",
"3280":"WGS 84 / SCAR IMW SU26-30",
"3281":"WGS 84 / SCAR IMW SU31-35",
"3282":"WGS 84 / SCAR IMW SU36-40",
"3283":"WGS 84 / SCAR IMW SU41-45",
"3284":"WGS 84 / SCAR IMW SU46-50",
"3285":"WGS 84 / SCAR IMW SU51-55",
"3286":"WGS 84 / SCAR IMW SU56-60",
"3287":"WGS 84 / SCAR IMW SV01-10",
"3288":"WGS 84 / SCAR IMW SV11-20",
"3289":"WGS 84 / SCAR IMW SV21-30",
"3290":"WGS 84 / SCAR IMW SV31-40",
"3291":"WGS 84 / SCAR IMW SV41-50",
"3292":"WGS 84 / SCAR IMW SV51-60",
"3293":"WGS 84 / SCAR IMW SW01-60",
"3294":"WGS 84 / USGS Transantarctic Mountains",
"3295":"Guam 1963 / Yap Islands",
"3296":"RGPF / UTM zone 5S",
"3297":"RGPF / UTM zone 6S",
"3298":"RGPF / UTM zone 7S",
"3299":"RGPF / UTM zone 8S",
"3300":"Estonian Coordinate System of 1992",
"3301":"Estonian Coordinate System of 1997",
"3302":"IGN63 Hiva Oa / UTM zone 7S",
"3303":"Fatu Iva 72 / UTM zone 7S",
"3304":"Tahiti 79 / UTM zone 6S",
"3305":"Moorea 87 / UTM zone 6S",
"3306":"Maupiti 83 / UTM zone 5S",
"3307":"Nakhl-e Ghanem / UTM zone 39N",
"3308":"GDA94 / NSW Lambert",
"3309":"NAD27 / California Albers",
"3310":"NAD83 / California Albers",
"3311":"NAD83(HARN) / California Albers",
"3312":"CSG67 / UTM zone 21N",
"3313":"RGFG95 / UTM zone 21N",
"3314":"Katanga 1955 / Katanga Lambert",
"3315":"Katanga 1955 / Katanga TM",
"3316":"Kasai 1953 / Congo TM zone 22",
"3317":"Kasai 1953 / Congo TM zone 24",
"3318":"IGC 1962 / Congo TM zone 12",
"3319":"IGC 1962 / Congo TM zone 14",
"3320":"IGC 1962 / Congo TM zone 16",
"3321":"IGC 1962 / Congo TM zone 18",
"3322":"IGC 1962 / Congo TM zone 20",
"3323":"IGC 1962 / Congo TM zone 22",
"3324":"IGC 1962 / Congo TM zone 24",
"3325":"IGC 1962 / Congo TM zone 26",
"3326":"IGC 1962 / Congo TM zone 28",
"3327":"IGC 1962 / Congo TM zone 30",
"3328":"Pulkovo 1942(58) / GUGiK-80",
"3329":"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 5",
"3330":"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 6",
"3331":"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 7",
"3332":"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 8",
"3333":"Pulkovo 1942(58) / Gauss-Kruger zone 3",
"3334":"Pulkovo 1942(58) / Gauss-Kruger zone 4",
"3335":"Pulkovo 1942(58) / Gauss-Kruger zone 5",
"3336":"IGN 1962 Kerguelen / UTM zone 42S",
"3337":"Le Pouce 1934 / Mauritius Grid",
"3338":"NAD83 / Alaska Albers",
"3339":"IGCB 1955 / Congo TM zone 12",
"3340":"IGCB 1955 / Congo TM zone 14",
"3341":"IGCB 1955 / Congo TM zone 16",
"3342":"IGCB 1955 / UTM zone 33S",
"3343":"Mauritania 1999 / UTM zone 28N",
"3344":"Mauritania 1999 / UTM zone 29N",
"3345":"Mauritania 1999 / UTM zone 30N",
"3346":"LKS94 / Lithuania TM",
"3347":"NAD83 / Statistics Canada Lambert",
"3348":"NAD83(CSRS) / Statistics Canada Lambert",
"3349":"WGS 84 / PDC Mercator",
"3350":"Pulkovo 1942 / CS63 zone C0",
"3351":"Pulkovo 1942 / CS63 zone C1",
"3352":"Pulkovo 1942 / CS63 zone C2",
"3353":"Mhast (onshore) / UTM zone 32S",
"3354":"Mhast (offshore) / UTM zone 32S",
"3355":"Egypt Gulf of Suez S-650 TL / Red Belt",
"3356":"Grand Cayman 1959 / UTM zone 17N",
"3357":"Little Cayman 1961 / UTM zone 17N",
"3358":"NAD83(HARN) / North Carolina",
"3359":"NAD83(HARN) / North Carolina (ftUS)",
"3360":"NAD83(HARN) / South Carolina",
"3361":"NAD83(HARN) / South Carolina (ft)",
"3362":"NAD83(HARN) / Pennsylvania North",
"3363":"NAD83(HARN) / Pennsylvania North (ftUS)",
"3364":"NAD83(HARN) / Pennsylvania South",
"3365":"NAD83(HARN) / Pennsylvania South (ftUS)",
"3366":"Hong Kong 1963 Grid System",
"3367":"IGN Astro 1960 / UTM zone 28N",
"3368":"IGN Astro 1960 / UTM zone 29N",
"3369":"IGN Astro 1960 / UTM zone 30N",
"3370":"NAD27 / UTM zone 59N",
"3371":"NAD27 / UTM zone 60N",
"3372":"NAD83 / UTM zone 59N",
"3373":"NAD83 / UTM zone 60N",
"3374":"FD54 / UTM zone 29N",
"3375":"GDM2000 / Peninsula RSO",
"3376":"GDM2000 / East Malaysia BRSO",
"3377":"GDM2000 / Johor Grid",
"3378":"GDM2000 / Sembilan and Melaka Grid",
"3379":"GDM2000 / Pahang Grid",
"3380":"GDM2000 / Selangor Grid",
"3381":"GDM2000 / Terengganu Grid",
"3382":"GDM2000 / Pinang Grid",
"3383":"GDM2000 / Kedah and Perlis Grid",
"3384":"GDM2000 / Perak Grid",
"3385":"GDM2000 / Kelantan Grid",
"3386":"KKJ / Finland zone 0",
"3387":"KKJ / Finland zone 5",
"3388":"Pulkovo 1942 / Caspian Sea Mercator",
"3389":"Pulkovo 1942 / 3-degree Gauss-Kruger zone 60",
"3390":"Pulkovo 1995 / 3-degree Gauss-Kruger zone 60",
"3391":"Karbala 1979 / UTM zone 37N",
"3392":"Karbala 1979 / UTM zone 38N",
"3393":"Karbala 1979 / UTM zone 39N",
"3394":"Nahrwan 1934 / Iraq zone",
"3395":"WGS 84 / World Mercator",
"3396":"PD/83 / 3-degree Gauss-Kruger zone 3",
"3397":"PD/83 / 3-degree Gauss-Kruger zone 4",
"3398":"RD/83 / 3-degree Gauss-Kruger zone 4",
"3399":"RD/83 / 3-degree Gauss-Kruger zone 5",
"3400":"NAD83 / Alberta 10-TM (Forest)",
"3401":"NAD83 / Alberta 10-TM (Resource)",
"3402":"NAD83(CSRS) / Alberta 10-TM (Forest)",
"3403":"NAD83(CSRS) / Alberta 10-TM (Resource)",
"3404":"NAD83(HARN) / North Carolina (ftUS)",
"3405":"VN-2000 / UTM zone 48N",
"3406":"VN-2000 / UTM zone 49N",
"3407":"Hong Kong 1963 Grid System",
"3408":"NSIDC EASE-Grid North",
"3409":"NSIDC EASE-Grid South",
"3410":"NSIDC EASE-Grid Global",
"3411":"NSIDC Sea Ice Polar Stereographic North",
"3412":"NSIDC Sea Ice Polar Stereographic South",
"3413":"WGS 84 / NSIDC Sea Ice Polar Stereographic North",
"3414":"SVY21 / Singapore TM",
"3415":"WGS 72BE / South China Sea Lambert",
"3416":"ETRS89 / Austria Lambert",
"3417":"NAD83 / Iowa North (ftUS)",
"3418":"NAD83 / Iowa South (ftUS)",
"3419":"NAD83 / Kansas North (ftUS)",
"3420":"NAD83 / Kansas South (ftUS)",
"3421":"NAD83 / Nevada East (ftUS)",
"3422":"NAD83 / Nevada Central (ftUS)",
"3423":"NAD83 / Nevada West (ftUS)",
"3424":"NAD83 / New Jersey (ftUS)",
"3425":"NAD83(HARN) / Iowa North (ftUS)",
"3426":"NAD83(HARN) / Iowa South (ftUS)",
"3427":"NAD83(HARN) / Kansas North (ftUS)",
"3428":"NAD83(HARN) / Kansas South (ftUS)",
"3429":"NAD83(HARN) / Nevada East (ftUS)",
"3430":"NAD83(HARN) / Nevada Central (ftUS)",
"3431":"NAD83(HARN) / Nevada West (ftUS)",
"3432":"NAD83(HARN) / New Jersey (ftUS)",
"3433":"NAD83 / Arkansas North (ftUS)",
"3434":"NAD83 / Arkansas South (ftUS)",
"3435":"NAD83 / Illinois East (ftUS)",
"3436":"NAD83 / Illinois West (ftUS)",
"3437":"NAD83 / New Hampshire (ftUS)",
"3438":"NAD83 / Rhode Island (ftUS)",
"3439":"PSD93 / UTM zone 39N",
"3440":"PSD93 / UTM zone 40N",
"3441":"NAD83(HARN) / Arkansas North (ftUS)",
"3442":"NAD83(HARN) / Arkansas South (ftUS)",
"3443":"NAD83(HARN) / Illinois East (ftUS)",
"3444":"NAD83(HARN) / Illinois West (ftUS)",
"3445":"NAD83(HARN) / New Hampshire (ftUS)",
"3446":"NAD83(HARN) / Rhode Island (ftUS)",
"3447":"ETRS89 / Belgian Lambert 2005",
"3448":"JAD2001 / Jamaica Metric Grid",
"3449":"JAD2001 / UTM zone 17N",
"3450":"JAD2001 / UTM zone 18N",
"3451":"NAD83 / Louisiana North (ftUS)",
"3452":"NAD83 / Louisiana South (ftUS)",
"3453":"NAD83 / Louisiana Offshore (ftUS)",
"3454":"NAD83 / South Dakota North (ftUS)",
"3455":"NAD83 / South Dakota South (ftUS)",
"3456":"NAD83(HARN) / Louisiana North (ftUS)",
"3457":"NAD83(HARN) / Louisiana South (ftUS)",
"3458":"NAD83(HARN) / South Dakota North (ftUS)",
"3459":"NAD83(HARN) / South Dakota South (ftUS)",
"3460":"Fiji 1986 / Fiji Map Grid",
"3461":"Dabola 1981 / UTM zone 28N",
"3462":"Dabola 1981 / UTM zone 29N",
"3463":"NAD83 / Maine CS2000 Central",
"3464":"NAD83(HARN) / Maine CS2000 Central",
"3465":"NAD83(NSRS2007) / Alabama East",
"3466":"NAD83(NSRS2007) / Alabama West",
"3467":"NAD83(NSRS2007) / Alaska Albers",
"3468":"NAD83(NSRS2007) / Alaska zone 1",
"3469":"NAD83(NSRS2007) / Alaska zone 2",
"3470":"NAD83(NSRS2007) / Alaska zone 3",
"3471":"NAD83(NSRS2007) / Alaska zone 4",
"3472":"NAD83(NSRS2007) / Alaska zone 5",
"3473":"NAD83(NSRS2007) / Alaska zone 6",
"3474":"NAD83(NSRS2007) / Alaska zone 7",
"3475":"NAD83(NSRS2007) / Alaska zone 8",
"3476":"NAD83(NSRS2007) / Alaska zone 9",
"3477":"NAD83(NSRS2007) / Alaska zone 10",
"3478":"NAD83(NSRS2007) / Arizona Central",
"3479":"NAD83(NSRS2007) / Arizona Central (ft)",
"3480":"NAD83(NSRS2007) / Arizona East",
"3481":"NAD83(NSRS2007) / Arizona East (ft)",
"3482":"NAD83(NSRS2007) / Arizona West",
"3483":"NAD83(NSRS2007) / Arizona West (ft)",
"3484":"NAD83(NSRS2007) / Arkansas North",
"3485":"NAD83(NSRS2007) / Arkansas North (ftUS)",
"3486":"NAD83(NSRS2007) / Arkansas South",
"3487":"NAD83(NSRS2007) / Arkansas South (ftUS)",
"3488":"NAD83(NSRS2007) / California Albers",
"3489":"NAD83(NSRS2007) / California zone 1",
"3490":"NAD83(NSRS2007) / California zone 1 (ftUS)",
"3491":"NAD83(NSRS2007) / California zone 2",
"3492":"NAD83(NSRS2007) / California zone 2 (ftUS)",
"3493":"NAD83(NSRS2007) / California zone 3",
"3494":"NAD83(NSRS2007) / California zone 3 (ftUS)",
"3495":"NAD83(NSRS2007) / California zone 4",
"3496":"NAD83(NSRS2007) / California zone 4 (ftUS)",
"3497":"NAD83(NSRS2007) / California zone 5",
"3498":"NAD83(NSRS2007) / California zone 5 (ftUS)",
"3499":"NAD83(NSRS2007) / California zone 6",
"3500":"NAD83(NSRS2007) / California zone 6 (ftUS)",
"3501":"NAD83(NSRS2007) / Colorado Central",
"3502":"NAD83(NSRS2007) / Colorado Central (ftUS)",
"3503":"NAD83(NSRS2007) / Colorado North",
"3504":"NAD83(NSRS2007) / Colorado North (ftUS)",
"3505":"NAD83(NSRS2007) / Colorado South",
"3506":"NAD83(NSRS2007) / Colorado South (ftUS)",
"3507":"NAD83(NSRS2007) / Connecticut",
"3508":"NAD83(NSRS2007) / Connecticut (ftUS)",
"3509":"NAD83(NSRS2007) / Delaware",
"3510":"NAD83(NSRS2007) / Delaware (ftUS)",
"3511":"NAD83(NSRS2007) / Florida East",
"3512":"NAD83(NSRS2007) / Florida East (ftUS)",
"3513":"NAD83(NSRS2007) / Florida GDL Albers",
"3514":"NAD83(NSRS2007) / Florida North",
"3515":"NAD83(NSRS2007) / Florida North (ftUS)",
"3516":"NAD83(NSRS2007) / Florida West",
"3517":"NAD83(NSRS2007) / Florida West (ftUS)",
"3518":"NAD83(NSRS2007) / Georgia East",
"3519":"NAD83(NSRS2007) / Georgia East (ftUS)",
"3520":"NAD83(NSRS2007) / Georgia West",
"3521":"NAD83(NSRS2007) / Georgia West (ftUS)",
"3522":"NAD83(NSRS2007) / Idaho Central",
"3523":"NAD83(NSRS2007) / Idaho Central (ftUS)",
"3524":"NAD83(NSRS2007) / Idaho East",
"3525":"NAD83(NSRS2007) / Idaho East (ftUS)",
"3526":"NAD83(NSRS2007) / Idaho West",
"3527":"NAD83(NSRS2007) / Idaho West (ftUS)",
"3528":"NAD83(NSRS2007) / Illinois East",
"3529":"NAD83(NSRS2007) / Illinois East (ftUS)",
"3530":"NAD83(NSRS2007) / Illinois West",
"3531":"NAD83(NSRS2007) / Illinois West (ftUS)",
"3532":"NAD83(NSRS2007) / Indiana East",
"3533":"NAD83(NSRS2007) / Indiana East (ftUS)",
"3534":"NAD83(NSRS2007) / Indiana West",
"3535":"NAD83(NSRS2007) / Indiana West (ftUS)",
"3536":"NAD83(NSRS2007) / Iowa North",
"3537":"NAD83(NSRS2007) / Iowa North (ftUS)",
"3538":"NAD83(NSRS2007) / Iowa South",
"3539":"NAD83(NSRS2007) / Iowa South (ftUS)",
"3540":"NAD83(NSRS2007) / Kansas North",
"3541":"NAD83(NSRS2007) / Kansas North (ftUS)",
"3542":"NAD83(NSRS2007) / Kansas South",
"3543":"NAD83(NSRS2007) / Kansas South (ftUS)",
"3544":"NAD83(NSRS2007) / Kentucky North",
"3545":"NAD83(NSRS2007) / Kentucky North (ftUS)",
"3546":"NAD83(NSRS2007) / Kentucky Single Zone",
"3547":"NAD83(NSRS2007) / Kentucky Single Zone (ftUS)",
"3548":"NAD83(NSRS2007) / Kentucky South",
"3549":"NAD83(NSRS2007) / Kentucky South (ftUS)",
"3550":"NAD83(NSRS2007) / Louisiana North",
"3551":"NAD83(NSRS2007) / Louisiana North (ftUS)",
"3552":"NAD83(NSRS2007) / Louisiana South",
"3553":"NAD83(NSRS2007) / Louisiana South (ftUS)",
"3554":"NAD83(NSRS2007) / Maine CS2000 Central",
"3555":"NAD83(NSRS2007) / Maine CS2000 East",
"3556":"NAD83(NSRS2007) / Maine CS2000 West",
"3557":"NAD83(NSRS2007) / Maine East",
"3558":"NAD83(NSRS2007) / Maine West",
"3559":"NAD83(NSRS2007) / Maryland",
"3560":"NAD83 / Utah North (ftUS)",
"3561":"Old Hawaiian / Hawaii zone 1",
"3562":"Old Hawaiian / Hawaii zone 2",
"3563":"Old Hawaiian / Hawaii zone 3",
"3564":"Old Hawaiian / Hawaii zone 4",
"3565":"Old Hawaiian / Hawaii zone 5",
"3566":"NAD83 / Utah Central (ftUS)",
"3567":"NAD83 / Utah South (ftUS)",
"3568":"NAD83(HARN) / Utah North (ftUS)",
"3569":"NAD83(HARN) / Utah Central (ftUS)",
"3570":"NAD83(HARN) / Utah South (ftUS)",
"3571":"WGS 84 / North Pole LAEA Bering Sea",
"3572":"WGS 84 / North Pole LAEA Alaska",
"3573":"WGS 84 / North Pole LAEA Canada",
"3574":"WGS 84 / North Pole LAEA Atlantic",
"3575":"WGS 84 / North Pole LAEA Europe",
"3576":"WGS 84 / North Pole LAEA Russia",
"3577":"GDA94 / Australian Albers",
"3578":"NAD83 / Yukon Albers",
"3579":"NAD83(CSRS) / Yukon Albers",
"3580":"NAD83 / NWT Lambert",
"3581":"NAD83(CSRS) / NWT Lambert",
"3582":"NAD83(NSRS2007) / Maryland (ftUS)",
"3583":"NAD83(NSRS2007) / Massachusetts Island",
"3584":"NAD83(NSRS2007) / Massachusetts Island (ftUS)",
"3585":"NAD83(NSRS2007) / Massachusetts Mainland",
"3586":"NAD83(NSRS2007) / Massachusetts Mainland (ftUS)",
"3587":"NAD83(NSRS2007) / Michigan Central",
"3588":"NAD83(NSRS2007) / Michigan Central (ft)",
"3589":"NAD83(NSRS2007) / Michigan North",
"3590":"NAD83(NSRS2007) / Michigan North (ft)",
"3591":"NAD83(NSRS2007) / Michigan Oblique Mercator",
"3592":"NAD83(NSRS2007) / Michigan South",
"3593":"NAD83(NSRS2007) / Michigan South (ft)",
"3594":"NAD83(NSRS2007) / Minnesota Central",
"3595":"NAD83(NSRS2007) / Minnesota North",
"3596":"NAD83(NSRS2007) / Minnesota South",
"3597":"NAD83(NSRS2007) / Mississippi East",
"3598":"NAD83(NSRS2007) / Mississippi East (ftUS)",
"3599":"NAD83(NSRS2007) / Mississippi West",
"3600":"NAD83(NSRS2007) / Mississippi West (ftUS)",
"3601":"NAD83(NSRS2007) / Missouri Central",
"3602":"NAD83(NSRS2007) / Missouri East",
"3603":"NAD83(NSRS2007) / Missouri West",
"3604":"NAD83(NSRS2007) / Montana",
"3605":"NAD83(NSRS2007) / Montana (ft)",
"3606":"NAD83(NSRS2007) / Nebraska",
"3607":"NAD83(NSRS2007) / Nevada Central",
"3608":"NAD83(NSRS2007) / Nevada Central (ftUS)",
"3609":"NAD83(NSRS2007) / Nevada East",
"3610":"NAD83(NSRS2007) / Nevada East (ftUS)",
"3611":"NAD83(NSRS2007) / Nevada West",
"3612":"NAD83(NSRS2007) / Nevada West (ftUS)",
"3613":"NAD83(NSRS2007) / New Hampshire",
"3614":"NAD83(NSRS2007) / New Hampshire (ftUS)",
"3615":"NAD83(NSRS2007) / New Jersey",
"3616":"NAD83(NSRS2007) / New Jersey (ftUS)",
"3617":"NAD83(NSRS2007) / New Mexico Central",
"3618":"NAD83(NSRS2007) / New Mexico Central (ftUS)",
"3619":"NAD83(NSRS2007) / New Mexico East",
"3620":"NAD83(NSRS2007) / New Mexico East (ftUS)",
"3621":"NAD83(NSRS2007) / New Mexico West",
"3622":"NAD83(NSRS2007) / New Mexico West (ftUS)",
"3623":"NAD83(NSRS2007) / New York Central",
"3624":"NAD83(NSRS2007) / New York Central (ftUS)",
"3625":"NAD83(NSRS2007) / New York East",
"3626":"NAD83(NSRS2007) / New York East (ftUS)",
"3627":"NAD83(NSRS2007) / New York Long Island",
"3628":"NAD83(NSRS2007) / New York Long Island (ftUS)",
"3629":"NAD83(NSRS2007) / New York West",
"3630":"NAD83(NSRS2007) / New York West (ftUS)",
"3631":"NAD83(NSRS2007) / North Carolina",
"3632":"NAD83(NSRS2007) / North Carolina (ftUS)",
"3633":"NAD83(NSRS2007) / North Dakota North",
"3634":"NAD83(NSRS2007) / North Dakota North (ft)",
"3635":"NAD83(NSRS2007) / North Dakota South",
"3636":"NAD83(NSRS2007) / North Dakota South (ft)",
"3637":"NAD83(NSRS2007) / Ohio North",
"3638":"NAD83(NSRS2007) / Ohio South",
"3639":"NAD83(NSRS2007) / Oklahoma North",
"3640":"NAD83(NSRS2007) / Oklahoma North (ftUS)",
"3641":"NAD83(NSRS2007) / Oklahoma South",
"3642":"NAD83(NSRS2007) / Oklahoma South (ftUS)",
"3643":"NAD83(NSRS2007) / Oregon LCC (m)",
"3644":"NAD83(NSRS2007) / Oregon GIC Lambert (ft)",
"3645":"NAD83(NSRS2007) / Oregon North",
"3646":"NAD83(NSRS2007) / Oregon North (ft)",
"3647":"NAD83(NSRS2007) / Oregon South",
"3648":"NAD83(NSRS2007) / Oregon South (ft)",
"3649":"NAD83(NSRS2007) / Pennsylvania North",
"3650":"NAD83(NSRS2007) / Pennsylvania North (ftUS)",
"3651":"NAD83(NSRS2007) / Pennsylvania South",
"3652":"NAD83(NSRS2007) / Pennsylvania South (ftUS)",
"3653":"NAD83(NSRS2007) / Rhode Island",
"3654":"NAD83(NSRS2007) / Rhode Island (ftUS)",
"3655":"NAD83(NSRS2007) / South Carolina",
"3656":"NAD83(NSRS2007) / South Carolina (ft)",
"3657":"NAD83(NSRS2007) / South Dakota North",
"3658":"NAD83(NSRS2007) / South Dakota North (ftUS)",
"3659":"NAD83(NSRS2007) / South Dakota South",
"3660":"NAD83(NSRS2007) / South Dakota South (ftUS)",
"3661":"NAD83(NSRS2007) / Tennessee",
"3662":"NAD83(NSRS2007) / Tennessee (ftUS)",
"3663":"NAD83(NSRS2007) / Texas Central",
"3664":"NAD83(NSRS2007) / Texas Central (ftUS)",
"3665":"NAD83(NSRS2007) / Texas Centric Albers Equal Area",
"3666":"NAD83(NSRS2007) / Texas Centric Lambert Conformal",
"3667":"NAD83(NSRS2007) / Texas North",
"3668":"NAD83(NSRS2007) / Texas North (ftUS)",
"3669":"NAD83(NSRS2007) / Texas North Central",
"3670":"NAD83(NSRS2007) / Texas North Central (ftUS)",
"3671":"NAD83(NSRS2007) / Texas South",
"3672":"NAD83(NSRS2007) / Texas South (ftUS)",
"3673":"NAD83(NSRS2007) / Texas South Central",
"3674":"NAD83(NSRS2007) / Texas South Central (ftUS)",
"3675":"NAD83(NSRS2007) / Utah Central",
"3676":"NAD83(NSRS2007) / Utah Central (ft)",
"3677":"NAD83(NSRS2007) / Utah Central (ftUS)",
"3678":"NAD83(NSRS2007) / Utah North",
"3679":"NAD83(NSRS2007) / Utah North (ft)",
"3680":"NAD83(NSRS2007) / Utah North (ftUS)",
"3681":"NAD83(NSRS2007) / Utah South",
"3682":"NAD83(NSRS2007) / Utah South (ft)",
"3683":"NAD83(NSRS2007) / Utah South (ftUS)",
"3684":"NAD83(NSRS2007) / Vermont",
"3685":"NAD83(NSRS2007) / Virginia North",
"3686":"NAD83(NSRS2007) / Virginia North (ftUS)",
"3687":"NAD83(NSRS2007) / Virginia South",
"3688":"NAD83(NSRS2007) / Virginia South (ftUS)",
"3689":"NAD83(NSRS2007) / Washington North",
"3690":"NAD83(NSRS2007) / Washington North (ftUS)",
"3691":"NAD83(NSRS2007) / Washington South",
"3692":"NAD83(NSRS2007) / Washington South (ftUS)",
"3693":"NAD83(NSRS2007) / West Virginia North",
"3694":"NAD83(NSRS2007) / West Virginia South",
"3695":"NAD83(NSRS2007) / Wisconsin Central",
"3696":"NAD83(NSRS2007) / Wisconsin Central (ftUS)",
"3697":"NAD83(NSRS2007) / Wisconsin North",
"3698":"NAD83(NSRS2007) / Wisconsin North (ftUS)",
"3699":"NAD83(NSRS2007) / Wisconsin South",
"3700":"NAD83(NSRS2007) / Wisconsin South (ftUS)",
"3701":"NAD83(NSRS2007) / Wisconsin Transverse Mercator",
"3702":"NAD83(NSRS2007) / Wyoming East",
"3703":"NAD83(NSRS2007) / Wyoming East Central",
"3704":"NAD83(NSRS2007) / Wyoming West Central",
"3705":"NAD83(NSRS2007) / Wyoming West",
"3706":"NAD83(NSRS2007) / UTM zone 59N",
"3707":"NAD83(NSRS2007) / UTM zone 60N",
"3708":"NAD83(NSRS2007) / UTM zone 1N",
"3709":"NAD83(NSRS2007) / UTM zone 2N",
"3710":"NAD83(NSRS2007) / UTM zone 3N",
"3711":"NAD83(NSRS2007) / UTM zone 4N",
"3712":"NAD83(NSRS2007) / UTM zone 5N",
"3713":"NAD83(NSRS2007) / UTM zone 6N",
"3714":"NAD83(NSRS2007) / UTM zone 7N",
"3715":"NAD83(NSRS2007) / UTM zone 8N",
"3716":"NAD83(NSRS2007) / UTM zone 9N",
"3717":"NAD83(NSRS2007) / UTM zone 10N",
"3718":"NAD83(NSRS2007) / UTM zone 11N",
"3719":"NAD83(NSRS2007) / UTM zone 12N",
"3720":"NAD83(NSRS2007) / UTM zone 13N",
"3721":"NAD83(NSRS2007) / UTM zone 14N",
"3722":"NAD83(NSRS2007) / UTM zone 15N",
"3723":"NAD83(NSRS2007) / UTM zone 16N",
"3724":"NAD83(NSRS2007) / UTM zone 17N",
"3725":"NAD83(NSRS2007) / UTM zone 18N",
"3726":"NAD83(NSRS2007) / UTM zone 19N",
"3727":"Reunion 1947 / TM Reunion",
"3728":"NAD83(NSRS2007) / Ohio North (ftUS)",
"3729":"NAD83(NSRS2007) / Ohio South (ftUS)",
"3730":"NAD83(NSRS2007) / Wyoming East (ftUS)",
"3731":"NAD83(NSRS2007) / Wyoming East Central (ftUS)",
"3732":"NAD83(NSRS2007) / Wyoming West Central (ftUS)",
"3733":"NAD83(NSRS2007) / Wyoming West (ftUS)",
"3734":"NAD83 / Ohio North (ftUS)",
"3735":"NAD83 / Ohio South (ftUS)",
"3736":"NAD83 / Wyoming East (ftUS)",
"3737":"NAD83 / Wyoming East Central (ftUS)",
"3738":"NAD83 / Wyoming West Central (ftUS)",
"3739":"NAD83 / Wyoming West (ftUS)",
"3740":"NAD83(HARN) / UTM zone 10N",
"3741":"NAD83(HARN) / UTM zone 11N",
"3742":"NAD83(HARN) / UTM zone 12N",
"3743":"NAD83(HARN) / UTM zone 13N",
"3744":"NAD83(HARN) / UTM zone 14N",
"3745":"NAD83(HARN) / UTM zone 15N",
"3746":"NAD83(HARN) / UTM zone 16N",
"3747":"NAD83(HARN) / UTM zone 17N",
"3748":"NAD83(HARN) / UTM zone 18N",
"3749":"NAD83(HARN) / UTM zone 19N",
"3750":"NAD83(HARN) / UTM zone 4N",
"3751":"NAD83(HARN) / UTM zone 5N",
"3752":"WGS 84 / Mercator 41",
"3753":"NAD83(HARN) / Ohio North (ftUS)",
"3754":"NAD83(HARN) / Ohio South (ftUS)",
"3755":"NAD83(HARN) / Wyoming East (ftUS)",
"3756":"NAD83(HARN) / Wyoming East Central (ftUS)",
"3757":"NAD83(HARN) / Wyoming West Central (ftUS)",
"3758":"NAD83(HARN) / Wyoming West (ftUS)",
"3759":"NAD83 / Hawaii zone 3 (ftUS)",
"3760":"NAD83(HARN) / Hawaii zone 3 (ftUS)",
"3761":"NAD83(CSRS) / UTM zone 22N",
"3762":"WGS 84 / South Georgia Lambert",
"3763":"ETRS89 / Portugal TM06",
"3764":"NZGD2000 / Chatham Island Circuit 2000",
"3765":"HTRS96 / Croatia TM",
"3766":"HTRS96 / Croatia LCC",
"3767":"HTRS96 / UTM zone 33N",
"3768":"HTRS96 / UTM zone 34N",
"3769":"Bermuda 1957 / UTM zone 20N",
"3770":"BDA2000 / Bermuda 2000 National Grid",
"3771":"NAD27 / Alberta 3TM ref merid 111 W",
"3772":"NAD27 / Alberta 3TM ref merid 114 W",
"3773":"NAD27 / Alberta 3TM ref merid 117 W",
"3774":"NAD27 / Alberta 3TM ref merid 120 W",
"3775":"NAD83 / Alberta 3TM ref merid 111 W",
"3776":"NAD83 / Alberta 3TM ref merid 114 W",
"3777":"NAD83 / Alberta 3TM ref merid 117 W",
"3778":"NAD83 / Alberta 3TM ref merid 120 W",
"3779":"NAD83(CSRS) / Alberta 3TM ref merid 111 W",
"3780":"NAD83(CSRS) / Alberta 3TM ref merid 114 W",
"3781":"NAD83(CSRS) / Alberta 3TM ref merid 117 W",
"3782":"NAD83(CSRS) / Alberta 3TM ref merid 120 W",
"3783":"Pitcairn 2006 / Pitcairn TM 2006",
"3784":"Pitcairn 1967 / UTM zone 9S",
"3785":"Popular Visualisation CRS / Mercator",
"3786":"World Equidistant Cylindrical (Sphere)",
"3787":"MGI / Slovene National Grid",
"3788":"NZGD2000 / Auckland Islands TM 2000",
"3789":"NZGD2000 / Campbell Island TM 2000",
"3790":"NZGD2000 / Antipodes Islands TM 2000",
"3791":"NZGD2000 / Raoul Island TM 2000",
"3793":"NZGD2000 / Chatham Islands TM 2000",
"3794":"Slovenia 1996 / Slovene National Grid",
"3795":"NAD27 / Cuba Norte",
"3796":"NAD27 / Cuba Sur",
"3797":"NAD27 / MTQ Lambert",
"3798":"NAD83 / MTQ Lambert",
"3799":"NAD83(CSRS) / MTQ Lambert",
"3800":"NAD27 / Alberta 3TM ref merid 120 W",
"3801":"NAD83 / Alberta 3TM ref merid 120 W",
"3802":"NAD83(CSRS) / Alberta 3TM ref merid 120 W",
"3812":"ETRS89 / Belgian Lambert 2008",
"3814":"NAD83 / Mississippi TM",
"3815":"NAD83(HARN) / Mississippi TM",
"3816":"NAD83(NSRS2007) / Mississippi TM",
"3819":"HD1909",
"3821":"TWD67",
"3822":"TWD97",
"3823":"TWD97",
"3824":"TWD97",
"3825":"TWD97 / TM2 zone 119",
"3826":"TWD97 / TM2 zone 121",
"3827":"TWD67 / TM2 zone 119",
"3828":"TWD67 / TM2 zone 121",
"3829":"Hu Tzu Shan 1950 / UTM zone 51N",
"3832":"WGS 84 / PDC Mercator",
"3833":"Pulkovo 1942(58) / Gauss-Kruger zone 2",
"3834":"Pulkovo 1942(83) / Gauss-Kruger zone 2",
"3835":"Pulkovo 1942(83) / Gauss-Kruger zone 3",
"3836":"Pulkovo 1942(83) / Gauss-Kruger zone 4",
"3837":"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 3",
"3838":"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 4",
"3839":"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 9",
"3840":"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 10",
"3841":"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 6",
"3842":"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 7",
"3843":"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 8",
"3844":"Pulkovo 1942(58) / Stereo70",
"3845":"SWEREF99 / RT90 7.5 gon V emulation",
"3846":"SWEREF99 / RT90 5 gon V emulation",
"3847":"SWEREF99 / RT90 2.5 gon V emulation",
"3848":"SWEREF99 / RT90 0 gon emulation",
"3849":"SWEREF99 / RT90 2.5 gon O emulation",
"3850":"SWEREF99 / RT90 5 gon O emulation",
"3851":"NZGD2000 / NZCS2000",
"3852":"RSRGD2000 / DGLC2000",
"3854":"County ST74",
"3855":"EGM2008 height",
"3857":"WGS 84 / Pseudo-Mercator",
"3873":"ETRS89 / GK19FIN",
"3874":"ETRS89 / GK20FIN",
"3875":"ETRS89 / GK21FIN",
"3876":"ETRS89 / GK22FIN",
"3877":"ETRS89 / GK23FIN",
"3878":"ETRS89 / GK24FIN",
"3879":"ETRS89 / GK25FIN",
"3880":"ETRS89 / GK26FIN",
"3881":"ETRS89 / GK27FIN",
"3882":"ETRS89 / GK28FIN",
"3883":"ETRS89 / GK29FIN",
"3884":"ETRS89 / GK30FIN",
"3885":"ETRS89 / GK31FIN",
"3886":"Fao 1979 height",
"3887":"IGRS",
"3888":"IGRS",
"3889":"IGRS",
"3890":"IGRS / UTM zone 37N",
"3891":"IGRS / UTM zone 38N",
"3892":"IGRS / UTM zone 39N",
"3893":"ED50 / Iraq National Grid",
"3900":"N2000 height",
"3901":"KKJ / Finland Uniform Coordinate System + N60 height",
"3902":"ETRS89 / TM35FIN(N,E) + N60 height",
"3903":"ETRS89 / TM35FIN(N,E) + N2000 height",
"3906":"MGI 1901",
"3907":"MGI 1901 / Balkans zone 5",
"3908":"MGI 1901 / Balkans zone 6",
"3909":"MGI 1901 / Balkans zone 7",
"3910":"MGI 1901 / Balkans zone 8",
"3911":"MGI 1901 / Slovenia Grid",
"3912":"MGI 1901 / Slovene National Grid",
"3920":"Puerto Rico / UTM zone 20N",
"3942":"RGF93 / CC42",
"3943":"RGF93 / CC43",
"3944":"RGF93 / CC44",
"3945":"RGF93 / CC45",
"3946":"RGF93 / CC46",
"3947":"RGF93 / CC47",
"3948":"RGF93 / CC48",
"3949":"RGF93 / CC49",
"3950":"RGF93 / CC50",
"3968":"NAD83 / Virginia Lambert",
"3969":"NAD83(HARN) / Virginia Lambert",
"3970":"NAD83(NSRS2007) / Virginia Lambert",
"3973":"WGS 84 / NSIDC EASE-Grid North",
"3974":"WGS 84 / NSIDC EASE-Grid South",
"3975":"WGS 84 / NSIDC EASE-Grid Global",
"3976":"WGS 84 / NSIDC Sea Ice Polar Stereographic South",
"3978":"NAD83 / Canada Atlas Lambert",
"3979":"NAD83(CSRS) / Canada Atlas Lambert",
"3985":"Katanga 1955 / Katanga Lambert",
"3986":"Katanga 1955 / Katanga Gauss zone A",
"3987":"Katanga 1955 / Katanga Gauss zone B",
"3988":"Katanga 1955 / Katanga Gauss zone C",
"3989":"Katanga 1955 / Katanga Gauss zone D",
"3991":"Puerto Rico State Plane CS of 1927",
"3992":"Puerto Rico / St. Croix",
"3993":"Guam 1963 / Guam SPCS",
"3994":"WGS 84 / Mercator 41",
"3995":"WGS 84 / Arctic Polar Stereographic",
"3996":"WGS 84 / IBCAO Polar Stereographic",
"3997":"WGS 84 / Dubai Local TM",
"4000":"MOLDREF99",
"4001":"Unknown datum based upon the Airy 1830 ellipsoid",
"4002":"Unknown datum based upon the Airy Modified 1849 ellipsoid",
"4003":"Unknown datum based upon the Australian National Spheroid",
"4004":"Unknown datum based upon the Bessel 1841 ellipsoid",
"4005":"Unknown datum based upon the Bessel Modified ellipsoid",
"4006":"Unknown datum based upon the Bessel Namibia ellipsoid",
"4007":"Unknown datum based upon the Clarke 1858 ellipsoid",
"4008":"Unknown datum based upon the Clarke 1866 ellipsoid",
"4009":"Unknown datum based upon the Clarke 1866 Michigan ellipsoid",
"4010":"Unknown datum based upon the Clarke 1880 (Benoit) ellipsoid",
"4011":"Unknown datum based upon the Clarke 1880 (IGN) ellipsoid",
"4012":"Unknown datum based upon the Clarke 1880 (RGS) ellipsoid",
"4013":"Unknown datum based upon the Clarke 1880 (Arc) ellipsoid",
"4014":"Unknown datum based upon the Clarke 1880 (SGA 1922) ellipsoid",
"4015":"Unknown datum based upon the Everest 1830 (1937 Adjustment) ellipsoid",
"4016":"Unknown datum based upon the Everest 1830 (1967 Definition) ellipsoid",
"4017":"MOLDREF99",
"4018":"Unknown datum based upon the Everest 1830 Modified ellipsoid",
"4019":"Unknown datum based upon the GRS 1980 ellipsoid",
"4020":"Unknown datum based upon the Helmert 1906 ellipsoid",
"4021":"Unknown datum based upon the Indonesian National Spheroid",
"4022":"Unknown datum based upon the International 1924 ellipsoid",
"4023":"MOLDREF99",
"4024":"Unknown datum based upon the Krassowsky 1940 ellipsoid",
"4025":"Unknown datum based upon the NWL 9D ellipsoid",
"4026":"MOLDREF99 / Moldova TM",
"4027":"Unknown datum based upon the Plessis 1817 ellipsoid",
"4028":"Unknown datum based upon the Struve 1860 ellipsoid",
"4029":"Unknown datum based upon the War Office ellipsoid",
"4030":"Unknown datum based upon the WGS 84 ellipsoid",
"4031":"Unknown datum based upon the GEM 10C ellipsoid",
"4032":"Unknown datum based upon the OSU86F ellipsoid",
"4033":"Unknown datum based upon the OSU91A ellipsoid",
"4034":"Unknown datum based upon the Clarke 1880 ellipsoid",
"4035":"Unknown datum based upon the Authalic Sphere",
"4036":"Unknown datum based upon the GRS 1967 ellipsoid",
"4037":"WGS 84 / TMzn35N",
"4038":"WGS 84 / TMzn36N",
"4039":"RGRDC 2005",
"4040":"RGRDC 2005",
"4041":"Unknown datum based upon the Average Terrestrial System 1977 ellipsoid",
"4042":"Unknown datum based upon the Everest (1830 Definition) ellipsoid",
"4043":"Unknown datum based upon the WGS 72 ellipsoid",
"4044":"Unknown datum based upon the Everest 1830 (1962 Definition) ellipsoid",
"4045":"Unknown datum based upon the Everest 1830 (1975 Definition) ellipsoid",
"4046":"RGRDC 2005",
"4047":"Unspecified datum based upon the GRS 1980 Authalic Sphere",
"4048":"RGRDC 2005 / Congo TM zone 12",
"4049":"RGRDC 2005 / Congo TM zone 14",
"4050":"RGRDC 2005 / Congo TM zone 16",
"4051":"RGRDC 2005 / Congo TM zone 18",
"4052":"Unspecified datum based upon the Clarke 1866 Authalic Sphere",
"4053":"Unspecified datum based upon the International 1924 Authalic Sphere",
"4054":"Unspecified datum based upon the Hughes 1980 ellipsoid",
"4055":"Popular Visualisation CRS",
"4056":"RGRDC 2005 / Congo TM zone 20",
"4057":"RGRDC 2005 / Congo TM zone 22",
"4058":"RGRDC 2005 / Congo TM zone 24",
"4059":"RGRDC 2005 / Congo TM zone 26",
"4060":"RGRDC 2005 / Congo TM zone 28",
"4061":"RGRDC 2005 / UTM zone 33S",
"4062":"RGRDC 2005 / UTM zone 34S",
"4063":"RGRDC 2005 / UTM zone 35S",
"4071":"Chua / UTM zone 23S",
"4073":"SREF98",
"4074":"SREF98",
"4075":"SREF98",
"4079":"REGCAN95",
"4080":"REGCAN95",
"4081":"REGCAN95",
"4082":"REGCAN95 / UTM zone 27N",
"4083":"REGCAN95 / UTM zone 28N",
"4087":"WGS 84 / World Equidistant Cylindrical",
"4088":"World Equidistant Cylindrical (Sphere)",
"4093":"ETRS89 / DKTM1",
"4094":"ETRS89 / DKTM2",
"4095":"ETRS89 / DKTM3",
"4096":"ETRS89 / DKTM4",
"4097":"ETRS89 / DKTM1 + DVR90 height",
"4098":"ETRS89 / DKTM2 + DVR90 height",
"4099":"ETRS89 / DKTM3 + DVR90 height",
"4100":"ETRS89 / DKTM4 + DVR90 height",
"4120":"Greek",
"4121":"GGRS87",
"4122":"ATS77",
"4123":"KKJ",
"4124":"RT90",
"4125":"Samboja",
"4126":"LKS94 (ETRS89)",
"4127":"Tete",
"4128":"Madzansua",
"4129":"Observatario",
"4130":"Moznet",
"4131":"Indian 1960",
"4132":"FD58",
"4133":"EST92",
"4134":"PSD93",
"4135":"Old Hawaiian",
"4136":"St. Lawrence Island",
"4137":"St. Paul Island",
"4138":"St. George Island",
"4139":"Puerto Rico",
"4140":"NAD83(CSRS98)",
"4141":"Israel 1993",
"4142":"Locodjo 1965",
"4143":"Abidjan 1987",
"4144":"Kalianpur 1937",
"4145":"Kalianpur 1962",
"4146":"Kalianpur 1975",
"4147":"Hanoi 1972",
"4148":"Hartebeesthoek94",
"4149":"CH1903",
"4150":"CH1903+",
"4151":"CHTRF95",
"4152":"NAD83(HARN)",
"4153":"Rassadiran",
"4154":"ED50(ED77)",
"4155":"Dabola 1981",
"4156":"S-JTSK",
"4157":"Mount Dillon",
"4158":"Naparima 1955",
"4159":"ELD79",
"4160":"Chos Malal 1914",
"4161":"Pampa del Castillo",
"4162":"Korean 1985",
"4163":"Yemen NGN96",
"4164":"South Yemen",
"4165":"Bissau",
"4166":"Korean 1995",
"4167":"NZGD2000",
"4168":"Accra",
"4169":"American Samoa 1962",
"4170":"SIRGAS 1995",
"4171":"RGF93",
"4172":"POSGAR",
"4173":"IRENET95",
"4174":"Sierra Leone 1924",
"4175":"Sierra Leone 1968",
"4176":"Australian Antarctic",
"4178":"Pulkovo 1942(83)",
"4179":"Pulkovo 1942(58)",
"4180":"EST97",
"4181":"Luxembourg 1930",
"4182":"Azores Occidental 1939",
"4183":"Azores Central 1948",
"4184":"Azores Oriental 1940",
"4185":"Madeira 1936",
"4188":"OSNI 1952",
"4189":"REGVEN",
"4190":"POSGAR 98",
"4191":"Albanian 1987",
"4192":"Douala 1948",
"4193":"Manoca 1962",
"4194":"Qornoq 1927",
"4195":"Scoresbysund 1952",
"4196":"Ammassalik 1958",
"4197":"Garoua",
"4198":"Kousseri",
"4199":"Egypt 1930",
"4200":"Pulkovo 1995",
"4201":"Adindan",
"4202":"AGD66",
"4203":"AGD84",
"4204":"Ain el Abd",
"4205":"Afgooye",
"4206":"Agadez",
"4207":"Lisbon",
"4208":"Aratu",
"4209":"Arc 1950",
"4210":"Arc 1960",
"4211":"Batavia",
"4212":"Barbados 1938",
"4213":"Beduaram",
"4214":"Beijing 1954",
"4215":"Belge 1950",
"4216":"Bermuda 1957",
"4217":"NAD83 / BLM 59N (ftUS)",
"4218":"Bogota 1975",
"4219":"Bukit Rimpah",
"4220":"Camacupa",
"4221":"Campo Inchauspe",
"4222":"Cape",
"4223":"Carthage",
"4224":"Chua",
"4225":"Corrego Alegre 1970-72",
"4226":"Cote d'Ivoire",
"4227":"Deir ez Zor",
"4228":"Douala",
"4229":"Egypt 1907",
"4230":"ED50",
"4231":"ED87",
"4232":"Fahud",
"4233":"Gandajika 1970",
"4234":"Garoua",
"4235":"Guyane Francaise",
"4236":"Hu Tzu Shan 1950",
"4237":"HD72",
"4238":"ID74",
"4239":"Indian 1954",
"4240":"Indian 1975",
"4241":"Jamaica 1875",
"4242":"JAD69",
"4243":"Kalianpur 1880",
"4244":"Kandawala",
"4245":"Kertau 1968",
"4246":"KOC",
"4247":"La Canoa",
"4248":"PSAD56",
"4249":"Lake",
"4250":"Leigon",
"4251":"Liberia 1964",
"4252":"Lome",
"4253":"Luzon 1911",
"4254":"Hito XVIII 1963",
"4255":"Herat North",
"4256":"Mahe 1971",
"4257":"Makassar",
"4258":"ETRS89",
"4259":"Malongo 1987",
"4260":"Manoca",
"4261":"Merchich",
"4262":"Massawa",
"4263":"Minna",
"4264":"Mhast",
"4265":"Monte Mario",
"4266":"M'poraloko",
"4267":"NAD27",
"4268":"NAD27 Michigan",
"4269":"NAD83",
"4270":"Nahrwan 1967",
"4271":"Naparima 1972",
"4272":"NZGD49",
"4273":"NGO 1948",
"4274":"Datum 73",
"4275":"NTF",
"4276":"NSWC 9Z-2",
"4277":"OSGB 1936",
"4278":"OSGB70",
"4279":"OS(SN)80",
"4280":"Padang",
"4281":"Palestine 1923",
"4282":"Pointe Noire",
"4283":"GDA94",
"4284":"Pulkovo 1942",
"4285":"Qatar 1974",
"4286":"Qatar 1948",
"4287":"Qornoq",
"4288":"Loma Quintana",
"4289":"Amersfoort",
"4291":"SAD69",
"4292":"Sapper Hill 1943",
"4293":"Schwarzeck",
"4294":"Segora",
"4295":"Serindung",
"4296":"Sudan",
"4297":"Tananarive",
"4298":"Timbalai 1948",
"4299":"TM65",
"4300":"TM75",
"4301":"Tokyo",
"4302":"Trinidad 1903",
"4303":"TC(1948)",
"4304":"Voirol 1875",
"4306":"Bern 1938",
"4307":"Nord Sahara 1959",
"4308":"RT38",
"4309":"Yacare",
"4310":"Yoff",
"4311":"Zanderij",
"4312":"MGI",
"4313":"Belge 1972",
"4314":"DHDN",
"4315":"Conakry 1905",
"4316":"Dealul Piscului 1930",
"4317":"Dealul Piscului 1970",
"4318":"NGN",
"4319":"KUDAMS",
"4322":"WGS 72",
"4324":"WGS 72BE",
"4326":"WGS 84",
"4327":"WGS 84 (geographic 3D)",
"4328":"WGS 84 (geocentric)",
"4329":"WGS 84 (3D)",
"4330":"ITRF88 (geocentric)",
"4331":"ITRF89 (geocentric)",
"4332":"ITRF90 (geocentric)",
"4333":"ITRF91 (geocentric)",
"4334":"ITRF92 (geocentric)",
"4335":"ITRF93 (geocentric)",
"4336":"ITRF94 (geocentric)",
"4337":"ITRF96 (geocentric)",
"4338":"ITRF97 (geocentric)",
"4339":"Australian Antarctic (3D)",
"4340":"Australian Antarctic (geocentric)",
"4341":"EST97 (3D)",
"4342":"EST97 (geocentric)",
"4343":"CHTRF95 (3D)",
"4344":"CHTRF95 (geocentric)",
"4345":"ETRS89 (3D)",
"4346":"ETRS89 (geocentric)",
"4347":"GDA94 (3D)",
"4348":"GDA94 (geocentric)",
"4349":"Hartebeesthoek94 (3D)",
"4350":"Hartebeesthoek94 (geocentric)",
"4351":"IRENET95 (3D)",
"4352":"IRENET95 (geocentric)",
"4353":"JGD2000 (3D)",
"4354":"JGD2000 (geocentric)",
"4355":"LKS94 (ETRS89) (3D)",
"4356":"LKS94 (ETRS89) (geocentric)",
"4357":"Moznet (3D)",
"4358":"Moznet (geocentric)",
"4359":"NAD83(CSRS) (3D)",
"4360":"NAD83(CSRS) (geocentric)",
"4361":"NAD83(HARN) (3D)",
"4362":"NAD83(HARN) (geocentric)",
"4363":"NZGD2000 (3D)",
"4364":"NZGD2000 (geocentric)",
"4365":"POSGAR 98 (3D)",
"4366":"POSGAR 98 (geocentric)",
"4367":"REGVEN (3D)",
"4368":"REGVEN (geocentric)",
"4369":"RGF93 (3D)",
"4370":"RGF93 (geocentric)",
"4371":"RGFG95 (3D)",
"4372":"RGFG95 (geocentric)",
"4373":"RGR92 (3D)",
"4374":"RGR92 (geocentric)",
"4375":"SIRGAS (3D)",
"4376":"SIRGAS (geocentric)",
"4377":"SWEREF99 (3D)",
"4378":"SWEREF99 (geocentric)",
"4379":"Yemen NGN96 (3D)",
"4380":"Yemen NGN96 (geocentric)",
"4381":"RGNC 1991 (3D)",
"4382":"RGNC 1991 (geocentric)",
"4383":"RRAF 1991 (3D)",
"4384":"RRAF 1991 (geocentric)",
"4385":"ITRF2000 (geocentric)",
"4386":"ISN93 (3D)",
"4387":"ISN93 (geocentric)",
"4388":"LKS92 (3D)",
"4389":"LKS92 (geocentric)",
"4390":"Kertau 1968 / Johor Grid",
"4391":"Kertau 1968 / Sembilan and Melaka Grid",
"4392":"Kertau 1968 / Pahang Grid",
"4393":"Kertau 1968 / Selangor Grid",
"4394":"Kertau 1968 / Terengganu Grid",
"4395":"Kertau 1968 / Pinang Grid",
"4396":"Kertau 1968 / Kedah and Perlis Grid",
"4397":"Kertau 1968 / Perak Revised Grid",
"4398":"Kertau 1968 / Kelantan Grid",
"4399":"NAD27 / BLM 59N (ftUS)",
"4400":"NAD27 / BLM 60N (ftUS)",
"4401":"NAD27 / BLM 1N (ftUS)",
"4402":"NAD27 / BLM 2N (ftUS)",
"4403":"NAD27 / BLM 3N (ftUS)",
"4404":"NAD27 / BLM 4N (ftUS)",
"4405":"NAD27 / BLM 5N (ftUS)",
"4406":"NAD27 / BLM 6N (ftUS)",
"4407":"NAD27 / BLM 7N (ftUS)",
"4408":"NAD27 / BLM 8N (ftUS)",
"4409":"NAD27 / BLM 9N (ftUS)",
"4410":"NAD27 / BLM 10N (ftUS)",
"4411":"NAD27 / BLM 11N (ftUS)",
"4412":"NAD27 / BLM 12N (ftUS)",
"4413":"NAD27 / BLM 13N (ftUS)",
"4414":"NAD83(HARN) / Guam Map Grid",
"4415":"Katanga 1955 / Katanga Lambert",
"4417":"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 7",
"4418":"NAD27 / BLM 18N (ftUS)",
"4419":"NAD27 / BLM 19N (ftUS)",
"4420":"NAD83 / BLM 60N (ftUS)",
"4421":"NAD83 / BLM 1N (ftUS)",
"4422":"NAD83 / BLM 2N (ftUS)",
"4423":"NAD83 / BLM 3N (ftUS)",
"4424":"NAD83 / BLM 4N (ftUS)",
"4425":"NAD83 / BLM 5N (ftUS)",
"4426":"NAD83 / BLM 6N (ftUS)",
"4427":"NAD83 / BLM 7N (ftUS)",
"4428":"NAD83 / BLM 8N (ftUS)",
"4429":"NAD83 / BLM 9N (ftUS)",
"4430":"NAD83 / BLM 10N (ftUS)",
"4431":"NAD83 / BLM 11N (ftUS)",
"4432":"NAD83 / BLM 12N (ftUS)",
"4433":"NAD83 / BLM 13N (ftUS)",
"4434":"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 8",
"4437":"NAD83(NSRS2007) / Puerto Rico and Virgin Is.",
"4438":"NAD83 / BLM 18N (ftUS)",
"4439":"NAD83 / BLM 19N (ftUS)",
"4440":"NZVD2009 height",
"4455":"NAD27 / Pennsylvania South",
"4456":"NAD27 / New York Long Island",
"4457":"NAD83 / South Dakota North (ftUS)",
"4458":"Dunedin-Bluff 1960 height",
"4462":"WGS 84 / Australian Centre for Remote Sensing Lambert",
"4463":"RGSPM06",
"4465":"RGSPM06",
"4466":"RGSPM06",
"4467":"RGSPM06 / UTM zone 21N",
"4468":"RGM04",
"4469":"RGM04",
"4470":"RGM04",
"4471":"RGM04 / UTM zone 38S",
"4472":"Cadastre 1997",
"4473":"Cadastre 1997",
"4474":"Cadastre 1997 / UTM zone 38S",
"4475":"Cadastre 1997",
"4479":"China Geodetic Coordinate System 2000",
"4480":"China Geodetic Coordinate System 2000",
"4481":"Mexico ITRF92",
"4482":"Mexico ITRF92",
"4483":"Mexico ITRF92",
"4484":"Mexico ITRF92 / UTM zone 11N",
"4485":"Mexico ITRF92 / UTM zone 12N",
"4486":"Mexico ITRF92 / UTM zone 13N",
"4487":"Mexico ITRF92 / UTM zone 14N",
"4488":"Mexico ITRF92 / UTM zone 15N",
"4489":"Mexico ITRF92 / UTM zone 16N",
"4490":"China Geodetic Coordinate System 2000",
"4491":"CGCS2000 / Gauss-Kruger zone 13",
"4492":"CGCS2000 / Gauss-Kruger zone 14",
"4493":"CGCS2000 / Gauss-Kruger zone 15",
"4494":"CGCS2000 / Gauss-Kruger zone 16",
"4495":"CGCS2000 / Gauss-Kruger zone 17",
"4496":"CGCS2000 / Gauss-Kruger zone 18",
"4497":"CGCS2000 / Gauss-Kruger zone 19",
"4498":"CGCS2000 / Gauss-Kruger zone 20",
"4499":"CGCS2000 / Gauss-Kruger zone 21",
"4500":"CGCS2000 / Gauss-Kruger zone 22",
"4501":"CGCS2000 / Gauss-Kruger zone 23",
"4502":"CGCS2000 / Gauss-Kruger CM 75E",
"4503":"CGCS2000 / Gauss-Kruger CM 81E",
"4504":"CGCS2000 / Gauss-Kruger CM 87E",
"4505":"CGCS2000 / Gauss-Kruger CM 93E",
"4506":"CGCS2000 / Gauss-Kruger CM 99E",
"4507":"CGCS2000 / Gauss-Kruger CM 105E",
"4508":"CGCS2000 / Gauss-Kruger CM 111E",
"4509":"CGCS2000 / Gauss-Kruger CM 117E",
"4510":"CGCS2000 / Gauss-Kruger CM 123E",
"4511":"CGCS2000 / Gauss-Kruger CM 129E",
"4512":"CGCS2000 / Gauss-Kruger CM 135E",
"4513":"CGCS2000 / 3-degree Gauss-Kruger zone 25",
"4514":"CGCS2000 / 3-degree Gauss-Kruger zone 26",
"4515":"CGCS2000 / 3-degree Gauss-Kruger zone 27",
"4516":"CGCS2000 / 3-degree Gauss-Kruger zone 28",
"4517":"CGCS2000 / 3-degree Gauss-Kruger zone 29",
"4518":"CGCS2000 / 3-degree Gauss-Kruger zone 30",
"4519":"CGCS2000 / 3-degree Gauss-Kruger zone 31",
"4520":"CGCS2000 / 3-degree Gauss-Kruger zone 32",
"4521":"CGCS2000 / 3-degree Gauss-Kruger zone 33",
"4522":"CGCS2000 / 3-degree Gauss-Kruger zone 34",
"4523":"CGCS2000 / 3-degree Gauss-Kruger zone 35",
"4524":"CGCS2000 / 3-degree Gauss-Kruger zone 36",
"4525":"CGCS2000 / 3-degree Gauss-Kruger zone 37",
"4526":"CGCS2000 / 3-degree Gauss-Kruger zone 38",
"4527":"CGCS2000 / 3-degree Gauss-Kruger zone 39",
"4528":"CGCS2000 / 3-degree Gauss-Kruger zone 40",
"4529":"CGCS2000 / 3-degree Gauss-Kruger zone 41",
"4530":"CGCS2000 / 3-degree Gauss-Kruger zone 42",
"4531":"CGCS2000 / 3-degree Gauss-Kruger zone 43",
"4532":"CGCS2000 / 3-degree Gauss-Kruger zone 44",
"4533":"CGCS2000 / 3-degree Gauss-Kruger zone 45",
"4534":"CGCS2000 / 3-degree Gauss-Kruger CM 75E",
"4535":"CGCS2000 / 3-degree Gauss-Kruger CM 78E",
"4536":"CGCS2000 / 3-degree Gauss-Kruger CM 81E",
"4537":"CGCS2000 / 3-degree Gauss-Kruger CM 84E",
"4538":"CGCS2000 / 3-degree Gauss-Kruger CM 87E",
"4539":"CGCS2000 / 3-degree Gauss-Kruger CM 90E",
"4540":"CGCS2000 / 3-degree Gauss-Kruger CM 93E",
"4541":"CGCS2000 / 3-degree Gauss-Kruger CM 96E",
"4542":"CGCS2000 / 3-degree Gauss-Kruger CM 99E",
"4543":"CGCS2000 / 3-degree Gauss-Kruger CM 102E",
"4544":"CGCS2000 / 3-degree Gauss-Kruger CM 105E",
"4545":"CGCS2000 / 3-degree Gauss-Kruger CM 108E",
"4546":"CGCS2000 / 3-degree Gauss-Kruger CM 111E",
"4547":"CGCS2000 / 3-degree Gauss-Kruger CM 114E",
"4548":"CGCS2000 / 3-degree Gauss-Kruger CM 117E",
"4549":"CGCS2000 / 3-degree Gauss-Kruger CM 120E",
"4550":"CGCS2000 / 3-degree Gauss-Kruger CM 123E",
"4551":"CGCS2000 / 3-degree Gauss-Kruger CM 126E",
"4552":"CGCS2000 / 3-degree Gauss-Kruger CM 129E",
"4553":"CGCS2000 / 3-degree Gauss-Kruger CM 132E",
"4554":"CGCS2000 / 3-degree Gauss-Kruger CM 135E",
"4555":"New Beijing",
"4556":"RRAF 1991",
"4557":"RRAF 1991",
"4558":"RRAF 1991",
"4559":"RRAF 1991 / UTM zone 20N",
"4568":"New Beijing / Gauss-Kruger zone 13",
"4569":"New Beijing / Gauss-Kruger zone 14",
"4570":"New Beijing / Gauss-Kruger zone 15",
"4571":"New Beijing / Gauss-Kruger zone 16",
"4572":"New Beijing / Gauss-Kruger zone 17",
"4573":"New Beijing / Gauss-Kruger zone 18",
"4574":"New Beijing / Gauss-Kruger zone 19",
"4575":"New Beijing / Gauss-Kruger zone 20",
"4576":"New Beijing / Gauss-Kruger zone 21",
"4577":"New Beijing / Gauss-Kruger zone 22",
"4578":"New Beijing / Gauss-Kruger zone 23",
"4579":"New Beijing / Gauss-Kruger CM 75E",
"4580":"New Beijing / Gauss-Kruger CM 81E",
"4581":"New Beijing / Gauss-Kruger CM 87E",
"4582":"New Beijing / Gauss-Kruger CM 93E",
"4583":"New Beijing / Gauss-Kruger CM 99E",
"4584":"New Beijing / Gauss-Kruger CM 105E",
"4585":"New Beijing / Gauss-Kruger CM 111E",
"4586":"New Beijing / Gauss-Kruger CM 117E",
"4587":"New Beijing / Gauss-Kruger CM 123E",
"4588":"New Beijing / Gauss-Kruger CM 129E",
"4589":"New Beijing / Gauss-Kruger CM 135E",
"4600":"Anguilla 1957",
"4601":"Antigua 1943",
"4602":"Dominica 1945",
"4603":"Grenada 1953",
"4604":"Montserrat 1958",
"4605":"St. Kitts 1955",
"4606":"St. Lucia 1955",
"4607":"St. Vincent 1945",
"4608":"NAD27(76)",
"4609":"NAD27(CGQ77)",
"4610":"Xian 1980",
"4611":"Hong Kong 1980",
"4612":"JGD2000",
"4613":"Segara",
"4614":"QND95",
"4615":"Porto Santo",
"4616":"Selvagem Grande",
"4617":"NAD83(CSRS)",
"4618":"SAD69",
"4619":"SWEREF99",
"4620":"Point 58",
"4621":"Fort Marigot",
"4622":"Guadeloupe 1948",
"4623":"CSG67",
"4624":"RGFG95",
"4625":"Martinique 1938",
"4626":"Reunion 1947",
"4627":"RGR92",
"4628":"Tahiti 52",
"4629":"Tahaa 54",
"4630":"IGN72 Nuku Hiva",
"4631":"K0 1949",
"4632":"Combani 1950",
"4633":"IGN56 Lifou",
"4634":"IGN72 Grand Terre",
"4635":"ST87 Ouvea",
"4636":"Petrels 1972",
"4637":"Perroud 1950",
"4638":"Saint Pierre et Miquelon 1950",
"4639":"MOP78",
"4640":"RRAF 1991",
"4641":"IGN53 Mare",
"4642":"ST84 Ile des Pins",
"4643":"ST71 Belep",
"4644":"NEA74 Noumea",
"4645":"RGNC 1991",
"4646":"Grand Comoros",
"4647":"ETRS89 / UTM zone 32N (zE-N)",
"4652":"New Beijing / 3-degree Gauss-Kruger zone 25",
"4653":"New Beijing / 3-degree Gauss-Kruger zone 26",
"4654":"New Beijing / 3-degree Gauss-Kruger zone 27",
"4655":"New Beijing / 3-degree Gauss-Kruger zone 28",
"4656":"New Beijing / 3-degree Gauss-Kruger zone 29",
"4657":"Reykjavik 1900",
"4658":"Hjorsey 1955",
"4659":"ISN93",
"4660":"Helle 1954",
"4661":"LKS92",
"4662":"IGN72 Grande Terre",
"4663":"Porto Santo 1995",
"4664":"Azores Oriental 1995",
"4665":"Azores Central 1995",
"4666":"Lisbon 1890",
"4667":"IKBD-92",
"4668":"ED79",
"4669":"LKS94",
"4670":"IGM95",
"4671":"Voirol 1879",
"4672":"Chatham Islands 1971",
"4673":"Chatham Islands 1979",
"4674":"SIRGAS 2000",
"4675":"Guam 1963",
"4676":"Vientiane 1982",
"4677":"Lao 1993",
"4678":"Lao 1997",
"4679":"Jouik 1961",
"4680":"Nouakchott 1965",
"4681":"Mauritania 1999",
"4682":"Gulshan 303",
"4683":"PRS92",
"4684":"Gan 1970",
"4685":"Gandajika",
"4686":"MAGNA-SIRGAS",
"4687":"RGPF",
"4688":"Fatu Iva 72",
"4689":"IGN63 Hiva Oa",
"4690":"Tahiti 79",
"4691":"Moorea 87",
"4692":"Maupiti 83",
"4693":"Nakhl-e Ghanem",
"4694":"POSGAR 94",
"4695":"Katanga 1955",
"4696":"Kasai 1953",
"4697":"IGC 1962 6th Parallel South",
"4698":"IGN 1962 Kerguelen",
"4699":"Le Pouce 1934",
"4700":"IGN Astro 1960",
"4701":"IGCB 1955",
"4702":"Mauritania 1999",
"4703":"Mhast 1951",
"4704":"Mhast (onshore)",
"4705":"Mhast (offshore)",
"4706":"Egypt Gulf of Suez S-650 TL",
"4707":"Tern Island 1961",
"4708":"Cocos Islands 1965",
"4709":"Iwo Jima 1945",
"4710":"Astro DOS 71",
"4711":"Marcus Island 1952",
"4712":"Ascension Island 1958",
"4713":"Ayabelle Lighthouse",
"4714":"Bellevue",
"4715":"Camp Area Astro",
"4716":"Phoenix Islands 1966",
"4717":"Cape Canaveral",
"4718":"Solomon 1968",
"4719":"Easter Island 1967",
"4720":"Fiji 1986",
"4721":"Fiji 1956",
"4722":"South Georgia 1968",
"4723":"GCGD59",
"4724":"Diego Garcia 1969",
"4725":"Johnston Island 1961",
"4726":"SIGD61",
"4727":"Midway 1961",
"4728":"Pico de las Nieves 1984",
"4729":"Pitcairn 1967",
"4730":"Santo 1965",
"4731":"Viti Levu 1916",
"4732":"Marshall Islands 1960",
"4733":"Wake Island 1952",
"4734":"Tristan 1968",
"4735":"Kusaie 1951",
"4736":"Deception Island",
"4737":"Korea 2000",
"4738":"Hong Kong 1963",
"4739":"Hong Kong 1963(67)",
"4740":"PZ-90",
"4741":"FD54",
"4742":"GDM2000",
"4743":"Karbala 1979",
"4744":"Nahrwan 1934",
"4745":"RD/83",
"4746":"PD/83",
"4747":"GR96",
"4748":"Vanua Levu 1915",
"4749":"RGNC91-93",
"4750":"ST87 Ouvea",
"4751":"Kertau (RSO)",
"4752":"Viti Levu 1912",
"4753":"fk89",
"4754":"LGD2006",
"4755":"DGN95",
"4756":"VN-2000",
"4757":"SVY21",
"4758":"JAD2001",
"4759":"NAD83(NSRS2007)",
"4760":"WGS 66",
"4761":"HTRS96",
"4762":"BDA2000",
"4763":"Pitcairn 2006",
"4764":"RSRGD2000",
"4765":"Slovenia 1996",
"4766":"New Beijing / 3-degree Gauss-Kruger zone 30",
"4767":"New Beijing / 3-degree Gauss-Kruger zone 31",
"4768":"New Beijing / 3-degree Gauss-Kruger zone 32",
"4769":"New Beijing / 3-degree Gauss-Kruger zone 33",
"4770":"New Beijing / 3-degree Gauss-Kruger zone 34",
"4771":"New Beijing / 3-degree Gauss-Kruger zone 35",
"4772":"New Beijing / 3-degree Gauss-Kruger zone 36",
"4773":"New Beijing / 3-degree Gauss-Kruger zone 37",
"4774":"New Beijing / 3-degree Gauss-Kruger zone 38",
"4775":"New Beijing / 3-degree Gauss-Kruger zone 39",
"4776":"New Beijing / 3-degree Gauss-Kruger zone 40",
"4777":"New Beijing / 3-degree Gauss-Kruger zone 41",
"4778":"New Beijing / 3-degree Gauss-Kruger zone 42",
"4779":"New Beijing / 3-degree Gauss-Kruger zone 43",
"4780":"New Beijing / 3-degree Gauss-Kruger zone 44",
"4781":"New Beijing / 3-degree Gauss-Kruger zone 45",
"4782":"New Beijing / 3-degree Gauss-Kruger CM 75E",
"4783":"New Beijing / 3-degree Gauss-Kruger CM 78E",
"4784":"New Beijing / 3-degree Gauss-Kruger CM 81E",
"4785":"New Beijing / 3-degree Gauss-Kruger CM 84E",
"4786":"New Beijing / 3-degree Gauss-Kruger CM 87E",
"4787":"New Beijing / 3-degree Gauss-Kruger CM 90E",
"4788":"New Beijing / 3-degree Gauss-Kruger CM 93E",
"4789":"New Beijing / 3-degree Gauss-Kruger CM 96E",
"4790":"New Beijing / 3-degree Gauss-Kruger CM 99E",
"4791":"New Beijing / 3-degree Gauss-Kruger CM 102E",
"4792":"New Beijing / 3-degree Gauss-Kruger CM 105E",
"4793":"New Beijing / 3-degree Gauss-Kruger CM 108E",
"4794":"New Beijing / 3-degree Gauss-Kruger CM 111E",
"4795":"New Beijing / 3-degree Gauss-Kruger CM 114E",
"4796":"New Beijing / 3-degree Gauss-Kruger CM 117E",
"4797":"New Beijing / 3-degree Gauss-Kruger CM 120E",
"4798":"New Beijing / 3-degree Gauss-Kruger CM 123E",
"4799":"New Beijing / 3-degree Gauss-Kruger CM 126E",
"4800":"New Beijing / 3-degree Gauss-Kruger CM 129E",
"4801":"Bern 1898 (Bern)",
"4802":"Bogota 1975 (Bogota)",
"4803":"Lisbon (Lisbon)",
"4804":"Makassar (Jakarta)",
"4805":"MGI (Ferro)",
"4806":"Monte Mario (Rome)",
"4807":"NTF (Paris)",
"4808":"Padang (Jakarta)",
"4809":"Belge 1950 (Brussels)",
"4810":"Tananarive (Paris)",
"4811":"Voirol 1875 (Paris)",
"4812":"New Beijing / 3-degree Gauss-Kruger CM 132E",
"4813":"Batavia (Jakarta)",
"4814":"RT38 (Stockholm)",
"4815":"Greek (Athens)",
"4816":"Carthage (Paris)",
"4817":"NGO 1948 (Oslo)",
"4818":"S-JTSK (Ferro)",
"4819":"Nord Sahara 1959 (Paris)",
"4820":"Segara (Jakarta)",
"4821":"Voirol 1879 (Paris)",
"4822":"New Beijing / 3-degree Gauss-Kruger CM 135E",
"4823":"Sao Tome",
"4824":"Principe",
"4826":"WGS 84 / Cape Verde National",
"4839":"ETRS89 / LCC Germany (N-E)",
"4855":"ETRS89 / NTM zone 5",
"4856":"ETRS89 / NTM zone 6",
"4857":"ETRS89 / NTM zone 7",
"4858":"ETRS89 / NTM zone 8",
"4859":"ETRS89 / NTM zone 9",
"4860":"ETRS89 / NTM zone 10",
"4861":"ETRS89 / NTM zone 11",
"4862":"ETRS89 / NTM zone 12",
"4863":"ETRS89 / NTM zone 13",
"4864":"ETRS89 / NTM zone 14",
"4865":"ETRS89 / NTM zone 15",
"4866":"ETRS89 / NTM zone 16",
"4867":"ETRS89 / NTM zone 17",
"4868":"ETRS89 / NTM zone 18",
"4869":"ETRS89 / NTM zone 19",
"4870":"ETRS89 / NTM zone 20",
"4871":"ETRS89 / NTM zone 21",
"4872":"ETRS89 / NTM zone 22",
"4873":"ETRS89 / NTM zone 23",
"4874":"ETRS89 / NTM zone 24",
"4875":"ETRS89 / NTM zone 25",
"4876":"ETRS89 / NTM zone 26",
"4877":"ETRS89 / NTM zone 27",
"4878":"ETRS89 / NTM zone 28",
"4879":"ETRS89 / NTM zone 29",
"4880":"ETRS89 / NTM zone 30",
"4882":"Slovenia 1996",
"4883":"Slovenia 1996",
"4884":"RSRGD2000",
"4885":"RSRGD2000",
"4886":"BDA2000",
"4887":"BDA2000",
"4888":"HTRS96",
"4889":"HTRS96",
"4890":"WGS 66",
"4891":"WGS 66",
"4892":"NAD83(NSRS2007)",
"4893":"NAD83(NSRS2007)",
"4894":"JAD2001",
"4895":"JAD2001",
"4896":"ITRF2005",
"4897":"DGN95",
"4898":"DGN95",
"4899":"LGD2006",
"4900":"LGD2006",
"4901":"ATF (Paris)",
"4902":"NDG (Paris)",
"4903":"Madrid 1870 (Madrid)",
"4904":"Lisbon 1890 (Lisbon)",
"4906":"RGNC91-93",
"4907":"RGNC91-93",
"4908":"GR96",
"4909":"GR96",
"4910":"ITRF88",
"4911":"ITRF89",
"4912":"ITRF90",
"4913":"ITRF91",
"4914":"ITRF92",
"4915":"ITRF93",
"4916":"ITRF94",
"4917":"ITRF96",
"4918":"ITRF97",
"4919":"ITRF2000",
"4920":"GDM2000",
"4921":"GDM2000",
"4922":"PZ-90",
"4923":"PZ-90",
"4924":"Mauritania 1999",
"4925":"Mauritania 1999",
"4926":"Korea 2000",
"4927":"Korea 2000",
"4928":"POSGAR 94",
"4929":"POSGAR 94",
"4930":"Australian Antarctic",
"4931":"Australian Antarctic",
"4932":"CHTRF95",
"4933":"CHTRF95",
"4934":"EST97",
"4935":"EST97",
"4936":"ETRS89",
"4937":"ETRS89",
"4938":"GDA94",
"4939":"GDA94",
"4940":"Hartebeesthoek94",
"4941":"Hartebeesthoek94",
"4942":"IRENET95",
"4943":"IRENET95",
"4944":"ISN93",
"4945":"ISN93",
"4946":"JGD2000",
"4947":"JGD2000",
"4948":"LKS92",
"4949":"LKS92",
"4950":"LKS94",
"4951":"LKS94",
"4952":"Moznet",
"4953":"Moznet",
"4954":"NAD83(CSRS)",
"4955":"NAD83(CSRS)",
"4956":"NAD83(HARN)",
"4957":"NAD83(HARN)",
"4958":"NZGD2000",
"4959":"NZGD2000",
"4960":"POSGAR 98",
"4961":"POSGAR 98",
"4962":"REGVEN",
"4963":"REGVEN",
"4964":"RGF93",
"4965":"RGF93",
"4966":"RGFG95",
"4967":"RGFG95",
"4968":"RGNC 1991",
"4969":"RGNC 1991",
"4970":"RGR92",
"4971":"RGR92",
"4972":"RRAF 1991",
"4973":"RRAF 1991",
"4974":"SIRGAS 1995",
"4975":"SIRGAS 1995",
"4976":"SWEREF99",
"4977":"SWEREF99",
"4978":"WGS 84",
"4979":"WGS 84",
"4980":"Yemen NGN96",
"4981":"Yemen NGN96",
"4982":"IGM95",
"4983":"IGM95",
"4984":"WGS 72",
"4985":"WGS 72",
"4986":"WGS 72BE",
"4987":"WGS 72BE",
"4988":"SIRGAS 2000",
"4989":"SIRGAS 2000",
"4990":"Lao 1993",
"4991":"Lao 1993",
"4992":"Lao 1997",
"4993":"Lao 1997",
"4994":"PRS92",
"4995":"PRS92",
"4996":"MAGNA-SIRGAS",
"4997":"MAGNA-SIRGAS",
"4998":"RGPF",
"4999":"RGPF",
"5011":"PTRA08",
"5012":"PTRA08",
"5013":"PTRA08",
"5014":"PTRA08 / UTM zone 25N",
"5015":"PTRA08 / UTM zone 26N",
"5016":"PTRA08 / UTM zone 28N",
"5017":"Lisbon 1890 / Portugal Bonne New",
"5018":"Lisbon / Portuguese Grid New",
"5041":"WGS 84 / UPS North (E,N)",
"5042":"WGS 84 / UPS South (E,N)",
"5048":"ETRS89 / TM35FIN(N,E)",
"5069":"NAD27 / Conus Albers",
"5070":"NAD83 / Conus Albers",
"5071":"NAD83(HARN) / Conus Albers",
"5072":"NAD83(NSRS2007) / Conus Albers",
"5105":"ETRS89 / NTM zone 5",
"5106":"ETRS89 / NTM zone 6",
"5107":"ETRS89 / NTM zone 7",
"5108":"ETRS89 / NTM zone 8",
"5109":"ETRS89 / NTM zone 9",
"5110":"ETRS89 / NTM zone 10",
"5111":"ETRS89 / NTM zone 11",
"5112":"ETRS89 / NTM zone 12",
"5113":"ETRS89 / NTM zone 13",
"5114":"ETRS89 / NTM zone 14",
"5115":"ETRS89 / NTM zone 15",
"5116":"ETRS89 / NTM zone 16",
"5117":"ETRS89 / NTM zone 17",
"5118":"ETRS89 / NTM zone 18",
"5119":"ETRS89 / NTM zone 19",
"5120":"ETRS89 / NTM zone 20",
"5121":"ETRS89 / NTM zone 21",
"5122":"ETRS89 / NTM zone 22",
"5123":"ETRS89 / NTM zone 23",
"5124":"ETRS89 / NTM zone 24",
"5125":"ETRS89 / NTM zone 25",
"5126":"ETRS89 / NTM zone 26",
"5127":"ETRS89 / NTM zone 27",
"5128":"ETRS89 / NTM zone 28",
"5129":"ETRS89 / NTM zone 29",
"5130":"ETRS89 / NTM zone 30",
"5132":"Tokyo 1892",
"5167":"Korean 1985 / East Sea Belt",
"5168":"Korean 1985 / Central Belt Jeju",
"5169":"Tokyo 1892 / Korea West Belt",
"5170":"Tokyo 1892 / Korea Central Belt",
"5171":"Tokyo 1892 / Korea East Belt",
"5172":"Tokyo 1892 / Korea East Sea Belt",
"5173":"Korean 1985 / Modified West Belt",
"5174":"Korean 1985 / Modified Central Belt",
"5175":"Korean 1985 / Modified Central Belt Jeju",
"5176":"Korean 1985 / Modified East Belt",
"5177":"Korean 1985 / Modified East Sea Belt",
"5178":"Korean 1985 / Unified CS",
"5179":"Korea 2000 / Unified CS",
"5180":"Korea 2000 / West Belt",
"5181":"Korea 2000 / Central Belt",
"5182":"Korea 2000 / Central Belt Jeju",
"5183":"Korea 2000 / East Belt",
"5184":"Korea 2000 / East Sea Belt",
"5185":"Korea 2000 / West Belt 2010",
"5186":"Korea 2000 / Central Belt 2010",
"5187":"Korea 2000 / East Belt 2010",
"5188":"Korea 2000 / East Sea Belt 2010",
"5193":"Incheon height",
"5195":"Trieste height",
"5214":"Genoa height",
"5221":"S-JTSK (Ferro) / Krovak East North",
"5223":"WGS 84 / Gabon TM",
"5224":"S-JTSK/05 (Ferro) / Modified Krovak",
"5225":"S-JTSK/05 (Ferro) / Modified Krovak East North",
"5228":"S-JTSK/05",
"5229":"S-JTSK/05 (Ferro)",
"5233":"SLD99",
"5234":"Kandawala / Sri Lanka Grid",
"5235":"SLD99 / Sri Lanka Grid 1999",
"5237":"SLVD height",
"5243":"ETRS89 / LCC Germany (E-N)",
"5244":"GDBD2009",
"5245":"GDBD2009",
"5246":"GDBD2009",
"5247":"GDBD2009 / Brunei BRSO",
"5250":"TUREF",
"5251":"TUREF",
"5252":"TUREF",
"5253":"TUREF / TM27",
"5254":"TUREF / TM30",
"5255":"TUREF / TM33",
"5256":"TUREF / TM36",
"5257":"TUREF / TM39",
"5258":"TUREF / TM42",
"5259":"TUREF / TM45",
"5262":"DRUKREF 03",
"5263":"DRUKREF 03",
"5264":"DRUKREF 03",
"5266":"DRUKREF 03 / Bhutan National Grid",
"5269":"TUREF / 3-degree Gauss-Kruger zone 9",
"5270":"TUREF / 3-degree Gauss-Kruger zone 10",
"5271":"TUREF / 3-degree Gauss-Kruger zone 11",
"5272":"TUREF / 3-degree Gauss-Kruger zone 12",
"5273":"TUREF / 3-degree Gauss-Kruger zone 13",
"5274":"TUREF / 3-degree Gauss-Kruger zone 14",
"5275":"TUREF / 3-degree Gauss-Kruger zone 15",
"5292":"DRUKREF 03 / Bumthang TM",
"5293":"DRUKREF 03 / Chhukha TM",
"5294":"DRUKREF 03 / Dagana TM",
"5295":"DRUKREF 03 / Gasa TM",
"5296":"DRUKREF 03 / Ha TM",
"5297":"DRUKREF 03 / Lhuentse TM",
"5298":"DRUKREF 03 / Mongar TM",
"5299":"DRUKREF 03 / Paro TM",
"5300":"DRUKREF 03 / Pemagatshel TM",
"5301":"DRUKREF 03 / Punakha TM",
"5302":"DRUKREF 03 / Samdrup Jongkhar TM",
"5303":"DRUKREF 03 / Samtse TM",
"5304":"DRUKREF 03 / Sarpang TM",
"5305":"DRUKREF 03 / Thimphu TM",
"5306":"DRUKREF 03 / Trashigang TM",
"5307":"DRUKREF 03 / Trongsa TM",
"5308":"DRUKREF 03 / Tsirang TM",
"5309":"DRUKREF 03 / Wangdue Phodrang TM",
"5310":"DRUKREF 03 / Yangtse TM",
"5311":"DRUKREF 03 / Zhemgang TM",
"5316":"ETRS89 / Faroe TM",
"5317":"FVR09 height",
"5318":"ETRS89 / Faroe TM + FVR09 height",
"5320":"NAD83 / Teranet Ontario Lambert",
"5321":"NAD83(CSRS) / Teranet Ontario Lambert",
"5322":"ISN2004",
"5323":"ISN2004",
"5324":"ISN2004",
"5325":"ISN2004 / Lambert 2004",
"5329":"Segara (Jakarta) / NEIEZ",
"5330":"Batavia (Jakarta) / NEIEZ",
"5331":"Makassar (Jakarta) / NEIEZ",
"5332":"ITRF2008",
"5336":"Black Sea depth",
"5337":"Aratu / UTM zone 25S",
"5340":"POSGAR 2007",
"5341":"POSGAR 2007",
"5342":"POSGAR 2007",
"5343":"POSGAR 2007 / Argentina 1",
"5344":"POSGAR 2007 / Argentina 2",
"5345":"POSGAR 2007 / Argentina 3",
"5346":"POSGAR 2007 / Argentina 4",
"5347":"POSGAR 2007 / Argentina 5",
"5348":"POSGAR 2007 / Argentina 6",
"5349":"POSGAR 2007 / Argentina 7",
"5352":"MARGEN",
"5353":"MARGEN",
"5354":"MARGEN",
"5355":"MARGEN / UTM zone 20S",
"5356":"MARGEN / UTM zone 19S",
"5357":"MARGEN / UTM zone 21S",
"5358":"SIRGAS-Chile",
"5359":"SIRGAS-Chile",
"5360":"SIRGAS-Chile",
"5361":"SIRGAS-Chile / UTM zone 19S",
"5362":"SIRGAS-Chile / UTM zone 18S",
"5363":"CR05",
"5364":"CR05",
"5365":"CR05",
"5367":"CR05 / CRTM05",
"5368":"MACARIO SOLIS",
"5369":"Peru96",
"5370":"MACARIO SOLIS",
"5371":"MACARIO SOLIS",
"5372":"Peru96",
"5373":"Peru96",
"5379":"SIRGAS-ROU98",
"5380":"SIRGAS-ROU98",
"5381":"SIRGAS-ROU98",
"5382":"SIRGAS-ROU98 / UTM zone 21S",
"5383":"SIRGAS-ROU98 / UTM zone 22S",
"5387":"Peru96 / UTM zone 18S",
"5388":"Peru96 / UTM zone 17S",
"5389":"Peru96 / UTM zone 19S",
"5391":"SIRGAS_ES2007.8",
"5392":"SIRGAS_ES2007.8",
"5393":"SIRGAS_ES2007.8",
"5396":"SIRGAS 2000 / UTM zone 26S",
"5451":"Ocotepeque 1935",
"5456":"Ocotepeque 1935 / Costa Rica Norte",
"5457":"Ocotepeque 1935 / Costa Rica Sur",
"5458":"Ocotepeque 1935 / Guatemala Norte",
"5459":"Ocotepeque 1935 / Guatemala Sur",
"5460":"Ocotepeque 1935 / El Salvador Lambert",
"5461":"Ocotepeque 1935 / Nicaragua Norte",
"5462":"Ocotepeque 1935 / Nicaragua Sur",
"5463":"SAD69 / UTM zone 17N",
"5464":"Sibun Gorge 1922",
"5466":"Sibun Gorge 1922 / Colony Grid",
"5467":"Panama-Colon 1911",
"5469":"Panama-Colon 1911 / Panama Lambert",
"5472":"Panama-Colon 1911 / Panama Polyconic",
"5479":"RSRGD2000 / MSLC2000",
"5480":"RSRGD2000 / BCLC2000",
"5481":"RSRGD2000 / PCLC2000",
"5482":"RSRGD2000 / RSPS2000",
"5487":"RGAF09",
"5488":"RGAF09",
"5489":"RGAF09",
"5490":"RGAF09 / UTM zone 20N",
"5498":"NAD83 + NAVD88 height",
"5499":"NAD83(HARN) + NAVD88 height",
"5500":"NAD83(NSRS2007) + NAVD88 height",
"5513":"S-JTSK / Krovak",
"5514":"S-JTSK / Krovak East North",
"5515":"S-JTSK/05 / Modified Krovak",
"5516":"S-JTSK/05 / Modified Krovak East North",
"5518":"CI1971 / Chatham Islands Map Grid",
"5519":"CI1979 / Chatham Islands Map Grid",
"5520":"DHDN / 3-degree Gauss-Kruger zone 1",
"5523":"WGS 84 / Gabon TM 2011",
"5524":"Corrego Alegre 1961",
"5527":"SAD69(96)",
"5530":"SAD69(96) / Brazil Polyconic",
"5531":"SAD69(96) / UTM zone 21S",
"5532":"SAD69(96) / UTM zone 22S",
"5533":"SAD69(96) / UTM zone 23S",
"5534":"SAD69(96) / UTM zone 24S",
"5535":"SAD69(96) / UTM zone 25S",
"5536":"Corrego Alegre 1961 / UTM zone 21S",
"5537":"Corrego Alegre 1961 / UTM zone 22S",
"5538":"Corrego Alegre 1961 / UTM zone 23S",
"5539":"Corrego Alegre 1961 / UTM zone 24S",
"5544":"PNG94",
"5545":"PNG94",
"5546":"PNG94",
"5550":"PNG94 / PNGMG94 zone 54",
"5551":"PNG94 / PNGMG94 zone 55",
"5552":"PNG94 / PNGMG94 zone 56",
"5554":"ETRS89 / UTM zone 31N + DHHN92 height",
"5555":"ETRS89 / UTM zone 32N + DHHN92 height",
"5556":"ETRS89 / UTM zone 33N + DHHN92 height",
"5558":"UCS-2000",
"5559":"Ocotepeque 1935 / Guatemala Norte",
"5560":"UCS-2000",
"5561":"UCS-2000",
"5562":"UCS-2000 / Gauss-Kruger zone 4",
"5563":"UCS-2000 / Gauss-Kruger zone 5",
"5564":"UCS-2000 / Gauss-Kruger zone 6",
"5565":"UCS-2000 / Gauss-Kruger zone 7",
"5566":"UCS-2000 / Gauss-Kruger CM 21E",
"5567":"UCS-2000 / Gauss-Kruger CM 27E",
"5568":"UCS-2000 / Gauss-Kruger CM 33E",
"5569":"UCS-2000 / Gauss-Kruger CM 39E",
"5570":"UCS-2000 / 3-degree Gauss-Kruger zone 7",
"5571":"UCS-2000 / 3-degree Gauss-Kruger zone 8",
"5572":"UCS-2000 / 3-degree Gauss-Kruger zone 9",
"5573":"UCS-2000 / 3-degree Gauss-Kruger zone 10",
"5574":"UCS-2000 / 3-degree Gauss-Kruger zone 11",
"5575":"UCS-2000 / 3-degree Gauss-Kruger zone 12",
"5576":"UCS-2000 / 3-degree Gauss-Kruger zone 13",
"5577":"UCS-2000 / 3-degree Gauss-Kruger CM 21E",
"5578":"UCS-2000 / 3-degree Gauss-Kruger CM 24E",
"5579":"UCS-2000 / 3-degree Gauss-Kruger CM 27E",
"5580":"UCS-2000 / 3-degree Gauss-Kruger CM 30E",
"5581":"UCS-2000 / 3-degree Gauss-Kruger CM 33E",
"5582":"UCS-2000 / 3-degree Gauss-Kruger CM 36E",
"5583":"UCS-2000 / 3-degree Gauss-Kruger CM 39E",
"5588":"NAD27 / New Brunswick Stereographic (NAD27)",
"5589":"Sibun Gorge 1922 / Colony Grid",
"5591":"FEH2010",
"5592":"FEH2010",
"5593":"FEH2010",
"5596":"FEH2010 / Fehmarnbelt TM",
"5597":"FCSVR10 height",
"5598":"FEH2010 / Fehmarnbelt TM + FCSVR10 height",
"5600":"NGPF height",
"5601":"IGN 1966 height",
"5602":"Moorea SAU 1981 height",
"5603":"Raiatea SAU 2001 height",
"5604":"Maupiti SAU 2001 height",
"5605":"Huahine SAU 2001 height",
"5606":"Tahaa SAU 2001 height",
"5607":"Bora Bora SAU 2001 height",
"5608":"IGLD 1955 height",
"5609":"IGLD 1985 height",
"5610":"HVRS71 height",
"5611":"Caspian height",
"5612":"Baltic 1977 depth",
"5613":"RH2000 height",
"5614":"KOC WD depth (ft)",
"5615":"RH00 height",
"5616":"IGN 1988 LS height",
"5617":"IGN 1988 MG height",
"5618":"IGN 1992 LD height",
"5619":"IGN 1988 SB height",
"5620":"IGN 1988 SM height",
"5621":"EVRF2007 height",
"5623":"NAD27 / Michigan East",
"5624":"NAD27 / Michigan Old Central",
"5625":"NAD27 / Michigan West",
"5627":"ED50 / TM 6 NE",
"5628":"SWEREF99 + RH2000 height",
"5629":"Moznet / UTM zone 38S",
"5631":"Pulkovo 1942(58) / Gauss-Kruger zone 2 (E-N)",
"5632":"PTRA08 / LCC Europe",
"5633":"PTRA08 / LAEA Europe",
"5634":"REGCAN95 / LCC Europe",
"5635":"REGCAN95 / LAEA Europe",
"5636":"TUREF / LAEA Europe",
"5637":"TUREF / LCC Europe",
"5638":"ISN2004 / LAEA Europe",
"5639":"ISN2004 / LCC Europe",
"5641":"SIRGAS 2000 / Brazil Mercator",
"5643":"ED50 / SPBA LCC",
"5644":"RGR92 / UTM zone 39S",
"5646":"NAD83 / Vermont (ftUS)",
"5649":"ETRS89 / UTM zone 31N (zE-N)",
"5650":"ETRS89 / UTM zone 33N (zE-N)",
"5651":"ETRS89 / UTM zone 31N (N-zE)",
"5652":"ETRS89 / UTM zone 32N (N-zE)",
"5653":"ETRS89 / UTM zone 33N (N-zE)",
"5654":"NAD83(HARN) / Vermont (ftUS)",
"5655":"NAD83(NSRS2007) / Vermont (ftUS)",
"5659":"Monte Mario / TM Emilia-Romagna",
"5663":"Pulkovo 1942(58) / Gauss-Kruger zone 3 (E-N)",
"5664":"Pulkovo 1942(83) / Gauss-Kruger zone 2 (E-N)",
"5665":"Pulkovo 1942(83) / Gauss-Kruger zone 3 (E-N)",
"5666":"PD/83 / 3-degree Gauss-Kruger zone 3 (E-N)",
"5667":"PD/83 / 3-degree Gauss-Kruger zone 4 (E-N)",
"5668":"RD/83 / 3-degree Gauss-Kruger zone 4 (E-N)",
"5669":"RD/83 / 3-degree Gauss-Kruger zone 5 (E-N)",
"5670":"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 3 (E-N)",
"5671":"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 4 (E-N)",
"5672":"Pulkovo 1942(58) / 3-degree Gauss-Kruger zone 5 (E-N)",
"5673":"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 3 (E-N)",
"5674":"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 4 (E-N)",
"5675":"Pulkovo 1942(83) / 3-degree Gauss-Kruger zone 5 (E-N)",
"5676":"DHDN / 3-degree Gauss-Kruger zone 2 (E-N)",
"5677":"DHDN / 3-degree Gauss-Kruger zone 3 (E-N)",
"5678":"DHDN / 3-degree Gauss-Kruger zone 4 (E-N)",
"5679":"DHDN / 3-degree Gauss-Kruger zone 5 (E-N)",
"5680":"DHDN / 3-degree Gauss-Kruger zone 1 (E-N)",
"5681":"DB_REF",
"5682":"DB_REF / 3-degree Gauss-Kruger zone 2 (E-N)",
"5683":"DB_REF / 3-degree Gauss-Kruger zone 3 (E-N)",
"5684":"DB_REF / 3-degree Gauss-Kruger zone 4 (E-N)",
"5685":"DB_REF / 3-degree Gauss-Kruger zone 5 (E-N)",
"5698":"RGF93 / Lambert-93 + NGF-IGN69 height",
"5699":"RGF93 / Lambert-93 + NGF-IGN78 height",
"5700":"NZGD2000 / UTM zone 1S",
"5701":"ODN height",
"5702":"NGVD29 height (ftUS)",
"5703":"NAVD88 height",
"5704":"Yellow Sea",
"5705":"Baltic 1977 height",
"5706":"Caspian depth",
"5707":"NTF (Paris) / Lambert zone I + NGF-IGN69 height",
"5708":"NTF (Paris) / Lambert zone IV + NGF-IGN78 height",
"5709":"NAP height",
"5710":"Ostend height",
"5711":"AHD height",
"5712":"AHD (Tasmania) height",
"5713":"CGVD28 height",
"5714":"MSL height",
"5715":"MSL depth",
"5716":"Piraeus height",
"5717":"N60 height",
"5718":"RH70 height",
"5719":"NGF Lallemand height",
"5720":"NGF-IGN69 height",
"5721":"NGF-IGN78 height",
"5722":"Maputo height",
"5723":"JSLD69 height",
"5724":"PHD93 height",
"5725":"Fahud HD height",
"5726":"Ha Tien 1960 height",
"5727":"Hon Dau 1992 height",
"5728":"LN02 height",
"5729":"LHN95 height",
"5730":"EVRF2000 height",
"5731":"Malin Head height",
"5732":"Belfast height",
"5733":"DNN height",
"5734":"AIOC95 depth",
"5735":"Black Sea height",
"5736":"Yellow Sea 1956 height",
"5737":"Yellow Sea 1985 height",
"5738":"HKPD height",
"5739":"HKCD depth",
"5740":"ODN Orkney height",
"5741":"Fair Isle height",
"5742":"Lerwick height",
"5743":"Foula height",
"5744":"Sule Skerry height",
"5745":"North Rona height",
"5746":"Stornoway height",
"5747":"St Kilda height",
"5748":"Flannan Isles height",
"5749":"St Marys height",
"5750":"Douglas height",
"5751":"Fao height",
"5752":"Bandar Abbas height",
"5753":"NGNC height",
"5754":"Poolbeg height (ft(Br36))",
"5755":"NGG1977 height",
"5756":"Martinique 1987 height",
"5757":"Guadeloupe 1988 height",
"5758":"Reunion 1989 height",
"5759":"Auckland 1946 height",
"5760":"Bluff 1955 height",
"5761":"Dunedin 1958 height",
"5762":"Gisborne 1926 height",
"5763":"Lyttelton 1937 height",
"5764":"Moturiki 1953 height",
"5765":"Napier 1962 height",
"5766":"Nelson 1955 height",
"5767":"One Tree Point 1964 height",
"5768":"Tararu 1952 height",
"5769":"Taranaki 1970 height",
"5770":"Wellington 1953 height",
"5771":"Chatham Island 1959 height",
"5772":"Stewart Island 1977 height",
"5773":"EGM96 height",
"5774":"NG-L height",
"5775":"Antalya height",
"5776":"NN54 height",
"5777":"Durres height",
"5778":"GHA height",
"5779":"SVS2000 height",
"5780":"Cascais height",
"5781":"Constanta height",
"5782":"Alicante height",
"5783":"DHHN92 height",
"5784":"DHHN85 height",
"5785":"SNN76 height",
"5786":"Baltic 1982 height",
"5787":"EOMA 1980 height",
"5788":"Kuwait PWD height",
"5789":"KOC WD depth",
"5790":"KOC CD height",
"5791":"NGC 1948 height",
"5792":"Danger 1950 height",
"5793":"Mayotte 1950 height",
"5794":"Martinique 1955 height",
"5795":"Guadeloupe 1951 height",
"5796":"Lagos 1955 height",
"5797":"AIOC95 height",
"5798":"EGM84 height",
"5799":"DVR90 height",
"5800":"Astra Minas Grid",
"5801":"Barcelona Grid B1",
"5802":"Barcelona Grid B2",
"5803":"Maturin Grid",
"5804":"EPSG seismic bin grid example A",
"5805":"EPSG seismic bin grid example B",
"5806":"EPSG local engineering grid example A",
"5807":"EPSG local engineering grid example B",
"5808":"Maracaibo Cross Grid M4",
"5809":"Maracaibo Cross Grid M5",
"5810":"La Rosa Grid",
"5811":"Mene Grande",
"5812":"El Cubo",
"5813":"Dabajuro",
"5814":"Tucupita",
"5815":"Santa Maria de Ipire",
"5816":"Barinas west base",
"5817":"Tombak LNG plant",
"5818":"[enter here name of (I = J+90°) bin grid]",
"5819":"EPSG topocentric example A",
"5820":"EPSG topocentric example B",
"5821":"EPSG vertical perspective example",
"5825":"AGD66 / ACT Standard Grid",
"5828":"DB_REF",
"5829":"Instantaneous Water Level height",
"5830":"DB_REF",
"5831":"Instantaneous Water Level depth",
"5832":"DB_REF / 3-degree Gauss-Kruger zone 2 (E-N) + DHHN92 height",
"5833":"DB_REF / 3-degree Gauss-Kruger zone 3 (E-N) + DHHN92 height",
"5834":"DB_REF / 3-degree Gauss-Kruger zone 4 (E-N) + DHHN92 height",
"5835":"DB_REF / 3-degree Gauss-Kruger zone 5 (E-N) + DHHN92 height",
"5836":"Yemen NGN96 / UTM zone 37N",
"5837":"Yemen NGN96 / UTM zone 40N",
"5839":"Peru96 / UTM zone 17S",
"5842":"WGS 84 / TM 12 SE",
"5843":"Ras Ghumays height",
"5844":"RGRDC 2005 / Congo TM zone 30",
"5845":"SWEREF99 TM + RH2000 height",
"5846":"SWEREF99 12 00 + RH2000 height",
"5847":"SWEREF99 13 30 + RH2000 height",
"5848":"SWEREF99 15 00 + RH2000 height",
"5849":"SWEREF99 16 30 + RH2000 height",
"5850":"SWEREF99 18 00 + RH2000 height",
"5851":"SWEREF99 14 15 + RH2000 height",
"5852":"SWEREF99 15 45 + RH2000 height",
"5853":"SWEREF99 17 15 + RH2000 height",
"5854":"SWEREF99 18 45 + RH2000 height",
"5855":"SWEREF99 20 15 + RH2000 height",
"5856":"SWEREF99 21 45 + RH2000 height",
"5857":"SWEREF99 23 15 + RH2000 height",
"5858":"SAD69(96) / UTM zone 22S",
"5859":"[enter here name of (I = J-90°) bin grid]",
"5861":"LAT depth",
"5862":"LLWLT depth",
"5863":"ISLW depth",
"5864":"MLLWS depth",
"5865":"MLWS depth",
"5866":"MLLW depth",
"5867":"MLW depth",
"5868":"MHW height",
"5869":"MHHW height",
"5870":"MHWS height",
"5871":"HHWLT height",
"5872":"HAT height",
"5873":"Low Water depth",
"5874":"High Water height",
"5875":"SAD69(96) / UTM zone 18S",
"5876":"SAD69(96) / UTM zone 19S",
"5877":"SAD69(96) / UTM zone 20S",
"5879":"Cadastre 1997 / UTM zone 38S",
"5880":"SIRGAS 2000 / Brazil Polyconic",
"5884":"TGD2005",
"5885":"TGD2005",
"5886":"TGD2005",
"5887":"TGD2005 / Tonga Map Grid",
"5890":"JAXA Snow Depth Polar Stereographic North",
"5896":"VN-2000 / TM-3 zone 481",
"5897":"VN-2000 / TM-3 zone 482",
"5898":"VN-2000 / TM-3 zone 491",
"5899":"VN-2000 / TM-3 Da Nang zone",
"5921":"WGS 84 / EPSG Arctic Regional zone A1",
"5922":"WGS 84 / EPSG Arctic Regional zone A2",
"5923":"WGS 84 / EPSG Arctic Regional zone A3",
"5924":"WGS 84 / EPSG Arctic Regional zone A4",
"5925":"WGS 84 / EPSG Arctic Regional zone A5",
"5926":"WGS 84 / EPSG Arctic Regional zone B1",
"5927":"WGS 84 / EPSG Arctic Regional zone B2",
"5928":"WGS 84 / EPSG Arctic Regional zone B3",
"5929":"WGS 84 / EPSG Arctic Regional zone B4",
"5930":"WGS 84 / EPSG Arctic Regional zone B5",
"5931":"WGS 84 / EPSG Arctic Regional zone C1",
"5932":"WGS 84 / EPSG Arctic Regional zone C2",
"5933":"WGS 84 / EPSG Arctic Regional zone C3",
"5934":"WGS 84 / EPSG Arctic Regional zone C4",
"5935":"WGS 84 / EPSG Arctic Regional zone C5",
"5936":"WGS 84 / EPSG Alaska Polar Stereographic",
"5937":"WGS 84 / EPSG Canada Polar Stereographic",
"5938":"WGS 84 / EPSG Greenland Polar Stereographic",
"5939":"WGS 84 / EPSG Norway Polar Stereographic",
"5940":"WGS 84 / EPSG Russia Polar Stereographic",
"5941":"NN2000 height",
"5942":"ETRS89 + NN2000 height",
"5945":"ETRS89 / NTM zone 5 + NN2000 height",
"5946":"ETRS89 / NTM zone 6 + NN2000 height",
"5947":"ETRS89 / NTM zone 7 + NN2000 height",
"5948":"ETRS89 / NTM zone 8 + NN2000 height",
"5949":"ETRS89 / NTM zone 9 + NN2000 height",
"5950":"ETRS89 / NTM zone 10 + NN2000 height",
"5951":"ETRS89 / NTM zone 11 + NN2000 height",
"5952":"ETRS89 / NTM zone 12 + NN2000 height",
"5953":"ETRS89 / NTM zone 13 + NN2000 height",
"5954":"ETRS89 / NTM zone 14 + NN2000 height",
"5955":"ETRS89 / NTM zone 15 + NN2000 height",
"5956":"ETRS89 / NTM zone 16 + NN2000 height",
"5957":"ETRS89 / NTM zone 17 + NN2000 height",
"5958":"ETRS89 / NTM zone 18 + NN2000 height",
"5959":"ETRS89 / NTM zone 19 + NN2000 height",
"5960":"ETRS89 / NTM zone 20 + NN2000 height",
"5961":"ETRS89 / NTM zone 21 + NN2000 height",
"5962":"ETRS89 / NTM zone 22 + NN2000 height",
"5963":"ETRS89 / NTM zone 23 + NN2000 height",
"5964":"ETRS89 / NTM zone 24 + NN2000 height",
"5965":"ETRS89 / NTM zone 25 + NN2000 height",
"5966":"ETRS89 / NTM zone 26 + NN2000 height",
"5967":"ETRS89 / NTM zone 27 + NN2000 height",
"5968":"ETRS89 / NTM zone 28 + NN2000 height",
"5969":"ETRS89 / NTM zone 29 + NN2000 height",
"5970":"ETRS89 / NTM zone 30 + NN2000 height",
"5971":"ETRS89 / UTM zone 31 + NN2000 height",
"5972":"ETRS89 / UTM zone 32 + NN2000 height",
"5973":"ETRS89 / UTM zone 33 + NN2000 height",
"5974":"ETRS89 / UTM zone 34 + NN2000 height",
"5975":"ETRS89 / UTM zone 35 + NN2000 height",
"5976":"ETRS89 / UTM zone 36 + NN2000 height",
"6050":"GR96 / EPSG Arctic zone 1-25",
"6051":"GR96 / EPSG Arctic zone 2-18",
"6052":"GR96 / EPSG Arctic zone 2-20",
"6053":"GR96 / EPSG Arctic zone 3-29",
"6054":"GR96 / EPSG Arctic zone 3-31",
"6055":"GR96 / EPSG Arctic zone 3-33",
"6056":"GR96 / EPSG Arctic zone 4-20",
"6057":"GR96 / EPSG Arctic zone 4-22",
"6058":"GR96 / EPSG Arctic zone 4-24",
"6059":"GR96 / EPSG Arctic zone 5-41",
"6060":"GR96 / EPSG Arctic zone 5-43",
"6061":"GR96 / EPSG Arctic zone 5-45",
"6062":"GR96 / EPSG Arctic zone 6-26",
"6063":"GR96 / EPSG Arctic zone 6-28",
"6064":"GR96 / EPSG Arctic zone 6-30",
"6065":"GR96 / EPSG Arctic zone 7-11",
"6066":"GR96 / EPSG Arctic zone 7-13",
"6067":"GR96 / EPSG Arctic zone 8-20",
"6068":"GR96 / EPSG Arctic zone 8-22",
"6069":"ETRS89 / EPSG Arctic zone 2-22",
"6070":"ETRS89 / EPSG Arctic zone 3-11",
"6071":"ETRS89 / EPSG Arctic zone 4-26",
"6072":"ETRS89 / EPSG Arctic zone 4-28",
"6073":"ETRS89 / EPSG Arctic zone 5-11",
"6074":"ETRS89 / EPSG Arctic zone 5-13",
"6075":"WGS 84 / EPSG Arctic zone 2-24",
"6076":"WGS 84 / EPSG Arctic zone 2-26",
"6077":"WGS 84 / EPSG Arctic zone 3-13",
"6078":"WGS 84 / EPSG Arctic zone 3-15",
"6079":"WGS 84 / EPSG Arctic zone 3-17",
"6080":"WGS 84 / EPSG Arctic zone 3-19",
"6081":"WGS 84 / EPSG Arctic zone 4-30",
"6082":"WGS 84 / EPSG Arctic zone 4-32",
"6083":"WGS 84 / EPSG Arctic zone 4-34",
"6084":"WGS 84 / EPSG Arctic zone 4-36",
"6085":"WGS 84 / EPSG Arctic zone 4-38",
"6086":"WGS 84 / EPSG Arctic zone 4-40",
"6087":"WGS 84 / EPSG Arctic zone 5-15",
"6088":"WGS 84 / EPSG Arctic zone 5-17",
"6089":"WGS 84 / EPSG Arctic zone 5-19",
"6090":"WGS 84 / EPSG Arctic zone 5-21",
"6091":"WGS 84 / EPSG Arctic zone 5-23",
"6092":"WGS 84 / EPSG Arctic zone 5-25",
"6093":"WGS 84 / EPSG Arctic zone 5-27",
"6094":"NAD83(NSRS2007) / EPSG Arctic zone 5-29",
"6095":"NAD83(NSRS2007) / EPSG Arctic zone 5-31",
"6096":"NAD83(NSRS2007) / EPSG Arctic zone 6-14",
"6097":"NAD83(NSRS2007) / EPSG Arctic zone 6-16",
"6098":"NAD83(CSRS) / EPSG Arctic zone 1-23",
"6099":"NAD83(CSRS) / EPSG Arctic zone 2-14",
"6100":"NAD83(CSRS) / EPSG Arctic zone 2-16",
"6101":"NAD83(CSRS) / EPSG Arctic zone 3-25",
"6102":"NAD83(CSRS) / EPSG Arctic zone 3-27",
"6103":"NAD83(CSRS) / EPSG Arctic zone 3-29",
"6104":"NAD83(CSRS) / EPSG Arctic zone 4-14",
"6105":"NAD83(CSRS) / EPSG Arctic zone 4-16",
"6106":"NAD83(CSRS) / EPSG Arctic zone 4-18",
"6107":"NAD83(CSRS) / EPSG Arctic zone 5-33",
"6108":"NAD83(CSRS) / EPSG Arctic zone 5-35",
"6109":"NAD83(CSRS) / EPSG Arctic zone 5-37",
"6110":"NAD83(CSRS) / EPSG Arctic zone 5-39",
"6111":"NAD83(CSRS) / EPSG Arctic zone 6-18",
"6112":"NAD83(CSRS) / EPSG Arctic zone 6-20",
"6113":"NAD83(CSRS) / EPSG Arctic zone 6-22",
"6114":"NAD83(CSRS) / EPSG Arctic zone 6-24",
"6115":"WGS 84 / EPSG Arctic zone 1-27",
"6116":"WGS 84 / EPSG Arctic zone 1-29",
"6117":"WGS 84 / EPSG Arctic zone 1-31",
"6118":"WGS 84 / EPSG Arctic zone 1-21",
"6119":"WGS 84 / EPSG Arctic zone 2-28",
"6120":"WGS 84 / EPSG Arctic zone 2-10",
"6121":"WGS 84 / EPSG Arctic zone 2-12",
"6122":"WGS 84 / EPSG Arctic zone 3-21",
"6123":"WGS 84 / EPSG Arctic zone 3-23",
"6124":"WGS 84 / EPSG Arctic zone 4-12",
"6125":"ETRS89 / EPSG Arctic zone 5-47",
"6128":"Grand Cayman National Grid 1959",
"6129":"Sister Islands National Grid 1961",
"6130":"GCVD54 height (ft)",
"6131":"LCVD61 height (ft)",
"6132":"CBVD61 height (ft)",
"6133":"CIGD11",
"6134":"CIGD11",
"6135":"CIGD11",
"6141":"Cayman Islands National Grid 2011",
"6144":"ETRS89 + NN54 height",
"6145":"ETRS89 / NTM zone 5 + NN54 height",
"6146":"ETRS89 / NTM zone 6 + NN54 height",
"6147":"ETRS89 / NTM zone 7 + NN54 height",
"6148":"ETRS89 / NTM zone 8 + NN54 height",
"6149":"ETRS89 / NTM zone 9 + NN54 height",
"6150":"ETRS89 / NTM zone 10 + NN54 height",
"6151":"ETRS89 / NTM zone 11 + NN54 height",
"6152":"ETRS89 / NTM zone 12 + NN54 height",
"6153":"ETRS89 / NTM zone 13 + NN54 height",
"6154":"ETRS89 / NTM zone 14 + NN54 height",
"6155":"ETRS89 / NTM zone 15 + NN54 height",
"6156":"ETRS89 / NTM zone 16 + NN54 height",
"6157":"ETRS89 / NTM zone 17 + NN54 height",
"6158":"ETRS89 / NTM zone 18 + NN54 height",
"6159":"ETRS89 / NTM zone 19 + NN54 height",
"6160":"ETRS89 / NTM zone 20 + NN54 height",
"6161":"ETRS89 / NTM zone 21 + NN54 height",
"6162":"ETRS89 / NTM zone 22 + NN54 height",
"6163":"ETRS89 / NTM zone 23 + NN54 height",
"6164":"ETRS89 / NTM zone 24 + NN54 height",
"6165":"ETRS89 / NTM zone 25 + NN54 height",
"6166":"ETRS89 / NTM zone 26 + NN54 height",
"6167":"ETRS89 / NTM zone 27 + NN54 height",
"6168":"ETRS89 / NTM zone 28 + NN54 height",
"6169":"ETRS89 / NTM zone 29 + NN54 height",
"6170":"ETRS89 / NTM zone 30 + NN54 height",
"6171":"ETRS89 / UTM zone 31 + NN54 height",
"6172":"ETRS89 / UTM zone 32 + NN54 height",
"6173":"ETRS89 / UTM zone 33 + NN54 height",
"6174":"ETRS89 / UTM zone 34 + NN54 height",
"6175":"ETRS89 / UTM zone 35 + NN54 height",
"6176":"ETRS89 / UTM zone 36 + NN54 height",
"6178":"Cais da Pontinha - Funchal height",
"6179":"Cais da Vila - Porto Santo height",
"6180":"Cais das Velas height",
"6181":"Horta height",
"6182":"Cais da Madalena height",
"6183":"Santa Cruz da Graciosa height",
"6184":"Cais da Figueirinha - Angra do Heroismo height",
"6185":"Santa Cruz das Flores height",
"6186":"Cais da Vila do Porto height",
"6187":"Ponta Delgada height",
"6190":"Belge 1972 / Belgian Lambert 72 + Ostend height",
"6200":"NAD27 / Michigan North",
"6201":"NAD27 / Michigan Central",
"6202":"NAD27 / Michigan South",
"6204":"Macedonia State Coordinate System",
"6207":"Nepal 1981",
"6210":"SIRGAS 2000 / UTM zone 23N",
"6211":"SIRGAS 2000 / UTM zone 24N",
"6244":"MAGNA-SIRGAS / Arauca urban grid",
"6245":"MAGNA-SIRGAS / Armenia urban grid",
"6246":"MAGNA-SIRGAS / Barranquilla urban grid",
"6247":"MAGNA-SIRGAS / Bogota urban grid",
"6248":"MAGNA-SIRGAS / Bucaramanga urban grid",
"6249":"MAGNA-SIRGAS / Cali urban grid",
"6250":"MAGNA-SIRGAS / Cartagena urban grid",
"6251":"MAGNA-SIRGAS / Cucuta urban grid",
"6252":"MAGNA-SIRGAS / Florencia urban grid",
"6253":"MAGNA-SIRGAS / Ibague urban grid",
"6254":"MAGNA-SIRGAS / Inirida urban grid",
"6255":"MAGNA-SIRGAS / Leticia urban grid",
"6256":"MAGNA-SIRGAS / Manizales urban grid",
"6257":"MAGNA-SIRGAS / Medellin urban grid",
"6258":"MAGNA-SIRGAS / Mitu urban grid",
"6259":"MAGNA-SIRGAS / Mocoa urban grid",
"6260":"MAGNA-SIRGAS / Monteria urban grid",
"6261":"MAGNA-SIRGAS / Neiva urban grid",
"6262":"MAGNA-SIRGAS / Pasto urban grid",
"6263":"MAGNA-SIRGAS / Pereira urban grid",
"6264":"MAGNA-SIRGAS / Popayan urban grid",
"6265":"MAGNA-SIRGAS / Puerto Carreno urban grid",
"6266":"MAGNA-SIRGAS / Quibdo urban grid",
"6267":"MAGNA-SIRGAS / Riohacha urban grid",
"6268":"MAGNA-SIRGAS / San Andres urban grid",
"6269":"MAGNA-SIRGAS / San Jose del Guaviare urban grid",
"6270":"MAGNA-SIRGAS / Santa Marta urban grid",
"6271":"MAGNA-SIRGAS / Sucre urban grid",
"6272":"MAGNA-SIRGAS / Tunja urban grid",
"6273":"MAGNA-SIRGAS / Valledupar urban grid",
"6274":"MAGNA-SIRGAS / Villavicencio urban grid",
"6275":"MAGNA-SIRGAS / Yopal urban grid",
"6307":"NAD83(CORS96) / Puerto Rico and Virgin Is.",
"6309":"CGRS93",
"6310":"CGRS93",
"6311":"CGRS93",
"6312":"CGRS93 / Cyprus Local Transverse Mercator",
"6316":"MGI 1901 / Balkans zone 7",
"6317":"NAD83(2011)",
"6318":"NAD83(2011)",
"6319":"NAD83(2011)",
"6320":"NAD83(PA11)",
"6321":"NAD83(PA11)",
"6322":"NAD83(PA11)",
"6323":"NAD83(MA11)",
"6324":"NAD83(MA11)",
"6325":"NAD83(MA11)",
"6328":"NAD83(2011) / UTM zone 59N",
"6329":"NAD83(2011) / UTM zone 60N",
"6330":"NAD83(2011) / UTM zone 1N",
"6331":"NAD83(2011) / UTM zone 2N",
"6332":"NAD83(2011) / UTM zone 3N",
"6333":"NAD83(2011) / UTM zone 4N",
"6334":"NAD83(2011) / UTM zone 5N",
"6335":"NAD83(2011) / UTM zone 6N",
"6336":"NAD83(2011) / UTM zone 7N",
"6337":"NAD83(2011) / UTM zone 8N",
"6338":"NAD83(2011) / UTM zone 9N",
"6339":"NAD83(2011) / UTM zone 10N",
"6340":"NAD83(2011) / UTM zone 11N",
"6341":"NAD83(2011) / UTM zone 12N",
"6342":"NAD83(2011) / UTM zone 13N",
"6343":"NAD83(2011) / UTM zone 14N",
"6344":"NAD83(2011) / UTM zone 15N",
"6345":"NAD83(2011) / UTM zone 16N",
"6346":"NAD83(2011) / UTM zone 17N",
"6347":"NAD83(2011) / UTM zone 18N",
"6348":"NAD83(2011) / UTM zone 19N",
"6349":"NAD83(2011) + NAVD88 height",
"6350":"NAD83(2011) / Conus Albers",
"6351":"NAD83(2011) / EPSG Arctic zone 5-29",
"6352":"NAD83(2011) / EPSG Arctic zone 5-31",
"6353":"NAD83(2011) / EPSG Arctic zone 6-14",
"6354":"NAD83(2011) / EPSG Arctic zone 6-16",
"6355":"NAD83(2011) / Alabama East",
"6356":"NAD83(2011) / Alabama West",
"6357":"NAVD88 depth",
"6358":"NAVD88 depth (ftUS)",
"6359":"NGVD29 depth (ftUS)",
"6360":"NAVD88 height (ftUS)",
"6362":"Mexico ITRF92 / LCC",
"6363":"Mexico ITRF2008",
"6364":"Mexico ITRF2008",
"6365":"Mexico ITRF2008",
"6366":"Mexico ITRF2008 / UTM zone 11N",
"6367":"Mexico ITRF2008 / UTM zone 12N",
"6368":"Mexico ITRF2008 / UTM zone 13N",
"6369":"Mexico ITRF2008 / UTM zone 14N",
"6370":"Mexico ITRF2008 / UTM zone 15N",
"6371":"Mexico ITRF2008 / UTM zone 16N",
"6372":"Mexico ITRF2008 / LCC",
"6381":"UCS-2000 / Ukraine TM zone 7",
"6382":"UCS-2000 / Ukraine TM zone 8",
"6383":"UCS-2000 / Ukraine TM zone 9",
"6384":"UCS-2000 / Ukraine TM zone 10",
"6385":"UCS-2000 / Ukraine TM zone 11",
"6386":"UCS-2000 / Ukraine TM zone 12",
"6387":"UCS-2000 / Ukraine TM zone 13",
"6391":"Cayman Islands National Grid 2011",
"6393":"NAD83(2011) / Alaska Albers",
"6394":"NAD83(2011) / Alaska zone 1",
"6395":"NAD83(2011) / Alaska zone 2",
"6396":"NAD83(2011) / Alaska zone 3",
"6397":"NAD83(2011) / Alaska zone 4",
"6398":"NAD83(2011) / Alaska zone 5",
"6399":"NAD83(2011) / Alaska zone 6",
"6400":"NAD83(2011) / Alaska zone 7",
"6401":"NAD83(2011) / Alaska zone 8",
"6402":"NAD83(2011) / Alaska zone 9",
"6403":"NAD83(2011) / Alaska zone 10",
"6404":"NAD83(2011) / Arizona Central",
"6405":"NAD83(2011) / Arizona Central (ft)",
"6406":"NAD83(2011) / Arizona East",
"6407":"NAD83(2011) / Arizona East (ft)",
"6408":"NAD83(2011) / Arizona West",
"6409":"NAD83(2011) / Arizona West (ft)",
"6410":"NAD83(2011) / Arkansas North",
"6411":"NAD83(2011) / Arkansas North (ftUS)",
"6412":"NAD83(2011) / Arkansas South",
"6413":"NAD83(2011) / Arkansas South (ftUS)",
"6414":"NAD83(2011) / California Albers",
"6415":"NAD83(2011) / California zone 1",
"6416":"NAD83(2011) / California zone 1 (ftUS)",
"6417":"NAD83(2011) / California zone 2",
"6418":"NAD83(2011) / California zone 2 (ftUS)",
"6419":"NAD83(2011) / California zone 3",
"6420":"NAD83(2011) / California zone 3 (ftUS)",
"6421":"NAD83(2011) / California zone 4",
"6422":"NAD83(2011) / California zone 4 (ftUS)",
"6423":"NAD83(2011) / California zone 5",
"6424":"NAD83(2011) / California zone 5 (ftUS)",
"6425":"NAD83(2011) / California zone 6",
"6426":"NAD83(2011) / California zone 6 (ftUS)",
"6427":"NAD83(2011) / Colorado Central",
"6428":"NAD83(2011) / Colorado Central (ftUS)",
"6429":"NAD83(2011) / Colorado North",
"6430":"NAD83(2011) / Colorado North (ftUS)",
"6431":"NAD83(2011) / Colorado South",
"6432":"NAD83(2011) / Colorado South (ftUS)",
"6433":"NAD83(2011) / Connecticut",
"6434":"NAD83(2011) / Connecticut (ftUS)",
"6435":"NAD83(2011) / Delaware",
"6436":"NAD83(2011) / Delaware (ftUS)",
"6437":"NAD83(2011) / Florida East",
"6438":"NAD83(2011) / Florida East (ftUS)",
"6439":"NAD83(2011) / Florida GDL Albers",
"6440":"NAD83(2011) / Florida North",
"6441":"NAD83(2011) / Florida North (ftUS)",
"6442":"NAD83(2011) / Florida West",
"6443":"NAD83(2011) / Florida West (ftUS)",
"6444":"NAD83(2011) / Georgia East",
"6445":"NAD83(2011) / Georgia East (ftUS)",
"6446":"NAD83(2011) / Georgia West",
"6447":"NAD83(2011) / Georgia West (ftUS)",
"6448":"NAD83(2011) / Idaho Central",
"6449":"NAD83(2011) / Idaho Central (ftUS)",
"6450":"NAD83(2011) / Idaho East",
"6451":"NAD83(2011) / Idaho East (ftUS)",
"6452":"NAD83(2011) / Idaho West",
"6453":"NAD83(2011) / Idaho West (ftUS)",
"6454":"NAD83(2011) / Illinois East",
"6455":"NAD83(2011) / Illinois East (ftUS)",
"6456":"NAD83(2011) / Illinois West",
"6457":"NAD83(2011) / Illinois West (ftUS)",
"6458":"NAD83(2011) / Indiana East",
"6459":"NAD83(2011) / Indiana East (ftUS)",
"6460":"NAD83(2011) / Indiana West",
"6461":"NAD83(2011) / Indiana West (ftUS)",
"6462":"NAD83(2011) / Iowa North",
"6463":"NAD83(2011) / Iowa North (ftUS)",
"6464":"NAD83(2011) / Iowa South",
"6465":"NAD83(2011) / Iowa South (ftUS)",
"6466":"NAD83(2011) / Kansas North",
"6467":"NAD83(2011) / Kansas North (ftUS)",
"6468":"NAD83(2011) / Kansas South",
"6469":"NAD83(2011) / Kansas South (ftUS)",
"6470":"NAD83(2011) / Kentucky North",
"6471":"NAD83(2011) / Kentucky North (ftUS)",
"6472":"NAD83(2011) / Kentucky Single Zone",
"6473":"NAD83(2011) / Kentucky Single Zone (ftUS)",
"6474":"NAD83(2011) / Kentucky South",
"6475":"NAD83(2011) / Kentucky South (ftUS)",
"6476":"NAD83(2011) / Louisiana North",
"6477":"NAD83(2011) / Louisiana North (ftUS)",
"6478":"NAD83(2011) / Louisiana South",
"6479":"NAD83(2011) / Louisiana South (ftUS)",
"6480":"NAD83(2011) / Maine CS2000 Central",
"6481":"NAD83(2011) / Maine CS2000 East",
"6482":"NAD83(2011) / Maine CS2000 West",
"6483":"NAD83(2011) / Maine East",
"6484":"NAD83(2011) / Maine East (ftUS)",
"6485":"NAD83(2011) / Maine West",
"6486":"NAD83(2011) / Maine West (ftUS)",
"6487":"NAD83(2011) / Maryland",
"6488":"NAD83(2011) / Maryland (ftUS)",
"6489":"NAD83(2011) / Massachusetts Island",
"6490":"NAD83(2011) / Massachusetts Island (ftUS)",
"6491":"NAD83(2011) / Massachusetts Mainland",
"6492":"NAD83(2011) / Massachusetts Mainland (ftUS)",
"6493":"NAD83(2011) / Michigan Central",
"6494":"NAD83(2011) / Michigan Central (ft)",
"6495":"NAD83(2011) / Michigan North",
"6496":"NAD83(2011) / Michigan North (ft)",
"6497":"NAD83(2011) / Michigan Oblique Mercator",
"6498":"NAD83(2011) / Michigan South",
"6499":"NAD83(2011) / Michigan South (ft)",
"6500":"NAD83(2011) / Minnesota Central",
"6501":"NAD83(2011) / Minnesota Central (ftUS)",
"6502":"NAD83(2011) / Minnesota North",
"6503":"NAD83(2011) / Minnesota North (ftUS)",
"6504":"NAD83(2011) / Minnesota South",
"6505":"NAD83(2011) / Minnesota South (ftUS)",
"6506":"NAD83(2011) / Mississippi East",
"6507":"NAD83(2011) / Mississippi East (ftUS)",
"6508":"NAD83(2011) / Mississippi TM",
"6509":"NAD83(2011) / Mississippi West",
"6510":"NAD83(2011) / Mississippi West (ftUS)",
"6511":"NAD83(2011) / Missouri Central",
"6512":"NAD83(2011) / Missouri East",
"6513":"NAD83(2011) / Missouri West",
"6514":"NAD83(2011) / Montana",
"6515":"NAD83(2011) / Montana (ft)",
"6516":"NAD83(2011) / Nebraska",
"6517":"NAD83(2011) / Nebraska (ftUS)",
"6518":"NAD83(2011) / Nevada Central",
"6519":"NAD83(2011) / Nevada Central (ftUS)",
"6520":"NAD83(2011) / Nevada East",
"6521":"NAD83(2011) / Nevada East (ftUS)",
"6522":"NAD83(2011) / Nevada West",
"6523":"NAD83(2011) / Nevada West (ftUS)",
"6524":"NAD83(2011) / New Hampshire",
"6525":"NAD83(2011) / New Hampshire (ftUS)",
"6526":"NAD83(2011) / New Jersey",
"6527":"NAD83(2011) / New Jersey (ftUS)",
"6528":"NAD83(2011) / New Mexico Central",
"6529":"NAD83(2011) / New Mexico Central (ftUS)",
"6530":"NAD83(2011) / New Mexico East",
"6531":"NAD83(2011) / New Mexico East (ftUS)",
"6532":"NAD83(2011) / New Mexico West",
"6533":"NAD83(2011) / New Mexico West (ftUS)",
"6534":"NAD83(2011) / New York Central",
"6535":"NAD83(2011) / New York Central (ftUS)",
"6536":"NAD83(2011) / New York East",
"6537":"NAD83(2011) / New York East (ftUS)",
"6538":"NAD83(2011) / New York Long Island",
"6539":"NAD83(2011) / New York Long Island (ftUS)",
"6540":"NAD83(2011) / New York West",
"6541":"NAD83(2011) / New York West (ftUS)",
"6542":"NAD83(2011) / North Carolina",
"6543":"NAD83(2011) / North Carolina (ftUS)",
"6544":"NAD83(2011) / North Dakota North",
"6545":"NAD83(2011) / North Dakota North (ft)",
"6546":"NAD83(2011) / North Dakota South",
"6547":"NAD83(2011) / North Dakota South (ft)",
"6548":"NAD83(2011) / Ohio North",
"6549":"NAD83(2011) / Ohio North (ftUS)",
"6550":"NAD83(2011) / Ohio South",
"6551":"NAD83(2011) / Ohio South (ftUS)",
"6552":"NAD83(2011) / Oklahoma North",
"6553":"NAD83(2011) / Oklahoma North (ftUS)",
"6554":"NAD83(2011) / Oklahoma South",
"6555":"NAD83(2011) / Oklahoma South (ftUS)",
"6556":"NAD83(2011) / Oregon LCC (m)",
"6557":"NAD83(2011) / Oregon GIC Lambert (ft)",
"6558":"NAD83(2011) / Oregon North",
"6559":"NAD83(2011) / Oregon North (ft)",
"6560":"NAD83(2011) / Oregon South",
"6561":"NAD83(2011) / Oregon South (ft)",
"6562":"NAD83(2011) / Pennsylvania North",
"6563":"NAD83(2011) / Pennsylvania North (ftUS)",
"6564":"NAD83(2011) / Pennsylvania South",
"6565":"NAD83(2011) / Pennsylvania South (ftUS)",
"6566":"NAD83(2011) / Puerto Rico and Virgin Is.",
"6567":"NAD83(2011) / Rhode Island",
"6568":"NAD83(2011) / Rhode Island (ftUS)",
"6569":"NAD83(2011) / South Carolina",
"6570":"NAD83(2011) / South Carolina (ft)",
"6571":"NAD83(2011) / South Dakota North",
"6572":"NAD83(2011) / South Dakota North (ftUS)",
"6573":"NAD83(2011) / South Dakota South",
"6574":"NAD83(2011) / South Dakota South (ftUS)",
"6575":"NAD83(2011) / Tennessee",
"6576":"NAD83(2011) / Tennessee (ftUS)",
"6577":"NAD83(2011) / Texas Central",
"6578":"NAD83(2011) / Texas Central (ftUS)",
"6579":"NAD83(2011) / Texas Centric Albers Equal Area",
"6580":"NAD83(2011) / Texas Centric Lambert Conformal",
"6581":"NAD83(2011) / Texas North",
"6582":"NAD83(2011) / Texas North (ftUS)",
"6583":"NAD83(2011) / Texas North Central",
"6584":"NAD83(2011) / Texas North Central (ftUS)",
"6585":"NAD83(2011) / Texas South",
"6586":"NAD83(2011) / Texas South (ftUS)",
"6587":"NAD83(2011) / Texas South Central",
"6588":"NAD83(2011) / Texas South Central (ftUS)",
"6589":"NAD83(2011) / Vermont",
"6590":"NAD83(2011) / Vermont (ftUS)",
"6591":"NAD83(2011) / Virginia Lambert",
"6592":"NAD83(2011) / Virginia North",
"6593":"NAD83(2011) / Virginia North (ftUS)",
"6594":"NAD83(2011) / Virginia South",
"6595":"NAD83(2011) / Virginia South (ftUS)",
"6596":"NAD83(2011) / Washington North",
"6597":"NAD83(2011) / Washington North (ftUS)",
"6598":"NAD83(2011) / Washington South",
"6599":"NAD83(2011) / Washington South (ftUS)",
"6600":"NAD83(2011) / West Virginia North",
"6601":"NAD83(2011) / West Virginia North (ftUS)",
"6602":"NAD83(2011) / West Virginia South",
"6603":"NAD83(2011) / West Virginia South (ftUS)",
"6604":"NAD83(2011) / Wisconsin Central",
"6605":"NAD83(2011) / Wisconsin Central (ftUS)",
"6606":"NAD83(2011) / Wisconsin North",
"6607":"NAD83(2011) / Wisconsin North (ftUS)",
"6608":"NAD83(2011) / Wisconsin South",
"6609":"NAD83(2011) / Wisconsin South (ftUS)",
"6610":"NAD83(2011) / Wisconsin Transverse Mercator",
"6611":"NAD83(2011) / Wyoming East",
"6612":"NAD83(2011) / Wyoming East (ftUS)",
"6613":"NAD83(2011) / Wyoming East Central",
"6614":"NAD83(2011) / Wyoming East Central (ftUS)",
"6615":"NAD83(2011) / Wyoming West",
"6616":"NAD83(2011) / Wyoming West (ftUS)",
"6617":"NAD83(2011) / Wyoming West Central",
"6618":"NAD83(2011) / Wyoming West Central (ftUS)",
"6619":"NAD83(2011) / Utah Central",
"6620":"NAD83(2011) / Utah North",
"6621":"NAD83(2011) / Utah South",
"6622":"NAD83(CSRS) / Quebec Lambert",
"6623":"NAD83 / Quebec Albers",
"6624":"NAD83(CSRS) / Quebec Albers",
"6625":"NAD83(2011) / Utah Central (ftUS)",
"6626":"NAD83(2011) / Utah North (ftUS)",
"6627":"NAD83(2011) / Utah South (ftUS)",
"6628":"NAD83(PA11) / Hawaii zone 1",
"6629":"NAD83(PA11) / Hawaii zone 2",
"6630":"NAD83(PA11) / Hawaii zone 3",
"6631":"NAD83(PA11) / Hawaii zone 4",
"6632":"NAD83(PA11) / Hawaii zone 5",
"6633":"NAD83(PA11) / Hawaii zone 3 (ftUS)",
"6634":"NAD83(PA11) / UTM zone 4N",
"6635":"NAD83(PA11) / UTM zone 5N",
"6636":"NAD83(PA11) / UTM zone 2S",
"6637":"NAD83(MA11) / Guam Map Grid",
"6638":"Tutuila 1962 height",
"6639":"Guam 1963 height",
"6640":"NMVD03 height",
"6641":"PRVD02 height",
"6642":"VIVD09 height",
"6643":"ASVD02 height",
"6644":"GUVD04 height",
"6646":"Karbala 1979 / Iraq National Grid",
"6647":"CGVD2013 height",
"6649":"NAD83(CSRS) + CGVD2013 height",
"6650":"NAD83(CSRS) / UTM zone 7N + CGVD2013 height",
"6651":"NAD83(CSRS) / UTM zone 8N + CGVD2013 height",
"6652":"NAD83(CSRS) / UTM zone 9N + CGVD2013 height",
"6653":"NAD83(CSRS) / UTM zone 10N + CGVD2013 height",
"6654":"NAD83(CSRS) / UTM zone 11N + CGVD2013 height",
"6655":"NAD83(CSRS) / UTM zone 12N + CGVD2013 height",
"6656":"NAD83(CSRS) / UTM zone 13N + CGVD2013 height",
"6657":"NAD83(CSRS) / UTM zone 14N + CGVD2013 height",
"6658":"NAD83(CSRS) / UTM zone 15N + CGVD2013 height",
"6659":"NAD83(CSRS) / UTM zone 16N + CGVD2013 height",
"6660":"NAD83(CSRS) / UTM zone 17N + CGVD2013 height",
"6661":"NAD83(CSRS) / UTM zone 18N + CGVD2013 height",
"6662":"NAD83(CSRS) / UTM zone 19N + CGVD2013 height",
"6663":"NAD83(CSRS) / UTM zone 20N + CGVD2013 height",
"6664":"NAD83(CSRS) / UTM zone 21N + CGVD2013 height",
"6665":"NAD83(CSRS) / UTM zone 22N + CGVD2013 height",
"6666":"JGD2011",
"6667":"JGD2011",
"6668":"JGD2011",
"6669":"JGD2011 / Japan Plane Rectangular CS I",
"6670":"JGD2011 / Japan Plane Rectangular CS II",
"6671":"JGD2011 / Japan Plane Rectangular CS III",
"6672":"JGD2011 / Japan Plane Rectangular CS IV",
"6673":"JGD2011 / Japan Plane Rectangular CS V",
"6674":"JGD2011 / Japan Plane Rectangular CS VI",
"6675":"JGD2011 / Japan Plane Rectangular CS VII",
"6676":"JGD2011 / Japan Plane Rectangular CS VIII",
"6677":"JGD2011 / Japan Plane Rectangular CS IX",
"6678":"JGD2011 / Japan Plane Rectangular CS X",
"6679":"JGD2011 / Japan Plane Rectangular CS XI",
"6680":"JGD2011 / Japan Plane Rectangular CS XII",
"6681":"JGD2011 / Japan Plane Rectangular CS XIII",
"6682":"JGD2011 / Japan Plane Rectangular CS XIV",
"6683":"JGD2011 / Japan Plane Rectangular CS XV",
"6684":"JGD2011 / Japan Plane Rectangular CS XVI",
"6685":"JGD2011 / Japan Plane Rectangular CS XVII",
"6686":"JGD2011 / Japan Plane Rectangular CS XVIII",
"6687":"JGD2011 / Japan Plane Rectangular CS XIX",
"6688":"JGD2011 / UTM zone 51N",
"6689":"JGD2011 / UTM zone 52N",
"6690":"JGD2011 / UTM zone 53N",
"6691":"JGD2011 / UTM zone 54N",
"6692":"JGD2011 / UTM zone 55N",
"6693":"JSLD72 height",
"6694":"JGD2000 (vertical) height",
"6695":"JGD2011 (vertical) height",
"6696":"JGD2000 + JGD2000 (vertical) height",
"6697":"JGD2011 + JGD2011 (vertical) height",
"6700":"Tokyo + JSLD72 height",
"6703":"WGS 84 / TM 60 SW",
"6704":"RDN2008",
"6705":"RDN2008",
"6706":"RDN2008",
"6707":"RDN2008 / UTM zone 32N (N-E)",
"6708":"RDN2008 / UTM zone 33N (N-E)",
"6709":"RDN2008 / UTM zone 34N (N-E)",
"6715":"Christmas Island Grid 1985",
"6720":"WGS 84 / CIG92",
"6721":"GDA94 / CIG94",
"6722":"WGS 84 / CKIG92",
"6723":"GDA94 / CKIG94",
"6732":"GDA94 / MGA zone 41",
"6733":"GDA94 / MGA zone 42",
"6734":"GDA94 / MGA zone 43",
"6735":"GDA94 / MGA zone 44",
"6736":"GDA94 / MGA zone 46",
"6737":"GDA94 / MGA zone 47",
"6738":"GDA94 / MGA zone 59",
"6781":"NAD83(CORS96)",
"6782":"NAD83(CORS96)",
"6783":"NAD83(CORS96)",
"6784":"NAD83(CORS96) / Oregon Baker zone (m)",
"6785":"NAD83(CORS96) / Oregon Baker zone (ft)",
"6786":"NAD83(2011) / Oregon Baker zone (m)",
"6787":"NAD83(2011) / Oregon Baker zone (ft)",
"6788":"NAD83(CORS96) / Oregon Bend-Klamath Falls zone (m)",
"6789":"NAD83(CORS96) / Oregon Bend-Klamath Falls zone (ft)",
"6790":"NAD83(2011) / Oregon Bend-Klamath Falls zone (m)",
"6791":"NAD83(2011) / Oregon Bend-Klamath Falls zone (ft)",
"6792":"NAD83(CORS96) / Oregon Bend-Redmond-Prineville zone (m)",
"6793":"NAD83(CORS96) / Oregon Bend-Redmond-Prineville zone (ft)",
"6794":"NAD83(2011) / Oregon Bend-Redmond-Prineville zone (m)",
"6795":"NAD83(2011) / Oregon Bend-Redmond-Prineville zone (ft)",
"6796":"NAD83(CORS96) / Oregon Bend-Burns zone (m)",
"6797":"NAD83(CORS96) / Oregon Bend-Burns zone (ft)",
"6798":"NAD83(2011) / Oregon Bend-Burns zone (m)",
"6799":"NAD83(2011) / Oregon Bend-Burns zone (ft)",
"6800":"NAD83(CORS96) / Oregon Canyonville-Grants Pass zone (m)",
"6801":"NAD83(CORS96) / Oregon Canyonville-Grants Pass zone (ft)",
"6802":"NAD83(2011) / Oregon Canyonville-Grants Pass zone (m)",
"6803":"NAD83(2011) / Oregon Canyonville-Grants Pass zone (ft)",
"6804":"NAD83(CORS96) / Oregon Columbia River East zone (m)",
"6805":"NAD83(CORS96) / Oregon Columbia River East zone (ft)",
"6806":"NAD83(2011) / Oregon Columbia River East zone (m)",
"6807":"NAD83(2011) / Oregon Columbia River East zone (ft)",
"6808":"NAD83(CORS96) / Oregon Columbia River West zone (m)",
"6809":"NAD83(CORS96) / Oregon Columbia River West zone (ft)",
"6810":"NAD83(2011) / Oregon Columbia River West zone (m)",
"6811":"NAD83(2011) / Oregon Columbia River West zone (ft)",
"6812":"NAD83(CORS96) / Oregon Cottage Grove-Canyonville zone (m)",
"6813":"NAD83(CORS96) / Oregon Cottage Grove-Canyonville zone (ft)",
"6814":"NAD83(2011) / Oregon Cottage Grove-Canyonville zone (m)",
"6815":"NAD83(2011) / Oregon Cottage Grove-Canyonville zone (ft)",
"6816":"NAD83(CORS96) / Oregon Dufur-Madras zone (m)",
"6817":"NAD83(CORS96) / Oregon Dufur-Madras zone (ft)",
"6818":"NAD83(2011) / Oregon Dufur-Madras zone (m)",
"6819":"NAD83(2011) / Oregon Dufur-Madras zone (ft)",
"6820":"NAD83(CORS96) / Oregon Eugene zone (m)",
"6821":"NAD83(CORS96) / Oregon Eugene zone (ft)",
"6822":"NAD83(2011) / Oregon Eugene zone (m)",
"6823":"NAD83(2011) / Oregon Eugene zone (ft)",
"6824":"NAD83(CORS96) / Oregon Grants Pass-Ashland zone (m)",
"6825":"NAD83(CORS96) / Oregon Grants Pass-Ashland zone (ft)",
"6826":"NAD83(2011) / Oregon Grants Pass-Ashland zone (m)",
"6827":"NAD83(2011) / Oregon Grants Pass-Ashland zone (ft)",
"6828":"NAD83(CORS96) / Oregon Gresham-Warm Springs zone (m)",
"6829":"NAD83(CORS96) / Oregon Gresham-Warm Springs zone (ft)",
"6830":"NAD83(2011) / Oregon Gresham-Warm Springs zone (m)",
"6831":"NAD83(2011) / Oregon Gresham-Warm Springs zone (ft)",
"6832":"NAD83(CORS96) / Oregon La Grande zone (m)",
"6833":"NAD83(CORS96) / Oregon La Grande zone (ft)",
"6834":"NAD83(2011) / Oregon La Grande zone (m)",
"6835":"NAD83(2011) / Oregon La Grande zone (ft)",
"6836":"NAD83(CORS96) / Oregon Ontario zone (m)",
"6837":"NAD83(CORS96) / Oregon Ontario zone (ft)",
"6838":"NAD83(2011) / Oregon Ontario zone (m)",
"6839":"NAD83(2011) / Oregon Ontario zone (ft)",
"6840":"NAD83(CORS96) / Oregon Coast zone (m)",
"6841":"NAD83(CORS96) / Oregon Coast zone (ft)",
"6842":"NAD83(2011) / Oregon Coast zone (m)",
"6843":"NAD83(2011) / Oregon Coast zone (ft)",
"6844":"NAD83(CORS96) / Oregon Pendleton zone (m)",
"6845":"NAD83(CORS96) / Oregon Pendleton zone (ft)",
"6846":"NAD83(2011) / Oregon Pendleton zone (m)",
"6847":"NAD83(2011) / Oregon Pendleton zone (ft)",
"6848":"NAD83(CORS96) / Oregon Pendleton-La Grande zone (m)",
"6849":"NAD83(CORS96) / Oregon Pendleton-La Grande zone (ft)",
"6850":"NAD83(2011) / Oregon Pendleton-La Grande zone (m)",
"6851":"NAD83(2011) / Oregon Pendleton-La Grande zone (ft)",
"6852":"NAD83(CORS96) / Oregon Portland zone (m)",
"6853":"NAD83(CORS96) / Oregon Portland zone (ft)",
"6854":"NAD83(2011) / Oregon Portland zone (m)",
"6855":"NAD83(2011) / Oregon Portland zone (ft)",
"6856":"NAD83(CORS96) / Oregon Salem zone (m)",
"6857":"NAD83(CORS96) / Oregon Salem zone (ft)",
"6858":"NAD83(2011) / Oregon Salem zone (m)",
"6859":"NAD83(2011) / Oregon Salem zone (ft)",
"6860":"NAD83(CORS96) / Oregon Santiam Pass zone (m)",
"6861":"NAD83(CORS96) / Oregon Santiam Pass zone (ft)",
"6862":"NAD83(2011) / Oregon Santiam Pass zone (m)",
"6863":"NAD83(2011) / Oregon Santiam Pass zone (ft)",
"6867":"NAD83(CORS96) / Oregon LCC (m)",
"6868":"NAD83(CORS96) / Oregon GIC Lambert (ft)",
"6870":"ETRS89 / Albania TM 2010",
"6871":"WGS 84 / Pseudo-Mercator +  EGM2008 geoid height",
"6875":"RDN2008 / Italy zone (N-E)",
"6876":"RDN2008 / Zone 12 (N-E)",
"6879":"NAD83(2011) / Wisconsin Central",
"6880":"NAD83(2011) / Nebraska (ftUS)",
"6881":"Aden 1925",
"6882":"Bekaa Valley 1920",
"6883":"Bioko",
"6884":"NAD83(CORS96) / Oregon North",
"6885":"NAD83(CORS96) / Oregon North (ft)",
"6886":"NAD83(CORS96) / Oregon South",
"6887":"NAD83(CORS96) / Oregon South (ft)",
"6892":"South East Island 1943",
"6893":"WGS 84 / World Mercator +  EGM2008 height",
"6894":"Gambia",
"6915":"South East Island 1943 / UTM zone 40N",
"6916":"SHD height",
"6917":"SVY21 + SHD height",
"6922":"NAD83 / Kansas LCC",
"6923":"NAD83 / Kansas LCC (ftUS)",
"6924":"NAD83(2011) / Kansas LCC",
"6925":"NAD83(2011) / Kansas LCC (ftUS)",
"6927":"SVY21 / Singapore TM + SHD height",
"6931":"WGS 84 / NSIDC EASE-Grid 2.0 North",
"6932":"WGS 84 / NSIDC EASE-Grid 2.0 South",
"6933":"WGS 84 / NSIDC EASE-Grid 2.0 Global",
"6934":"IGS08",
"6956":"VN-2000 / TM-3 zone 481",
"6957":"VN-2000 / TM-3 zone 482",
"6958":"VN-2000 / TM-3 zone 491",
"6959":"VN-2000 / TM-3 Da Nang zone",
"6962":"ETRS89 / Albania LCC 2010",
"6966":"NAD27 / Michigan North",
"6978":"IGD05",
"6979":"IGD05",
"6980":"IGD05",
"6981":"IG05 Intermediate CRS",
"6982":"IG05 Intermediate CRS",
"6983":"IG05 Intermediate CRS",
"6984":"Israeli Grid 05",
"6985":"IGD05/12",
"6986":"IGD05/12",
"6987":"IGD05/12",
"6988":"IG05/12 Intermediate CRS",
"6989":"IG05/12 Intermediate CRS",
"6990":"IG05/12 Intermediate CRS",
"6991":"Israeli Grid 05/12",
"6996":"NAD83(2011) / San Francisco CS13",
"6997":"NAD83(2011) / San Francisco CS13 (ftUS)",
"7005":"Nahrwan 1934 / UTM zone 37N",
"7006":"Nahrwan 1934 / UTM zone 38N",
"7007":"Nahrwan 1934 / UTM zone 39N",
"7034":"RGSPM06 (lon-lat)",
"7035":"RGSPM06 (lon-lat)",
"7036":"RGR92 (lon-lat)",
"7037":"RGR92 (lon-lat)",
"7038":"RGM04 (lon-lat)",
"7039":"RGM04 (lon-lat)",
"7040":"RGFG95 (lon-lat)",
"7041":"RGFG95 (lon-lat)",
"7042":"RGF93 (lon-lat)",
"7057":"NAD83(2011) / IaRCS zone 1",
"7058":"NAD83(2011) / IaRCS zone 2",
"7059":"NAD83(2011) / IaRCS zone 3",
"7060":"NAD83(2011) / IaRCS zone 4",
"7061":"NAD83(2011) / IaRCS zone 5",
"7062":"NAD83(2011) / IaRCS zone 6",
"7063":"NAD83(2011) / IaRCS zone 7",
"7064":"NAD83(2011) / IaRCS zone 8",
"7065":"NAD83(2011) / IaRCS zone 9",
"7066":"NAD83(2011) / IaRCS zone 10",
"7067":"NAD83(2011) / IaRCS zone 11",
"7068":"NAD83(2011) / IaRCS zone 12",
"7069":"NAD83(2011) / IaRCS zone 13",
"7070":"NAD83(2011) / IaRCS zone 14",
"7071":"RGTAAF07",
"7072":"RGTAAF07",
"7073":"RGTAAF07",
"7074":"RGTAAF07 / UTM zone 37S",
"7075":"RGTAAF07 / UTM zone 38S",
"7076":"RGTAAF07 / UTM zone 39S",
"7077":"RGTAAF07 / UTM zone 40S",
"7078":"RGTAAF07 / UTM zone 41S",
"7079":"RGTAAF07 / UTM zone 42S",
"7080":"RGTAAF07 / UTM zone 43S",
"7081":"RGTAAF07 / UTM zone 44S",
"7082":"RGTAAF07 / Terre Adelie Polar Stereographic",
"7084":"RGF93 (lon-lat)",
"7085":"RGAF09 (lon-lat)",
"7086":"RGAF09 (lon-lat)",
"7087":"RGTAAF07 (lon-lat)",
"7088":"RGTAAF07 (lon-lat)",
"7109":"NAD83(2011) / RMTCRS St Mary (m)",
"7110":"NAD83(2011) / RMTCRS Blackfeet (m)",
"7111":"NAD83(2011) / RMTCRS Milk River (m)",
"7112":"NAD83(2011) / RMTCRS Fort Belknap (m)",
"7113":"NAD83(2011) / RMTCRS Fort Peck Assiniboine (m)",
"7114":"NAD83(2011) / RMTCRS Fort Peck Sioux (m)",
"7115":"NAD83(2011) / RMTCRS Crow (m)",
"7116":"NAD83(2011) / RMTCRS Bobcat (m)",
"7117":"NAD83(2011) / RMTCRS Billings (m)",
"7118":"NAD83(2011) / RMTCRS Wind River (m)",
"7119":"NAD83(2011) / RMTCRS St Mary (ft)",
"7120":"NAD83(2011) / RMTCRS Blackfeet (ft)",
"7121":"NAD83(2011) / RMTCRS Milk River (ft)",
"7122":"NAD83(2011) / RMTCRS Fort Belknap (ft)",
"7123":"NAD83(2011) / RMTCRS Fort Peck Assiniboine (ft)",
"7124":"NAD83(2011) / RMTCRS Fort Peck Sioux (ft)",
"7125":"NAD83(2011) / RMTCRS Crow (ft)",
"7126":"NAD83(2011) / RMTCRS Bobcat (ft)",
"7127":"NAD83(2011) / RMTCRS Billings (ft)",
"7128":"NAD83(2011) / RMTCRS Wind River (ftUS)",
"7131":"NAD83(2011) / San Francisco CS13",
"7132":"NAD83(2011) / San Francisco CS13 (ftUS)",
"7133":"RGTAAF07 (lon-lat)",
"7134":"IGD05",
"7135":"IGD05",
"7136":"IGD05",
"7137":"IGD05/12",
"7138":"IGD05/12",
"7139":"IGD05/12",
"7142":"Palestine 1923 / Palestine Grid modified",
"7257":"NAD83(2011) / InGCS Adams (m)",
"7258":"NAD83(2011) / InGCS Adams (ftUS)",
"7259":"NAD83(2011) / InGCS Allen (m)",
"7260":"NAD83(2011) / InGCS Allen (ftUS)",
"7261":"NAD83(2011) / InGCS Bartholomew (m)",
"7262":"NAD83(2011) / InGCS Bartholomew (ftUS)",
"7263":"NAD83(2011) / InGCS Benton (m)",
"7264":"NAD83(2011) / InGCS Benton (ftUS)",
"7265":"NAD83(2011) / InGCS Blackford-Delaware (m)",
"7266":"NAD83(2011) / InGCS Blackford-Delaware (ftUS)",
"7267":"NAD83(2011) / InGCS Boone-Hendricks (m)",
"7268":"NAD83(2011) / InGCS Boone-Hendricks (ftUS)",
"7269":"NAD83(2011) / InGCS Brown (m)",
"7270":"NAD83(2011) / InGCS Brown (ftUS)",
"7271":"NAD83(2011) / InGCS Carroll (m)",
"7272":"NAD83(2011) / InGCS Carroll (ftUS)",
"7273":"NAD83(2011) / InGCS Cass (m)",
"7274":"NAD83(2011) / InGCS Cass (ftUS)",
"7275":"NAD83(2011) / InGCS Clark-Floyd-Scott (m)",
"7276":"NAD83(2011) / InGCS Clark-Floyd-Scott (ftUS)",
"7277":"NAD83(2011) / InGCS Clay (m)",
"7278":"NAD83(2011) / InGCS Clay (ftUS)",
"7279":"NAD83(2011) / InGCS Clinton (m)",
"7280":"NAD83(2011) / InGCS Clinton (ftUS)",
"7281":"NAD83(2011) / InGCS Crawford-Lawrence-Orange (m)",
"7282":"NAD83(2011) / InGCS Crawford-Lawrence-Orange (ftUS)",
"7283":"NAD83(2011) / InGCS Daviess-Greene (m)",
"7284":"NAD83(2011) / InGCS Daviess-Greene (ftUS)",
"7285":"NAD83(2011) / InGCS Dearborn-Ohio-Switzerland (m)",
"7286":"NAD83(2011) / InGCS Dearborn-Ohio-Switzerland (ftUS)",
"7287":"NAD83(2011) / InGCS Decatur-Rush (m)",
"7288":"NAD83(2011) / InGCS Decatur-Rush (ftUS)",
"7289":"NAD83(2011) / InGCS DeKalb (m)",
"7290":"NAD83(2011) / InGCS DeKalb (ftUS)",
"7291":"NAD83(2011) / InGCS Dubois-Martin (m)",
"7292":"NAD83(2011) / InGCS Dubois-Martin (ftUS)",
"7293":"NAD83(2011) / InGCS Elkhart-Kosciusko-Wabash (m)",
"7294":"NAD83(2011) / InGCS Elkhart-Kosciusko-Wabash (ftUS)",
"7295":"NAD83(2011) / InGCS Fayette-Franklin-Union (m)",
"7296":"NAD83(2011) / InGCS Fayette-Franklin-Union (ftUS)",
"7297":"NAD83(2011) / InGCS Fountain-Warren (m)",
"7298":"NAD83(2011) / InGCS Fountain-Warren (ftUS)",
"7299":"NAD83(2011) / InGCS Fulton-Marshall-St. Joseph (m)",
"7300":"NAD83(2011) / InGCS Fulton-Marshall-St. Joseph (ftUS)",
"7301":"NAD83(2011) / InGCS Gibson (m)",
"7302":"NAD83(2011) / InGCS Gibson (ftUS)",
"7303":"NAD83(2011) / InGCS Grant (m)",
"7304":"NAD83(2011) / InGCS Grant (ftUS)",
"7305":"NAD83(2011) / InGCS Hamilton-Tipton (m)",
"7306":"NAD83(2011) / InGCS Hamilton-Tipton (ftUS)",
"7307":"NAD83(2011) / InGCS Hancock-Madison (m)",
"7308":"NAD83(2011) / InGCS Hancock-Madison (ftUS)",
"7309":"NAD83(2011) / InGCS Harrison-Washington (m)",
"7310":"NAD83(2011) / InGCS Harrison-Washington (ftUS)",
"7311":"NAD83(2011) / InGCS Henry (m)",
"7312":"NAD83(2011) / InGCS Henry (ftUS)",
"7313":"NAD83(2011) / InGCS Howard-Miami (m)",
"7314":"NAD83(2011) / InGCS Howard-Miami (ftUS)",
"7315":"NAD83(2011) / InGCS Huntington-Whitley (m)",
"7316":"NAD83(2011) / InGCS Huntington-Whitley (ftUS)",
"7317":"NAD83(2011) / InGCS Jackson (m)",
"7318":"NAD83(2011) / InGCS Jackson (ftUS)",
"7319":"NAD83(2011) / InGCS Jasper-Porter (m)",
"7320":"NAD83(2011) / InGCS Jasper-Porter (ftUS)",
"7321":"NAD83(2011) / InGCS Jay (m)",
"7322":"NAD83(2011) / InGCS Jay (ftUS)",
"7323":"NAD83(2011) / InGCS Jefferson (m)",
"7324":"NAD83(2011) / InGCS Jefferson (ftUS)",
"7325":"NAD83(2011) / InGCS Jennings (m)",
"7326":"NAD83(2011) / InGCS Jennings (ftUS)",
"7327":"NAD83(2011) / InGCS Johnson-Marion (m)",
"7328":"NAD83(2011) / InGCS Johnson-Marion (ftUS)",
"7329":"NAD83(2011) / InGCS Knox (m)",
"7330":"NAD83(2011) / InGCS Knox (ftUS)",
"7331":"NAD83(2011) / InGCS LaGrange-Noble (m)",
"7332":"NAD83(2011) / InGCS LaGrange-Noble (ftUS)",
"7333":"NAD83(2011) / InGCS Lake-Newton (m)",
"7334":"NAD83(2011) / InGCS Lake-Newton (ftUS)",
"7335":"NAD83(2011) / InGCS LaPorte-Pulaski-Starke (m)",
"7336":"NAD83(2011) / InGCS LaPorte-Pulaski-Starke (ftUS)",
"7337":"NAD83(2011) / InGCS Monroe-Morgan (m)",
"7338":"NAD83(2011) / InGCS Monroe-Morgan (ftUS)",
"7339":"NAD83(2011) / InGCS Montgomery-Putnam (m)",
"7340":"NAD83(2011) / InGCS Montgomery-Putnam (ftUS)",
"7341":"NAD83(2011) / InGCS Owen (m)",
"7342":"NAD83(2011) / InGCS Owen (ftUS)",
"7343":"NAD83(2011) / InGCS Parke-Vermillion (m)",
"7344":"NAD83(2011) / InGCS Parke-Vermillion (ftUS)",
"7345":"NAD83(2011) / InGCS Perry (m)",
"7346":"NAD83(2011) / InGCS Perry (ftUS)",
"7347":"NAD83(2011) / InGCS Pike-Warrick (m)",
"7348":"NAD83(2011) / InGCS Pike-Warrick (ftUS)",
"7349":"NAD83(2011) / InGCS Posey (m)",
"7350":"NAD83(2011) / InGCS Posey (ftUS)",
"7351":"NAD83(2011) / InGCS Randolph-Wayne (m)",
"7352":"NAD83(2011) / InGCS Randolph-Wayne (ftUS)",
"7353":"NAD83(2011) / InGCS Ripley (m)",
"7354":"NAD83(2011) / InGCS Ripley (ftUS)",
"7355":"NAD83(2011) / InGCS Shelby (m)",
"7356":"NAD83(2011) / InGCS Shelby (ftUS)",
"7357":"NAD83(2011) / InGCS Spencer (m)",
"7358":"NAD83(2011) / InGCS Spencer (ftUS)",
"7359":"NAD83(2011) / InGCS Steuben (m)",
"7360":"NAD83(2011) / InGCS Steuben (ftUS)",
"7361":"NAD83(2011) / InGCS Sullivan (m)",
"7362":"NAD83(2011) / InGCS Sullivan (ftUS)",
"7363":"NAD83(2011) / InGCS Tippecanoe-White (m)",
"7364":"NAD83(2011) / InGCS Tippecanoe-White (ftUS)",
"7365":"NAD83(2011) / InGCS Vanderburgh (m)",
"7366":"NAD83(2011) / InGCS Vanderburgh (ftUS)",
"7367":"NAD83(2011) / InGCS Vigo (m)",
"7368":"NAD83(2011) / InGCS Vigo (ftUS)",
"7369":"NAD83(2011) / InGCS Wells (m)",
"7370":"NAD83(2011) / InGCS Wells (ftUS)",
"7371":"ONGD14",
"7372":"ONGD14",
"7373":"ONGD14",
"7374":"ONGD14 / UTM zone 39N",
"7375":"ONGD14 / UTM zone 40N",
"7376":"ONGD14 / UTM zone 41N",
"7400":"NTF (Paris) + NGF IGN69 height",
"7401":"NTF (Paris) / France II + NGF Lallemand",
"7402":"NTF (Paris) / France II + NGF IGN69",
"7403":"NTF (Paris) / France III + NGF IGN69",
"7404":"RT90 + RH70 height",
"7405":"OSGB 1936 / British National Grid + ODN height",
"7406":"NAD27 + NGVD29 height (ftUS)",
"7407":"NAD27 / Texas North + NGVD29 height (ftUS)",
"7408":"RD/NAP",
"7409":"ETRS89 + EVRF2000 height",
"7410":"PSHD93",
"7411":"NTF (Paris) / Lambert zone II + NGF Lallemand height",
"7412":"NTF (Paris) / Lambert zone II + NGF IGN69",
"7413":"NTF (Paris) / Lambert zone III + NGF IGN69",
"7414":"Tokyo + JSLD69 height",
"7415":"Amersfoort / RD New + NAP height",
"7416":"ETRS89 / UTM zone 32N + DVR90 height",
"7417":"ETRS89 / UTM zone 33N + DVR90 height",
"7418":"ETRS89 / Kp2000 Jutland + DVR90 height",
"7419":"ETRS89 / Kp2000 Zealand + DVR90 height",
"7420":"ETRS89 / Kp2000 Bornholm + DVR90 height",
"7421":"NTF (Paris) / Lambert zone II + NGF-IGN69 height",
"7422":"NTF (Paris) / Lambert zone III + NGF-IGN69 height",
"7423":"ETRS89 + EVRF2007 height",
"7446":"Famagusta 1960 height",
"7447":"PNG08 height",
"7528":"NAD83(2011) / WISCRS Adams and Juneau (m)",
"7529":"NAD83(2011) / WISCRS Ashland (m)",
"7530":"NAD83(2011) / WISCRS Barron (m)",
"7531":"NAD83(2011) / WISCRS Bayfield (m)",
"7532":"NAD83(2011) / WISCRS Brown (m)",
"7533":"NAD83(2011) / WISCRS Buffalo (m)",
"7534":"NAD83(2011) / WISCRS Burnett (m)",
"7535":"NAD83(2011) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (m)",
"7536":"NAD83(2011) / WISCRS Chippewa (m)",
"7537":"NAD83(2011) / WISCRS Clark (m)",
"7538":"NAD83(2011) / WISCRS Columbia (m)",
"7539":"NAD83(2011) / WISCRS Crawford (m)",
"7540":"NAD83(2011) / WISCRS Dane (m)",
"7541":"NAD83(2011) / WISCRS Dodge and Jefferson (m)",
"7542":"NAD83(2011) / WISCRS Door (m)",
"7543":"NAD83(2011) / WISCRS Douglas (m)",
"7544":"NAD83(2011) / WISCRS Dunn (m)",
"7545":"NAD83(2011) / WISCRS Eau Claire (m)",
"7546":"NAD83(2011) / WISCRS Florence (m)",
"7547":"NAD83(2011) / WISCRS Forest (m)",
"7548":"NAD83(2011) / WISCRS Grant (m)",
"7549":"NAD83(2011) / WISCRS Green and Lafayette (m)",
"7550":"NAD83(2011) / WISCRS Green Lake and Marquette (m)",
"7551":"NAD83(2011) / WISCRS Iowa (m)",
"7552":"NAD83(2011) / WISCRS Iron (m)",
"7553":"NAD83(2011) / WISCRS Jackson (m)",
"7554":"NAD83(2011) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (m)",
"7555":"NAD83(2011) / WISCRS Kewaunee, Manitowoc and Sheboygan (m)",
"7556":"NAD83(2011) / WISCRS La Crosse (m)",
"7557":"NAD83(2011) / WISCRS Langlade (m)",
"7558":"NAD83(2011) / WISCRS Lincoln (m)",
"7559":"NAD83(2011) / WISCRS Marathon (m)",
"7560":"NAD83(2011) / WISCRS Marinette (m)",
"7561":"NAD83(2011) / WISCRS Menominee (m)",
"7562":"NAD83(2011) / WISCRS Monroe (m)",
"7563":"NAD83(2011) / WISCRS Oconto (m)",
"7564":"NAD83(2011) / WISCRS Oneida (m)",
"7565":"NAD83(2011) / WISCRS Pepin and Pierce (m)",
"7566":"NAD83(2011) / WISCRS Polk (m)",
"7567":"NAD83(2011) / WISCRS Portage (m)",
"7568":"NAD83(2011) / WISCRS Price (m)",
"7569":"NAD83(2011) / WISCRS Richland (m)",
"7570":"NAD83(2011) / WISCRS Rock (m)",
"7571":"NAD83(2011) / WISCRS Rusk (m)",
"7572":"NAD83(2011) / WISCRS Sauk (m)",
"7573":"NAD83(2011) / WISCRS Sawyer (m)",
"7574":"NAD83(2011) / WISCRS Shawano (m)",
"7575":"NAD83(2011) / WISCRS St. Croix (m)",
"7576":"NAD83(2011) / WISCRS Taylor (m)",
"7577":"NAD83(2011) / WISCRS Trempealeau (m)",
"7578":"NAD83(2011) / WISCRS Vernon (m)",
"7579":"NAD83(2011) / WISCRS Vilas (m)",
"7580":"NAD83(2011) / WISCRS Walworth (m)",
"7581":"NAD83(2011) / WISCRS Washburn (m)",
"7582":"NAD83(2011) / WISCRS Washington (m)",
"7583":"NAD83(2011) / WISCRS Waukesha (m)",
"7584":"NAD83(2011) / WISCRS Waupaca (m)",
"7585":"NAD83(2011) / WISCRS Waushara (m)",
"7586":"NAD83(2011) / WISCRS Wood (m)",
"7587":"NAD83(2011) / WISCRS Adams and Juneau (ftUS)",
"7588":"NAD83(2011) / WISCRS Ashland (ftUS)",
"7589":"NAD83(2011) / WISCRS Barron (ftUS)",
"7590":"NAD83(2011) / WISCRS Bayfield (ftUS)",
"7591":"NAD83(2011) / WISCRS Brown (ftUS)",
"7592":"NAD83(2011) / WISCRS Buffalo (ftUS)",
"7593":"NAD83(2011) / WISCRS Burnett (ftUS)",
"7594":"NAD83(2011) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (ftUS)",
"7595":"NAD83(2011) / WISCRS Chippewa (ftUS)",
"7596":"NAD83(2011) / WISCRS Clark (ftUS)",
"7597":"NAD83(2011) / WISCRS Columbia (ftUS)",
"7598":"NAD83(2011) / WISCRS Crawford (ftUS)",
"7599":"NAD83(2011) / WISCRS Dane (ftUS)",
"7600":"NAD83(2011) / WISCRS Dodge and Jefferson (ftUS)",
"7601":"NAD83(2011) / WISCRS Door (ftUS)",
"7602":"NAD83(2011) / WISCRS Douglas (ftUS)",
"7603":"NAD83(2011) / WISCRS Dunn (ftUS)",
"7604":"NAD83(2011) / WISCRS Eau Claire (ftUS)",
"7605":"NAD83(2011) / WISCRS Florence (ftUS)",
"7606":"NAD83(2011) / WISCRS Forest (ftUS)",
"7607":"NAD83(2011) / WISCRS Grant (ftUS)",
"7608":"NAD83(2011) / WISCRS Green and Lafayette (ftUS)",
"7609":"NAD83(2011) / WISCRS Green Lake and Marquette (ftUS)",
"7610":"NAD83(2011) / WISCRS Iowa (ftUS)",
"7611":"NAD83(2011) / WISCRS Iron (ftUS)",
"7612":"NAD83(2011) / WISCRS Jackson (ftUS)",
"7613":"NAD83(2011) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (ftUS)",
"7614":"NAD83(2011) / WISCRS Kewaunee, Manitowoc and Sheboygan (ftUS)",
"7615":"NAD83(2011) / WISCRS La Crosse (ftUS)",
"7616":"NAD83(2011) / WISCRS Langlade (ftUS)",
"7617":"NAD83(2011) / WISCRS Lincoln (ftUS)",
"7618":"NAD83(2011) / WISCRS Marathon (ftUS)",
"7619":"NAD83(2011) / WISCRS Marinette (ftUS)",
"7620":"NAD83(2011) / WISCRS Menominee (ftUS)",
"7621":"NAD83(2011) / WISCRS Monroe (ftUS)",
"7622":"NAD83(2011) / WISCRS Oconto (ftUS)",
"7623":"NAD83(2011) / WISCRS Oneida (ftUS)",
"7624":"NAD83(2011) / WISCRS Pepin and Pierce (ftUS)",
"7625":"NAD83(2011) / WISCRS Polk (ftUS)",
"7626":"NAD83(2011) / WISCRS Portage (ftUS)",
"7627":"NAD83(2011) / WISCRS Price (ftUS)",
"7628":"NAD83(2011) / WISCRS Richland (ftUS)",
"7629":"NAD83(2011) / WISCRS Rock (ftUS)",
"7630":"NAD83(2011) / WISCRS Rusk (ftUS)",
"7631":"NAD83(2011) / WISCRS Sauk (ftUS)",
"7632":"NAD83(2011) / WISCRS Sawyer (ftUS)",
"7633":"NAD83(2011) / WISCRS Shawano (ftUS)",
"7634":"NAD83(2011) / WISCRS St. Croix (ftUS)",
"7635":"NAD83(2011) / WISCRS Taylor (ftUS)",
"7636":"NAD83(2011) / WISCRS Trempealeau (ftUS)",
"7637":"NAD83(2011) / WISCRS Vernon (ftUS)",
"7638":"NAD83(2011) / WISCRS Vilas (ftUS)",
"7639":"NAD83(2011) / WISCRS Walworth (ftUS)",
"7640":"NAD83(2011) / WISCRS Washburn (ftUS)",
"7641":"NAD83(2011) / WISCRS Washington (ftUS)",
"7642":"NAD83(2011) / WISCRS Waukesha (ftUS)",
"7643":"NAD83(2011) / WISCRS Waupaca (ftUS)",
"7644":"NAD83(2011) / WISCRS Waushara (ftUS)",
"7645":"NAD83(2011) / WISCRS Wood (ftUS)",
"7651":"Kumul 34 height",
"7652":"Kiunga height",
"7656":"WGS 84 (G730)",
"7657":"WGS 84 (G730)",
"7658":"WGS 84 (G873)",
"7659":"WGS 84 (G873)",
"7660":"WGS 84 (G1150)",
"7661":"WGS 84 (G1150)",
"7662":"WGS 84 (G1674)",
"7663":"WGS 84 (G1674)",
"7664":"WGS 84 (G1762)",
"7665":"WGS 84 (G1762)",
"7677":"PZ-90.02",
"7678":"PZ-90.02",
"7679":"PZ-90.11",
"7680":"PZ-90.11",
"7681":"GSK-2011",
"7682":"GSK-2011",
"7683":"GSK-2011",
"7684":"Kyrg-06",
"7685":"Kyrg-06",
"7686":"Kyrg-06",
"7692":"Kyrg-06 / zone 1",
"7693":"Kyrg-06 / zone 2",
"7694":"Kyrg-06 / zone 3",
"7695":"Kyrg-06 / zone 4",
"7696":"Kyrg-06 / zone 5",
"7699":"DHHN12 height",
"7700":"Latvia 2000 height",
"7706":"EPSG moving platform example",
"7707":"ODN (Offshore) height",
"7755":"WGS 84 / India NSF LCC",
"7756":"WGS 84 / Andhra Pradesh",
"7757":"WGS 84 / Arunachal Pradesh",
"7758":"WGS 84 / Assam",
"7759":"WGS 84 / Bihar",
"7760":"WGS 84 / Delhi",
"7761":"WGS 84 / Gujarat",
"7762":"WGS 84 / Haryana",
"7763":"WGS 84 / Himachal Pradesh",
"7764":"WGS 84 / Jammu and Kashmir",
"7765":"WGS 84 / Jharkhand",
"7766":"WGS 84 / Madhya Pradesh",
"7767":"WGS 84 / Maharashtra",
"7768":"WGS 84 / Manipur",
"7769":"WGS 84 / Meghalaya",
"7770":"WGS 84 / Nagaland",
"7771":"WGS 84 / India Northeast",
"7772":"WGS 84 / Orissa",
"7773":"WGS 84 / Punjab",
"7774":"WGS 84 / Rajasthan",
"7775":"WGS 84 / Uttar Pradesh",
"7776":"WGS 84 / Uttaranchal",
"7777":"WGS 84 / Andaman and Nicobar",
"7778":"WGS 84 / Chhattisgarh",
"7779":"WGS 84 / Goa",
"7780":"WGS 84 / Karnataka",
"7781":"WGS 84 / Kerala",
"7782":"WGS 84 / Lakshadweep",
"7783":"WGS 84 / Mizoram",
"7784":"WGS 84 / Sikkim",
"7785":"WGS 84 / Tamil Nadu",
"7786":"WGS 84 / Tripura",
"7787":"WGS 84 / West Bengal",
"7789":"ITRF2014",
"7791":"RDN2008 / UTM zone 32N",
"7792":"RDN2008 / UTM zone 33N",
"7793":"RDN2008 / UTM zone 34N",
"7794":"RDN2008 / Italy zone (E-N)",
"7795":"RDN2008 / Zone 12 (E-N)",
"7796":"BGS2005",
"7797":"BGS2005",
"7798":"BGS2005",
"7799":"BGS2005 / UTM zone 34N (N-E)",
"7800":"BGS2005 / UTM zone 35N (N-E)",
"7801":"BGS2005 / CCS2005",
"7803":"BGS2005 / UTM zone 34N",
"7804":"BGS2005 / UTM zone 35N",
"7805":"BGS2005 / UTM zone 36N",
"7815":"WGS 84 (Transit)",
"7816":"WGS 84 (Transit)",
"7825":"Pulkovo 1942 / CS63 zone X1",
"7826":"Pulkovo 1942 / CS63 zone X2",
"7827":"Pulkovo 1942 / CS63 zone X3",
"7828":"Pulkovo 1942 / CS63 zone X4",
"7829":"Pulkovo 1942 / CS63 zone X5",
"7830":"Pulkovo 1942 / CS63 zone X6",
"7831":"Pulkovo 1942 / CS63 zone X7",
"7832":"POM96 height",
"7837":"DHHN2016 height",
"7839":"NZVD2016 height",
"7841":"POM08 height",
"7842":"GDA2020",
"7843":"GDA2020",
"7844":"GDA2020",
"7845":"GDA2020 / GA LCC",
"7846":"GDA2020 / MGA zone 46",
"7847":"GDA2020 / MGA zone 47",
"7848":"GDA2020 / MGA zone 48",
"7849":"GDA2020 / MGA zone 49",
"7850":"GDA2020 / MGA zone 50",
"7851":"GDA2020 / MGA zone 51",
"7852":"GDA2020 / MGA zone 52",
"7853":"GDA2020 / MGA zone 53",
"7854":"GDA2020 / MGA zone 54",
"7855":"GDA2020 / MGA zone 55",
"7856":"GDA2020 / MGA zone 56",
"7857":"GDA2020 / MGA zone 57",
"7858":"GDA2020 / MGA zone 58",
"7859":"GDA2020 / MGA zone 59",
"7877":"Astro DOS 71 / SHLG71",
"7878":"Astro DOS 71 / UTM zone 30S",
"7879":"St. Helena Tritan",
"7880":"St. Helena Tritan",
"7881":"St. Helena Tritan",
"7882":"St. Helena Tritan / SHLG(Tritan)",
"7883":"St. Helena Tritan / UTM zone 30S",
"7884":"SHGD2015",
"7885":"SHGD2015",
"7886":"SHGD2015",
"7887":"SHMG2015",
"7888":"Jamestown 1971 height",
"7889":"St. Helena Tritan 2011 height",
"7890":"SHVD2015 height",
"7899":"GDA2020 / Vicgrid",
"7900":"ITRF88",
"7901":"ITRF89",
"7902":"ITRF90",
"7903":"ITRF91",
"7904":"ITRF92",
"7905":"ITRF93",
"7906":"ITRF94",
"7907":"ITRF96",
"7908":"ITRF97",
"7909":"ITRF2000",
"7910":"ITRF2005",
"7911":"ITRF2008",
"7912":"ITRF2014",
"7914":"ETRF89",
"7915":"ETRF89",
"7916":"ETRF90",
"7917":"ETRF90",
"7918":"ETRF91",
"7919":"ETRF91",
"7920":"ETRF92",
"7921":"ETRF92",
"7922":"ETRF93",
"7923":"ETRF93",
"7924":"ETRF94",
"7925":"ETRF94",
"7926":"ETRF96",
"7927":"ETRF96",
"7928":"ETRF97",
"7929":"ETRF97",
"7930":"ETRF2000",
"7931":"ETRF2000",
"7954":"Astro DOS 71 / UTM zone 30S + Jamestown 1971 height",
"7955":"St. Helena Tritan / UTM zone 30S +  Tritan 2011 height",
"7956":"SHMG2015 +  SHVD2015 height",
"7962":"Poolbeg height (m)",
"7968":"NGVD29 height (m)",
"7976":"HKPD depth",
"7979":"KOC WD height",
"7991":"NAD27 / MTM zone 10",
"7992":"Malongo 1987 / UTM zone 33S",
"8013":"GDA2020 / ALB2020",
"8014":"GDA2020 / BIO2020",
"8015":"GDA2020 / BRO2020",
"8016":"GDA2020 / BCG2020",
"8017":"GDA2020 / CARN2020",
"8018":"GDA2020 / CIG2020",
"8019":"GDA2020 / CKIG2020",
"8020":"GDA2020 / COL2020",
"8021":"GDA2020 / ESP2020",
"8022":"GDA2020 / EXM2020",
"8023":"GDA2020 / GCG2020",
"8024":"GDA2020 / GOLD2020",
"8025":"GDA2020 / JCG2020",
"8026":"GDA2020 / KALB2020",
"8027":"GDA2020 / KAR2020",
"8028":"GDA2020 / KUN2020",
"8029":"GDA2020 / LCG2020",
"8030":"GDA2020 / MRCG2020",
"8031":"GDA2020 / PCG2020",
"8032":"GDA2020 / PHG2020",
"8035":"WGS 84 / TM Zone 20N (ftUS)",
"8036":"WGS 84 / TM Zone 21N (ftUS)",
"8042":"Gusterberg (Ferro)",
"8043":"St. Stephen (Ferro)",
"8044":"Gusterberg Grid (Ferro)",
"8045":"St. Stephen Grid (Ferro)",
"8050":"MSL height (ft)",
"8051":"MSL depth (ft)",
"8052":"MSL height (ftUS)",
"8053":"MSL depth (ftUS)",
"8058":"GDA2020 / NSW Lambert",
"8059":"GDA2020 / SA Lambert",
"8065":"NAD83(2011) / PCCS zone 1 (ft)",
"8066":"NAD83(2011) / PCCS zone 2 (ft)",
"8067":"NAD83(2011) / PCCS zone 3 (ft)",
"8068":"NAD83(2011) / PCCS zone 4 (ft)",
"8082":"NAD83(CSRS)v6 / MTM Nova Scotia zone 4",
"8083":"NAD83(CSRS)v6 / MTM Nova Scotia zone 5",
"8084":"ISN2016",
"8085":"ISN2016",
"8086":"ISN2016",
"8088":"ISN2016 / Lambert 2016",
"8089":"ISH2004 height",
"8090":"NAD83(HARN) / WISCRS Florence (m)",
"8091":"NAD83(HARN) / WISCRS Florence (ftUS)",
"8092":"NAD83(HARN) / WISCRS Eau Claire (m)",
"8093":"NAD83(HARN) / WISCRS Eau Claire (ftUS)",
"8095":"NAD83(HARN) / WISCRS Wood (m)",
"8096":"NAD83(HARN) / WISCRS Wood (ftUS)",
"8097":"NAD83(HARN) / WISCRS Waushara (m)",
"8098":"NAD83(HARN) / WISCRS Waushara (ftUS)",
"8099":"NAD83(HARN) / WISCRS Waupaca (m)",
"8100":"NAD83(HARN) / WISCRS Waupaca (ftUS)",
"8101":"NAD83(HARN) / WISCRS Waukesha (m)",
"8102":"NAD83(HARN) / WISCRS Waukesha (ftUS)",
"8103":"NAD83(HARN) / WISCRS Washington (m)",
"8104":"NAD83(HARN) / WISCRS Washington (ftUS)",
"8105":"NAD83(HARN) / WISCRS Washburn (m)",
"8106":"NAD83(HARN) / WISCRS Washburn (ftUS)",
"8107":"NAD83(HARN) / WISCRS Walworth (m)",
"8108":"NAD83(HARN) / WISCRS Walworth (ftUS)",
"8109":"NAD83(HARN) / WISCRS Vilas (m)",
"8110":"NAD83(HARN) / WISCRS Vilas (ftUS)",
"8111":"NAD83(HARN) / WISCRS Vernon (m)",
"8112":"NAD83(HARN) / WISCRS Vernon (ftUS)",
"8113":"NAD83(HARN) / WISCRS Trempealeau (m)",
"8114":"NAD83(HARN) / WISCRS Trempealeau (ftUS)",
"8115":"NAD83(HARN) / WISCRS Taylor (m)",
"8116":"NAD83(HARN) / WISCRS Taylor (ftUS)",
"8117":"NAD83(HARN) / WISCRS St. Croix (m)",
"8118":"NAD83(HARN) / WISCRS St. Croix (ftUS)",
"8119":"NAD83(HARN) / WISCRS Shawano (m)",
"8120":"NAD83(HARN) / WISCRS Shawano (ftUS)",
"8121":"NAD83(HARN) / WISCRS Sawyer (m)",
"8122":"NAD83(HARN) / WISCRS Sawyer (ftUS)",
"8123":"NAD83(HARN) / WISCRS Sauk (m)",
"8124":"NAD83(HARN) / WISCRS Sauk (ftUS)",
"8125":"NAD83(HARN) / WISCRS Rusk (m)",
"8126":"NAD83(HARN) / WISCRS Rusk (ftUS)",
"8127":"NAD83(HARN) / WISCRS Rock (m)",
"8128":"NAD83(HARN) / WISCRS Rock (ftUS)",
"8129":"NAD83(HARN) / WISCRS Richland (m)",
"8130":"NAD83(HARN) / WISCRS Richland (ftUS)",
"8131":"NAD83(HARN) / WISCRS Price (m)",
"8132":"NAD83(HARN) / WISCRS Price (ftUS)",
"8133":"NAD83(HARN) / WISCRS Portage (m)",
"8134":"NAD83(HARN) / WISCRS Portage (ftUS)",
"8135":"NAD83(HARN) / WISCRS Polk (m)",
"8136":"NAD83(HARN) / WISCRS Polk (ftUS)",
"8137":"NAD83(HARN) / WISCRS Pepin and Pierce (m)",
"8138":"NAD83(HARN) / WISCRS Pepin and Pierce (ftUS)",
"8139":"NAD83(HARN) / WISCRS Oneida (m)",
"8140":"NAD83(HARN) / WISCRS Oneida (ftUS)",
"8141":"NAD83(HARN) / WISCRS Oconto (m)",
"8142":"NAD83(HARN) / WISCRS Oconto (ftUS)",
"8143":"NAD83(HARN) / WISCRS Monroe (m)",
"8144":"NAD83(HARN) / WISCRS Monroe (ftUS)",
"8145":"NAD83(HARN) / WISCRS Menominee (m)",
"8146":"NAD83(HARN) / WISCRS Menominee (ftUS)",
"8147":"NAD83(HARN) / WISCRS Marinette (m)",
"8148":"NAD83(HARN) / WISCRS Marinette (ftUS)",
"8149":"NAD83(HARN) / WISCRS Marathon (m)",
"8150":"NAD83(HARN) / WISCRS Marathon (ftUS)",
"8151":"NAD83(HARN) / WISCRS Lincoln (m)",
"8152":"NAD83(HARN) / WISCRS Lincoln (ftUS)",
"8153":"NAD83(HARN) / WISCRS Langlade (m)",
"8154":"NAD83(HARN) / WISCRS Langlade (ftUS)",
"8155":"NAD83(HARN) / WISCRS La Crosse (m)",
"8156":"NAD83(HARN) / WISCRS La Crosse (ftUS)",
"8157":"NAD83(HARN) / WISCRS Kewaunee, Manitowoc and Sheboygan (m)",
"8158":"NAD83(HARN) / WISCRS Kewaunee, Manitowoc and Sheboygan (ftUS)",
"8159":"NAD83(HARN) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (m)",
"8160":"NAD83(HARN) / WISCRS Kenosha, Milwaukee, Ozaukee and Racine (ftUS)",
"8161":"NAD83(HARN) / WISCRS Jackson (m)",
"8162":"NAD83(HARN) / WISCRS Jackson (ftUS)",
"8163":"NAD83(HARN) / WISCRS Iron (m)",
"8164":"NAD83(HARN) / WISCRS Iron (ftUS)",
"8165":"NAD83(HARN) / WISCRS Iowa (m)",
"8166":"NAD83(HARN) / WISCRS Iowa (ftUS)",
"8167":"NAD83(HARN) / WISCRS Green Lake and Marquette (m)",
"8168":"NAD83(HARN) / WISCRS Green Lake and Marquette (ftUS)",
"8169":"NAD83(HARN) / WISCRS Green and Lafayette (m)",
"8170":"NAD83(HARN) / WISCRS Green and Lafayette (ftUS)",
"8171":"NAD83(HARN) / WISCRS Grant (m)",
"8172":"NAD83(HARN) / WISCRS Grant (ftUS)",
"8173":"NAD83(HARN) / WISCRS Forest (m)",
"8177":"NAD83(HARN) / WISCRS Forest (ftUS)",
"8179":"NAD83(HARN) / WISCRS Dunn (m)",
"8180":"NAD83(HARN) / WISCRS Dunn (ftUS)",
"8181":"NAD83(HARN) / WISCRS Douglas (m)",
"8182":"NAD83(HARN) / WISCRS Douglas (ftUS)",
"8184":"NAD83(HARN) / WISCRS Door (m)",
"8185":"NAD83(HARN) / WISCRS Door (ftUS)",
"8187":"NAD83(HARN) / WISCRS Dodge and Jefferson (m)",
"8189":"NAD83(HARN) / WISCRS Dodge and Jefferson (ftUS)",
"8191":"NAD83(HARN) / WISCRS Dane (m)",
"8193":"NAD83(HARN) / WISCRS Dane (ftUS)",
"8196":"NAD83(HARN) / WISCRS Crawford (m)",
"8197":"NAD83(HARN) / WISCRS Crawford (ftUS)",
"8198":"NAD83(HARN) / WISCRS Columbia (m)",
"8200":"NAD83(HARN) / WISCRS Columbia (ftUS)",
"8201":"NAD83(HARN) / WISCRS Clark (m)",
"8202":"NAD83(HARN) / WISCRS Clark (ftUS)",
"8203":"NAD83(HARN) / WISCRS Chippewa (m)",
"8204":"NAD83(HARN) / WISCRS Chippewa (ftUS)",
"8205":"NAD83(HARN) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (m)",
"8206":"NAD83(HARN) / WISCRS Calumet, Fond du Lac, Outagamie and Winnebago (ftUS)",
"8207":"NAD83(HARN) / WISCRS Burnett (m)",
"8208":"NAD83(HARN) / WISCRS Burnett (ftUS)",
"8209":"NAD83(HARN) / WISCRS Buffalo (m)",
"8210":"NAD83(HARN) / WISCRS Buffalo (ftUS)",
"8212":"NAD83(HARN) / WISCRS Brown (m)",
"8213":"NAD83(HARN) / WISCRS Brown (ftUS)",
"8214":"NAD83(HARN) / WISCRS Bayfield (m)",
"8216":"NAD83(HARN) / WISCRS Bayfield (ftUS)",
"8218":"NAD83(HARN) / WISCRS Barron (m)",
"8220":"NAD83(HARN) / WISCRS Barron (ftUS)",
"8222":"NAD83(HARN) / WISCRS Ashland (m)",
"8224":"NAD83(HARN) / WISCRS Ashland (ftUS)",
"8225":"NAD83(HARN) / WISCRS Adams and Juneau (m)",
"8226":"NAD83(HARN) / WISCRS Adams and Juneau (ftUS)",
"8227":"IGS14",
"8228":"NAVD88 height (ft)",
"8230":"NAD83(CSRS96)",
"8231":"NAD83(CSRS96)",
"8232":"NAD83(CSRS96)",
"8233":"NAD83(CSRS)v2",
"8235":"NAD83(CSRS)v2",
"8237":"NAD83(CSRS)v2",
"8238":"NAD83(CSRS)v3",
"8239":"NAD83(CSRS)v3",
"8240":"NAD83(CSRS)v3",
"8242":"NAD83(CSRS)v4",
"8244":"NAD83(CSRS)v4",
"8246":"NAD83(CSRS)v4",
"8247":"NAD83(CSRS)v5",
"8248":"NAD83(CSRS)v5",
"8249":"NAD83(CSRS)v5",
"8250":"NAD83(CSRS)v6",
"8251":"NAD83(CSRS)v6",
"8252":"NAD83(CSRS)v6",
"8253":"NAD83(CSRS)v7",
"8254":"NAD83(CSRS)v7",
"8255":"NAD83(CSRS)v7",
"8266":"GVR2000 height",
"8267":"GVR2016 height",
"8311":"NAD83(2011) / Oregon Burns-Harper zone (m)",
"8312":"NAD83(2011) / Oregon Burns-Harper zone (ft)",
"8313":"NAD83(2011) / Oregon Canyon City-Burns zone (m)",
"8314":"NAD83(2011) / Oregon Canyon City-Burns zone (ft)",
"8315":"NAD83(2011) / Oregon Coast Range North zone (m)",
"8316":"NAD83(2011) / Oregon Coast Range North zone (ft)",
"8317":"NAD83(2011) / Oregon Dayville-Prairie City zone (m)",
"8318":"NAD83(2011) / Oregon Dayville-Prairie City zone (ft)",
"8319":"NAD83(2011) / Oregon Denio-Burns zone (m)",
"8320":"NAD83(2011) / Oregon Denio-Burns zone (ft)",
"8321":"NAD83(2011) / Oregon Halfway zone (m)",
"8322":"NAD83(2011) / Oregon Halfway zone (ft)",
"8323":"NAD83(2011) / Oregon Medford-Diamond Lake zone (m)",
"8324":"NAD83(2011) / Oregon Medford-Diamond Lake zone (ft)",
"8325":"NAD83(2011) / Oregon Mitchell zone (m)",
"8326":"NAD83(2011) / Oregon Mitchell zone (ft)",
"8327":"NAD83(2011) / Oregon North Central zone (m)",
"8328":"NAD83(2011) / Oregon North Central zone (ft)",
"8329":"NAD83(2011) / Oregon Ochoco Summit zone (m)",
"8330":"NAD83(2011) / Oregon Ochoco Summit zone (ft)",
"8331":"NAD83(2011) / Oregon Owyhee zone (m)",
"8332":"NAD83(2011) / Oregon Owyhee zone (ft)",
"8333":"NAD83(2011) / Oregon Pilot Rock-Ukiah zone (m)",
"8334":"NAD83(2011) / Oregon Pilot Rock-Ukiah zone (ft)",
"8335":"NAD83(2011) / Oregon Prairie City-Brogan zone (m)",
"8336":"NAD83(2011) / Oregon Prairie City-Brogan zone (ft)",
"8337":"NAD83(2011) / Oregon Riley-Lakeview zone (m)",
"8338":"NAD83(2011) / Oregon Riley-Lakeview zone (ft)",
"8339":"NAD83(2011) / Oregon Siskiyou Pass zone (m)",
"8340":"NAD83(2011) / Oregon Siskiyou Pass zone (ft)",
"8341":"NAD83(2011) / Oregon Ukiah-Fox zone (m)",
"8342":"NAD83(2011) / Oregon Ukiah-Fox zone (ft)",
"8343":"NAD83(2011) / Oregon Wallowa zone (m)",
"8344":"NAD83(2011) / Oregon Wallowa zone (ft)",
"8345":"NAD83(2011) / Oregon Warner Highway zone (m)",
"8346":"NAD83(2011) / Oregon Warner Highway zone (ft)",
"8347":"NAD83(2011) / Oregon Willamette Pass zone (m)",
"8348":"NAD83(2011) / Oregon Willamette Pass zone (ft)",
"8349":"GR96 + GVR2000 height",
"8350":"GR96 + GVR2016 height",
"8351":"S-JTSK [JTSK03]",
"8352":"S-JTSK [JTSK03] / Krovak",
"8353":"S-JTSK [JTSK03] / Krovak East North",
"8357":"Baltic 1957 height",
"8358":"Baltic 1957 depth",
"8360":"ETRS89 + Baltic 1957 height",
"8370":"ETRS89 / Belgian Lambert 2008 + Ostend height",
"8377":"EPSG example wellbore local horizontal CRS - true north",
"8378":"EPSG example wellbore local vertical CRS",
"8379":"NAD83 / NCRS Las Vegas (m)",
"8380":"NAD83 / NCRS Las Vegas (ftUS)",
"8381":"NAD83 / NCRS Las Vegas high (m)",
"8382":"NAD83 / NCRS Las Vegas high (ftUS)",
"8383":"NAD83(2011) / NCRS Las Vegas (m)",
"8384":"NAD83(2011) / NCRS Las Vegas (ftUS)",
"8385":"NAD83(2011) / NCRS Las Vegas high (m)",
"8387":"NAD83(2011) / NCRS Las Vegas high (ftUS)",
"8391":"GDA94 / WEIPA94",
"8395":"ETRS89 / Gauss-Kruger CM 9E",
"8397":"ETRF2005",
"8399":"ETRF2005",
"8401":"ETRF2014",
"8403":"ETRF2014",
"8425":"Hong Kong Geodetic CS",
"8426":"Hong Kong Geodetic CS",
"8427":"Hong Kong Geodetic CS",
"8428":"Macao 1920",
"8429":"Macao 2008",
"8430":"Macao 2008",
"8431":"Macao 2008",
"8433":"Macao 1920 / Macao Grid",
"8434":"Macao height",
"8441":"Tananarive / Laborde Grid",
"8449":"NAD83(FBN)",
"8455":"RGTAAF07 / UTM zone 53S",
"8456":"RGTAAF07 / UTM zone 54S",
"8518":"NAD83(2011) / KS RCS zone 1",
"8519":"NAD83(2011) / KS RCS zone 2",
"8520":"NAD83(2011) / KS RCS zone 3",
"8521":"NAD83(2011) / KS RCS zone 4",
"8522":"NAD83(2011) / KS RCS zone 5",
"8523":"NAD83(2011) / KS RCS zone 6",
"8524":"NAD83(2011) / KS RCS zone 7",
"8525":"NAD83(2011) / KS RCS zone 8",
"8526":"NAD83(2011) / KS RCS zone 9",
"8527":"NAD83(2011) / KS RCS zone 10",
"8528":"NAD83(2011) / KS RCS zone 11",
"8529":"NAD83(2011) / KS RCS zone 12",
"8531":"NAD83(2011) / KS RCS zone 13",
"8533":"NAD83(2011) / KS RCS zone 14",
"8534":"NAD83(2011) / KS RCS zone 15",
"8535":"NAD83(2011) / KS RCS zone 16",
"8536":"NAD83(2011) / KS RCS zone 17",
"8538":"NAD83(2011) / KS RCS zone 18",
"8539":"NAD83(2011) / KS RCS zone 19",
"8540":"NAD83(2011) / KS RCS zone 20",
"8541":"NAD83(FBN)",
"8542":"NAD83(FBN)",
"8543":"NAD83(HARN Corrected)",
"8544":"NAD83(HARN Corrected)",
"8545":"NAD83(HARN Corrected)",
"8675":"N43 height",
"8677":"MGI 1901 / Balkans zone 5",
"8678":"MGI 1901 / Balkans zone 6",
"8679":"MGI 1901 / Balkans zone 8",
"8682":"SRB_ETRS89 / UTM zone 34N",
"8683":"SRB_ETRS89",
"8684":"SRB_ETRS89",
"8685":"SRB_ETRS89",
"8686":"MGI 1901 / Slovenia Grid",
"8687":"Slovenia 1996 / UTM zone 33N",
"8690":"SVS2010 height",
"8691":"SRB_VRS12 height",
"8692":"NAD83(MA11) / UTM zone 54N",
"8693":"NAD83(MA11) / UTM zone 55N",
"8700":"NAD83 / Arizona East (ft) + NAVD88 height (ft)",
"8701":"NAD83 / Arizona Central (ft) + NAVD88 height (ft)",
"8702":"NAD83 / Arizona West (ft) + NAVD88 height (ft)",
"8703":"NAD83 / Michigan North (ft) + NAVD88 height (ft)",
"8704":"NAD83 / Michigan Central (ft) + NAVD88 height (ft)",
"8705":"NAD83 / Michigan South (ft) + NAVD88 height (ft)",
"8706":"NAD83 / Montana (ft) + NAVD88 height (ft)",
"8707":"NAD83 / North Dakota North (ft) + NAVD88 height (ft)",
"8708":"NAD83 / North Dakota South (ft) + NAVD88 height (ft)",
"8709":"NAD83 / Oregon North (ft) + NAVD88 height (ft)",
"8710":"NAD83 / Oregon South (ft) + NAVD88 height (ft)",
"8711":"NAD83 / South Carolina (ft) + NAVD88 height (ft)",
"8712":"NAD83 / Arkansas North (ftUS) + NAVD88 height (ftUS)",
"8713":"NAD83 / Arkansas South (ftUS) + NAVD88 height (ftUS)",
"8714":"NAD83 / California zone 1 (ftUS) + NAVD88 height (ftUS)",
"8715":"NAD83 / California zone 2 (ftUS) + NAVD88 height (ftUS)",
"8716":"NAD83 / California zone 3 (ftUS) + NAVD88 height (ftUS)",
"8717":"NAD83 / California zone 4 (ftUS) + NAVD88 height (ftUS)",
"8718":"NAD83 / California zone 5 (ftUS) + NAVD88 height (ftUS)",
"8719":"NAD83 / California zone 6 (ftUS) + NAVD88 height (ftUS)",
"8720":"NAD83 / Colorado North (ftUS) + NAVD88 height (ftUS)",
"8721":"NAD83 / Colorado Central (ftUS) + NAVD88 height (ftUS)",
"8722":"NAD83 / Colorado South (ftUS) + NAVD88 height (ftUS)",
"8723":"NAD83 / Connecticut (ftUS) + NAVD88 height (ftUS)",
"8724":"NAD83 / Delaware (ftUS) + NAVD88 height (ftUS)",
"8725":"NAD83 / Florida North (ftUS) + NAVD88 height (ftUS)",
"8726":"NAD83 / Florida East (ftUS) + NAVD88 height (ftUS)",
"8727":"NAD83 / Florida West (ftUS) + NAVD88 height (ftUS)",
"8728":"NAD83 / Georgia East (ftUS) + NAVD88 height (ftUS)",
"8729":"NAD83 / Georgia West (ftUS) + NAVD88 height (ftUS)",
"8730":"NAD83 / Idaho East (ftUS) + NAVD88 height (ftUS)",
"8731":"NAD83 / Idaho Central (ftUS) + NAVD88 height (ftUS)",
"8732":"NAD83 / Idaho West (ftUS) + NAVD88 height (ftUS)",
"8733":"NAD83 / Illinois East (ftUS) + NAVD88 height (ftUS)",
"8734":"NAD83 / Illinois West (ftUS) + NAVD88 height (ftUS)",
"8735":"NAD83 / Indiana East (ftUS) + NAVD88 height (ftUS)",
"8736":"NAD83 / Indiana West (ftUS) + NAVD88 height (ftUS)",
"8737":"NAD83 / Iowa North (ftUS) + NAVD88 height (ftUS)",
"8738":"NAD83 / Iowa South (ftUS) + NAVD88 height (ftUS)",
"8739":"NAD83 / Kansas North (ftUS) + NAVD88 height (ftUS)",
"8740":"NAD83 / Kansas South (ftUS) + NAVD88 height (ftUS)",
"8741":"NAD83 / Kentucky North (ftUS) + NAVD88 height (ftUS)",
"8742":"NAD83 / Kentucky South (ftUS) + NAVD88 height (ftUS)",
"8743":"NAD83 / Louisiana North (ftUS) + NAVD88 height (ftUS)",
"8744":"NAD83 / Louisiana South (ftUS) + NAVD88 height (ftUS)",
"8745":"NAD83 / Maine East (ftUS) + NAVD88 height (ftUS)",
"8746":"NAD83 / Maine West (ftUS) + NAVD88 height (ftUS)",
"8747":"NAD83 / Maryland (ftUS) + NAVD88 height (ftUS)",
"8748":"NAD83 / Massachusetts Mainland (ftUS) + NAVD88 height (ftUS)",
"8749":"NAD83 / Massachusetts Island (ftUS) + NAVD88 height (ftUS)",
"8750":"NAD83 / Minnesota North (ftUS) + NAVD88 height (ftUS)",
"8751":"NAD83 / Minnesota Central (ftUS) + NAVD88 height (ftUS)",
"8752":"NAD83 / Minnesota South (ftUS) + NAVD88 height (ftUS)",
"8753":"NAD83 / Mississippi East (ftUS) + NAVD88 height (ftUS)",
"8754":"NAD83 / Mississippi West (ftUS) + NAVD88 height (ftUS)",
"8755":"NAD83 / Nebraska (ftUS) + NAVD88 height (ftUS)",
"8756":"NAD83 / Nevada East (ftUS) + NAVD88 height (ftUS)",
"8757":"NAD83 / Nevada Central (ftUS) + NAVD88 height (ftUS)",
"8758":"NAD83 / Nevada West (ftUS) + NAVD88 height (ftUS)",
"8759":"NAD83 / New Hampshire (ftUS) + NAVD88 height (ftUS)",
"8760":"NAD83 / New Jersey (ftUS) + NAVD88 height (ftUS)",
"8761":"NAD83 / New Mexico East (ftUS) + NAVD88 height (ftUS)",
"8762":"NAD83 / New Mexico Central (ftUS) + NAVD88 height (ftUS)",
"8763":"NAD83 / New Mexico West (ftUS) + NAVD88 height (ftUS)",
"8764":"NAD83 / New York East (ftUS) + NAVD88 height (ftUS)",
"8765":"NAD83 / New York Central (ftUS) + NAVD88 height (ftUS)",
"8766":"NAD83 / New York West (ftUS) + NAVD88 height (ftUS)",
"8767":"NAD83 / New York Long Island (ftUS) + NAVD88 height (ftUS)",
"8768":"NAD83 / North Carolina (ftUS) + NAVD88 height (ftUS)",
"8769":"NAD83 / Ohio North (ftUS) + NAVD88 height (ftUS)",
"8770":"NAD83 / Ohio South (ftUS) + NAVD88 height (ftUS)",
"8771":"NAD83 / Oklahoma North (ftUS) + NAVD88 height (ftUS)",
"8772":"NAD83 / Oklahoma South (ftUS) + NAVD88 height (ftUS)",
"8773":"NAD83 / Pennsylvania North (ftUS) + NAVD88 height (ftUS)",
"8774":"NAD83 / Pennsylvania South (ftUS) + NAVD88 height (ftUS)",
"8775":"NAD83 / Rhode Island (ftUS) + NAVD88 height (ftUS)",
"8776":"NAD83 / South Dakota North (ftUS) + NAVD88 height (ftUS)",
"8777":"NAD83 / South Dakota South (ftUS) + NAVD88 height (ftUS)",
"8778":"NAD83 / Tennessee (ftUS) + NAVD88 height (ftUS)",
"8779":"NAD83 / Texas North (ftUS) + NAVD88 height (ftUS)",
"8780":"NAD83 / Texas North Central (ftUS) + NAVD88 height (ftUS)",
"8781":"NAD83 / Texas Central (ftUS) + NAVD88 height (ftUS)",
"8782":"NAD83 / Texas South Central (ftUS) + NAVD88 height (ftUS)",
"8783":"NAD83 / Texas South (ftUS) + NAVD88 height (ftUS)",
"8784":"NAD83 / Utah North (ftUS) + NAVD88 height (ftUS)",
"8785":"NAD83 / Utah Central (ftUS) + NAVD88 height (ftUS)",
"8786":"NAD83 / Utah South (ftUS) + NAVD88 height (ftUS)",
"8787":"NAD83 / Vermont (ftUS) + NAVD88 height (ftUS)",
"8788":"NAD83 / Virginia North (ftUS) + NAVD88 height (ftUS)",
"8789":"NAD83 / Virginia South (ftUS) + NAVD88 height (ftUS)",
"8790":"NAD83 / Washington North (ftUS) + NAVD88 height (ftUS)",
"8791":"NAD83 / Washington South (ftUS) + NAVD88 height (ftUS)",
"8792":"NAD83 / West Virginia North (ftUS) + NAVD88 height (ftUS)",
"8793":"NAD83 / West Virginia South (ftUS) + NAVD88 height (ftUS)",
"8794":"NAD83 / Wisconsin North (ftUS) + NAVD88 height (ftUS)",
"8795":"NAD83 / Wisconsin Central (ftUS) + NAVD88 height (ftUS)",
"8796":"NAD83 / Wisconsin South (ftUS) + NAVD88 height (ftUS)",
"8797":"NAD83 / Wyoming East (ftUS) + NAVD88 height (ftUS)",
"8798":"NAD83 / Wyoming East Central (ftUS) + NAVD88 height (ftUS)",
"8799":"NAD83 / Wyoming West Central (ftUS) + NAVD88 height (ftUS)",
"8800":"NAD83 / Wyoming West (ftUS) + NAVD88 height (ftUS)",
"8801":"NAD83 / Alabama East + NAVD88 height",
"8802":"NAD83 / Alabama West + NAVD88 height",
"8803":"NAD83 / Alaska zone 1 + NAVD88 height",
"8804":"NAD83 / Alaska zone 2 + NAVD88 height",
"8805":"NAD83 / Alaska zone 3 + NAVD88 height",
"8806":"NAD83 / Alaska zone 4 + NAVD88 height",
"8807":"NAD83 / Alaska zone 5 + NAVD88 height",
"8808":"NAD83 / Alaska zone 6 + NAVD88 height",
"8809":"NAD83 / Alaska zone 7 + NAVD88 height",
"8810":"NAD83 / Alaska zone 8 + NAVD88 height",
"8811":"NAD83 / Alaska zone 9 + NAVD88 height",
"8812":"NAD83 / Alaska zone 10 + NAVD88 height",
"8813":"NAD83 / Missouri East + NAVD88 height",
"8814":"NAD83 / Missouri Central + NAVD88 height",
"8815":"NAD83 / Missouri West + NAVD88 height",
"8816":"MTRF-2000",
"8817":"MTRF-2000",
"8818":"MTRF-2000",
"8820":"EPSG example wellbore local cubic CRS - true north",
"8821":"EPSG example wellbore local cubic CRS - grid north (ft)",
"8826":"NAD83 / Idaho Transverse Mercator",
"8836":"MTRF-2000 / UTM zone 36N",
"8837":"MTRF-2000 / UTM zone 37N",
"8838":"MTRF-2000 / UTM zone 38N",
"8839":"MTRF-2000 / UTM zone 39N",
"8840":"MTRF-2000 / UTM zone 40N",
"8841":"MVGC height",
"8857":"WGS 84 / Equal Earth Greenwich",
"8858":"WGS 84 / Equal Earth Americas",
"8859":"WGS 84 / Equal Earth Asia-Pacific",
"8860":"NAD83(FBN)",
"8888":"WGS 84 (Transit)",
"8896":"EPSG example wellbore local horizontal CRS - grid north (ft)",
"8897":"EPSG example wellbore local vertical CRS (ft)",
"8898":"RGWF96",
"8899":"RGWF96",
"8900":"RGWF96",
"8901":"RGWF96 (lon-lat)",
"8902":"RGWF96 (lon-lat)",
"8903":"RGWF96 / UTM zone 1S",
"8904":"TWVD 2001 height",
"8905":"CR-SIRGAS",
"8906":"CR-SIRGAS",
"8907":"CR-SIRGAS",
"8908":"CR-SIRGAS / CRTM05",
"8909":"CR-SIRGAS / UTM zone 16N",
"8910":"CR-SIRGAS / UTM zone 17N",
"8911":"DACR52 height",
"8912":"CR-SIRGAS / CRTM05 + DACR52 height",
"8915":"SIRGAS-CON DGF00P01",
"8916":"SIRGAS-CON DGF00P01",
"8917":"SIRGAS-CON DGF01P01",
"8918":"SIRGAS-CON DGF01P01",
"8919":"SIRGAS-CON DGF01P02",
"8920":"SIRGAS-CON DGF01P02",
"8921":"SIRGAS-CON DGF02P01",
"8922":"SIRGAS-CON DGF02P01",
"8923":"SIRGAS-CON DGF04P01",
"8924":"SIRGAS-CON DGF04P01",
"8925":"SIRGAS-CON DGF05P01",
"8926":"SIRGAS-CON DGF05P01",
"8927":"SIRGAS-CON DGF06P01",
"8928":"SIRGAS-CON DGF06P01",
"8929":"SIRGAS-CON DGF07P01",
"8930":"SIRGAS-CON DGF07P01",
"8931":"SIRGAS-CON DGF08P01",
"8932":"SIRGAS-CON DGF08P01",
"8933":"SIRGAS-CON SIR09P01",
"8934":"SIRGAS-CON SIR09P01",
"8935":"SIRGAS-CON SIR10P01",
"8936":"SIRGAS-CON SIR10P01",
"8937":"SIRGAS-CON SIR11P01",
"8938":"SIRGAS-CON SIR11P01",
"8939":"SIRGAS-CON SIR13P01",
"8940":"SIRGAS-CON SIR13P01",
"8941":"SIRGAS-CON SIR14P01",
"8942":"SIRGAS-CON SIR14P01",
"8943":"SIRGAS-CON SIR15P01",
"8944":"SIRGAS-CON SIR15P01",
"8945":"SIRGAS-CON SIR17P01",
"8946":"SIRGAS-CON SIR17P01",
"8972":"SIRGAS-CON DGF00P01",
"8973":"SIRGAS-CON DGF01P01",
"8974":"SIRGAS-CON DGF01P02",
"8975":"SIRGAS-CON DGF02P01",
"8976":"SIRGAS-CON DGF04P01",
"8977":"SIRGAS-CON DGF05P01",
"8978":"SIRGAS-CON DGF06P01",
"8979":"SIRGAS-CON DGF07P01",
"8980":"SIRGAS-CON DGF08P01",
"8981":"SIRGAS-CON SIR09P01",
"8982":"SIRGAS-CON SIR10P01",
"8983":"SIRGAS-CON SIR11P01",
"8984":"SIRGAS-CON SIR13P01",
"8985":"SIRGAS-CON SIR14P01",
"8986":"SIRGAS-CON SIR15P01",
"8987":"SIRGAS-CON SIR17P01",
"8988":"ITRF88",
"8989":"ITRF89",
"8990":"ITRF90",
"8991":"ITRF91",
"8992":"ITRF92",
"8993":"ITRF93",
"8994":"ITRF94",
"8995":"ITRF96",
"8996":"ITRF97",
"8997":"ITRF2000",
"8998":"ITRF2005",
"8999":"ITRF2008",
"9000":"ITRF2014",
"9001":"IGS97",
"9002":"IGS97",
"9003":"IGS97",
"9004":"IGS00",
"9005":"IGS00",
"9006":"IGS00",
"9007":"IGb00",
"9008":"IGb00",
"9009":"IGb00",
"9010":"IGS05",
"9011":"IGS05",
"9012":"IGS05",
"9013":"IGS08",
"9014":"IGS08",
"9015":"IGb08",
"9016":"IGb08",
"9017":"IGb08",
"9018":"IGS14",
"9019":"IGS14",
"9039":"ISN2016 / LAEA Europe",
"9040":"ISN2016 / LCC Europe",
"9053":"WGS 84 (G730)",
"9054":"WGS 84 (G873)",
"9055":"WGS 84 (G1150)",
"9056":"WGS 84 (G1674)",
"9057":"WGS 84 (G1762)",
"9059":"ETRF89",
"9060":"ETRF90",
"9061":"ETRF91",
"9062":"ETRF92",
"9063":"ETRF93",
"9064":"ETRF94",
"9065":"ETRF96",
"9066":"ETRF97",
"9067":"ETRF2000",
"9068":"ETRF2005",
"9069":"ETRF2014",
"9130":"IGN 2008 LD height",
"9138":"KOSOVAREF01",
"9139":"KOSOVAREF01",
"9140":"KOSOVAREF01",
"9141":"KOSOVAREF01 / Balkans zone 7",
"20004":"Pulkovo 1995 / Gauss-Kruger zone 4",
"20005":"Pulkovo 1995 / Gauss-Kruger zone 5",
"20006":"Pulkovo 1995 / Gauss-Kruger zone 6",
"20007":"Pulkovo 1995 / Gauss-Kruger zone 7",
"20008":"Pulkovo 1995 / Gauss-Kruger zone 8",
"20009":"Pulkovo 1995 / Gauss-Kruger zone 9",
"20010":"Pulkovo 1995 / Gauss-Kruger zone 10",
"20011":"Pulkovo 1995 / Gauss-Kruger zone 11",
"20012":"Pulkovo 1995 / Gauss-Kruger zone 12",
"20013":"Pulkovo 1995 / Gauss-Kruger zone 13",
"20014":"Pulkovo 1995 / Gauss-Kruger zone 14",
"20015":"Pulkovo 1995 / Gauss-Kruger zone 15",
"20016":"Pulkovo 1995 / Gauss-Kruger zone 16",
"20017":"Pulkovo 1995 / Gauss-Kruger zone 17",
"20018":"Pulkovo 1995 / Gauss-Kruger zone 18",
"20019":"Pulkovo 1995 / Gauss-Kruger zone 19",
"20020":"Pulkovo 1995 / Gauss-Kruger zone 20",
"20021":"Pulkovo 1995 / Gauss-Kruger zone 21",
"20022":"Pulkovo 1995 / Gauss-Kruger zone 22",
"20023":"Pulkovo 1995 / Gauss-Kruger zone 23",
"20024":"Pulkovo 1995 / Gauss-Kruger zone 24",
"20025":"Pulkovo 1995 / Gauss-Kruger zone 25",
"20026":"Pulkovo 1995 / Gauss-Kruger zone 26",
"20027":"Pulkovo 1995 / Gauss-Kruger zone 27",
"20028":"Pulkovo 1995 / Gauss-Kruger zone 28",
"20029":"Pulkovo 1995 / Gauss-Kruger zone 29",
"20030":"Pulkovo 1995 / Gauss-Kruger zone 30",
"20031":"Pulkovo 1995 / Gauss-Kruger zone 31",
"20032":"Pulkovo 1995 / Gauss-Kruger zone 32",
"20064":"Pulkovo 1995 / Gauss-Kruger 4N",
"20065":"Pulkovo 1995 / Gauss-Kruger 5N",
"20066":"Pulkovo 1995 / Gauss-Kruger 6N",
"20067":"Pulkovo 1995 / Gauss-Kruger 7N",
"20068":"Pulkovo 1995 / Gauss-Kruger 8N",
"20069":"Pulkovo 1995 / Gauss-Kruger 9N",
"20070":"Pulkovo 1995 / Gauss-Kruger 10N",
"20071":"Pulkovo 1995 / Gauss-Kruger 11N",
"20072":"Pulkovo 1995 / Gauss-Kruger 12N",
"20073":"Pulkovo 1995 / Gauss-Kruger 13N",
"20074":"Pulkovo 1995 / Gauss-Kruger 14N",
"20075":"Pulkovo 1995 / Gauss-Kruger 15N",
"20076":"Pulkovo 1995 / Gauss-Kruger 16N",
"20077":"Pulkovo 1995 / Gauss-Kruger 17N",
"20078":"Pulkovo 1995 / Gauss-Kruger 18N",
"20079":"Pulkovo 1995 / Gauss-Kruger 19N",
"20080":"Pulkovo 1995 / Gauss-Kruger 20N",
"20081":"Pulkovo 1995 / Gauss-Kruger 21N",
"20082":"Pulkovo 1995 / Gauss-Kruger 22N",
"20083":"Pulkovo 1995 / Gauss-Kruger 23N",
"20084":"Pulkovo 1995 / Gauss-Kruger 24N",
"20085":"Pulkovo 1995 / Gauss-Kruger 25N",
"20086":"Pulkovo 1995 / Gauss-Kruger 26N",
"20087":"Pulkovo 1995 / Gauss-Kruger 27N",
"20088":"Pulkovo 1995 / Gauss-Kruger 28N",
"20089":"Pulkovo 1995 / Gauss-Kruger 29N",
"20090":"Pulkovo 1995 / Gauss-Kruger 30N",
"20091":"Pulkovo 1995 / Gauss-Kruger 31N",
"20092":"Pulkovo 1995 / Gauss-Kruger 32N",
"20135":"Adindan / UTM zone 35N",
"20136":"Adindan / UTM zone 36N",
"20137":"Adindan / UTM zone 37N",
"20138":"Adindan / UTM zone 38N",
"20248":"AGD66 / AMG zone 48",
"20249":"AGD66 / AMG zone 49",
"20250":"AGD66 / AMG zone 50",
"20251":"AGD66 / AMG zone 51",
"20252":"AGD66 / AMG zone 52",
"20253":"AGD66 / AMG zone 53",
"20254":"AGD66 / AMG zone 54",
"20255":"AGD66 / AMG zone 55",
"20256":"AGD66 / AMG zone 56",
"20257":"AGD66 / AMG zone 57",
"20258":"AGD66 / AMG zone 58",
"20348":"AGD84 / AMG zone 48",
"20349":"AGD84 / AMG zone 49",
"20350":"AGD84 / AMG zone 50",
"20351":"AGD84 / AMG zone 51",
"20352":"AGD84 / AMG zone 52",
"20353":"AGD84 / AMG zone 53",
"20354":"AGD84 / AMG zone 54",
"20355":"AGD84 / AMG zone 55",
"20356":"AGD84 / AMG zone 56",
"20357":"AGD84 / AMG zone 57",
"20358":"AGD84 / AMG zone 58",
"20436":"Ain el Abd / UTM zone 36N",
"20437":"Ain el Abd / UTM zone 37N",
"20438":"Ain el Abd / UTM zone 38N",
"20439":"Ain el Abd / UTM zone 39N",
"20440":"Ain el Abd / UTM zone 40N",
"20499":"Ain el Abd / Bahrain Grid",
"20538":"Afgooye / UTM zone 38N",
"20539":"Afgooye / UTM zone 39N",
"20790":"Lisbon (Lisbon) / Portuguese National Grid",
"20791":"Lisbon (Lisbon) / Portuguese Grid",
"20822":"Aratu / UTM zone 22S",
"20823":"Aratu / UTM zone 23S",
"20824":"Aratu / UTM zone 24S",
"20934":"Arc 1950 / UTM zone 34S",
"20935":"Arc 1950 / UTM zone 35S",
"20936":"Arc 1950 / UTM zone 36S",
"21035":"Arc 1960 / UTM zone 35S",
"21036":"Arc 1960 / UTM zone 36S",
"21037":"Arc 1960 / UTM zone 37S",
"21095":"Arc 1960 / UTM zone 35N",
"21096":"Arc 1960 / UTM zone 36N",
"21097":"Arc 1960 / UTM zone 37N",
"21100":"Batavia (Jakarta) / NEIEZ",
"21148":"Batavia / UTM zone 48S",
"21149":"Batavia / UTM zone 49S",
"21150":"Batavia / UTM zone 50S",
"21291":"Barbados 1938 / British West Indies Grid",
"21292":"Barbados 1938 / Barbados National Grid",
"21413":"Beijing 1954 / Gauss-Kruger zone 13",
"21414":"Beijing 1954 / Gauss-Kruger zone 14",
"21415":"Beijing 1954 / Gauss-Kruger zone 15",
"21416":"Beijing 1954 / Gauss-Kruger zone 16",
"21417":"Beijing 1954 / Gauss-Kruger zone 17",
"21418":"Beijing 1954 / Gauss-Kruger zone 18",
"21419":"Beijing 1954 / Gauss-Kruger zone 19",
"21420":"Beijing 1954 / Gauss-Kruger zone 20",
"21421":"Beijing 1954 / Gauss-Kruger zone 21",
"21422":"Beijing 1954 / Gauss-Kruger zone 22",
"21423":"Beijing 1954 / Gauss-Kruger zone 23",
"21453":"Beijing 1954 / Gauss-Kruger CM 75E",
"21454":"Beijing 1954 / Gauss-Kruger CM 81E",
"21455":"Beijing 1954 / Gauss-Kruger CM 87E",
"21456":"Beijing 1954 / Gauss-Kruger CM 93E",
"21457":"Beijing 1954 / Gauss-Kruger CM 99E",
"21458":"Beijing 1954 / Gauss-Kruger CM 105E",
"21459":"Beijing 1954 / Gauss-Kruger CM 111E",
"21460":"Beijing 1954 / Gauss-Kruger CM 117E",
"21461":"Beijing 1954 / Gauss-Kruger CM 123E",
"21462":"Beijing 1954 / Gauss-Kruger CM 129E",
"21463":"Beijing 1954 / Gauss-Kruger CM 135E",
"21473":"Beijing 1954 / Gauss-Kruger 13N",
"21474":"Beijing 1954 / Gauss-Kruger 14N",
"21475":"Beijing 1954 / Gauss-Kruger 15N",
"21476":"Beijing 1954 / Gauss-Kruger 16N",
"21477":"Beijing 1954 / Gauss-Kruger 17N",
"21478":"Beijing 1954 / Gauss-Kruger 18N",
"21479":"Beijing 1954 / Gauss-Kruger 19N",
"21480":"Beijing 1954 / Gauss-Kruger 20N",
"21481":"Beijing 1954 / Gauss-Kruger 21N",
"21482":"Beijing 1954 / Gauss-Kruger 22N",
"21483":"Beijing 1954 / Gauss-Kruger 23N",
"21500":"Belge 1950 (Brussels) / Belge Lambert 50",
"21780":"Bern 1898 (Bern) / LV03C",
"21781":"CH1903 / LV03",
"21782":"CH1903 / LV03C-G",
"21817":"Bogota 1975 / UTM zone 17N",
"21818":"Bogota 1975 / UTM zone 18N",
"21891":"Bogota 1975 / Colombia West zone",
"21892":"Bogota 1975 / Colombia Bogota zone",
"21893":"Bogota 1975 / Colombia East Central zone",
"21894":"Bogota 1975 / Colombia East",
"21896":"Bogota 1975 / Colombia West zone",
"21897":"Bogota 1975 / Colombia Bogota zone",
"21898":"Bogota 1975 / Colombia East Central zone",
"21899":"Bogota 1975 / Colombia East zone",
"22032":"Camacupa / UTM zone 32S",
"22033":"Camacupa / UTM zone 33S",
"22091":"Camacupa / TM 11.30 SE",
"22092":"Camacupa / TM 12 SE",
"22171":"POSGAR 98 / Argentina 1",
"22172":"POSGAR 98 / Argentina 2",
"22173":"POSGAR 98 / Argentina 3",
"22174":"POSGAR 98 / Argentina 4",
"22175":"POSGAR 98 / Argentina 5",
"22176":"POSGAR 98 / Argentina 6",
"22177":"POSGAR 98 / Argentina 7",
"22181":"POSGAR 94 / Argentina 1",
"22182":"POSGAR 94 / Argentina 2",
"22183":"POSGAR 94 / Argentina 3",
"22184":"POSGAR 94 / Argentina 4",
"22185":"POSGAR 94 / Argentina 5",
"22186":"POSGAR 94 / Argentina 6",
"22187":"POSGAR 94 / Argentina 7",
"22191":"Campo Inchauspe / Argentina 1",
"22192":"Campo Inchauspe / Argentina 2",
"22193":"Campo Inchauspe / Argentina 3",
"22194":"Campo Inchauspe / Argentina 4",
"22195":"Campo Inchauspe / Argentina 5",
"22196":"Campo Inchauspe / Argentina 6",
"22197":"Campo Inchauspe / Argentina 7",
"22234":"Cape / UTM zone 34S",
"22235":"Cape / UTM zone 35S",
"22236":"Cape / UTM zone 36S",
"22275":"Cape / Lo15",
"22277":"Cape / Lo17",
"22279":"Cape / Lo19",
"22281":"Cape / Lo21",
"22283":"Cape / Lo23",
"22285":"Cape / Lo25",
"22287":"Cape / Lo27",
"22289":"Cape / Lo29",
"22291":"Cape / Lo31",
"22293":"Cape / Lo33",
"22300":"Carthage (Paris) / Tunisia Mining Grid",
"22332":"Carthage / UTM zone 32N",
"22391":"Carthage / Nord Tunisie",
"22392":"Carthage / Sud Tunisie",
"22521":"Corrego Alegre 1970-72 / UTM zone 21S",
"22522":"Corrego Alegre 1970-72 / UTM zone 22S",
"22523":"Corrego Alegre 1970-72 / UTM zone 23S",
"22524":"Corrego Alegre 1970-72 / UTM zone 24S",
"22525":"Corrego Alegre 1970-72 / UTM zone 25S",
"22700":"Deir ez Zor / Levant Zone",
"22770":"Deir ez Zor / Syria Lambert",
"22780":"Deir ez Zor / Levant Stereographic",
"22832":"Douala / UTM zone 32N",
"22991":"Egypt 1907 / Blue Belt",
"22992":"Egypt 1907 / Red Belt",
"22993":"Egypt 1907 / Purple Belt",
"22994":"Egypt 1907 / Extended Purple Belt",
"23028":"ED50 / UTM zone 28N",
"23029":"ED50 / UTM zone 29N",
"23030":"ED50 / UTM zone 30N",
"23031":"ED50 / UTM zone 31N",
"23032":"ED50 / UTM zone 32N",
"23033":"ED50 / UTM zone 33N",
"23034":"ED50 / UTM zone 34N",
"23035":"ED50 / UTM zone 35N",
"23036":"ED50 / UTM zone 36N",
"23037":"ED50 / UTM zone 37N",
"23038":"ED50 / UTM zone 38N",
"23090":"ED50 / TM 0 N",
"23095":"ED50 / TM 5 NE",
"23239":"Fahud / UTM zone 39N",
"23240":"Fahud / UTM zone 40N",
"23433":"Garoua / UTM zone 33N",
"23700":"HD72 / EOV",
"23830":"DGN95 / Indonesia TM-3 zone 46.2",
"23831":"DGN95 / Indonesia TM-3 zone 47.1",
"23832":"DGN95 / Indonesia TM-3 zone 47.2",
"23833":"DGN95 / Indonesia TM-3 zone 48.1",
"23834":"DGN95 / Indonesia TM-3 zone 48.2",
"23835":"DGN95 / Indonesia TM-3 zone 49.1",
"23836":"DGN95 / Indonesia TM-3 zone 49.2",
"23837":"DGN95 / Indonesia TM-3 zone 50.1",
"23838":"DGN95 / Indonesia TM-3 zone 50.2",
"23839":"DGN95 / Indonesia TM-3 zone 51.1",
"23840":"DGN95 / Indonesia TM-3 zone 51.2",
"23841":"DGN95 / Indonesia TM-3 zone 52.1",
"23842":"DGN95 / Indonesia TM-3 zone 52.2",
"23843":"DGN95 / Indonesia TM-3 zone 53.1",
"23844":"DGN95 / Indonesia TM-3 zone 53.2",
"23845":"DGN95 / Indonesia TM-3 zone 54.1",
"23846":"ID74 / UTM zone 46N",
"23847":"ID74 / UTM zone 47N",
"23848":"ID74 / UTM zone 48N",
"23849":"ID74 / UTM zone 49N",
"23850":"ID74 / UTM zone 50N",
"23851":"ID74 / UTM zone 51N",
"23852":"ID74 / UTM zone 52N",
"23853":"ID74 / UTM zone 53N",
"23866":"DGN95 / UTM zone 46N",
"23867":"DGN95 / UTM zone 47N",
"23868":"DGN95 / UTM zone 48N",
"23869":"DGN95 / UTM zone 49N",
"23870":"DGN95 / UTM zone 50N",
"23871":"DGN95 / UTM zone 51N",
"23872":"DGN95 / UTM zone 52N",
"23877":"DGN95 / UTM zone 47S",
"23878":"DGN95 / UTM zone 48S",
"23879":"DGN95 / UTM zone 49S",
"23880":"DGN95 / UTM zone 50S",
"23881":"DGN95 / UTM zone 51S",
"23882":"DGN95 / UTM zone 52S",
"23883":"DGN95 / UTM zone 53S",
"23884":"DGN95 / UTM zone 54S",
"23886":"ID74 / UTM zone 46S",
"23887":"ID74 / UTM zone 47S",
"23888":"ID74 / UTM zone 48S",
"23889":"ID74 / UTM zone 49S",
"23890":"ID74 / UTM zone 50S",
"23891":"ID74 / UTM zone 51S",
"23892":"ID74 / UTM zone 52S",
"23893":"ID74 / UTM zone 53S",
"23894":"ID74 / UTM zone 54S",
"23946":"Indian 1954 / UTM zone 46N",
"23947":"Indian 1954 / UTM zone 47N",
"23948":"Indian 1954 / UTM zone 48N",
"24047":"Indian 1975 / UTM zone 47N",
"24048":"Indian 1975 / UTM zone 48N",
"24100":"Jamaica 1875 / Jamaica (Old Grid)",
"24200":"JAD69 / Jamaica National Grid",
"24305":"Kalianpur 1937 / UTM zone 45N",
"24306":"Kalianpur 1937 / UTM zone 46N",
"24311":"Kalianpur 1962 / UTM zone 41N",
"24312":"Kalianpur 1962 / UTM zone 42N",
"24313":"Kalianpur 1962 / UTM zone 43N",
"24342":"Kalianpur 1975 / UTM zone 42N",
"24343":"Kalianpur 1975 / UTM zone 43N",
"24344":"Kalianpur 1975 / UTM zone 44N",
"24345":"Kalianpur 1975 / UTM zone 45N",
"24346":"Kalianpur 1975 / UTM zone 46N",
"24347":"Kalianpur 1975 / UTM zone 47N",
"24370":"Kalianpur 1880 / India zone 0",
"24371":"Kalianpur 1880 / India zone I",
"24372":"Kalianpur 1880 / India zone IIa",
"24373":"Kalianpur 1880 / India zone IIIa",
"24374":"Kalianpur 1880 / India zone IVa",
"24375":"Kalianpur 1937 / India zone IIb",
"24376":"Kalianpur 1962 / India zone I",
"24377":"Kalianpur 1962 / India zone IIa",
"24378":"Kalianpur 1975 / India zone I",
"24379":"Kalianpur 1975 / India zone IIa",
"24380":"Kalianpur 1975 / India zone IIb",
"24381":"Kalianpur 1975 / India zone IIIa",
"24382":"Kalianpur 1880 / India zone IIb",
"24383":"Kalianpur 1975 / India zone IVa",
"24500":"Kertau 1968 / Singapore Grid",
"24547":"Kertau 1968 / UTM zone 47N",
"24548":"Kertau 1968 / UTM zone 48N",
"24571":"Kertau / R.S.O. Malaya (ch)",
"24600":"KOC Lambert",
"24718":"La Canoa / UTM zone 18N",
"24719":"La Canoa / UTM zone 19N",
"24720":"La Canoa / UTM zone 20N",
"24817":"PSAD56 / UTM zone 17N",
"24818":"PSAD56 / UTM zone 18N",
"24819":"PSAD56 / UTM zone 19N",
"24820":"PSAD56 / UTM zone 20N",
"24821":"PSAD56 / UTM zone 21N",
"24877":"PSAD56 / UTM zone 17S",
"24878":"PSAD56 / UTM zone 18S",
"24879":"PSAD56 / UTM zone 19S",
"24880":"PSAD56 / UTM zone 20S",
"24881":"PSAD56 / UTM zone 21S",
"24882":"PSAD56 / UTM zone 22S",
"24891":"PSAD56 / Peru west zone",
"24892":"PSAD56 / Peru central zone",
"24893":"PSAD56 / Peru east zone",
"25000":"Leigon / Ghana Metre Grid",
"25231":"Lome / UTM zone 31N",
"25391":"Luzon 1911 / Philippines zone I",
"25392":"Luzon 1911 / Philippines zone II",
"25393":"Luzon 1911 / Philippines zone III",
"25394":"Luzon 1911 / Philippines zone IV",
"25395":"Luzon 1911 / Philippines zone V",
"25700":"Makassar (Jakarta) / NEIEZ",
"25828":"ETRS89 / UTM zone 28N",
"25829":"ETRS89 / UTM zone 29N",
"25830":"ETRS89 / UTM zone 30N",
"25831":"ETRS89 / UTM zone 31N",
"25832":"ETRS89 / UTM zone 32N",
"25833":"ETRS89 / UTM zone 33N",
"25834":"ETRS89 / UTM zone 34N",
"25835":"ETRS89 / UTM zone 35N",
"25836":"ETRS89 / UTM zone 36N",
"25837":"ETRS89 / UTM zone 37N",
"25838":"ETRS89 / UTM zone 38N",
"25884":"ETRS89 / TM Baltic93",
"25932":"Malongo 1987 / UTM zone 32S",
"26191":"Merchich / Nord Maroc",
"26192":"Merchich / Sud Maroc",
"26193":"Merchich / Sahara",
"26194":"Merchich / Sahara Nord",
"26195":"Merchich / Sahara Sud",
"26237":"Massawa / UTM zone 37N",
"26331":"Minna / UTM zone 31N",
"26332":"Minna / UTM zone 32N",
"26391":"Minna / Nigeria West Belt",
"26392":"Minna / Nigeria Mid Belt",
"26393":"Minna / Nigeria East Belt",
"26432":"Mhast / UTM zone 32S",
"26591":"Monte Mario (Rome) / Italy zone 1",
"26592":"Monte Mario (Rome) / Italy zone 2",
"26632":"M'poraloko / UTM zone 32N",
"26692":"M'poraloko / UTM zone 32S",
"26701":"NAD27 / UTM zone 1N",
"26702":"NAD27 / UTM zone 2N",
"26703":"NAD27 / UTM zone 3N",
"26704":"NAD27 / UTM zone 4N",
"26705":"NAD27 / UTM zone 5N",
"26706":"NAD27 / UTM zone 6N",
"26707":"NAD27 / UTM zone 7N",
"26708":"NAD27 / UTM zone 8N",
"26709":"NAD27 / UTM zone 9N",
"26710":"NAD27 / UTM zone 10N",
"26711":"NAD27 / UTM zone 11N",
"26712":"NAD27 / UTM zone 12N",
"26713":"NAD27 / UTM zone 13N",
"26714":"NAD27 / UTM zone 14N",
"26715":"NAD27 / UTM zone 15N",
"26716":"NAD27 / UTM zone 16N",
"26717":"NAD27 / UTM zone 17N",
"26718":"NAD27 / UTM zone 18N",
"26719":"NAD27 / UTM zone 19N",
"26720":"NAD27 / UTM zone 20N",
"26721":"NAD27 / UTM zone 21N",
"26722":"NAD27 / UTM zone 22N",
"26729":"NAD27 / Alabama East",
"26730":"NAD27 / Alabama West",
"26731":"NAD27 / Alaska zone 1",
"26732":"NAD27 / Alaska zone 2",
"26733":"NAD27 / Alaska zone 3",
"26734":"NAD27 / Alaska zone 4",
"26735":"NAD27 / Alaska zone 5",
"26736":"NAD27 / Alaska zone 6",
"26737":"NAD27 / Alaska zone 7",
"26738":"NAD27 / Alaska zone 8",
"26739":"NAD27 / Alaska zone 9",
"26740":"NAD27 / Alaska zone 10",
"26741":"NAD27 / California zone I",
"26742":"NAD27 / California zone II",
"26743":"NAD27 / California zone III",
"26744":"NAD27 / California zone IV",
"26745":"NAD27 / California zone V",
"26746":"NAD27 / California zone VI",
"26747":"NAD27 / California zone VII",
"26748":"NAD27 / Arizona East",
"26749":"NAD27 / Arizona Central",
"26750":"NAD27 / Arizona West",
"26751":"NAD27 / Arkansas North",
"26752":"NAD27 / Arkansas South",
"26753":"NAD27 / Colorado North",
"26754":"NAD27 / Colorado Central",
"26755":"NAD27 / Colorado South",
"26756":"NAD27 / Connecticut",
"26757":"NAD27 / Delaware",
"26758":"NAD27 / Florida East",
"26759":"NAD27 / Florida West",
"26760":"NAD27 / Florida North",
"26766":"NAD27 / Georgia East",
"26767":"NAD27 / Georgia West",
"26768":"NAD27 / Idaho East",
"26769":"NAD27 / Idaho Central",
"26770":"NAD27 / Idaho West",
"26771":"NAD27 / Illinois East",
"26772":"NAD27 / Illinois West",
"26773":"NAD27 / Indiana East",
"26774":"NAD27 / Indiana West",
"26775":"NAD27 / Iowa North",
"26776":"NAD27 / Iowa South",
"26777":"NAD27 / Kansas North",
"26778":"NAD27 / Kansas South",
"26779":"NAD27 / Kentucky North",
"26780":"NAD27 / Kentucky South",
"26781":"NAD27 / Louisiana North",
"26782":"NAD27 / Louisiana South",
"26783":"NAD27 / Maine East",
"26784":"NAD27 / Maine West",
"26785":"NAD27 / Maryland",
"26786":"NAD27 / Massachusetts Mainland",
"26787":"NAD27 / Massachusetts Island",
"26791":"NAD27 / Minnesota North",
"26792":"NAD27 / Minnesota Central",
"26793":"NAD27 / Minnesota South",
"26794":"NAD27 / Mississippi East",
"26795":"NAD27 / Mississippi West",
"26796":"NAD27 / Missouri East",
"26797":"NAD27 / Missouri Central",
"26798":"NAD27 / Missouri West",
"26799":"NAD27 / California zone VII",
"26801":"NAD Michigan / Michigan East",
"26802":"NAD Michigan / Michigan Old Central",
"26803":"NAD Michigan / Michigan West",
"26811":"NAD Michigan / Michigan North",
"26812":"NAD Michigan / Michigan Central",
"26813":"NAD Michigan / Michigan South",
"26814":"NAD83 / Maine East (ftUS)",
"26815":"NAD83 / Maine West (ftUS)",
"26819":"NAD83 / Minnesota North (ftUS)",
"26820":"NAD83 / Minnesota Central (ftUS)",
"26821":"NAD83 / Minnesota South (ftUS)",
"26822":"NAD83 / Nebraska (ftUS)",
"26823":"NAD83 / West Virginia North (ftUS)",
"26824":"NAD83 / West Virginia South (ftUS)",
"26825":"NAD83(HARN) / Maine East (ftUS)",
"26826":"NAD83(HARN) / Maine West (ftUS)",
"26830":"NAD83(HARN) / Minnesota North (ftUS)",
"26831":"NAD83(HARN) / Minnesota Central (ftUS)",
"26832":"NAD83(HARN) / Minnesota South (ftUS)",
"26833":"NAD83(HARN) / Nebraska (ftUS)",
"26834":"NAD83(HARN) / West Virginia North (ftUS)",
"26835":"NAD83(HARN) / West Virginia South (ftUS)",
"26836":"NAD83(NSRS2007) / Maine East (ftUS)",
"26837":"NAD83(NSRS2007) / Maine West (ftUS)",
"26841":"NAD83(NSRS2007) / Minnesota North (ftUS)",
"26842":"NAD83(NSRS2007) / Minnesota Central (ftUS)",
"26843":"NAD83(NSRS2007) / Minnesota South (ftUS)",
"26844":"NAD83(NSRS2007) / Nebraska (ftUS)",
"26845":"NAD83(NSRS2007) / West Virginia North (ftUS)",
"26846":"NAD83(NSRS2007) / West Virginia South (ftUS)",
"26847":"NAD83 / Maine East (ftUS)",
"26848":"NAD83 / Maine West (ftUS)",
"26849":"NAD83 / Minnesota North (ftUS)",
"26850":"NAD83 / Minnesota Central (ftUS)",
"26851":"NAD83 / Minnesota South (ftUS)",
"26852":"NAD83 / Nebraska (ftUS)",
"26853":"NAD83 / West Virginia North (ftUS)",
"26854":"NAD83 / West Virginia South (ftUS)",
"26855":"NAD83(HARN) / Maine East (ftUS)",
"26856":"NAD83(HARN) / Maine West (ftUS)",
"26857":"NAD83(HARN) / Minnesota North (ftUS)",
"26858":"NAD83(HARN) / Minnesota Central (ftUS)",
"26859":"NAD83(HARN) / Minnesota South (ftUS)",
"26860":"NAD83(HARN) / Nebraska (ftUS)",
"26861":"NAD83(HARN) / West Virginia North (ftUS)",
"26862":"NAD83(HARN) / West Virginia South (ftUS)",
"26863":"NAD83(NSRS2007) / Maine East (ftUS)",
"26864":"NAD83(NSRS2007) / Maine West (ftUS)",
"26865":"NAD83(NSRS2007) / Minnesota North (ftUS)",
"26866":"NAD83(NSRS2007) / Minnesota Central (ftUS)",
"26867":"NAD83(NSRS2007) / Minnesota South (ftUS)",
"26868":"NAD83(NSRS2007) / Nebraska (ftUS)",
"26869":"NAD83(NSRS2007) / West Virginia North (ftUS)",
"26870":"NAD83(NSRS2007) / West Virginia South (ftUS)",
"26891":"NAD83(CSRS) / MTM zone 11",
"26892":"NAD83(CSRS) / MTM zone 12",
"26893":"NAD83(CSRS) / MTM zone 13",
"26894":"NAD83(CSRS) / MTM zone 14",
"26895":"NAD83(CSRS) / MTM zone 15",
"26896":"NAD83(CSRS) / MTM zone 16",
"26897":"NAD83(CSRS) / MTM zone 17",
"26898":"NAD83(CSRS) / MTM zone 1",
"26899":"NAD83(CSRS) / MTM zone 2",
"26901":"NAD83 / UTM zone 1N",
"26902":"NAD83 / UTM zone 2N",
"26903":"NAD83 / UTM zone 3N",
"26904":"NAD83 / UTM zone 4N",
"26905":"NAD83 / UTM zone 5N",
"26906":"NAD83 / UTM zone 6N",
"26907":"NAD83 / UTM zone 7N",
"26908":"NAD83 / UTM zone 8N",
"26909":"NAD83 / UTM zone 9N",
"26910":"NAD83 / UTM zone 10N",
"26911":"NAD83 / UTM zone 11N",
"26912":"NAD83 / UTM zone 12N",
"26913":"NAD83 / UTM zone 13N",
"26914":"NAD83 / UTM zone 14N",
"26915":"NAD83 / UTM zone 15N",
"26916":"NAD83 / UTM zone 16N",
"26917":"NAD83 / UTM zone 17N",
"26918":"NAD83 / UTM zone 18N",
"26919":"NAD83 / UTM zone 19N",
"26920":"NAD83 / UTM zone 20N",
"26921":"NAD83 / UTM zone 21N",
"26922":"NAD83 / UTM zone 22N",
"26923":"NAD83 / UTM zone 23N",
"26929":"NAD83 / Alabama East",
"26930":"NAD83 / Alabama West",
"26931":"NAD83 / Alaska zone 1",
"26932":"NAD83 / Alaska zone 2",
"26933":"NAD83 / Alaska zone 3",
"26934":"NAD83 / Alaska zone 4",
"26935":"NAD83 / Alaska zone 5",
"26936":"NAD83 / Alaska zone 6",
"26937":"NAD83 / Alaska zone 7",
"26938":"NAD83 / Alaska zone 8",
"26939":"NAD83 / Alaska zone 9",
"26940":"NAD83 / Alaska zone 10",
"26941":"NAD83 / California zone 1",
"26942":"NAD83 / California zone 2",
"26943":"NAD83 / California zone 3",
"26944":"NAD83 / California zone 4",
"26945":"NAD83 / California zone 5",
"26946":"NAD83 / California zone 6",
"26948":"NAD83 / Arizona East",
"26949":"NAD83 / Arizona Central",
"26950":"NAD83 / Arizona West",
"26951":"NAD83 / Arkansas North",
"26952":"NAD83 / Arkansas South",
"26953":"NAD83 / Colorado North",
"26954":"NAD83 / Colorado Central",
"26955":"NAD83 / Colorado South",
"26956":"NAD83 / Connecticut",
"26957":"NAD83 / Delaware",
"26958":"NAD83 / Florida East",
"26959":"NAD83 / Florida West",
"26960":"NAD83 / Florida North",
"26961":"NAD83 / Hawaii zone 1",
"26962":"NAD83 / Hawaii zone 2",
"26963":"NAD83 / Hawaii zone 3",
"26964":"NAD83 / Hawaii zone 4",
"26965":"NAD83 / Hawaii zone 5",
"26966":"NAD83 / Georgia East",
"26967":"NAD83 / Georgia West",
"26968":"NAD83 / Idaho East",
"26969":"NAD83 / Idaho Central",
"26970":"NAD83 / Idaho West",
"26971":"NAD83 / Illinois East",
"26972":"NAD83 / Illinois West",
"26973":"NAD83 / Indiana East",
"26974":"NAD83 / Indiana West",
"26975":"NAD83 / Iowa North",
"26976":"NAD83 / Iowa South",
"26977":"NAD83 / Kansas North",
"26978":"NAD83 / Kansas South",
"26979":"NAD83 / Kentucky North",
"26980":"NAD83 / Kentucky South",
"26981":"NAD83 / Louisiana North",
"26982":"NAD83 / Louisiana South",
"26983":"NAD83 / Maine East",
"26984":"NAD83 / Maine West",
"26985":"NAD83 / Maryland",
"26986":"NAD83 / Massachusetts Mainland",
"26987":"NAD83 / Massachusetts Island",
"26988":"NAD83 / Michigan North",
"26989":"NAD83 / Michigan Central",
"26990":"NAD83 / Michigan South",
"26991":"NAD83 / Minnesota North",
"26992":"NAD83 / Minnesota Central",
"26993":"NAD83 / Minnesota South",
"26994":"NAD83 / Mississippi East",
"26995":"NAD83 / Mississippi West",
"26996":"NAD83 / Missouri East",
"26997":"NAD83 / Missouri Central",
"26998":"NAD83 / Missouri West",
"27037":"Nahrwan 1967 / UTM zone 37N",
"27038":"Nahrwan 1967 / UTM zone 38N",
"27039":"Nahrwan 1967 / UTM zone 39N",
"27040":"Nahrwan 1967 / UTM zone 40N",
"27120":"Naparima 1972 / UTM zone 20N",
"27200":"NZGD49 / New Zealand Map Grid",
"27205":"NZGD49 / Mount Eden Circuit",
"27206":"NZGD49 / Bay of Plenty Circuit",
"27207":"NZGD49 / Poverty Bay Circuit",
"27208":"NZGD49 / Hawkes Bay Circuit",
"27209":"NZGD49 / Taranaki Circuit",
"27210":"NZGD49 / Tuhirangi Circuit",
"27211":"NZGD49 / Wanganui Circuit",
"27212":"NZGD49 / Wairarapa Circuit",
"27213":"NZGD49 / Wellington Circuit",
"27214":"NZGD49 / Collingwood Circuit",
"27215":"NZGD49 / Nelson Circuit",
"27216":"NZGD49 / Karamea Circuit",
"27217":"NZGD49 / Buller Circuit",
"27218":"NZGD49 / Grey Circuit",
"27219":"NZGD49 / Amuri Circuit",
"27220":"NZGD49 / Marlborough Circuit",
"27221":"NZGD49 / Hokitika Circuit",
"27222":"NZGD49 / Okarito Circuit",
"27223":"NZGD49 / Jacksons Bay Circuit",
"27224":"NZGD49 / Mount Pleasant Circuit",
"27225":"NZGD49 / Gawler Circuit",
"27226":"NZGD49 / Timaru Circuit",
"27227":"NZGD49 / Lindis Peak Circuit",
"27228":"NZGD49 / Mount Nicholas Circuit",
"27229":"NZGD49 / Mount York Circuit",
"27230":"NZGD49 / Observation Point Circuit",
"27231":"NZGD49 / North Taieri Circuit",
"27232":"NZGD49 / Bluff Circuit",
"27258":"NZGD49 / UTM zone 58S",
"27259":"NZGD49 / UTM zone 59S",
"27260":"NZGD49 / UTM zone 60S",
"27291":"NZGD49 / North Island Grid",
"27292":"NZGD49 / South Island Grid",
"27391":"NGO 1948 (Oslo) / NGO zone I",
"27392":"NGO 1948 (Oslo) / NGO zone II",
"27393":"NGO 1948 (Oslo) / NGO zone III",
"27394":"NGO 1948 (Oslo) / NGO zone IV",
"27395":"NGO 1948 (Oslo) / NGO zone V",
"27396":"NGO 1948 (Oslo) / NGO zone VI",
"27397":"NGO 1948 (Oslo) / NGO zone VII",
"27398":"NGO 1948 (Oslo) / NGO zone VIII",
"27429":"Datum 73 / UTM zone 29N",
"27492":"Datum 73 / Modified Portuguese Grid",
"27493":"Datum 73 / Modified Portuguese Grid",
"27500":"ATF (Paris) / Nord de Guerre",
"27561":"NTF (Paris) / Lambert Nord France",
"27562":"NTF (Paris) / Lambert Centre France",
"27563":"NTF (Paris) / Lambert Sud France",
"27564":"NTF (Paris) / Lambert Corse",
"27571":"NTF (Paris) / Lambert zone I",
"27572":"NTF (Paris) / Lambert zone II",
"27573":"NTF (Paris) / Lambert zone III",
"27574":"NTF (Paris) / Lambert zone IV",
"27581":"NTF (Paris) / France I",
"27582":"NTF (Paris) / France II",
"27583":"NTF (Paris) / France III",
"27584":"NTF (Paris) / France IV",
"27591":"NTF (Paris) / Nord France",
"27592":"NTF (Paris) / Centre France",
"27593":"NTF (Paris) / Sud France",
"27594":"NTF (Paris) / Corse",
"27700":"OSGB 1936 / British National Grid",
"28191":"Palestine 1923 / Palestine Grid",
"28192":"Palestine 1923 / Palestine Belt",
"28193":"Palestine 1923 / Israeli CS Grid",
"28232":"Pointe Noire / UTM zone 32S",
"28348":"GDA94 / MGA zone 48",
"28349":"GDA94 / MGA zone 49",
"28350":"GDA94 / MGA zone 50",
"28351":"GDA94 / MGA zone 51",
"28352":"GDA94 / MGA zone 52",
"28353":"GDA94 / MGA zone 53",
"28354":"GDA94 / MGA zone 54",
"28355":"GDA94 / MGA zone 55",
"28356":"GDA94 / MGA zone 56",
"28357":"GDA94 / MGA zone 57",
"28358":"GDA94 / MGA zone 58",
"28402":"Pulkovo 1942 / Gauss-Kruger zone 2",
"28403":"Pulkovo 1942 / Gauss-Kruger zone 3",
"28404":"Pulkovo 1942 / Gauss-Kruger zone 4",
"28405":"Pulkovo 1942 / Gauss-Kruger zone 5",
"28406":"Pulkovo 1942 / Gauss-Kruger zone 6",
"28407":"Pulkovo 1942 / Gauss-Kruger zone 7",
"28408":"Pulkovo 1942 / Gauss-Kruger zone 8",
"28409":"Pulkovo 1942 / Gauss-Kruger zone 9",
"28410":"Pulkovo 1942 / Gauss-Kruger zone 10",
"28411":"Pulkovo 1942 / Gauss-Kruger zone 11",
"28412":"Pulkovo 1942 / Gauss-Kruger zone 12",
"28413":"Pulkovo 1942 / Gauss-Kruger zone 13",
"28414":"Pulkovo 1942 / Gauss-Kruger zone 14",
"28415":"Pulkovo 1942 / Gauss-Kruger zone 15",
"28416":"Pulkovo 1942 / Gauss-Kruger zone 16",
"28417":"Pulkovo 1942 / Gauss-Kruger zone 17",
"28418":"Pulkovo 1942 / Gauss-Kruger zone 18",
"28419":"Pulkovo 1942 / Gauss-Kruger zone 19",
"28420":"Pulkovo 1942 / Gauss-Kruger zone 20",
"28421":"Pulkovo 1942 / Gauss-Kruger zone 21",
"28422":"Pulkovo 1942 / Gauss-Kruger zone 22",
"28423":"Pulkovo 1942 / Gauss-Kruger zone 23",
"28424":"Pulkovo 1942 / Gauss-Kruger zone 24",
"28425":"Pulkovo 1942 / Gauss-Kruger zone 25",
"28426":"Pulkovo 1942 / Gauss-Kruger zone 26",
"28427":"Pulkovo 1942 / Gauss-Kruger zone 27",
"28428":"Pulkovo 1942 / Gauss-Kruger zone 28",
"28429":"Pulkovo 1942 / Gauss-Kruger zone 29",
"28430":"Pulkovo 1942 / Gauss-Kruger zone 30",
"28431":"Pulkovo 1942 / Gauss-Kruger zone 31",
"28432":"Pulkovo 1942 / Gauss-Kruger zone 32",
"28462":"Pulkovo 1942 / Gauss-Kruger 2N",
"28463":"Pulkovo 1942 / Gauss-Kruger 3N",
"28464":"Pulkovo 1942 / Gauss-Kruger 4N",
"28465":"Pulkovo 1942 / Gauss-Kruger 5N",
"28466":"Pulkovo 1942 / Gauss-Kruger 6N",
"28467":"Pulkovo 1942 / Gauss-Kruger 7N",
"28468":"Pulkovo 1942 / Gauss-Kruger 8N",
"28469":"Pulkovo 1942 / Gauss-Kruger 9N",
"28470":"Pulkovo 1942 / Gauss-Kruger 10N",
"28471":"Pulkovo 1942 / Gauss-Kruger 11N",
"28472":"Pulkovo 1942 / Gauss-Kruger 12N",
"28473":"Pulkovo 1942 / Gauss-Kruger 13N",
"28474":"Pulkovo 1942 / Gauss-Kruger 14N",
"28475":"Pulkovo 1942 / Gauss-Kruger 15N",
"28476":"Pulkovo 1942 / Gauss-Kruger 16N",
"28477":"Pulkovo 1942 / Gauss-Kruger 17N",
"28478":"Pulkovo 1942 / Gauss-Kruger 18N",
"28479":"Pulkovo 1942 / Gauss-Kruger 19N",
"28480":"Pulkovo 1942 / Gauss-Kruger 20N",
"28481":"Pulkovo 1942 / Gauss-Kruger 21N",
"28482":"Pulkovo 1942 / Gauss-Kruger 22N",
"28483":"Pulkovo 1942 / Gauss-Kruger 23N",
"28484":"Pulkovo 1942 / Gauss-Kruger 24N",
"28485":"Pulkovo 1942 / Gauss-Kruger 25N",
"28486":"Pulkovo 1942 / Gauss-Kruger 26N",
"28487":"Pulkovo 1942 / Gauss-Kruger 27N",
"28488":"Pulkovo 1942 / Gauss-Kruger 28N",
"28489":"Pulkovo 1942 / Gauss-Kruger 29N",
"28490":"Pulkovo 1942 / Gauss-Kruger 30N",
"28491":"Pulkovo 1942 / Gauss-Kruger 31N",
"28492":"Pulkovo 1942 / Gauss-Kruger 32N",
"28600":"Qatar 1974 / Qatar National Grid",
"28991":"Amersfoort / RD Old",
"28992":"Amersfoort / RD New",
"29100":"SAD69 / Brazil Polyconic",
"29101":"SAD69 / Brazil Polyconic",
"29118":"SAD69 / UTM zone 18N",
"29119":"SAD69 / UTM zone 19N",
"29120":"SAD69 / UTM zone 20N",
"29121":"SAD69 / UTM zone 21N",
"29122":"SAD69 / UTM zone 22N",
"29168":"SAD69 / UTM zone 18N",
"29169":"SAD69 / UTM zone 19N",
"29170":"SAD69 / UTM zone 20N",
"29171":"SAD69 / UTM zone 21N",
"29172":"SAD69 / UTM zone 22N",
"29177":"SAD69 / UTM zone 17S",
"29178":"SAD69 / UTM zone 18S",
"29179":"SAD69 / UTM zone 19S",
"29180":"SAD69 / UTM zone 20S",
"29181":"SAD69 / UTM zone 21S",
"29182":"SAD69 / UTM zone 22S",
"29183":"SAD69 / UTM zone 23S",
"29184":"SAD69 / UTM zone 24S",
"29185":"SAD69 / UTM zone 25S",
"29187":"SAD69 / UTM zone 17S",
"29188":"SAD69 / UTM zone 18S",
"29189":"SAD69 / UTM zone 19S",
"29190":"SAD69 / UTM zone 20S",
"29191":"SAD69 / UTM zone 21S",
"29192":"SAD69 / UTM zone 22S",
"29193":"SAD69 / UTM zone 23S",
"29194":"SAD69 / UTM zone 24S",
"29195":"SAD69 / UTM zone 25S",
"29220":"Sapper Hill 1943 / UTM zone 20S",
"29221":"Sapper Hill 1943 / UTM zone 21S",
"29333":"Schwarzeck / UTM zone 33S",
"29371":"Schwarzeck / Lo22/11",
"29373":"Schwarzeck / Lo22/13",
"29375":"Schwarzeck / Lo22/15",
"29377":"Schwarzeck / Lo22/17",
"29379":"Schwarzeck / Lo22/19",
"29381":"Schwarzeck / Lo22/21",
"29383":"Schwarzeck / Lo22/23",
"29385":"Schwarzeck / Lo22/25",
"29635":"Sudan / UTM zone 35N",
"29636":"Sudan / UTM zone 36N",
"29700":"Tananarive (Paris) / Laborde Grid",
"29701":"Tananarive (Paris) / Laborde Grid",
"29702":"Tananarive (Paris) / Laborde Grid approximation",
"29738":"Tananarive / UTM zone 38S",
"29739":"Tananarive / UTM zone 39S",
"29849":"Timbalai 1948 / UTM zone 49N",
"29850":"Timbalai 1948 / UTM zone 50N",
"29871":"Timbalai 1948 / RSO Borneo (ch)",
"29872":"Timbalai 1948 / RSO Borneo (ftSe)",
"29873":"Timbalai 1948 / RSO Borneo (m)",
"29900":"TM65 / Irish National Grid",
"29901":"OSNI 1952 / Irish National Grid",
"29902":"TM65 / Irish Grid",
"29903":"TM75 / Irish Grid",
"30161":"Tokyo / Japan Plane Rectangular CS I",
"30162":"Tokyo / Japan Plane Rectangular CS II",
"30163":"Tokyo / Japan Plane Rectangular CS III",
"30164":"Tokyo / Japan Plane Rectangular CS IV",
"30165":"Tokyo / Japan Plane Rectangular CS V",
"30166":"Tokyo / Japan Plane Rectangular CS VI",
"30167":"Tokyo / Japan Plane Rectangular CS VII",
"30168":"Tokyo / Japan Plane Rectangular CS VIII",
"30169":"Tokyo / Japan Plane Rectangular CS IX",
"30170":"Tokyo / Japan Plane Rectangular CS X",
"30171":"Tokyo / Japan Plane Rectangular CS XI",
"30172":"Tokyo / Japan Plane Rectangular CS XII",
"30173":"Tokyo / Japan Plane Rectangular CS XIII",
"30174":"Tokyo / Japan Plane Rectangular CS XIV",
"30175":"Tokyo / Japan Plane Rectangular CS XV",
"30176":"Tokyo / Japan Plane Rectangular CS XVI",
"30177":"Tokyo / Japan Plane Rectangular CS XVII",
"30178":"Tokyo / Japan Plane Rectangular CS XVIII",
"30179":"Tokyo / Japan Plane Rectangular CS XIX",
"30200":"Trinidad 1903 / Trinidad Grid",
"30339":"TC(1948) / UTM zone 39N",
"30340":"TC(1948) / UTM zone 40N",
"30491":"Voirol 1875 / Nord Algerie (ancienne)",
"30492":"Voirol 1875 / Sud Algerie (ancienne)",
"30493":"Voirol 1879 / Nord Algerie (ancienne)",
"30494":"Voirol 1879 / Sud Algerie (ancienne)",
"30729":"Nord Sahara 1959 / UTM zone 29N",
"30730":"Nord Sahara 1959 / UTM zone 30N",
"30731":"Nord Sahara 1959 / UTM zone 31N",
"30732":"Nord Sahara 1959 / UTM zone 32N",
"30791":"Nord Sahara 1959 / Nord Algerie",
"30792":"Nord Sahara 1959 / Sud Algerie",
"30800":"RT38 2.5 gon W",
"31028":"Yoff / UTM zone 28N",
"31121":"Zanderij / UTM zone 21N",
"31154":"Zanderij / TM 54 NW",
"31170":"Zanderij / Suriname Old TM",
"31171":"Zanderij / Suriname TM",
"31251":"MGI (Ferro) / Austria GK West Zone",
"31252":"MGI (Ferro) / Austria GK Central Zone",
"31253":"MGI (Ferro) / Austria GK East Zone",
"31254":"MGI / Austria GK West",
"31255":"MGI / Austria GK Central",
"31256":"MGI / Austria GK East",
"31257":"MGI / Austria GK M28",
"31258":"MGI / Austria GK M31",
"31259":"MGI / Austria GK M34",
"31265":"MGI / 3-degree Gauss zone 5",
"31266":"MGI / 3-degree Gauss zone 6",
"31267":"MGI / 3-degree Gauss zone 7",
"31268":"MGI / 3-degree Gauss zone 8",
"31275":"MGI / Balkans zone 5",
"31276":"MGI / Balkans zone 6",
"31277":"MGI / Balkans zone 7",
"31278":"MGI / Balkans zone 8",
"31279":"MGI / Balkans zone 8",
"31281":"MGI (Ferro) / Austria West Zone",
"31282":"MGI (Ferro) / Austria Central Zone",
"31283":"MGI (Ferro) / Austria East Zone",
"31284":"MGI / Austria M28",
"31285":"MGI / Austria M31",
"31286":"MGI / Austria M34",
"31287":"MGI / Austria Lambert",
"31288":"MGI (Ferro) / M28",
"31289":"MGI (Ferro) / M31",
"31290":"MGI (Ferro) / M34",
"31291":"MGI (Ferro) / Austria West Zone",
"31292":"MGI (Ferro) / Austria Central Zone",
"31293":"MGI (Ferro) / Austria East Zone",
"31294":"MGI / M28",
"31295":"MGI / M31",
"31296":"MGI / M34",
"31297":"MGI / Austria Lambert",
"31300":"Belge 1972 / Belge Lambert 72",
"31370":"Belge 1972 / Belgian Lambert 72",
"31461":"DHDN / 3-degree Gauss zone 1",
"31462":"DHDN / 3-degree Gauss zone 2",
"31463":"DHDN / 3-degree Gauss zone 3",
"31464":"DHDN / 3-degree Gauss zone 4",
"31465":"DHDN / 3-degree Gauss zone 5",
"31466":"DHDN / 3-degree Gauss-Kruger zone 2",
"31467":"DHDN / 3-degree Gauss-Kruger zone 3",
"31468":"DHDN / 3-degree Gauss-Kruger zone 4",
"31469":"DHDN / 3-degree Gauss-Kruger zone 5",
"31528":"Conakry 1905 / UTM zone 28N",
"31529":"Conakry 1905 / UTM zone 29N",
"31600":"Dealul Piscului 1930 / Stereo 33",
"31700":"Dealul Piscului 1970/ Stereo 70",
"31838":"NGN / UTM zone 38N",
"31839":"NGN / UTM zone 39N",
"31900":"KUDAMS / KTM",
"31901":"KUDAMS / KTM",
"31965":"SIRGAS 2000 / UTM zone 11N",
"31966":"SIRGAS 2000 / UTM zone 12N",
"31967":"SIRGAS 2000 / UTM zone 13N",
"31968":"SIRGAS 2000 / UTM zone 14N",
"31969":"SIRGAS 2000 / UTM zone 15N",
"31970":"SIRGAS 2000 / UTM zone 16N",
"31971":"SIRGAS 2000 / UTM zone 17N",
"31972":"SIRGAS 2000 / UTM zone 18N",
"31973":"SIRGAS 2000 / UTM zone 19N",
"31974":"SIRGAS 2000 / UTM zone 20N",
"31975":"SIRGAS 2000 / UTM zone 21N",
"31976":"SIRGAS 2000 / UTM zone 22N",
"31977":"SIRGAS 2000 / UTM zone 17S",
"31978":"SIRGAS 2000 / UTM zone 18S",
"31979":"SIRGAS 2000 / UTM zone 19S",
"31980":"SIRGAS 2000 / UTM zone 20S",
"31981":"SIRGAS 2000 / UTM zone 21S",
"31982":"SIRGAS 2000 / UTM zone 22S",
"31983":"SIRGAS 2000 / UTM zone 23S",
"31984":"SIRGAS 2000 / UTM zone 24S",
"31985":"SIRGAS 2000 / UTM zone 25S",
"31986":"SIRGAS 1995 / UTM zone 17N",
"31987":"SIRGAS 1995 / UTM zone 18N",
"31988":"SIRGAS 1995 / UTM zone 19N",
"31989":"SIRGAS 1995 / UTM zone 20N",
"31990":"SIRGAS 1995 / UTM zone 21N",
"31991":"SIRGAS 1995 / UTM zone 22N",
"31992":"SIRGAS 1995 / UTM zone 17S",
"31993":"SIRGAS 1995 / UTM zone 18S",
"31994":"SIRGAS 1995 / UTM zone 19S",
"31995":"SIRGAS 1995 / UTM zone 20S",
"31996":"SIRGAS 1995 / UTM zone 21S",
"31997":"SIRGAS 1995 / UTM zone 22S",
"31998":"SIRGAS 1995 / UTM zone 23S",
"31999":"SIRGAS 1995 / UTM zone 24S",
"32000":"SIRGAS 1995 / UTM zone 25S",
"32001":"NAD27 / Montana North",
"32002":"NAD27 / Montana Central",
"32003":"NAD27 / Montana South",
"32005":"NAD27 / Nebraska North",
"32006":"NAD27 / Nebraska South",
"32007":"NAD27 / Nevada East",
"32008":"NAD27 / Nevada Central",
"32009":"NAD27 / Nevada West",
"32010":"NAD27 / New Hampshire",
"32011":"NAD27 / New Jersey",
"32012":"NAD27 / New Mexico East",
"32013":"NAD27 / New Mexico Central",
"32014":"NAD27 / New Mexico West",
"32015":"NAD27 / New York East",
"32016":"NAD27 / New York Central",
"32017":"NAD27 / New York West",
"32018":"NAD27 / New York Long Island",
"32019":"NAD27 / North Carolina",
"32020":"NAD27 / North Dakota North",
"32021":"NAD27 / North Dakota South",
"32022":"NAD27 / Ohio North",
"32023":"NAD27 / Ohio South",
"32024":"NAD27 / Oklahoma North",
"32025":"NAD27 / Oklahoma South",
"32026":"NAD27 / Oregon North",
"32027":"NAD27 / Oregon South",
"32028":"NAD27 / Pennsylvania North",
"32029":"NAD27 / Pennsylvania South",
"32030":"NAD27 / Rhode Island",
"32031":"NAD27 / South Carolina North",
"32033":"NAD27 / South Carolina South",
"32034":"NAD27 / South Dakota North",
"32035":"NAD27 / South Dakota South",
"32036":"NAD27 / Tennessee",
"32037":"NAD27 / Texas North",
"32038":"NAD27 / Texas North Central",
"32039":"NAD27 / Texas Central",
"32040":"NAD27 / Texas South Central",
"32041":"NAD27 / Texas South",
"32042":"NAD27 / Utah North",
"32043":"NAD27 / Utah Central",
"32044":"NAD27 / Utah South",
"32045":"NAD27 / Vermont",
"32046":"NAD27 / Virginia North",
"32047":"NAD27 / Virginia South",
"32048":"NAD27 / Washington North",
"32049":"NAD27 / Washington South",
"32050":"NAD27 / West Virginia North",
"32051":"NAD27 / West Virginia South",
"32052":"NAD27 / Wisconsin North",
"32053":"NAD27 / Wisconsin Central",
"32054":"NAD27 / Wisconsin South",
"32055":"NAD27 / Wyoming East",
"32056":"NAD27 / Wyoming East Central",
"32057":"NAD27 / Wyoming West Central",
"32058":"NAD27 / Wyoming West",
"32061":"NAD27 / Guatemala Norte",
"32062":"NAD27 / Guatemala Sur",
"32064":"NAD27 / BLM 14N (ftUS)",
"32065":"NAD27 / BLM 15N (ftUS)",
"32066":"NAD27 / BLM 16N (ftUS)",
"32067":"NAD27 / BLM 17N (ftUS)",
"32074":"NAD27 / BLM 14N (feet)",
"32075":"NAD27 / BLM 15N (feet)",
"32076":"NAD27 / BLM 16N (feet)",
"32077":"NAD27 / BLM 17N (feet)",
"32081":"NAD27 / MTM zone 1",
"32082":"NAD27 / MTM zone 2",
"32083":"NAD27 / MTM zone 3",
"32084":"NAD27 / MTM zone 4",
"32085":"NAD27 / MTM zone 5",
"32086":"NAD27 / MTM zone 6",
"32098":"NAD27 / Quebec Lambert",
"32099":"NAD27 / Louisiana Offshore",
"32100":"NAD83 / Montana",
"32104":"NAD83 / Nebraska",
"32107":"NAD83 / Nevada East",
"32108":"NAD83 / Nevada Central",
"32109":"NAD83 / Nevada West",
"32110":"NAD83 / New Hampshire",
"32111":"NAD83 / New Jersey",
"32112":"NAD83 / New Mexico East",
"32113":"NAD83 / New Mexico Central",
"32114":"NAD83 / New Mexico West",
"32115":"NAD83 / New York East",
"32116":"NAD83 / New York Central",
"32117":"NAD83 / New York West",
"32118":"NAD83 / New York Long Island",
"32119":"NAD83 / North Carolina",
"32120":"NAD83 / North Dakota North",
"32121":"NAD83 / North Dakota South",
"32122":"NAD83 / Ohio North",
"32123":"NAD83 / Ohio South",
"32124":"NAD83 / Oklahoma North",
"32125":"NAD83 / Oklahoma South",
"32126":"NAD83 / Oregon North",
"32127":"NAD83 / Oregon South",
"32128":"NAD83 / Pennsylvania North",
"32129":"NAD83 / Pennsylvania South",
"32130":"NAD83 / Rhode Island",
"32133":"NAD83 / South Carolina",
"32134":"NAD83 / South Dakota North",
"32135":"NAD83 / South Dakota South",
"32136":"NAD83 / Tennessee",
"32137":"NAD83 / Texas North",
"32138":"NAD83 / Texas North Central",
"32139":"NAD83 / Texas Central",
"32140":"NAD83 / Texas South Central",
"32141":"NAD83 / Texas South",
"32142":"NAD83 / Utah North",
"32143":"NAD83 / Utah Central",
"32144":"NAD83 / Utah South",
"32145":"NAD83 / Vermont",
"32146":"NAD83 / Virginia North",
"32147":"NAD83 / Virginia South",
"32148":"NAD83 / Washington North",
"32149":"NAD83 / Washington South",
"32150":"NAD83 / West Virginia North",
"32151":"NAD83 / West Virginia South",
"32152":"NAD83 / Wisconsin North",
"32153":"NAD83 / Wisconsin Central",
"32154":"NAD83 / Wisconsin South",
"32155":"NAD83 / Wyoming East",
"32156":"NAD83 / Wyoming East Central",
"32157":"NAD83 / Wyoming West Central",
"32158":"NAD83 / Wyoming West",
"32161":"NAD83 / Puerto Rico & Virgin Is.",
"32164":"NAD83 / BLM 14N (ftUS)",
"32165":"NAD83 / BLM 15N (ftUS)",
"32166":"NAD83 / BLM 16N (ftUS)",
"32167":"NAD83 / BLM 17N (ftUS)",
"32180":"NAD83 / SCoPQ zone 2",
"32181":"NAD83 / MTM zone 1",
"32182":"NAD83 / MTM zone 2",
"32183":"NAD83 / MTM zone 3",
"32184":"NAD83 / MTM zone 4",
"32185":"NAD83 / MTM zone 5",
"32186":"NAD83 / MTM zone 6",
"32187":"NAD83 / MTM zone 7",
"32188":"NAD83 / MTM zone 8",
"32189":"NAD83 / MTM zone 9",
"32190":"NAD83 / MTM zone 10",
"32191":"NAD83 / MTM zone 11",
"32192":"NAD83 / MTM zone 12",
"32193":"NAD83 / MTM zone 13",
"32194":"NAD83 / MTM zone 14",
"32195":"NAD83 / MTM zone 15",
"32196":"NAD83 / MTM zone 16",
"32197":"NAD83 / MTM zone 17",
"32198":"NAD83 / Quebec Lambert",
"32199":"NAD83 / Louisiana Offshore",
"32201":"WGS 72 / UTM zone 1N",
"32202":"WGS 72 / UTM zone 2N",
"32203":"WGS 72 / UTM zone 3N",
"32204":"WGS 72 / UTM zone 4N",
"32205":"WGS 72 / UTM zone 5N",
"32206":"WGS 72 / UTM zone 6N",
"32207":"WGS 72 / UTM zone 7N",
"32208":"WGS 72 / UTM zone 8N",
"32209":"WGS 72 / UTM zone 9N",
"32210":"WGS 72 / UTM zone 10N",
"32211":"WGS 72 / UTM zone 11N",
"32212":"WGS 72 / UTM zone 12N",
"32213":"WGS 72 / UTM zone 13N",
"32214":"WGS 72 / UTM zone 14N",
"32215":"WGS 72 / UTM zone 15N",
"32216":"WGS 72 / UTM zone 16N",
"32217":"WGS 72 / UTM zone 17N",
"32218":"WGS 72 / UTM zone 18N",
"32219":"WGS 72 / UTM zone 19N",
"32220":"WGS 72 / UTM zone 20N",
"32221":"WGS 72 / UTM zone 21N",
"32222":"WGS 72 / UTM zone 22N",
"32223":"WGS 72 / UTM zone 23N",
"32224":"WGS 72 / UTM zone 24N",
"32225":"WGS 72 / UTM zone 25N",
"32226":"WGS 72 / UTM zone 26N",
"32227":"WGS 72 / UTM zone 27N",
"32228":"WGS 72 / UTM zone 28N",
"32229":"WGS 72 / UTM zone 29N",
"32230":"WGS 72 / UTM zone 30N",
"32231":"WGS 72 / UTM zone 31N",
"32232":"WGS 72 / UTM zone 32N",
"32233":"WGS 72 / UTM zone 33N",
"32234":"WGS 72 / UTM zone 34N",
"32235":"WGS 72 / UTM zone 35N",
"32236":"WGS 72 / UTM zone 36N",
"32237":"WGS 72 / UTM zone 37N",
"32238":"WGS 72 / UTM zone 38N",
"32239":"WGS 72 / UTM zone 39N",
"32240":"WGS 72 / UTM zone 40N",
"32241":"WGS 72 / UTM zone 41N",
"32242":"WGS 72 / UTM zone 42N",
"32243":"WGS 72 / UTM zone 43N",
"32244":"WGS 72 / UTM zone 44N",
"32245":"WGS 72 / UTM zone 45N",
"32246":"WGS 72 / UTM zone 46N",
"32247":"WGS 72 / UTM zone 47N",
"32248":"WGS 72 / UTM zone 48N",
"32249":"WGS 72 / UTM zone 49N",
"32250":"WGS 72 / UTM zone 50N",
"32251":"WGS 72 / UTM zone 51N",
"32252":"WGS 72 / UTM zone 52N",
"32253":"WGS 72 / UTM zone 53N",
"32254":"WGS 72 / UTM zone 54N",
"32255":"WGS 72 / UTM zone 55N",
"32256":"WGS 72 / UTM zone 56N",
"32257":"WGS 72 / UTM zone 57N",
"32258":"WGS 72 / UTM zone 58N",
"32259":"WGS 72 / UTM zone 59N",
"32260":"WGS 72 / UTM zone 60N",
"32301":"WGS 72 / UTM zone 1S",
"32302":"WGS 72 / UTM zone 2S",
"32303":"WGS 72 / UTM zone 3S",
"32304":"WGS 72 / UTM zone 4S",
"32305":"WGS 72 / UTM zone 5S",
"32306":"WGS 72 / UTM zone 6S",
"32307":"WGS 72 / UTM zone 7S",
"32308":"WGS 72 / UTM zone 8S",
"32309":"WGS 72 / UTM zone 9S",
"32310":"WGS 72 / UTM zone 10S",
"32311":"WGS 72 / UTM zone 11S",
"32312":"WGS 72 / UTM zone 12S",
"32313":"WGS 72 / UTM zone 13S",
"32314":"WGS 72 / UTM zone 14S",
"32315":"WGS 72 / UTM zone 15S",
"32316":"WGS 72 / UTM zone 16S",
"32317":"WGS 72 / UTM zone 17S",
"32318":"WGS 72 / UTM zone 18S",
"32319":"WGS 72 / UTM zone 19S",
"32320":"WGS 72 / UTM zone 20S",
"32321":"WGS 72 / UTM zone 21S",
"32322":"WGS 72 / UTM zone 22S",
"32323":"WGS 72 / UTM zone 23S",
"32324":"WGS 72 / UTM zone 24S",
"32325":"WGS 72 / UTM zone 25S",
"32326":"WGS 72 / UTM zone 26S",
"32327":"WGS 72 / UTM zone 27S",
"32328":"WGS 72 / UTM zone 28S",
"32329":"WGS 72 / UTM zone 29S",
"32330":"WGS 72 / UTM zone 30S",
"32331":"WGS 72 / UTM zone 31S",
"32332":"WGS 72 / UTM zone 32S",
"32333":"WGS 72 / UTM zone 33S",
"32334":"WGS 72 / UTM zone 34S",
"32335":"WGS 72 / UTM zone 35S",
"32336":"WGS 72 / UTM zone 36S",
"32337":"WGS 72 / UTM zone 37S",
"32338":"WGS 72 / UTM zone 38S",
"32339":"WGS 72 / UTM zone 39S",
"32340":"WGS 72 / UTM zone 40S",
"32341":"WGS 72 / UTM zone 41S",
"32342":"WGS 72 / UTM zone 42S",
"32343":"WGS 72 / UTM zone 43S",
"32344":"WGS 72 / UTM zone 44S",
"32345":"WGS 72 / UTM zone 45S",
"32346":"WGS 72 / UTM zone 46S",
"32347":"WGS 72 / UTM zone 47S",
"32348":"WGS 72 / UTM zone 48S",
"32349":"WGS 72 / UTM zone 49S",
"32350":"WGS 72 / UTM zone 50S",
"32351":"WGS 72 / UTM zone 51S",
"32352":"WGS 72 / UTM zone 52S",
"32353":"WGS 72 / UTM zone 53S",
"32354":"WGS 72 / UTM zone 54S",
"32355":"WGS 72 / UTM zone 55S",
"32356":"WGS 72 / UTM zone 56S",
"32357":"WGS 72 / UTM zone 57S",
"32358":"WGS 72 / UTM zone 58S",
"32359":"WGS 72 / UTM zone 59S",
"32360":"WGS 72 / UTM zone 60S",
"32401":"WGS 72BE / UTM zone 1N",
"32402":"WGS 72BE / UTM zone 2N",
"32403":"WGS 72BE / UTM zone 3N",
"32404":"WGS 72BE / UTM zone 4N",
"32405":"WGS 72BE / UTM zone 5N",
"32406":"WGS 72BE / UTM zone 6N",
"32407":"WGS 72BE / UTM zone 7N",
"32408":"WGS 72BE / UTM zone 8N",
"32409":"WGS 72BE / UTM zone 9N",
"32410":"WGS 72BE / UTM zone 10N",
"32411":"WGS 72BE / UTM zone 11N",
"32412":"WGS 72BE / UTM zone 12N",
"32413":"WGS 72BE / UTM zone 13N",
"32414":"WGS 72BE / UTM zone 14N",
"32415":"WGS 72BE / UTM zone 15N",
"32416":"WGS 72BE / UTM zone 16N",
"32417":"WGS 72BE / UTM zone 17N",
"32418":"WGS 72BE / UTM zone 18N",
"32419":"WGS 72BE / UTM zone 19N",
"32420":"WGS 72BE / UTM zone 20N",
"32421":"WGS 72BE / UTM zone 21N",
"32422":"WGS 72BE / UTM zone 22N",
"32423":"WGS 72BE / UTM zone 23N",
"32424":"WGS 72BE / UTM zone 24N",
"32425":"WGS 72BE / UTM zone 25N",
"32426":"WGS 72BE / UTM zone 26N",
"32427":"WGS 72BE / UTM zone 27N",
"32428":"WGS 72BE / UTM zone 28N",
"32429":"WGS 72BE / UTM zone 29N",
"32430":"WGS 72BE / UTM zone 30N",
"32431":"WGS 72BE / UTM zone 31N",
"32432":"WGS 72BE / UTM zone 32N",
"32433":"WGS 72BE / UTM zone 33N",
"32434":"WGS 72BE / UTM zone 34N",
"32435":"WGS 72BE / UTM zone 35N",
"32436":"WGS 72BE / UTM zone 36N",
"32437":"WGS 72BE / UTM zone 37N",
"32438":"WGS 72BE / UTM zone 38N",
"32439":"WGS 72BE / UTM zone 39N",
"32440":"WGS 72BE / UTM zone 40N",
"32441":"WGS 72BE / UTM zone 41N",
"32442":"WGS 72BE / UTM zone 42N",
"32443":"WGS 72BE / UTM zone 43N",
"32444":"WGS 72BE / UTM zone 44N",
"32445":"WGS 72BE / UTM zone 45N",
"32446":"WGS 72BE / UTM zone 46N",
"32447":"WGS 72BE / UTM zone 47N",
"32448":"WGS 72BE / UTM zone 48N",
"32449":"WGS 72BE / UTM zone 49N",
"32450":"WGS 72BE / UTM zone 50N",
"32451":"WGS 72BE / UTM zone 51N",
"32452":"WGS 72BE / UTM zone 52N",
"32453":"WGS 72BE / UTM zone 53N",
"32454":"WGS 72BE / UTM zone 54N",
"32455":"WGS 72BE / UTM zone 55N",
"32456":"WGS 72BE / UTM zone 56N",
"32457":"WGS 72BE / UTM zone 57N",
"32458":"WGS 72BE / UTM zone 58N",
"32459":"WGS 72BE / UTM zone 59N",
"32460":"WGS 72BE / UTM zone 60N",
"32501":"WGS 72BE / UTM zone 1S",
"32502":"WGS 72BE / UTM zone 2S",
"32503":"WGS 72BE / UTM zone 3S",
"32504":"WGS 72BE / UTM zone 4S",
"32505":"WGS 72BE / UTM zone 5S",
"32506":"WGS 72BE / UTM zone 6S",
"32507":"WGS 72BE / UTM zone 7S",
"32508":"WGS 72BE / UTM zone 8S",
"32509":"WGS 72BE / UTM zone 9S",
"32510":"WGS 72BE / UTM zone 10S",
"32511":"WGS 72BE / UTM zone 11S",
"32512":"WGS 72BE / UTM zone 12S",
"32513":"WGS 72BE / UTM zone 13S",
"32514":"WGS 72BE / UTM zone 14S",
"32515":"WGS 72BE / UTM zone 15S",
"32516":"WGS 72BE / UTM zone 16S",
"32517":"WGS 72BE / UTM zone 17S",
"32518":"WGS 72BE / UTM zone 18S",
"32519":"WGS 72BE / UTM zone 19S",
"32520":"WGS 72BE / UTM zone 20S",
"32521":"WGS 72BE / UTM zone 21S",
"32522":"WGS 72BE / UTM zone 22S",
"32523":"WGS 72BE / UTM zone 23S",
"32524":"WGS 72BE / UTM zone 24S",
"32525":"WGS 72BE / UTM zone 25S",
"32526":"WGS 72BE / UTM zone 26S",
"32527":"WGS 72BE / UTM zone 27S",
"32528":"WGS 72BE / UTM zone 28S",
"32529":"WGS 72BE / UTM zone 29S",
"32530":"WGS 72BE / UTM zone 30S",
"32531":"WGS 72BE / UTM zone 31S",
"32532":"WGS 72BE / UTM zone 32S",
"32533":"WGS 72BE / UTM zone 33S",
"32534":"WGS 72BE / UTM zone 34S",
"32535":"WGS 72BE / UTM zone 35S",
"32536":"WGS 72BE / UTM zone 36S",
"32537":"WGS 72BE / UTM zone 37S",
"32538":"WGS 72BE / UTM zone 38S",
"32539":"WGS 72BE / UTM zone 39S",
"32540":"WGS 72BE / UTM zone 40S",
"32541":"WGS 72BE / UTM zone 41S",
"32542":"WGS 72BE / UTM zone 42S",
"32543":"WGS 72BE / UTM zone 43S",
"32544":"WGS 72BE / UTM zone 44S",
"32545":"WGS 72BE / UTM zone 45S",
"32546":"WGS 72BE / UTM zone 46S",
"32547":"WGS 72BE / UTM zone 47S",
"32548":"WGS 72BE / UTM zone 48S",
"32549":"WGS 72BE / UTM zone 49S",
"32550":"WGS 72BE / UTM zone 50S",
"32551":"WGS 72BE / UTM zone 51S",
"32552":"WGS 72BE / UTM zone 52S",
"32553":"WGS 72BE / UTM zone 53S",
"32554":"WGS 72BE / UTM zone 54S",
"32555":"WGS 72BE / UTM zone 55S",
"32556":"WGS 72BE / UTM zone 56S",
"32557":"WGS 72BE / UTM zone 57S",
"32558":"WGS 72BE / UTM zone 58S",
"32559":"WGS 72BE / UTM zone 59S",
"32560":"WGS 72BE / UTM zone 60S",
"32600":"WGS 84 / UTM grid system (northern hemisphere)",
"32601":"WGS 84 / UTM zone 1N",
"32602":"WGS 84 / UTM zone 2N",
"32603":"WGS 84 / UTM zone 3N",
"32604":"WGS 84 / UTM zone 4N",
"32605":"WGS 84 / UTM zone 5N",
"32606":"WGS 84 / UTM zone 6N",
"32607":"WGS 84 / UTM zone 7N",
"32608":"WGS 84 / UTM zone 8N",
"32609":"WGS 84 / UTM zone 9N",
"32610":"WGS 84 / UTM zone 10N",
"32611":"WGS 84 / UTM zone 11N",
"32612":"WGS 84 / UTM zone 12N",
"32613":"WGS 84 / UTM zone 13N",
"32614":"WGS 84 / UTM zone 14N",
"32615":"WGS 84 / UTM zone 15N",
"32616":"WGS 84 / UTM zone 16N",
"32617":"WGS 84 / UTM zone 17N",
"32618":"WGS 84 / UTM zone 18N",
"32619":"WGS 84 / UTM zone 19N",
"32620":"WGS 84 / UTM zone 20N",
"32621":"WGS 84 / UTM zone 21N",
"32622":"WGS 84 / UTM zone 22N",
"32623":"WGS 84 / UTM zone 23N",
"32624":"WGS 84 / UTM zone 24N",
"32625":"WGS 84 / UTM zone 25N",
"32626":"WGS 84 / UTM zone 26N",
"32627":"WGS 84 / UTM zone 27N",
"32628":"WGS 84 / UTM zone 28N",
"32629":"WGS 84 / UTM zone 29N",
"32630":"WGS 84 / UTM zone 30N",
"32631":"WGS 84 / UTM zone 31N",
"32632":"WGS 84 / UTM zone 32N",
"32633":"WGS 84 / UTM zone 33N",
"32634":"WGS 84 / UTM zone 34N",
"32635":"WGS 84 / UTM zone 35N",
"32636":"WGS 84 / UTM zone 36N",
"32637":"WGS 84 / UTM zone 37N",
"32638":"WGS 84 / UTM zone 38N",
"32639":"WGS 84 / UTM zone 39N",
"32640":"WGS 84 / UTM zone 40N",
"32641":"WGS 84 / UTM zone 41N",
"32642":"WGS 84 / UTM zone 42N",
"32643":"WGS 84 / UTM zone 43N",
"32644":"WGS 84 / UTM zone 44N",
"32645":"WGS 84 / UTM zone 45N",
"32646":"WGS 84 / UTM zone 46N",
"32647":"WGS 84 / UTM zone 47N",
"32648":"WGS 84 / UTM zone 48N",
"32649":"WGS 84 / UTM zone 49N",
"32650":"WGS 84 / UTM zone 50N",
"32651":"WGS 84 / UTM zone 51N",
"32652":"WGS 84 / UTM zone 52N",
"32653":"WGS 84 / UTM zone 53N",
"32654":"WGS 84 / UTM zone 54N",
"32655":"WGS 84 / UTM zone 55N",
"32656":"WGS 84 / UTM zone 56N",
"32657":"WGS 84 / UTM zone 57N",
"32658":"WGS 84 / UTM zone 58N",
"32659":"WGS 84 / UTM zone 59N",
"32660":"WGS 84 / UTM zone 60N",
"32661":"WGS 84 / UPS North (N,E)",
"32662":"WGS 84 / Plate Carree",
"32663":"WGS 84 / World Equidistant Cylindrical",
"32664":"WGS 84 / BLM 14N (ftUS)",
"32665":"WGS 84 / BLM 15N (ftUS)",
"32666":"WGS 84 / BLM 16N (ftUS)",
"32667":"WGS 84 / BLM 17N (ftUS)",
"32700":"WGS 84 / UTM grid system (southern hemisphere)",
"32701":"WGS 84 / UTM zone 1S",
"32702":"WGS 84 / UTM zone 2S",
"32703":"WGS 84 / UTM zone 3S",
"32704":"WGS 84 / UTM zone 4S",
"32705":"WGS 84 / UTM zone 5S",
"32706":"WGS 84 / UTM zone 6S",
"32707":"WGS 84 / UTM zone 7S",
"32708":"WGS 84 / UTM zone 8S",
"32709":"WGS 84 / UTM zone 9S",
"32710":"WGS 84 / UTM zone 10S",
"32711":"WGS 84 / UTM zone 11S",
"32712":"WGS 84 / UTM zone 12S",
"32713":"WGS 84 / UTM zone 13S",
"32714":"WGS 84 / UTM zone 14S",
"32715":"WGS 84 / UTM zone 15S",
"32716":"WGS 84 / UTM zone 16S",
"32717":"WGS 84 / UTM zone 17S",
"32718":"WGS 84 / UTM zone 18S",
"32719":"WGS 84 / UTM zone 19S",
"32720":"WGS 84 / UTM zone 20S",
"32721":"WGS 84 / UTM zone 21S",
"32722":"WGS 84 / UTM zone 22S",
"32723":"WGS 84 / UTM zone 23S",
"32724":"WGS 84 / UTM zone 24S",
"32725":"WGS 84 / UTM zone 25S",
"32726":"WGS 84 / UTM zone 26S",
"32727":"WGS 84 / UTM zone 27S",
"32728":"WGS 84 / UTM zone 28S",
"32729":"WGS 84 / UTM zone 29S",
"32730":"WGS 84 / UTM zone 30S",
"32731":"WGS 84 / UTM zone 31S",
"32732":"WGS 84 / UTM zone 32S",
"32733":"WGS 84 / UTM zone 33S",
"32734":"WGS 84 / UTM zone 34S",
"32735":"WGS 84 / UTM zone 35S",
"32736":"WGS 84 / UTM zone 36S",
"32737":"WGS 84 / UTM zone 37S",
"32738":"WGS 84 / UTM zone 38S",
"32739":"WGS 84 / UTM zone 39S",
"32740":"WGS 84 / UTM zone 40S",
"32741":"WGS 84 / UTM zone 41S",
"32742":"WGS 84 / UTM zone 42S",
"32743":"WGS 84 / UTM zone 43S",
"32744":"WGS 84 / UTM zone 44S",
"32745":"WGS 84 / UTM zone 45S",
"32746":"WGS 84 / UTM zone 46S",
"32747":"WGS 84 / UTM zone 47S",
"32748":"WGS 84 / UTM zone 48S",
"32749":"WGS 84 / UTM zone 49S",
"32750":"WGS 84 / UTM zone 50S",
"32751":"WGS 84 / UTM zone 51S",
"32752":"WGS 84 / UTM zone 52S",
"32753":"WGS 84 / UTM zone 53S",
"32754":"WGS 84 / UTM zone 54S",
"32755":"WGS 84 / UTM zone 55S",
"32756":"WGS 84 / UTM zone 56S",
"32757":"WGS 84 / UTM zone 57S",
"32758":"WGS 84 / UTM zone 58S",
"32759":"WGS 84 / UTM zone 59S",
"32760":"WGS 84 / UTM zone 60S",
"32761":"WGS 84 / UPS South (N,E)",
"32766":"WGS 84 / TM 36 SE",
"61206405":"Greek (deg)",
"61216405":"GGRS87 (deg)",
"61226405":"ATS77 (deg)",
"61236405":"KKJ (deg)",
"61246405":"RT90 (deg)",
"61266405":"LKS94 (ETRS89) (deg)",
"61266413":"LKS94 (ETRS89) (3D deg)",
"61276405":"Tete (deg)",
"61286405":"Madzansua (deg)",
"61296405":"Observatario (deg)",
"61306405":"Moznet (deg)",
"61306413":"Moznet (3D deg)",
"61316405":"Indian 1960 (deg)",
"61326405":"FD58 (deg)",
"61336405":"EST92 (deg)",
"61346405":"PDO Survey Datum 1993 (deg)",
"61356405":"Old Hawaiian (deg)",
"61366405":"St. Lawrence Island (deg)",
"61376405":"St. Paul Island (deg)",
"61386405":"St. George Island (deg)",
"61396405":"Puerto Rico (deg)",
"61406405":"NAD83(CSRS) (deg)",
"61406413":"NAD83(CSRS) (3D deg)",
"61416405":"Israel (deg)",
"61426405":"Locodjo 1965 (deg)",
"61436405":"Abidjan 1987 (deg)",
"61446405":"Kalianpur 1937 (deg)",
"61456405":"Kalianpur 1962 (deg)",
"61466405":"Kalianpur 1975 (deg)",
"61476405":"Hanoi 1972 (deg)",
"61486405":"Hartebeesthoek94 (deg)",
"61486413":"Hartebeesthoek94 (3D deg)",
"61496405":"CH1903 (deg)",
"61506405":"CH1903+ (deg)",
"61516405":"CHTRF95 (deg)",
"61516413":"CHTRF95 (3D deg)",
"61526405":"NAD83(HARN) (deg)",
"61526413":"NAD83(HARN) (3D deg)",
"61536405":"Rassadiran (deg)",
"61546405":"ED50(ED77) (deg)",
"61556405":"Dabola 1981 (deg)",
"61566405":"S-JTSK (deg)",
"61576405":"Mount Dillon (deg)",
"61586405":"Naparima 1955 (deg)",
"61596405":"ELD79 (deg)",
"61606405":"Chos Malal 1914 (deg)",
"61616405":"Pampa del Castillo (deg)",
"61626405":"Korean 1985 (deg)",
"61636405":"Yemen NGN96 (deg)",
"61636413":"Yemen NGN96 (3D deg)",
"61646405":"South Yemen (deg)",
"61656405":"Bissau (deg)",
"61666405":"Korean 1995 (deg)",
"61676405":"NZGD2000 (deg)",
"61676413":"NZGD2000 (3D deg)",
"61686405":"Accra (deg)",
"61696405":"American Samoa 1962 (deg)",
"61706405":"SIRGAS (deg)",
"61706413":"SIRGAS (3D deg)",
"61716405":"RGF93 (deg)",
"61716413":"RGF93 (3D deg)",
"61736405":"IRENET95 (deg)",
"61736413":"IRENET95 (3D deg)",
"61746405":"Sierra Leone 1924 (deg)",
"61756405":"Sierra Leone 1968 (deg)",
"61766405":"Australian Antarctic (deg)",
"61766413":"Australian Antarctic (3D deg)",
"61786405":"Pulkovo 1942(83) (deg)",
"61796405":"Pulkovo 1942(58) (deg)",
"61806405":"EST97 (deg)",
"61806413":"EST97 (3D deg)",
"61816405":"Luxembourg 1930 (deg)",
"61826405":"Azores Occidental 1939 (deg)",
"61836405":"Azores Central 1948 (deg)",
"61846405":"Azores Oriental 1940 (deg)",
"61886405":"OSNI 1952 (deg)",
"61896405":"REGVEN (deg)",
"61896413":"REGVEN (3D deg)",
"61906405":"POSGAR 98 (deg)",
"61906413":"POSGAR 98 (3D deg)",
"61916405":"Albanian 1987 (deg)",
"61926405":"Douala 1948 (deg)",
"61936405":"Manoca 1962 (deg)",
"61946405":"Qornoq 1927 (deg)",
"61956405":"Scoresbysund 1952 (deg)",
"61966405":"Ammassalik 1958 (deg)",
"61976405":"Garoua (deg)",
"61986405":"Kousseri (deg)",
"61996405":"Egypt 1930 (deg)",
"62006405":"Pulkovo 1995 (deg)",
"62016405":"Adindan (deg)",
"62026405":"AGD66 (deg)",
"62036405":"AGD84 (deg)",
"62046405":"Ain el Abd (deg)",
"62056405":"Afgooye (deg)",
"62066405":"Agadez (deg)",
"62076405":"Lisbon (deg)",
"62086405":"Aratu (deg)",
"62096405":"Arc 1950 (deg)",
"62106405":"Arc 1960 (deg)",
"62116405":"Batavia (deg)",
"62126405":"Barbados 1938 (deg)",
"62136405":"Beduaram (deg)",
"62146405":"Beijing 1954 (deg)",
"62156405":"Belge 1950 (deg)",
"62166405":"Bermuda 1957 (deg)",
"62186405":"Bogota 1975 (deg)",
"62196405":"Bukit Rimpah (deg)",
"62206405":"Camacupa (deg)",
"62216405":"Campo Inchauspe (deg)",
"62226405":"Cape (deg)",
"62236405":"Carthage (deg)",
"62246405":"Chua (deg)",
"62256405":"Corrego Alegre (deg)",
"62276405":"Deir ez Zor (deg)",
"62296405":"Egypt 1907 (deg)",
"62306405":"ED50 (deg)",
"62316405":"ED87 (deg)",
"62326405":"Fahud (deg)",
"62336405":"Gandajika 1970 (deg)",
"62366405":"Hu Tzu Shan (deg)",
"62376405":"HD72 (deg)",
"62386405":"ID74 (deg)",
"62396405":"Indian 1954 (deg)",
"62406405":"Indian 1975 (deg)",
"62416405":"Jamaica 1875 (deg)",
"62426405":"JAD69 (deg)",
"62436405":"Kalianpur 1880 (deg)",
"62446405":"Kandawala (deg)",
"62456405":"Kertau (deg)",
"62466405":"KOC (deg)",
"62476405":"La Canoa (deg)",
"62486405":"PSAD56 (deg)",
"62496405":"Lake (deg)",
"62506405":"Leigon (deg)",
"62516405":"Liberia 1964 (deg)",
"62526405":"Lome (deg)",
"62536405":"Luzon 1911 (deg)",
"62546405":"Hito XVIII 1963 (deg)",
"62556405":"Herat North (deg)",
"62566405":"Mahe 1971 (deg)",
"62576405":"Makassar (deg)",
"62586405":"ETRS89 (deg)",
"62586413":"ETRS89 (3D deg)",
"62596405":"Malongo 1987 (deg)",
"62616405":"Merchich (deg)",
"62626405":"Massawa (deg)",
"62636405":"Minna (deg)",
"62646405":"Mhast (deg)",
"62656405":"Monte Mario (deg)",
"62666405":"M'poraloko (deg)",
"62676405":"NAD27 (deg)",
"62686405":"NAD27 Michigan (deg)",
"62696405":"NAD83 (deg)",
"62706405":"Nahrwan 1967 (deg)",
"62716405":"Naparima 1972 (deg)",
"62726405":"NZGD49 (deg)",
"62736405":"NGO 1948 (deg)",
"62746405":"Datum 73 (deg)",
"62756405":"NTF (deg)",
"62766405":"NSWC 9Z-2 (deg)",
"62776405":"OSGB 1936 (deg)",
"62786405":"OSGB70 (deg)",
"62796405":"OS(SN)80 (deg)",
"62806405":"Padang (deg)",
"62816405":"Palestine 1923 (deg)",
"62826405":"Pointe Noire (deg)",
"62836405":"GDA94 (deg)",
"62836413":"GDA94 (3D deg)",
"62846405":"Pulkovo 1942 (deg)",
"62856405":"Qatar 1974 (deg)",
"62866405":"Qatar 1948 (deg)",
"62886405":"Loma Quintana (deg)",
"62896405":"Amersfoort (deg)",
"62926405":"Sapper Hill 1943 (deg)",
"62936405":"Schwarzeck (deg)",
"62956405":"Serindung (deg)",
"62976405":"Tananarive (deg)",
"62986405":"Timbalai 1948 (deg)",
"62996405":"TM65 (deg)",
"63006405":"TM75 (deg)",
"63016405":"Tokyo (deg)",
"63026405":"Trinidad 1903 (deg)",
"63036405":"TC(1948) (deg)",
"63046405":"Voirol 1875 (deg)",
"63066405":"Bern 1938 (deg)",
"63076405":"Nord Sahara 1959 (deg)",
"63086405":"RT38 (deg)",
"63096405":"Yacare (deg)",
"63106405":"Yoff (deg)",
"63116405":"Zanderij (deg)",
"63126405":"MGI (deg)",
"63136405":"Belge 1972 (deg)",
"63146405":"DHDN (deg)",
"63156405":"Conakry 1905 (deg)",
"63166405":"Dealul Piscului 1933 (deg)",
"63176405":"Dealul Piscului 1970 (deg)",
"63186405":"NGN (deg)",
"63196405":"KUDAMS (deg)",
"63226405":"WGS 72 (deg)",
"63246405":"WGS 72BE (deg)",
"63266405":"WGS 84 (deg)",
"63266406":"WGS 84 (degH)",
"63266407":"WGS 84 (Hdeg)",
"63266408":"WGS 84 (DM)",
"63266409":"WGS 84 (DMH)",
"63266410":"WGS 84 (HDM)",
"63266411":"WGS 84 (DMS)",
"63266412":"WGS 84 (HDMS)",
"63266413":"WGS 84 (3D deg)",
"63266414":"WGS 84 (3D degH)",
"63266415":"WGS 84 (3D Hdeg)",
"63266416":"WGS 84 (3D DM)",
"63266417":"WGS 84 (3D DMH)",
"63266418":"WGS 84 (3D HDM)",
"63266419":"WGS 84 (3D DMS)",
"63266420":"WGS 84 (3D HDMS)",
"66006405":"Anguilla 1957 (deg)",
"66016405":"Antigua 1943 (deg)",
"66026405":"Dominica 1945 (deg)",
"66036405":"Grenada 1953 (deg)",
"66046405":"Montserrat 1958 (deg)",
"66056405":"St. Kitts 1955 (deg)",
"66066405":"St. Lucia 1955 (deg)",
"66076405":"St. Vincent 1945 (deg)",
"66086405":"NAD27(76) (deg)",
"66096405":"NAD27(CGQ77) (deg)",
"66106405":"Xian 1980 (deg)",
"66116405":"Hong Kong 1980 (deg)",
"66126405":"JGD2000 (deg)",
"66126413":"JGD2000 (3D deg)",
"66136405":"Segara (deg)",
"66146405":"QND95 (deg)",
"66156405":"Porto Santo (deg)",
"66166405":"Selvagem Grande (deg)",
"66186405":"SAD69 (deg)",
"66196405":"SWEREF99 (deg)",
"66196413":"SWEREF99 (3D deg)",
"66206405":"Point 58 (deg)",
"66216405":"Fort Marigot (deg)",
"66226405":"Sainte Anne (deg)",
"66236405":"CSG67 (deg)",
"66246405":"RGFG95 (deg)",
"66246413":"RGFG95 (3D deg)",
"66256405":"Fort Desaix (deg)",
"66266405":"Piton des Neiges (deg)",
"66276405":"RGR92 (deg)",
"66276413":"RGR92 (3D deg)",
"66286405":"Tahiti (deg)",
"66296405":"Tahaa (deg)",
"66306405":"IGN72 Nuku Hiva (deg)",
"66316405":"K0 1949 (deg)",
"66326405":"Combani 1950 (deg)",
"66336405":"IGN56 Lifou (deg)",
"66346405":"IGN72 Grande Terre (deg)",
"66356405":"ST87 Ouvea (deg)",
"66366405":"Petrels 1972 (deg)",
"66376405":"Perroud 1950 (deg)",
"66386405":"Saint Pierre et Miquelon 1950 (deg)",
"66396405":"MOP78 (deg)",
"66406405":"RRAF 1991 (deg)",
"66406413":"RRAF 1991 (3D deg)",
"66416405":"IGN53 Mare (deg)",
"66426405":"ST84 Ile des Pins (deg)",
"66436405":"ST71 Belep (deg)",
"66446405":"NEA74 Noumea (deg)",
"66456405":"RGNC 1991 (deg)",
"66456413":"RGNC 1991 (3D deg)",
"66466405":"Grand Comoros (deg)",
"66576405":"Reykjavik 1900 (deg)",
"66586405":"Hjorsey 1955 (deg)",
"66596405":"ISN93 (deg)",
"66596413":"ISN93 (3D deg)",
"66606405":"Helle 1954 (deg)",
"66616405":"LKS92 (deg)",
"66616413":"LKS92 (3D deg)",
"66636405":"Porto Santo 1995 (deg)",
"66646405":"Azores Oriental 1995 (deg)",
"66656405":"Azores Central 1995 (deg)",
"66666405":"Lisbon 1890 (deg)",
"66676405":"IKBD-92 (deg)",
"68016405":"Bern 1898 (Bern) (deg)",
"68026405":"Bogota 1975 (Bogota) (deg)",
"68036405":"Lisbon (Lisbon) (deg)",
"68046405":"Makassar (Jakarta) (deg)",
"68056405":"MGI (Ferro) (deg)",
"68066405":"Monte Mario (Rome) (deg)",
"68086405":"Padang (Jakarta) (deg)",
"68096405":"Belge 1950 (Brussels) (deg)",
"68136405":"Batavia (Jakarta) (deg)",
"68146405":"RT38 (Stockholm) (deg)",
"68156405":"Greek (Athens) (deg)",
"68186405":"S-JTSK (Ferro) (deg)",
"68206405":"Segara (Jakarta) (deg)",
"69036405":"Madrid 1870 (Madrid) (deg)",
}

from liblas import file

def getBetween(t,s1,s2):
    p1 = t.find(s1)
    if p1!=-1:
        p1 = p1 + len(s1)
        t1 = t[p1:]
        p2 = t1.find(s2)
        if p1 != -1:
            chunck = t[p1:p1+p2]
            return chunck
    return False



#apt-get -y install liblas-c3
def getEPSG(filename, default=None):
    
    try:
        f_with_liblas = file.File(filename, mode='r')
        header_file = f_with_liblas.header
        srs_file = header_file.srs

        wkt = str(srs_file.wkt)
        crs_name = getBetween(wkt, 'PROJCS["', '"')
        epsg = ""
        if crs_name != False:
            L_crs_name = crs_name.split(" ")
            while len(L_crs_name) != 0:
                crs_j = " ".join(L_crs_name)
                if crs_j in crs2epsg:
                    return crs2epsg[crs_j]
                L_crs_name = L_crs_name[:-1]            
        
        L_epsg = [x[:x.find('"')] for x in wkt.split('EPSG","')[1:]]
        if len(L_epsg)>0:
            return L_epsg[-1]
    except Exception as err:
        print("[Warning] getEPSG:",err)
    print("[Warning] getEPSG: getting '"+str(default)+"' by default")
    return default
